(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    736085,      20857]
NotebookOptionsPosition[    717866,      20285]
NotebookOutlinePosition[    718255,      20302]
CellTagsIndexPosition[    718212,      20299]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Setting up required functions", "Section",
 CellChangeTimes->{{3.678793324410656*^9, 3.678793347451144*^9}, {
  3.737288344324541*^9, 
  3.737288345589094*^9}},ExpressionUUID->"6d0508b8-508f-49d0-81d5-\
fbc2f513ec8f"],

Cell[CellGroupData[{

Cell["Einstein Convention", "Subsection",
 CellChangeTimes->{{3.73727221835075*^9, 
  3.737272227214916*^9}},ExpressionUUID->"2f587959-29e0-480d-b4a0-\
8c74c6d79d5e"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "ii", ",", "jj", ",", "ex", ",", "ex0", ",", "ex1", ",", "ex2", ",", 
    "idx1", ",", "idx2", ",", "rule", ",", "\[Delta]", ",", "pos", ",", "idx",
     ",", " ", "double", ",", "sidx", ",", "dummy", ",", "xx", ",", 
    "\[Delta]$", ",", "\[Delta]", ",", "d"}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"StandardizeIdx", "[", 
    RowBox[{"ex_", ",", "flag_"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "ex0", ",", "ex1", ",", "pos", ",", "idx", ",", "double", ",", "dummy", 
       ",", 
       RowBox[{"sidx", "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "s0", ",", "s1", ",", "s2", ",", "s3", ",", "s4", ",", "s5", ",", 
            "s6", ",", "s7", ",", "s8", ",", "s9"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
           "p0", ",", "p1", ",", "p2", ",", "p3", ",", "p4", ",", "p5", ",", 
            "p6", ",", "p7", ",", "p8", ",", "p9"}], "}"}]}], "}"}]}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"ex0", "=", 
       RowBox[{"dummy", " ", "ex"}]}], ";", "    ", 
      RowBox[{"(*", 
       StyleBox[
        RowBox[{
        "makes", " ", "sure", " ", "expression", " ", "is", " ", "a", " ", 
         "product"}],
        FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"pos", "=", 
       RowBox[{"Drop", "[", 
        RowBox[{
         RowBox[{"Position", "[", 
          RowBox[{"ex0", ",", "List"}], "]"}], ",", "None", ",", 
         RowBox[{"-", "1"}]}], "]"}]}], ";", "     ", 
      RowBox[{"(*", 
       StyleBox[
        RowBox[{
        "pos", " ", "identifies", " ", "all", " ", "lists", " ", "of", " ", 
         "indices", " ", "in", " ", "the", " ", "expression"}],
        FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"idx", "=", 
       RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Do", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"idx", "=", 
          RowBox[{"Join", "[", 
           RowBox[{"idx", ",", 
            RowBox[{"Extract", "[", 
             RowBox[{"ex0", ",", 
              RowBox[{
              "pos", "\[LeftDoubleBracket]", "ii", 
               "\[RightDoubleBracket]"}]}], "]"}]}], "]"}]}], ";", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Length", "[", 
             RowBox[{
             "pos", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}], 
             "]"}], "\[Equal]", "3"}], ",", 
           RowBox[{"idx", "=", 
            RowBox[{"Join", "[", 
             RowBox[{"idx", ",", 
              RowBox[{"Extract", "[", 
               RowBox[{"ex0", ",", 
                RowBox[{
                "pos", "\[LeftDoubleBracket]", "ii", 
                 "\[RightDoubleBracket]"}]}], "]"}]}], "]"}]}]}], "]"}]}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"ii", ",", "1", ",", 
          RowBox[{"Length", "[", "pos", "]"}]}], "}"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", 
       StyleBox[
        RowBox[{
        "idx", " ", "contains", " ", "all", " ", "the", " ", "indices", " ", 
         "in", " ", "the", " ", "expression"}],
        FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"ex1", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
         "ex0", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}], ",", 
         
         RowBox[{"{", 
          RowBox[{"ii", ",", "1", ",", 
           RowBox[{"Length", "[", "ex0", "]"}]}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"double", "=", 
       RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Do", "[", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Count", "[", 
             RowBox[{"idx", ",", 
              RowBox[{
              "idx", "\[LeftDoubleBracket]", "ii", 
               "\[RightDoubleBracket]"}]}], "]"}], "\[Equal]", "2"}], "&&", 
           RowBox[{"!", 
            RowBox[{"MemberQ", "[", 
             RowBox[{"double", ",", 
              RowBox[{
              "idx", "\[LeftDoubleBracket]", "ii", 
               "\[RightDoubleBracket]"}]}], "]"}]}]}], ",", 
          RowBox[{"double", "=", 
           RowBox[{"Join", "[", 
            RowBox[{"double", ",", 
             RowBox[{"{", 
              RowBox[{
              "idx", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}], 
              "}"}]}], "]"}]}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"ii", ",", "1", ",", 
          RowBox[{"Length", "[", "idx", "]"}]}], "}"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", 
       StyleBox[
        RowBox[{
        "double", " ", "contains", " ", "all", " ", "the", " ", "double", " ",
          "indices"}],
        FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
      RowBox[{"Do", "[", 
       RowBox[{
        RowBox[{"ex1", "=", 
         RowBox[{"ReplacePart", "[", 
          RowBox[{"ex1", ",", 
           RowBox[{
            RowBox[{"Position", "[", 
             RowBox[{"ex1", ",", 
              RowBox[{
              "double", "\[LeftDoubleBracket]", "ii", 
               "\[RightDoubleBracket]"}]}], "]"}], "\[Rule]", 
            RowBox[{"sidx", "\[LeftDoubleBracket]", 
             RowBox[{"flag", ",", "ii"}], "\[RightDoubleBracket]"}]}]}], 
          "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"ii", ",", "1", ",", 
          RowBox[{"Length", "[", "double", "]"}]}], "}"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Do", "[", 
       RowBox[{
        RowBox[{"ex1", "=", 
         RowBox[{"ReplacePart", "[", 
          RowBox[{"ex1", ",", 
           RowBox[{
            RowBox[{
            "pos", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}], 
            "\[Rule]", 
            RowBox[{"Sort", "[", 
             RowBox[{"Extract", "[", 
              RowBox[{"ex1", ",", 
               RowBox[{
               "pos", "\[LeftDoubleBracket]", "ii", 
                "\[RightDoubleBracket]"}]}], "]"}], "]"}]}]}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"ii", ",", "1", ",", 
          RowBox[{"Length", "[", "pos", "]"}]}], "}"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Apply", "[", 
        RowBox[{"Times", ",", "ex1"}], "]"}], "/.", 
       RowBox[{"{", 
        RowBox[{"dummy", "\[Rule]", "1"}], "}"}]}]}]}], "\[IndentingNewLine]",
     "]"}]}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Einstein1", "[", "ex_", "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "ex0", ",", "ex1", ",", "ex2", ",", "idx1", ",", "idx2", ",", "rule", 
       ",", "dummy"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"ex", "\[Equal]", "0"}], ",", 
        RowBox[{"Return", "[", "ex", "]"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"ex0", "=", 
       RowBox[{"dummy", " ", "ex"}]}], ";", "  ", 
      RowBox[{"(*", 
       StyleBox[
        RowBox[{
        "makes", " ", "sure", " ", "expression", " ", "is", " ", "a", " ", 
         "product"}],
        FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"ex0", "=", 
       RowBox[{"Flatten", "[", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Head", "[", 
               RowBox[{
               "ex0", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}],
                "]"}], "===", "Power"}], "&&", 
             RowBox[{
              RowBox[{"Length", "[", 
               RowBox[{"Position", "[", 
                RowBox[{
                 RowBox[{
                 "ex0", "\[LeftDoubleBracket]", "ii", 
                  "\[RightDoubleBracket]"}], ",", "List"}], "]"}], "]"}], ">",
               "0"}]}], ",", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"ex0", "\[LeftDoubleBracket]", 
               RowBox[{"ii", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
              RowBox[{"{", 
               RowBox[{"jj", ",", "1", ",", 
                RowBox[{"ex0", "\[LeftDoubleBracket]", 
                 RowBox[{"ii", ",", "2"}], "\[RightDoubleBracket]"}]}], 
               "}"}]}], "]"}], ",", 
            RowBox[{
            "ex0", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}]}], 
           "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"ii", ",", "1", ",", 
            RowBox[{"Length", "[", "ex0", "]"}]}], "}"}]}], "]"}], "]"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"(*", 
       StyleBox[
        RowBox[{
        "makes", " ", "sure", " ", "expression", " ", "is", " ", "a", " ", 
         "product"}],
        FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"ex1", "=", 
       RowBox[{"Extract", "[", 
        RowBox[{"ex0", ",", 
         RowBox[{"Position", "[", 
          RowBox[{"ex0", ",", 
           RowBox[{"\[Delta]", "[", "_", "]"}]}], "]"}]}], "]"}]}], ";", 
      "   ", 
      RowBox[{"(*", 
       StyleBox[
        RowBox[{
        "list", " ", "all", " ", "\[Delta]", " ", "expressions", " ", "and", 
         " ", "corresponding", " ", "indices"}],
        FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
      RowBox[{"idx1", "=", 
       RowBox[{"Extract", "[", 
        RowBox[{"ex1", ",", 
         RowBox[{"Drop", "[", 
          RowBox[{
           RowBox[{"Drop", "[", 
            RowBox[{
             RowBox[{"Position", "[", 
              RowBox[{"ex1", ",", "List"}], "]"}], ",", "None", ",", 
             RowBox[{"-", "1"}]}], "]"}], ",", "1"}], "]"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"ex2", "=", 
       RowBox[{"Delete", "[", 
        RowBox[{"ex0", ",", 
         RowBox[{"Position", "[", 
          RowBox[{"ex0", ",", 
           RowBox[{"\[Delta]", "[", "_", "]"}]}], "]"}]}], "]"}]}], ";", 
      "    ", 
      RowBox[{"(*", 
       StyleBox[
        RowBox[{
        "list", " ", "expressions", " ", "without", " ", "\[Delta]", " ", 
         "and", " ", "corresponding", " ", "indices"}],
        FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
      RowBox[{"idx2", "=", 
       RowBox[{"Flatten", "[", 
        RowBox[{"Extract", "[", 
         RowBox[{"ex2", ",", 
          RowBox[{"Drop", "[", 
           RowBox[{
            RowBox[{"Drop", "[", 
             RowBox[{
              RowBox[{"Position", "[", 
               RowBox[{"ex2", ",", "List"}], "]"}], ",", "None", ",", 
              RowBox[{"-", "1"}]}], "]"}], ",", "1"}], "]"}]}], "]"}], 
        "]"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"Do", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"rule", "=", 
          RowBox[{"{", "}"}]}], ";", "     ", 
         RowBox[{"(*", 
          StyleBox[
           RowBox[{
           "extract", " ", "of", " ", "index", " ", "replacement", " ", 
            "rule"}],
           FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Count", "[", 
             RowBox[{
              RowBox[{"Join", "[", 
               RowBox[{"idx2", ",", 
                RowBox[{"Flatten", "[", 
                 RowBox[{"Delete", "[", 
                  RowBox[{"idx1", ",", 
                   RowBox[{"{", "ii", "}"}]}], "]"}], "]"}]}], "]"}], ",", 
              RowBox[{"idx1", "\[LeftDoubleBracket]", 
               RowBox[{"ii", ",", "1"}], "\[RightDoubleBracket]"}]}], "]"}], 
            "\[Equal]", "1"}], ",", 
           RowBox[{
            RowBox[{"rule", "=", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"idx1", "\[LeftDoubleBracket]", 
                RowBox[{"ii", ",", "1"}], "\[RightDoubleBracket]"}], "->", 
               RowBox[{"idx1", "\[LeftDoubleBracket]", 
                RowBox[{"ii", ",", "2"}], "\[RightDoubleBracket]"}]}], 
              "}"}]}], ";"}], "\[IndentingNewLine]", ",", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Count", "[", 
               RowBox[{
                RowBox[{"Join", "[", 
                 RowBox[{"idx2", ",", 
                  RowBox[{"Flatten", "[", 
                   RowBox[{"Delete", "[", 
                    RowBox[{"idx1", ",", 
                    RowBox[{"{", "ii", "}"}]}], "]"}], "]"}]}], "]"}], ",", 
                RowBox[{"idx1", "\[LeftDoubleBracket]", 
                 RowBox[{"ii", ",", "2"}], "\[RightDoubleBracket]"}]}], "]"}],
               "\[Equal]", "1"}], ",", 
             RowBox[{
              RowBox[{"rule", "=", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"idx1", "\[LeftDoubleBracket]", 
                  RowBox[{"ii", ",", "2"}], "\[RightDoubleBracket]"}], "->", 
                 RowBox[{"idx1", "\[LeftDoubleBracket]", 
                  RowBox[{"ii", ",", "1"}], "\[RightDoubleBracket]"}]}], 
                "}"}]}], ";"}]}], "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
         "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Length", "[", "rule", "]"}], "\[Equal]", "1"}], ",", 
           "     ", 
           RowBox[{"(*", 
            StyleBox[
             RowBox[{"apply", " ", "index", " ", "replacement", " ", "rule"}],
             
             FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"ex1", "=", 
             RowBox[{
              RowBox[{"ReplacePart", "[", 
               RowBox[{"ex1", ",", 
                RowBox[{
                 RowBox[{"{", "ii", "}"}], "\[Rule]", "1"}]}], "]"}], "/.", 
              "rule"}]}], ";", "\[IndentingNewLine]", 
            RowBox[{"ex2", "=", 
             RowBox[{"ex2", "/.", "rule"}]}], ";", "\[IndentingNewLine]", 
            RowBox[{"idx1", "=", 
             RowBox[{
              RowBox[{"ReplacePart", "[", 
               RowBox[{"idx1", ",", 
                RowBox[{
                 RowBox[{"{", "ii", "}"}], "\[Rule]", 
                 RowBox[{"{", 
                  RowBox[{"0", ",", 
                   RowBox[{"-", "1"}]}], "}"}]}]}], "]"}], "/.", "rule"}]}], 
            ";", "\[IndentingNewLine]", 
            RowBox[{"idx2", "=", 
             RowBox[{"idx2", "/.", "rule"}]}], ";"}]}], "\[IndentingNewLine]",
           "]"}], ";"}], "\[IndentingNewLine]", ",", 
        RowBox[{"{", 
         RowBox[{"ii", ",", "1", ",", 
          RowBox[{"Length", "[", "idx1", "]"}]}], "}"}]}], "]"}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"Do", "[", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Length", "[", 
            RowBox[{
            "idx1", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}], 
            "]"}], ">", "0"}], ",", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"idx1", "\[LeftDoubleBracket]", 
              RowBox[{"ii", ",", "1"}], "\[RightDoubleBracket]"}], "\[Equal]", 
             RowBox[{"idx1", "\[LeftDoubleBracket]", 
              RowBox[{"ii", ",", "2"}], "\[RightDoubleBracket]"}]}], ",", 
            RowBox[{"ex1", "=", 
             RowBox[{"ReplacePart", "[", 
              RowBox[{"ex1", ",", 
               RowBox[{
                RowBox[{"{", "ii", "}"}], "\[Rule]", "d"}]}], "]"}]}]}], 
           "]"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"ii", ",", "1", ",", 
          RowBox[{"Length", "[", "idx1", "]"}]}], "}"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       StyleBox[
        RowBox[{
         RowBox[{
         "d", " ", "is", " ", "dimesnion", " ", "of", " ", "the", " ", 
          "problem"}], ",", " ", 
         RowBox[{"i", ".", "e", "."}], ",", " ", 
         RowBox[{
          SubscriptBox[
           StyleBox["\[Delta]",
            FontColor->RGBColor[1, 0, 0]], "ii"], "=", "d"}]}],
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[" ",
        FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"StandardizeIdx", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Apply", "[", 
          RowBox[{"Times", ",", 
           RowBox[{"Join", "[", 
            RowBox[{"ex1", ",", "ex2"}], "]"}]}], "]"}], "/.", 
         RowBox[{"{", 
          RowBox[{"dummy", "\[Rule]", "1"}], "}"}]}], ",", "1"}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Einstein", "[", "ex_", "]"}], ":=", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Head", "[", "ex", "]"}], "===", " ", "Plus"}], ",", 
     RowBox[{"Apply", "[", 
      RowBox[{"Plus", ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Einstein1", "[", 
          RowBox[{
          "ex", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}], 
          "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"ii", ",", "1", ",", 
           RowBox[{"Length", "[", "ex", "]"}]}], "}"}]}], "]"}]}], "]"}], ",", 
     RowBox[{"Einstein1", "[", "ex", "]"}]}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Delta]$", "[", 
    RowBox[{"ii_", ",", "jj_"}], "]"}], "=", 
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"ii", ",", "jj"}], "}"}], "]"}]}], ";"}], "\[IndentingNewLine]", 

 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"DeltaTensor", "[", "idx_", "]"}], ":=", 
    RowBox[{"Block", "[", 
     RowBox[{
      RowBox[{"{", "xx", "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"OddQ", "[", 
          RowBox[{"Length", "[", "idx", "]"}], "]"}], ",", 
         RowBox[{"Return", "[", "0", "]"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"xx", "=", 
        RowBox[{"Permutations", "[", "idx", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Expand", "[", 
        RowBox[{
         FractionBox["1", 
          RowBox[{
           RowBox[{"Length", "[", "idx", "]"}], "!"}]], 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{"Product", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"KroneckerDelta", "[", 
               RowBox[{
                RowBox[{"xx", "\[LeftDoubleBracket]", 
                 RowBox[{"ii", ",", "jj"}], "\[RightDoubleBracket]"}], ",", 
                RowBox[{"xx", "\[LeftDoubleBracket]", 
                 RowBox[{"ii", ",", 
                  RowBox[{"jj", "+", "1"}]}], "\[RightDoubleBracket]"}]}], 
               "]"}], "/.", 
              RowBox[{"{", 
               RowBox[{"KroneckerDelta", "\[Rule]", "\[Delta]$"}], "}"}]}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"jj", ",", "1", ",", 
               RowBox[{"Length", "[", "idx", "]"}], ",", "2"}], "}"}]}], 
            "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"ii", ",", "1", ",", 
             RowBox[{
              RowBox[{"Length", "[", "idx", "]"}], "!"}]}], "}"}]}], "]"}]}], 
        "]"}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"sym1", "[", "ex_", "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"ex0", "=", "ex"}], ",", "pos", ",", "idx", ",", "perm", ",", 
       "double", ",", "tmp"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"pos", "=", 
       RowBox[{"Drop", "[", 
        RowBox[{
         RowBox[{"Position", "[", 
          RowBox[{"ex0", ",", "List"}], "]"}], ",", "None", ",", 
         RowBox[{"-", "1"}]}], "]"}]}], ";", "  ", "\[IndentingNewLine]", 
      RowBox[{"idx", "=", 
       RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Do", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"idx", "=", 
          RowBox[{"Join", "[", 
           RowBox[{"idx", ",", 
            RowBox[{"Extract", "[", 
             RowBox[{"ex0", ",", 
              RowBox[{
              "pos", "\[LeftDoubleBracket]", "ii", 
               "\[RightDoubleBracket]"}]}], "]"}]}], "]"}]}], ";", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Length", "[", 
             RowBox[{
             "pos", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}], 
             "]"}], "\[Equal]", "3"}], ",", 
           RowBox[{"idx", "=", 
            RowBox[{"Join", "[", 
             RowBox[{"idx", ",", 
              RowBox[{"Extract", "[", 
               RowBox[{"ex0", ",", 
                RowBox[{
                "pos", "\[LeftDoubleBracket]", "ii", 
                 "\[RightDoubleBracket]"}]}], "]"}]}], "]"}]}]}], "]"}]}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"ii", ",", "1", ",", 
          RowBox[{"Length", "[", "pos", "]"}]}], "}"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"double", "=", 
       RowBox[{
        RowBox[{"Select", "[", 
         RowBox[{
          RowBox[{"Tally", "[", "idx", "]"}], ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
             "#", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], ">",
              "1"}], ")"}], "&"}]}], "]"}], "\[LeftDoubleBracket]", 
        RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Do", "[", 
       RowBox[{
        RowBox[{"idx", "=", 
         RowBox[{"Delete", "[", 
          RowBox[{"idx", ",", 
           RowBox[{"Position", "[", 
            RowBox[{"idx", ",", 
             RowBox[{
             "double", "\[LeftDoubleBracket]", "kk", 
              "\[RightDoubleBracket]"}]}], "]"}]}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"kk", ",", "1", ",", 
          RowBox[{"Length", "[", "double", "]"}]}], "}"}]}], "]"}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"perm", "=", 
       RowBox[{"Permutations", "[", "idx", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"tmp", "=", 
       RowBox[{"ex0", "/.", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Thread", "[", 
           RowBox[{"idx", "\[Rule]", 
            RowBox[{
            "perm", "\[LeftDoubleBracket]", "kk", "\[RightDoubleBracket]"}]}],
            "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"kk", ",", "1", ",", 
            RowBox[{
             RowBox[{"Length", "[", "idx", "]"}], "!"}]}], "}"}]}], "]"}]}]}],
       ";", "\[IndentingNewLine]", 
      RowBox[{"tmp", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"StandardizeIdx", "[", 
          RowBox[{
           RowBox[{
           "tmp", "\[LeftDoubleBracket]", "kk", "\[RightDoubleBracket]"}], 
           ",", "2"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"kk", ",", "1", ",", 
           RowBox[{"Length", "[", "tmp", "]"}]}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Apply", "[", 
       RowBox[{"Plus", ",", 
        RowBox[{
         FractionBox["1", 
          RowBox[{"Length", "[", "perm", "]"}]], "tmp"}]}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sym", "[", "ex_", "]"}], ":=", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Head", "[", "ex", "]"}], "===", " ", "Plus"}], ",", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"sym1", "[", 
         RowBox[{
         "ex", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}], "]"}],
         ",", 
        RowBox[{"{", 
         RowBox[{"ii", ",", "1", ",", 
          RowBox[{"Length", "[", "ex", "]"}]}], "}"}]}], "]"}]}], "]"}], ",", 
    
    RowBox[{"sym1", "[", "ex", "]"}]}], 
   "]"}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.535821055158787*^9, 3.535821066078806*^9}, {
   3.535821166901783*^9, 3.5358212958048096`*^9}, {3.5358214123838143`*^9, 
   3.5358214147862186`*^9}, {3.5358215618008766`*^9, 3.535821604123751*^9}, {
   3.535821698332317*^9, 3.5358217011715217`*^9}, {3.5358217447579985`*^9, 
   3.5358217566140194`*^9}, {3.535822680152241*^9, 3.535822696126669*^9}, {
   3.5358228323617086`*^9, 3.5358228417061253`*^9}, {3.5358231551106753`*^9, 
   3.535823169774701*^9}, {3.5358232120663757`*^9, 3.535823265168869*^9}, {
   3.5358233044185376`*^9, 3.53582333451099*^9}, {3.535823374915062*^9, 
   3.5358235131157045`*^9}, {3.5358235856090317`*^9, 3.5358236244219*^9}, {
   3.535823671143982*^9, 3.5358236829064026`*^9}, {3.5358237600797377`*^9, 
   3.535823791919394*^9}, {3.535823830810262*^9, 3.535823834351468*^9}, {
   3.535823891807369*^9, 3.5358239053637934`*^9}, {3.5358239420706577`*^9, 
   3.5358239633490953`*^9}, 3.535863647709474*^9, 3.535867745488166*^9, {
   3.535870455408924*^9, 3.535870473645012*^9}, {3.536173856347906*^9, 
   3.536173963457694*^9}, {3.536174014454184*^9, 3.536174027729807*^9}, {
   3.5361746053218217`*^9, 3.5361746149314384`*^9}, {3.5361749406132107`*^9, 
   3.5361749546688356`*^9}, {3.537099203659336*^9, 3.537099204123344*^9}, {
   3.537099273283682*^9, 3.5370992965788307`*^9}, 3.5371001026471033`*^9, {
   3.5371002063851147`*^9, 3.537100208309923*^9}, {3.537100238826915*^9, 
   3.5371004036702833`*^9}, {3.537100455360618*^9, 3.537100530540921*^9}, {
   3.537100577355506*^9, 3.53710059160116*^9}, {3.537109198461097*^9, 
   3.537109236618764*^9}, {3.537111875319599*^9, 3.537111966766959*^9}, {
   3.544510085142268*^9, 3.544510086491521*^9}, {3.544511135130258*^9, 
   3.544511149122176*^9}, {3.544511265775567*^9, 3.5445112663694477`*^9}, {
   3.544511306595739*^9, 3.544511450576692*^9}, {3.54451148203868*^9, 
   3.544511513829035*^9}, {3.544511554825622*^9, 3.544511571921101*^9}, {
   3.544589325870937*^9, 3.5445893449341707`*^9}, {3.545669873420969*^9, 
   3.5456699152446423`*^9}, {3.73678534119002*^9, 3.736785499923944*^9}, {
   3.736785561742168*^9, 3.7367855622511272`*^9}, {3.736785791969393*^9, 
   3.736785808825666*^9}, {3.7371070607483997`*^9, 3.737107084991353*^9}},
 ExpressionUUID -> "b49738c3-74c0-4bcd-ab11-cb94d76ffaa8"]
}, Closed]],

Cell[CellGroupData[{

Cell["Computation of integrals", "Subsection",
 CellChangeTimes->{{3.736944715146167*^9, 3.736944721056355*^9}},
 ExpressionUUID -> "fb6391b4-0e74-47bd-99f7-136e871443b6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"B", "[", "r_", "]"}], ":=", 
  RowBox[{"\[CapitalOmega]d", " ", 
   SuperscriptBox["\[Pi]", 
    RowBox[{
     RowBox[{"-", "1"}], "/", "2"}]], " ", 
   FractionBox[
    RowBox[{
     RowBox[{"Gamma", "[", 
      FractionBox["dim", "2"], "]"}], 
     RowBox[{"Gamma", "[", 
      RowBox[{"r", "+", 
       FractionBox["1", "2"]}], "]"}]}], 
    RowBox[{"Gamma", "[", 
     RowBox[{"r", "+", 
      FractionBox["dim", "2"]}], "]"}]]}]}]], "Input",
 CellChangeTimes->{{3.73690570553272*^9, 3.736905816457932*^9}, {
   3.736905888820139*^9, 3.736905962597438*^9}, {3.736906021882346*^9, 
   3.736906026624702*^9}, 3.7369436192475023`*^9},
 ExpressionUUID -> "ea48a670-9aa8-4762-8d02-7b72b3201e4e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"{", 
   RowBox[{
    FractionBox[
     RowBox[{"B", "[", 
      RowBox[{"r", "+", "1"}], "]"}], 
     RowBox[{"B", "[", "r", "]"}]], ",", 
    FractionBox[
     RowBox[{"B", "[", 
      RowBox[{"r", "+", "2"}], "]"}], 
     RowBox[{"B", "[", "r", "]"}]], ",", 
    FractionBox[
     RowBox[{"B", "[", 
      RowBox[{"r", "+", "2"}], "]"}], 
     RowBox[{"B", "[", 
      RowBox[{"r", "+", "1"}], "]"}]]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.7369059683810787`*^9, 3.736905997332217*^9}, {
   3.736916957718183*^9, 3.7369169581401043`*^9}, {3.7369193413123198`*^9, 
   3.7369193415433064`*^9}, {3.7369259131886806`*^9, 3.736925913376774*^9}, 
   3.736943977385257*^9, {3.736944020197422*^9, 3.736944036157935*^9}},
 ExpressionUUID -> "8ff23557-c576-4549-8086-b53fe3e95854"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{"1", "+", 
     RowBox[{"2", " ", "r"}]}], 
    RowBox[{"dim", "+", 
     RowBox[{"2", " ", "r"}]}]], ",", 
   FractionBox[
    RowBox[{"3", "+", 
     RowBox[{"4", " ", "r", " ", 
      RowBox[{"(", 
       RowBox[{"2", "+", "r"}], ")"}]}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"dim", "+", 
       RowBox[{"2", " ", "r"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"2", "+", "dim", "+", 
       RowBox[{"2", " ", "r"}]}], ")"}]}]], ",", 
   FractionBox[
    RowBox[{"3", "+", 
     RowBox[{"2", " ", "r"}]}], 
    RowBox[{"2", "+", "dim", "+", 
     RowBox[{"2", " ", "r"}]}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.736905980172008*^9, 3.73690599835153*^9}, 
   3.736906030708213*^9, {3.7369169527732964`*^9, 3.736916958664093*^9}, {
   3.736919341970129*^9, 3.736919346351637*^9}, 3.736925917364929*^9, {
   3.736944036716361*^9, 3.736944043255599*^9}, 3.7369448137710333`*^9, 
   3.736945737440893*^9, {3.736945801853591*^9, 3.736945818527402*^9}, 
   3.7369458895444813`*^9, 3.7369461045539103`*^9},
 ExpressionUUID -> "ebb3a047-e6fb-4c83-ac16-80b26db6171b"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   StyleBox[
    RowBox[{
     RowBox[{
     "General", " ", "form", " ", "of", " ", "integrals", " ", "over", " ", 
      StyleBox["k",
       FontWeight->"Bold"]}], ",", 
     RowBox[{
      RowBox[{"e", ".", "g", ".", 
       FormBox[
        RowBox[{
         RowBox[{"\[Integral]", 
          RowBox[{
           SubscriptBox["k", "i"], 
           SuperscriptBox[
            RowBox[{
             SubscriptBox["k", "j"], "(", 
             StyleBox[
              RowBox[{"k", ".", 
               FractionBox["g", 
                StyleBox["g",
                 FontWeight->"Plain"]]}],
              FontWeight->"Bold"], ")"}], "n"], 
           RowBox[{"\[DifferentialD]", 
            StyleBox["k",
             FontWeight->"Bold"]}]}]}], "="}],
        TraditionalForm]}], 
      FormBox[
       RowBox[{
        RowBox[{
         SubsuperscriptBox["\[Alpha]", "0", "2"], 
         FractionBox[
          RowBox[{
           SubscriptBox["g", "i"], 
           SubscriptBox["g", "j"]}], 
          SuperscriptBox["g", "2"]]}], "+", 
        RowBox[{
         SubsuperscriptBox["\[Alpha]", "1", "2"], 
         SubscriptBox["\[Delta]", "ij"]}]}],
       TraditionalForm]}]}],
    FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"range", "[", 
     RowBox[{"i_", ",", "j_"}], "]"}], "=", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"j", "<", "i"}], "||", 
       RowBox[{"j", "\[LessEqual]", "0"}], "||", 
       RowBox[{"i", "<", "0"}]}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"i", "\[Equal]", "0"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"1", ",", "j"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"i", ",", "j"}], "]"}]}], "]"}]}], "]"}]}], ";", 
   RowBox[{
    RowBox[{"intform", "[", "idx_", "]"}], ":=", 
    RowBox[{"Block", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "\[Beta]", ",", "exp1", ",", "perm", ",", "exp", ",", "gg", ",", 
        "idx1", ",", "Delta"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"\[Beta]", "=", 
        RowBox[{"Length", "[", "idx", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"gg", "[", "idx1_", "]"}], ":=", 
        RowBox[{
         UnderoverscriptBox["\[Product]", 
          RowBox[{"ii", "=", "1"}], 
          RowBox[{"Length", "[", "idx1", "]"}]], 
         FractionBox[
          RowBox[{"g", "[", 
           RowBox[{"{", 
            RowBox[{
            "idx1", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}], 
            "}"}], "]"}], "g"]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Delta", "[", 
         RowBox[{"idx1_", ",", "idx2_"}], "]"}], ":=", 
        RowBox[{
         UnderoverscriptBox["\[Product]", 
          RowBox[{"ii", "=", "1"}], 
          RowBox[{"Length", "[", "idx1", "]"}]], 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"Sort", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
             "idx1", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}], 
             ",", 
             RowBox[{
             "idx2", "\[LeftDoubleBracket]", "ii", 
              "\[RightDoubleBracket]"}]}], "}"}], "]"}], "]"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"exp1", "=", 
        RowBox[{
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"\[Gamma]", "=", "0"}], 
          RowBox[{"\[Beta]", "/", "2"}]], 
         RowBox[{
          RowBox[{"Delta", "[", 
           RowBox[{
            RowBox[{"idx", "\[LeftDoubleBracket]", 
             RowBox[{"range", "[", 
              RowBox[{"1", ",", "\[Gamma]"}], "]"}], 
             "\[RightDoubleBracket]"}], ",", 
            RowBox[{"idx", "\[LeftDoubleBracket]", 
             RowBox[{"range", "[", 
              RowBox[{
               RowBox[{"\[Gamma]", "+", "1"}], ",", 
               RowBox[{"2", "\[Gamma]"}]}], "]"}], 
             "\[RightDoubleBracket]"}]}], "]"}], 
          RowBox[{"\[Alpha]", "[", 
           RowBox[{"\[Gamma]", ",", "\[Beta]"}], "]"}], 
          RowBox[{"gg", "[", 
           RowBox[{"idx", "\[LeftDoubleBracket]", 
            RowBox[{"range", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"2", "\[Gamma]"}], "+", "1"}], ",", "\[Beta]"}], "]"}],
             "\[RightDoubleBracket]"}], "]"}]}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"perm", "=", 
        RowBox[{"Permutations", "[", "idx", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"exp", "=", "0"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Do", "[", 
        RowBox[{
         RowBox[{"exp", "+=", 
          RowBox[{"exp1", "/.", 
           RowBox[{"Thread", "[", 
            RowBox[{"idx", "\[Rule]", 
             RowBox[{
             "perm", "\[LeftDoubleBracket]", "ii", 
              "\[RightDoubleBracket]"}]}], "]"}]}]}], ",", 
         RowBox[{"{", 
          RowBox[{"ii", ",", "1", ",", 
           RowBox[{"Length", "[", "perm", "]"}]}], "}"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"exp", "=", 
        RowBox[{"Sort", "[", "exp", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Collect", "[", 
        RowBox[{
         RowBox[{"ExpandAll", "[", 
          FractionBox[
           RowBox[{"exp", "/.", 
            RowBox[{"\[Delta]", "\[Rule]", "DeltaTensor"}]}], 
           RowBox[{"Length", "[", "perm", "]"}]], "]"}], ",", 
         RowBox[{"\[Alpha]", "[", 
          RowBox[{"_", ",", "_"}], "]"}], ",", "Simplify"}], "]"}]}]}], 
     "\[IndentingNewLine]", "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.736906097016273*^9, 3.7369060994112673`*^9}, 
   3.7369071490914516`*^9, 3.736907441324892*^9, {3.7369075456645403`*^9, 
   3.736907582797571*^9}, {3.736907677740307*^9, 3.736907684243194*^9}, {
   3.736907872135254*^9, 3.736907966138248*^9}, {3.73690804787066*^9, 
   3.73690804818004*^9}, {3.736908096593272*^9, 3.7369082659328537`*^9}, {
   3.736908399939362*^9, 3.736908439911964*^9}, {3.736908503445677*^9, 
   3.736908539626677*^9}, {3.73690858035642*^9, 3.736908685952475*^9}, {
   3.7369087282339563`*^9, 3.7369087637284403`*^9}, {3.736908806345924*^9, 
   3.7369088633688*^9}, {3.736909166104995*^9, 3.736909178981028*^9}, 
   3.736909880010206*^9, {3.736909941505691*^9, 3.736909950887566*^9}, {
   3.736909981850313*^9, 3.7369100502543507`*^9}, {3.736919551838657*^9, 
   3.73691957801045*^9}, {3.736919664582204*^9, 3.736919666139063*^9}, {
   3.7369440748503933`*^9, 3.736944104756591*^9}, {3.7369444818068733`*^9, 
   3.7369445220568113`*^9}, 3.736944598883333*^9, 3.73694588505689*^9, {
   3.7369459469857607`*^9, 3.736945958647559*^9}},
 ExpressionUUID -> "ff31e7e7-a3af-4342-b35b-c5b5e130c53c"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"idx", "=", 
  RowBox[{"{", 
   RowBox[{"i", ",", "j", ",", "k"}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"intform", "[", "idx", "]"}]}], "Input",
 CellChangeTimes->{{3.7369459885692987`*^9, 3.736945996521847*^9}},
 ExpressionUUID -> "1b3d6fdf-5b0a-4512-8f4f-724de2a74ab0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"i", ",", "j", ",", "k"}], "}"}]], "Output",
 CellChangeTimes->{3.736945997311965*^9, 3.736946104700691*^9},
 ExpressionUUID -> "a0876d38-766f-41dc-b886-21d54b60b2d4"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    RowBox[{"g", "[", 
     RowBox[{"{", "i", "}"}], "]"}], " ", 
    RowBox[{"g", "[", 
     RowBox[{"{", "j", "}"}], "]"}], " ", 
    RowBox[{"g", "[", 
     RowBox[{"{", "k", "}"}], "]"}], " ", 
    RowBox[{"\[Alpha]", "[", 
     RowBox[{"0", ",", "3"}], "]"}]}], 
   SuperscriptBox["g", "3"]], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"\[Alpha]", "[", 
     RowBox[{"1", ",", "3"}], "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"g", "[", 
        RowBox[{"{", "k", "}"}], "]"}], " ", 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"g", "[", 
        RowBox[{"{", "j", "}"}], "]"}], " ", 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"g", "[", 
        RowBox[{"{", "i", "}"}], "]"}], " ", 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"j", ",", "k"}], "}"}], "]"}]}]}], ")"}]}], 
   RowBox[{"3", " ", "g"}]]}]], "Output",
 CellChangeTimes->{3.736945997311965*^9, 3.73694610472729*^9},
 ExpressionUUID -> "792c750d-b849-448a-9a7b-8f6f8d60f668"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   StyleBox[
    RowBox[{
     RowBox[{"Values", " ", "of", " ", "integrals", " ", "over", " ", 
      StyleBox["k",
       FontWeight->"Bold"]}], ",", " ", 
     RowBox[{"e", ".", "g", "."}], ",", 
     RowBox[{"\[Integral]", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         StyleBox[
          RowBox[{"k", ".", "g"}],
          FontWeight->"Bold"], ")"}], "n"], 
       SubscriptBox["k", "i"], 
       SubscriptBox["k", "j"], 
       RowBox[{"\[DifferentialD]", 
        StyleBox["k",
         FontWeight->"Bold"]}]}]}]}],
    FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Clear", "[", "B", "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"int", "[", 
     RowBox[{"pow_", ",", "idx_"}], "]"}], ":=", 
    RowBox[{"Block", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"$Assumptions", "=", 
         RowBox[{
          RowBox[{"pow", ">", "0"}], "&&", 
          RowBox[{"pow", "\[Element]", "Integers"}]}]}], ",", "\[Beta]", ",", 
        "factors", ",", "intformaftermulti", ",", "list", ",", "alphas", ",", 
        "eqns", ",", "gg"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"\[Beta]", "=", 
        RowBox[{"Length", "[", "idx", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{
          RowBox[{"eqn", "[", "1", "]"}], "=", 
          RowBox[{
           RowBox[{"B", "[", 
            RowBox[{"Simplify", "[", 
             FractionBox[
              RowBox[{"pow", "+", "\[Beta]"}], "2"], "]"}], "]"}], "\[Equal]", 
           RowBox[{
            SuperscriptBox["g", "pow"], 
            RowBox[{"intform", "[", "idx", "]"}]}]}]}], ";"}], "*)"}], 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"gg", "[", "idx1_", "]"}], ":=", 
        RowBox[{
         UnderoverscriptBox["\[Product]", 
          RowBox[{"ii", "=", "1"}], 
          RowBox[{"Length", "[", "idx1", "]"}]], 
         FractionBox[
          RowBox[{"g", "[", 
           RowBox[{"{", 
            RowBox[{
            "idx1", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}], 
            "}"}], "]"}], "g"]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"factors", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Apply", "[", 
           RowBox[{"Times", ",", 
            RowBox[{"Flatten", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"gg", "[", 
                RowBox[{"Drop", "[", 
                 RowBox[{"idx", ",", 
                  RowBox[{
                   RowBox[{"-", "2"}], "ii"}]}], "]"}], "]"}], ",", 
               RowBox[{"\[Delta]", "/@", 
                RowBox[{"Partition", "[", 
                 RowBox[{
                  RowBox[{"Take", "[", 
                   RowBox[{"idx", ",", 
                    RowBox[{
                    RowBox[{"-", "2"}], "ii"}]}], "]"}], ",", "2"}], 
                 "]"}]}]}], "}"}], "]"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"ii", ",", "0", ",", 
            RowBox[{
             RowBox[{"Length", "[", "idx", "]"}], "/", "2"}]}], "}"}]}], 
         "]"}]}], ";", 
       RowBox[{"(*", 
        RowBox[{"Join", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"gg", "[", "idx", "]"}], "}"}], ",", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"Apply", "[", 
             RowBox[{"Times", ",", 
              RowBox[{"Flatten", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"gg", "[", 
                  RowBox[{"Drop", "[", 
                   RowBox[{"idx", ",", 
                    RowBox[{
                    RowBox[{"-", "2"}], "ii"}]}], "]"}], "]"}], ",", 
                 RowBox[{"\[Delta]", "/@", 
                  RowBox[{"Partition", "[", 
                   RowBox[{
                    RowBox[{"Take", "[", 
                    RowBox[{"idx", ",", 
                    RowBox[{
                    RowBox[{"-", "2"}], "ii"}]}], "]"}], ",", "2"}], 
                   "]"}]}]}], "}"}], "]"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"ii", ",", "1", ",", 
              RowBox[{
               RowBox[{"Length", "[", "idx", "]"}], "/", "2"}]}], "}"}]}], 
           "]"}]}], "]"}], "*)"}], "\[IndentingNewLine]", 
       RowBox[{"(*", "factors", "*)"}], "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"intformaftermulti", "=", 
        RowBox[{"Expand", "[", 
         RowBox[{
          RowBox[{"intform", "[", "idx", "]"}], "factors"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"list", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Length", "[", 
           RowBox[{"Drop", "[", 
            RowBox[{"idx", ",", 
             RowBox[{
              RowBox[{"-", "2"}], "ii"}]}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"ii", ",", "0", ",", 
            RowBox[{
             RowBox[{"Length", "[", "idx", "]"}], "/", "2"}]}], "}"}]}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"eqns", "=", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["g", "pow"], 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"B", "[", 
              RowBox[{"Simplify", "[", 
               FractionBox[
                RowBox[{"pow", "+", 
                 RowBox[{
                 "list", "\[LeftDoubleBracket]", "ii", 
                  "\[RightDoubleBracket]"}]}], "2"], "]"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"ii", ",", "1", ",", 
               RowBox[{"Length", "[", "list", "]"}]}], "}"}]}], "]"}]}], 
          "\[Equal]", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{
             SuperscriptBox["g", "pow"], 
             RowBox[{"Einstein", "[", 
              RowBox[{
              "intformaftermulti", "\[LeftDoubleBracket]", "ii", 
               "\[RightDoubleBracket]"}], "]"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"ii", ",", "1", ",", 
              RowBox[{"Length", "[", "intformaftermulti", "]"}]}], "}"}]}], 
           "]"}]}], "/.", 
         RowBox[{"{", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"g", "[", 
             RowBox[{"{", "_", "}"}], "]"}], "2"], "\[Rule]", 
           SuperscriptBox["g", "2"]}], "}"}]}]}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"alphas", "=", 
        RowBox[{
         RowBox[{"Simplify", "[", 
          RowBox[{"Solve", "[", 
           RowBox[{"eqns", ",", 
            RowBox[{"Extract", "[", 
             RowBox[{
              RowBox[{"intform", "[", "idx", "]"}], ",", 
              RowBox[{"Position", "[", 
               RowBox[{
                RowBox[{"intform", "[", "idx", "]"}], ",", 
                RowBox[{"\[Alpha]", "[", 
                 RowBox[{"_", ",", "_"}], "]"}]}], "]"}]}], "]"}]}], "]"}], 
          "]"}], "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         SuperscriptBox["g", "pow"], 
         RowBox[{"intform", "[", "idx", "]"}]}], "/.", "alphas"}]}]}], 
     "\[IndentingNewLine]", "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.7369100745346737`*^9, 3.736910132995966*^9}, {
   3.73691022659793*^9, 3.736910250744864*^9}, {3.736910281668597*^9, 
   3.736910297910387*^9}, {3.7369103658419037`*^9, 3.736910405563429*^9}, {
   3.736910591327293*^9, 3.7369106255436277`*^9}, {3.736910656257234*^9, 
   3.736910750196639*^9}, {3.736911049622835*^9, 3.7369110601021423`*^9}, {
   3.736911239784625*^9, 3.736911268909232*^9}, {3.73691405095881*^9, 
   3.736914078095009*^9}, {3.736914366076579*^9, 3.736914395736459*^9}, {
   3.736914431063031*^9, 3.736914441325923*^9}, {3.736914474213986*^9, 
   3.736914571665707*^9}, {3.7369213183982286`*^9, 3.736921403804656*^9}, {
   3.736921446365354*^9, 3.736921447229228*^9}, {3.736921681690722*^9, 
   3.7369216845775757`*^9}, {3.73692177155293*^9, 3.736921773844635*^9}, {
   3.736921818646865*^9, 3.7369218350865602`*^9}, {3.736921865642324*^9, 
   3.736921900225636*^9}, {3.7369219319972553`*^9, 3.736922025653954*^9}, {
   3.7369223355873203`*^9, 3.736922354183971*^9}, {3.736922387024332*^9, 
   3.736922508577649*^9}, {3.736922563690387*^9, 3.736922583328568*^9}, {
   3.736922968091776*^9, 3.7369229728111143`*^9}, {3.736923713755473*^9, 
   3.736923730918229*^9}, {3.736923870424797*^9, 3.7369238944377203`*^9}, {
   3.736924813133884*^9, 3.736924827484396*^9}, {3.736924987969734*^9, 
   3.7369250214457293`*^9}, 3.73692520722558*^9, {3.736925297562553*^9, 
   3.736925382768395*^9}, 3.7369254436033688`*^9, {3.7369254813400717`*^9, 
   3.7369254870349617`*^9}, 3.736925526292924*^9, {3.73692560906558*^9, 
   3.736925630182569*^9}, {3.736925664634647*^9, 3.7369256692710457`*^9}, {
   3.73692575322656*^9, 3.736925759737006*^9}, 3.736926427093626*^9, 
   3.736926468338003*^9, 3.736926526529089*^9, {3.736927061167759*^9, 
   3.7369271032602243`*^9}, 3.7369272021812677`*^9, {3.736927312064184*^9, 
   3.7369273823726673`*^9}, {3.736927431102604*^9, 3.736927469118387*^9}, {
   3.736927501192852*^9, 3.736927508247607*^9}, {3.736927579008955*^9, 
   3.7369276084713182`*^9}, 3.736927698051108*^9, 3.736927828374116*^9, 
   3.736928074512824*^9, 3.7369281264341507`*^9, {3.7369428304809923`*^9, 
   3.736942839840691*^9}, {3.736942889998458*^9, 3.7369428945021887`*^9}, {
   3.736942962256591*^9, 3.736942966902293*^9}, {3.73694368133209*^9, 
   3.7369436843829403`*^9}, {3.736943778087233*^9, 3.736943788478709*^9}, {
   3.7369445566817636`*^9, 3.7369446460613823`*^9}, {3.736946036981924*^9, 
   3.736946043104837*^9}, 3.736946079060444*^9},
 ExpressionUUID -> "9e400df0-6a5a-4e70-ad2f-06b4e8901173"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Verification with Appendix A of Vicente Garz\[OAcute] and Andr\[EAcute]s \
Santos 2007 J. Phys. A: Math. Theor. 40 14927\
\>", "Subsection",
 CellChangeTimes->{{3.736944748939127*^9, 3.736944804082196*^9}},
 ExpressionUUID -> "6cbfef37-74c3-4eb1-a292-25cae3566d15"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"int", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"2", "r"}], "+", "1"}], ",", 
   RowBox[{"{", "i", "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7369448449023943`*^9, 
  3.736944861608761*^9}},ExpressionUUID->"08467bea-e411-496a-8f85-\
8ef14984f039"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["g", 
   RowBox[{"2", " ", "r"}]], " ", 
  RowBox[{"B", "[", 
   RowBox[{"1", "+", "r"}], "]"}], " ", 
  RowBox[{"g", "[", 
   RowBox[{"{", "i", "}"}], "]"}]}]], "Output",
 CellChangeTimes->{
  3.736944862730466*^9, 3.736945758517572*^9, {3.736945804659173*^9, 
   3.736945826565065*^9}, 3.736945892445818*^9, 3.736945967374251*^9, 
   3.736946050685935*^9, 
   3.736946114461187*^9},ExpressionUUID->"95c69ee1-64d9-4993-b40e-\
359c95f82677"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"int", "[", 
    RowBox[{
     RowBox[{"2", "r"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "j"}], "}"}]}], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"B", "[", 
      RowBox[{"r", "+", "1"}], "]"}], "\[Rule]", 
     RowBox[{
      FractionBox[
       RowBox[{"1", "+", 
        RowBox[{"2", " ", "r"}]}], 
       RowBox[{"dim", "+", 
        RowBox[{"2", " ", "r"}]}]], 
      RowBox[{"B", "[", "r", "]"}]}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7369448799097967`*^9, 
  3.7369449499854403`*^9}},ExpressionUUID->"3ecd345b-7b4f-4a94-8c60-\
09478e70621b"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["g", 
    RowBox[{
     RowBox[{"-", "2"}], "+", 
     RowBox[{"2", " ", "r"}]}]], " ", 
   RowBox[{"B", "[", "r", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", "r", " ", 
      RowBox[{"g", "[", 
       RowBox[{"{", "i", "}"}], "]"}], " ", 
      RowBox[{"g", "[", 
       RowBox[{"{", "j", "}"}], "]"}]}], "+", 
     RowBox[{
      SuperscriptBox["g", "2"], " ", 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"i", ",", "j"}], "}"}], "]"}]}]}], ")"}]}], 
  RowBox[{"dim", "+", 
   RowBox[{"2", " ", "r"}]}]]], "Output",
 CellChangeTimes->{{3.736944881493889*^9, 3.736944890949643*^9}, {
   3.7369449403556747`*^9, 3.73694495054235*^9}, 3.7369457588966312`*^9, 
   3.736946056398929*^9, 
   3.7369461147094507`*^9},ExpressionUUID->"c6a664bb-8d39-45fc-8699-\
7291bbc35eac"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"int", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", "r"}], "+", "1"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "j", ",", "k"}], "}"}]}], "]"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"B", "[", 
        RowBox[{"r", "+", "2"}], "]"}], "\[Rule]", 
       RowBox[{
        FractionBox[
         RowBox[{"(", 
          RowBox[{"3", "+", 
           RowBox[{"2", " ", "r"}]}], ")"}], 
         RowBox[{"2", "+", "dim", "+", 
          RowBox[{"2", " ", "r"}]}]], 
        RowBox[{"B", "[", 
         RowBox[{"r", "+", "1"}], "]"}]}]}], "}"}]}], ")"}], "-", 
   RowBox[{
    FractionBox[
     RowBox[{"B", "[", 
      RowBox[{"r", "+", "1"}], "]"}], 
     RowBox[{
      RowBox[{"2", 
       RowBox[{"(", 
        RowBox[{"r", "+", "1"}], ")"}]}], "+", "dim"}]], 
    SuperscriptBox["g", 
     RowBox[{"2", 
      RowBox[{"(", 
       RowBox[{"r", "-", "1"}], ")"}]}]], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", "r", " ", 
       RowBox[{"g", "[", 
        RowBox[{"{", "i", "}"}], "]"}], " ", 
       RowBox[{"g", "[", 
        RowBox[{"{", "j", "}"}], "]"}], 
       RowBox[{"g", "[", 
        RowBox[{"{", "k", "}"}], "]"}]}], " ", "+", 
      RowBox[{
       SuperscriptBox["g", "2"], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i", ",", "j"}], "}"}], "]"}], 
          RowBox[{"g", "[", 
           RowBox[{"{", "k", "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i", ",", "k"}], "}"}], "]"}], 
          RowBox[{"g", "[", 
           RowBox[{"{", "j", "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"j", ",", "k"}], "}"}], "]"}], 
          RowBox[{"g", "[", 
           RowBox[{"{", "i", "}"}], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.736945011057638*^9, 3.736945121725787*^9}, {
  3.736945175567994*^9, 
  3.736945213897201*^9}},ExpressionUUID->"b9b405a2-8599-4f1c-8205-\
37b0b9297277"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.736945019115705*^9, 3.736945215805847*^9, 
  3.736945759292725*^9, 3.736946063456266*^9, 
  3.736946114823352*^9},ExpressionUUID->"d45b4981-72f9-4057-b098-\
ffe5abfd4d20"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"int", "[", 
      RowBox[{
       RowBox[{"2", "r"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}]}], "]"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"B", "[", 
         RowBox[{"r", "+", "2"}], "]"}], "\[Rule]", 
        RowBox[{
         FractionBox[
          RowBox[{"3", "+", 
           RowBox[{"4", " ", "r", " ", 
            RowBox[{"(", 
             RowBox[{"2", "+", "r"}], ")"}]}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"dim", "+", 
             RowBox[{"2", " ", "r"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"2", "+", "dim", "+", 
             RowBox[{"2", " ", "r"}]}], ")"}]}]], 
         RowBox[{"B", "[", "r", "]"}]}]}], ",", 
       RowBox[{
        RowBox[{"B", "[", 
         RowBox[{"r", "+", "1"}], "]"}], "\[Rule]", 
        RowBox[{
         FractionBox[
          RowBox[{"1", "+", 
           RowBox[{"2", " ", "r"}]}], 
          RowBox[{"dim", "+", 
           RowBox[{"2", " ", "r"}]}]], 
         RowBox[{"B", "[", "r", "]"}]}]}]}], "}"}]}], ")"}], "-", 
   RowBox[{
    FractionBox[
     RowBox[{"B", "[", "r", "]"}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", "r"}], "+", "dim"}], ")"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", 
         RowBox[{"(", 
          RowBox[{"r", "+", "1"}], ")"}]}], "+", "dim"}], ")"}]}]], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"4", "r", 
       RowBox[{"(", 
        RowBox[{"r", "-", "1"}], ")"}], 
       SuperscriptBox["g", 
        RowBox[{"2", 
         RowBox[{"(", 
          RowBox[{"r", "-", "2"}], ")"}]}]], 
       RowBox[{"g", "[", 
        RowBox[{"{", "i", "}"}], "]"}], " ", 
       RowBox[{"g", "[", 
        RowBox[{"{", "j", "}"}], "]"}], " ", 
       RowBox[{"g", "[", 
        RowBox[{"{", "k", "}"}], "]"}], " ", 
       RowBox[{"g", "[", 
        RowBox[{"{", "l", "}"}], "]"}]}], "+", 
      RowBox[{"2", "r", 
       SuperscriptBox["g", 
        RowBox[{"2", 
         RowBox[{"(", 
          RowBox[{"r", "-", "1"}], ")"}]}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"g", "[", 
           RowBox[{"{", "i", "}"}], "]"}], " ", 
          RowBox[{"g", "[", 
           RowBox[{"{", "j", "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"k", ",", "l"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"g", "[", 
           RowBox[{"{", "i", "}"}], "]"}], " ", 
          RowBox[{"g", "[", 
           RowBox[{"{", "k", "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"g", "[", 
           RowBox[{"{", "i", "}"}], "]"}], " ", 
          RowBox[{"g", "[", 
           RowBox[{"{", "l", "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"g", "[", 
           RowBox[{"{", "j", "}"}], "]"}], " ", 
          RowBox[{"g", "[", 
           RowBox[{"{", "k", "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i", ",", "l"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"g", "[", 
           RowBox[{"{", "j", "}"}], "]"}], " ", 
          RowBox[{"g", "[", 
           RowBox[{"{", "l", "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"g", "[", 
           RowBox[{"{", "k", "}"}], "]"}], " ", 
          RowBox[{"g", "[", 
           RowBox[{"{", "l", "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i", ",", "j"}], "}"}], "]"}]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"2", "r"}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"k", ",", "l"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i", ",", "k"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i", ",", "l"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"j", ",", "k"}], "}"}], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.7369452383588552`*^9, 
  3.736945691804522*^9}},ExpressionUUID->"cc6485b2-51e3-44b0-9d6d-\
1e2d2130a462"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.73694524383425*^9, 3.7369452494845467`*^9}, {
   3.736945329112414*^9, 3.736945341867915*^9}, 3.736945694012011*^9, 
   3.736945777509747*^9, 3.736946066035625*^9, 
   3.736946115007215*^9},ExpressionUUID->"a00d2161-abea-4ad1-a520-\
181a02107326"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Computation of Coefficients \[Alpha][i,j] appearing in production terms for \
Maxwell molecules\
\>", "Section",
 CellChangeTimes->{{3.7372651824233418`*^9, 
  3.737265242743628*^9}},ExpressionUUID->"cf789ac7-14fc-4563-845b-\
28c5d71d18fe"],

Cell[BoxData[
 RowBox[{
  RowBox[{"B", "[", "r_", "]"}], ":=", 
  RowBox[{"\[CapitalOmega]d", " ", 
   SuperscriptBox["\[Pi]", 
    RowBox[{
     RowBox[{"-", "1"}], "/", "2"}]], " ", 
   FractionBox[
    RowBox[{
     RowBox[{"Gamma", "[", 
      FractionBox["dim", "2"], "]"}], 
     RowBox[{"Gamma", "[", 
      RowBox[{"r", "+", 
       FractionBox["1", "2"]}], "]"}]}], 
    RowBox[{"Gamma", "[", 
     RowBox[{"r", "+", 
      FractionBox["dim", "2"]}], "]"}]]}]}]], "Input",
 CellChangeTimes->{{3.73690570553272*^9, 3.736905816457932*^9}, {
   3.736905888820139*^9, 3.736905962597438*^9}, {3.736906021882346*^9, 
   3.736906026624702*^9}, 
   3.7369436192475023`*^9},ExpressionUUID->"99c9fb3a-77c9-4e38-9a7c-\
88720a820489"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"{", 
   RowBox[{
    FractionBox[
     RowBox[{"B", "[", 
      RowBox[{"r", "+", "1"}], "]"}], 
     RowBox[{"B", "[", "r", "]"}]], ",", 
    FractionBox[
     RowBox[{"B", "[", 
      RowBox[{"r", "+", "2"}], "]"}], 
     RowBox[{"B", "[", "r", "]"}]], ",", 
    FractionBox[
     RowBox[{"B", "[", 
      RowBox[{"r", "+", "2"}], "]"}], 
     RowBox[{"B", "[", 
      RowBox[{"r", "+", "1"}], "]"}]]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.7369059683810787`*^9, 3.736905997332217*^9}, {
   3.736916957718183*^9, 3.7369169581401043`*^9}, {3.7369193413123198`*^9, 
   3.7369193415433064`*^9}, {3.7369259131886806`*^9, 3.736925913376774*^9}, 
   3.736943977385257*^9, {3.736944020197422*^9, 
   3.736944036157935*^9}},ExpressionUUID->"f642dcdb-f9f6-4d03-9288-\
d8c029a6e7d4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{"1", "+", 
     RowBox[{"2", " ", "r"}]}], 
    RowBox[{"dim", "+", 
     RowBox[{"2", " ", "r"}]}]], ",", 
   FractionBox[
    RowBox[{"3", "+", 
     RowBox[{"4", " ", "r", " ", 
      RowBox[{"(", 
       RowBox[{"2", "+", "r"}], ")"}]}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"dim", "+", 
       RowBox[{"2", " ", "r"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"2", "+", "dim", "+", 
       RowBox[{"2", " ", "r"}]}], ")"}]}]], ",", 
   FractionBox[
    RowBox[{"3", "+", 
     RowBox[{"2", " ", "r"}]}], 
    RowBox[{"2", "+", "dim", "+", 
     RowBox[{"2", " ", "r"}]}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.736905980172008*^9, 3.73690599835153*^9}, 
   3.736906030708213*^9, {3.7369169527732964`*^9, 3.736916958664093*^9}, {
   3.736919341970129*^9, 3.736919346351637*^9}, 3.736925917364929*^9, {
   3.736944036716361*^9, 3.736944043255599*^9}, 3.7369448137710333`*^9, 
   3.736945737440893*^9, {3.736945801853591*^9, 3.736945818527402*^9}, 
   3.7369458895444813`*^9, 
   3.7369461045539103`*^9},ExpressionUUID->"cf504ef3-3667-4f72-b81a-\
55d607a99fd5"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   StyleBox[
    RowBox[{
     RowBox[{
     "General", " ", "form", " ", "of", " ", "integrals", " ", "over", " ", 
      StyleBox["k",
       FontWeight->"Bold"]}], ",", 
     RowBox[{
      RowBox[{"e", ".", "g", ".", 
       FormBox[
        RowBox[{
         RowBox[{"\[Integral]", 
          RowBox[{
           SubscriptBox["k", "i"], 
           SuperscriptBox[
            RowBox[{
             SubscriptBox["k", "j"], "(", 
             StyleBox[
              RowBox[{"k", ".", 
               FractionBox["g", 
                StyleBox["g",
                 FontWeight->"Plain"]]}],
              FontWeight->"Bold"], ")"}], "n"], 
           RowBox[{"\[DifferentialD]", 
            StyleBox["k",
             FontWeight->"Bold"]}]}]}], "="}],
        TraditionalForm]}], 
      FormBox[
       RowBox[{
        RowBox[{
         SubsuperscriptBox["\[Alpha]", "0", "2"], 
         FractionBox[
          RowBox[{
           SubscriptBox["g", "i"], 
           SubscriptBox["g", "j"]}], 
          SuperscriptBox["g", "2"]]}], "+", 
        RowBox[{
         SubsuperscriptBox["\[Alpha]", "1", "2"], 
         SubscriptBox["\[Delta]", "ij"]}]}],
       TraditionalForm]}]}],
    FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"range", "[", 
     RowBox[{"i_", ",", "j_"}], "]"}], "=", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"j", "<", "i"}], "||", 
       RowBox[{"j", "\[LessEqual]", "0"}], "||", 
       RowBox[{"i", "<", "0"}]}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"i", "\[Equal]", "0"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"1", ",", "j"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"i", ",", "j"}], "]"}]}], "]"}]}], "]"}]}], ";", 
   RowBox[{
    RowBox[{"intform", "[", "idx_", "]"}], ":=", 
    RowBox[{"Block", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "\[Beta]", ",", "exp1", ",", "perm", ",", "exp", ",", "gg", ",", 
        "idx1", ",", "Delta"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"\[Beta]", "=", 
        RowBox[{"Length", "[", "idx", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"gg", "[", "idx1_", "]"}], ":=", 
        RowBox[{
         UnderoverscriptBox["\[Product]", 
          RowBox[{"ii", "=", "1"}], 
          RowBox[{"Length", "[", "idx1", "]"}]], 
         FractionBox[
          RowBox[{"g", "[", 
           RowBox[{"{", 
            RowBox[{
            "idx1", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}], 
            "}"}], "]"}], "g"]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Delta", "[", 
         RowBox[{"idx1_", ",", "idx2_"}], "]"}], ":=", 
        RowBox[{
         UnderoverscriptBox["\[Product]", 
          RowBox[{"ii", "=", "1"}], 
          RowBox[{"Length", "[", "idx1", "]"}]], 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"Sort", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
             "idx1", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}], 
             ",", 
             RowBox[{
             "idx2", "\[LeftDoubleBracket]", "ii", 
              "\[RightDoubleBracket]"}]}], "}"}], "]"}], "]"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"exp1", "=", 
        RowBox[{
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"\[Gamma]", "=", "0"}], 
          RowBox[{"\[Beta]", "/", "2"}]], 
         RowBox[{
          RowBox[{"Delta", "[", 
           RowBox[{
            RowBox[{"idx", "\[LeftDoubleBracket]", 
             RowBox[{"range", "[", 
              RowBox[{"1", ",", "\[Gamma]"}], "]"}], 
             "\[RightDoubleBracket]"}], ",", 
            RowBox[{"idx", "\[LeftDoubleBracket]", 
             RowBox[{"range", "[", 
              RowBox[{
               RowBox[{"\[Gamma]", "+", "1"}], ",", 
               RowBox[{"2", "\[Gamma]"}]}], "]"}], 
             "\[RightDoubleBracket]"}]}], "]"}], 
          RowBox[{"\[Alpha]", "[", 
           RowBox[{"\[Gamma]", ",", "\[Beta]"}], "]"}], 
          RowBox[{"gg", "[", 
           RowBox[{"idx", "\[LeftDoubleBracket]", 
            RowBox[{"range", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"2", "\[Gamma]"}], "+", "1"}], ",", "\[Beta]"}], "]"}],
             "\[RightDoubleBracket]"}], "]"}]}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"perm", "=", 
        RowBox[{"Permutations", "[", "idx", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"exp", "=", "0"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Do", "[", 
        RowBox[{
         RowBox[{"exp", "+=", 
          RowBox[{"exp1", "/.", 
           RowBox[{"Thread", "[", 
            RowBox[{"idx", "\[Rule]", 
             RowBox[{
             "perm", "\[LeftDoubleBracket]", "ii", 
              "\[RightDoubleBracket]"}]}], "]"}]}]}], ",", 
         RowBox[{"{", 
          RowBox[{"ii", ",", "1", ",", 
           RowBox[{"Length", "[", "perm", "]"}]}], "}"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"exp", "=", 
        RowBox[{"Sort", "[", "exp", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Collect", "[", 
        RowBox[{
         RowBox[{"ExpandAll", "[", 
          FractionBox[
           RowBox[{"exp", "/.", 
            RowBox[{"\[Delta]", "\[Rule]", "DeltaTensor"}]}], 
           RowBox[{"Length", "[", "perm", "]"}]], "]"}], ",", 
         RowBox[{"\[Alpha]", "[", 
          RowBox[{"_", ",", "_"}], "]"}], ",", "Simplify"}], "]"}]}]}], 
     "\[IndentingNewLine]", "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.736906097016273*^9, 3.7369060994112673`*^9}, 
   3.7369071490914516`*^9, 3.736907441324892*^9, {3.7369075456645403`*^9, 
   3.736907582797571*^9}, {3.736907677740307*^9, 3.736907684243194*^9}, {
   3.736907872135254*^9, 3.736907966138248*^9}, {3.73690804787066*^9, 
   3.73690804818004*^9}, {3.736908096593272*^9, 3.7369082659328537`*^9}, {
   3.736908399939362*^9, 3.736908439911964*^9}, {3.736908503445677*^9, 
   3.736908539626677*^9}, {3.73690858035642*^9, 3.736908685952475*^9}, {
   3.7369087282339563`*^9, 3.7369087637284403`*^9}, {3.736908806345924*^9, 
   3.7369088633688*^9}, {3.736909166104995*^9, 3.736909178981028*^9}, 
   3.736909880010206*^9, {3.736909941505691*^9, 3.736909950887566*^9}, {
   3.736909981850313*^9, 3.7369100502543507`*^9}, {3.736919551838657*^9, 
   3.73691957801045*^9}, {3.736919664582204*^9, 3.736919666139063*^9}, {
   3.7369440748503933`*^9, 3.736944104756591*^9}, {3.7369444818068733`*^9, 
   3.7369445220568113`*^9}, 3.736944598883333*^9, 3.73694588505689*^9, {
   3.7369459469857607`*^9, 3.736945958647559*^9}, {3.7372659221913853`*^9, 
   3.737265934689365*^9}},ExpressionUUID->"73a8f965-a4a9-4e3d-909d-\
d7a42ecc86d4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   StyleBox[
    RowBox[{
     RowBox[{"Values", " ", "of", " ", "integrals", " ", "over", " ", 
      StyleBox["k",
       FontWeight->"Bold"]}], ",", " ", 
     RowBox[{"e", ".", "g", "."}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Integral]", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           StyleBox[
            RowBox[{"k", ".", "g"}],
            FontWeight->"Bold"], ")"}], "n"], 
         SubscriptBox["k", 
          SubscriptBox["i", "1"]], 
         SubscriptBox["k", 
          SubscriptBox["i", "2"]]}]}], "..."}], 
      SubscriptBox["k", 
       SubscriptBox["i", "n"]], 
      RowBox[{"\[DifferentialD]", 
       StyleBox["k",
        FontWeight->"Bold"]}]}]}],
    FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Clear", "[", "B", "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"kint", "[", "idx_", "]"}], ":=", 
    RowBox[{"Block", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "pow", ",", "\[Beta]", ",", "factors", ",", "intformaftermulti", ",", 
        "list", ",", "alphas", ",", "eqns", ",", "gg"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"\[Beta]", "=", 
        RowBox[{"Length", "[", "idx", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"pow", "=", "\[Beta]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{
          RowBox[{"eqn", "[", "1", "]"}], "=", 
          RowBox[{
           RowBox[{"B", "[", 
            RowBox[{"Simplify", "[", 
             FractionBox[
              RowBox[{"pow", "+", "\[Beta]"}], "2"], "]"}], "]"}], "\[Equal]", 
           RowBox[{
            SuperscriptBox["g", "pow"], 
            RowBox[{"intform", "[", "idx", "]"}]}]}]}], ";"}], "*)"}], 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"gg", "[", "idx1_", "]"}], ":=", 
        RowBox[{
         UnderoverscriptBox["\[Product]", 
          RowBox[{"ii", "=", "1"}], 
          RowBox[{"Length", "[", "idx1", "]"}]], 
         FractionBox[
          RowBox[{"g", "[", 
           RowBox[{"{", 
            RowBox[{
            "idx1", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}], 
            "}"}], "]"}], "g"]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"factors", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Apply", "[", 
           RowBox[{"Times", ",", 
            RowBox[{"Flatten", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"gg", "[", 
                RowBox[{"Drop", "[", 
                 RowBox[{"idx", ",", 
                  RowBox[{
                   RowBox[{"-", "2"}], "ii"}]}], "]"}], "]"}], ",", 
               RowBox[{"\[Delta]", "/@", 
                RowBox[{"Partition", "[", 
                 RowBox[{
                  RowBox[{"Take", "[", 
                   RowBox[{"idx", ",", 
                    RowBox[{
                    RowBox[{"-", "2"}], "ii"}]}], "]"}], ",", "2"}], 
                 "]"}]}]}], "}"}], "]"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"ii", ",", "0", ",", 
            RowBox[{
             RowBox[{"Length", "[", "idx", "]"}], "/", "2"}]}], "}"}]}], 
         "]"}]}], ";", 
       RowBox[{"(*", 
        RowBox[{"Join", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"gg", "[", "idx", "]"}], "}"}], ",", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"Apply", "[", 
             RowBox[{"Times", ",", 
              RowBox[{"Flatten", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"gg", "[", 
                  RowBox[{"Drop", "[", 
                   RowBox[{"idx", ",", 
                    RowBox[{
                    RowBox[{"-", "2"}], "ii"}]}], "]"}], "]"}], ",", 
                 RowBox[{"\[Delta]", "/@", 
                  RowBox[{"Partition", "[", 
                   RowBox[{
                    RowBox[{"Take", "[", 
                    RowBox[{"idx", ",", 
                    RowBox[{
                    RowBox[{"-", "2"}], "ii"}]}], "]"}], ",", "2"}], 
                   "]"}]}]}], "}"}], "]"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"ii", ",", "1", ",", 
              RowBox[{
               RowBox[{"Length", "[", "idx", "]"}], "/", "2"}]}], "}"}]}], 
           "]"}]}], "]"}], "*)"}], "\[IndentingNewLine]", 
       RowBox[{"(*", "factors", "*)"}], "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"intformaftermulti", "=", 
        RowBox[{"Expand", "[", 
         RowBox[{
          RowBox[{"intform", "[", "idx", "]"}], "factors"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"list", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Length", "[", 
           RowBox[{"Drop", "[", 
            RowBox[{"idx", ",", 
             RowBox[{
              RowBox[{"-", "2"}], "ii"}]}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"ii", ",", "0", ",", 
            RowBox[{
             RowBox[{"Length", "[", "idx", "]"}], "/", "2"}]}], "}"}]}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"eqns", "=", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["g", "pow"], 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"B", "[", 
              RowBox[{"Simplify", "[", 
               FractionBox[
                RowBox[{"pow", "+", 
                 RowBox[{
                 "list", "\[LeftDoubleBracket]", "ii", 
                  "\[RightDoubleBracket]"}]}], "2"], "]"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"ii", ",", "1", ",", 
               RowBox[{"Length", "[", "list", "]"}]}], "}"}]}], "]"}]}], 
          "\[Equal]", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{
             SuperscriptBox["g", "pow"], 
             RowBox[{"Einstein", "[", 
              RowBox[{
              "intformaftermulti", "\[LeftDoubleBracket]", "ii", 
               "\[RightDoubleBracket]"}], "]"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"ii", ",", "1", ",", 
              RowBox[{"Length", "[", "intformaftermulti", "]"}]}], "}"}]}], 
           "]"}]}], "/.", 
         RowBox[{"{", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"g", "[", 
             RowBox[{"{", "_", "}"}], "]"}], "2"], "\[Rule]", 
           SuperscriptBox["g", "2"]}], "}"}]}]}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"alphas", "=", 
        RowBox[{
         RowBox[{"Simplify", "[", 
          RowBox[{"Solve", "[", 
           RowBox[{"eqns", ",", 
            RowBox[{"Extract", "[", 
             RowBox[{
              RowBox[{"intform", "[", "idx", "]"}], ",", 
              RowBox[{"Position", "[", 
               RowBox[{
                RowBox[{"intform", "[", "idx", "]"}], ",", 
                RowBox[{"\[Alpha]", "[", 
                 RowBox[{"_", ",", "_"}], "]"}]}], "]"}]}], "]"}]}], "]"}], 
          "]"}], "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
       ";", "\[IndentingNewLine]", "alphas"}]}], "\[IndentingNewLine]", 
     "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.7369100745346737`*^9, 3.736910132995966*^9}, {
   3.73691022659793*^9, 3.736910250744864*^9}, {3.736910281668597*^9, 
   3.736910297910387*^9}, {3.7369103658419037`*^9, 3.736910405563429*^9}, {
   3.736910591327293*^9, 3.7369106255436277`*^9}, {3.736910656257234*^9, 
   3.736910750196639*^9}, {3.736911049622835*^9, 3.7369110601021423`*^9}, {
   3.736911239784625*^9, 3.736911268909232*^9}, {3.73691405095881*^9, 
   3.736914078095009*^9}, {3.736914366076579*^9, 3.736914395736459*^9}, {
   3.736914431063031*^9, 3.736914441325923*^9}, {3.736914474213986*^9, 
   3.736914571665707*^9}, {3.7369213183982286`*^9, 3.736921403804656*^9}, {
   3.736921446365354*^9, 3.736921447229228*^9}, {3.736921681690722*^9, 
   3.7369216845775757`*^9}, {3.73692177155293*^9, 3.736921773844635*^9}, {
   3.736921818646865*^9, 3.7369218350865602`*^9}, {3.736921865642324*^9, 
   3.736921900225636*^9}, {3.7369219319972553`*^9, 3.736922025653954*^9}, {
   3.7369223355873203`*^9, 3.736922354183971*^9}, {3.736922387024332*^9, 
   3.736922508577649*^9}, {3.736922563690387*^9, 3.736922583328568*^9}, {
   3.736922968091776*^9, 3.7369229728111143`*^9}, {3.736923713755473*^9, 
   3.736923730918229*^9}, {3.736923870424797*^9, 3.7369238944377203`*^9}, {
   3.736924813133884*^9, 3.736924827484396*^9}, {3.736924987969734*^9, 
   3.7369250214457293`*^9}, 3.73692520722558*^9, {3.736925297562553*^9, 
   3.736925382768395*^9}, 3.7369254436033688`*^9, {3.7369254813400717`*^9, 
   3.7369254870349617`*^9}, 3.736925526292924*^9, {3.73692560906558*^9, 
   3.736925630182569*^9}, {3.736925664634647*^9, 3.7369256692710457`*^9}, {
   3.73692575322656*^9, 3.736925759737006*^9}, 3.736926427093626*^9, 
   3.736926468338003*^9, 3.736926526529089*^9, {3.736927061167759*^9, 
   3.7369271032602243`*^9}, 3.7369272021812677`*^9, {3.736927312064184*^9, 
   3.7369273823726673`*^9}, {3.736927431102604*^9, 3.736927469118387*^9}, {
   3.736927501192852*^9, 3.736927508247607*^9}, {3.736927579008955*^9, 
   3.7369276084713182`*^9}, 3.736927698051108*^9, 3.736927828374116*^9, 
   3.736928074512824*^9, 3.7369281264341507`*^9, {3.7369428304809923`*^9, 
   3.736942839840691*^9}, {3.736942889998458*^9, 3.7369428945021887`*^9}, {
   3.736942962256591*^9, 3.736942966902293*^9}, {3.73694368133209*^9, 
   3.7369436843829403`*^9}, {3.736943778087233*^9, 3.736943788478709*^9}, {
   3.7369445566817636`*^9, 3.7369446460613823`*^9}, {3.736946036981924*^9, 
   3.736946043104837*^9}, 3.736946079060444*^9, {3.737265350504778*^9, 
   3.737265375769023*^9}, {3.7372654140285053`*^9, 3.7372654189737*^9}, {
   3.737265943708345*^9, 3.7372659563994093`*^9}, 3.737265999153723*^9},
 ExpressionUUID -> "7ac48f95-96a7-445c-bd7a-13e2f2de7dd8"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"list", "=", 
   RowBox[{"{", 
    RowBox[{
    "i0", ",", "i1", ",", "i2", ",", "i3", ",", "i4", ",", "i5", ",", "i6"}], 
    
    RowBox[{"(*", 
     RowBox[{",", "i6", ",", "i7", ",", "i8", ",", "i9"}], "*)"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"idx", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"list", "\[LeftDoubleBracket]", 
      RowBox[{"1", ";;", "ii"}], "\[RightDoubleBracket]"}], ",", 
     RowBox[{"{", 
      RowBox[{"ii", ",", "1", ",", 
       RowBox[{"Length", "[", "list", "]"}]}], "}"}]}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.737266042573063*^9, 3.7372660494034653`*^9}, {
  3.737266242287315*^9, 3.7372662599970827`*^9}, {3.737266366159232*^9, 
  3.737266368685705*^9}, {3.737266500043556*^9, 3.7372665191827593`*^9}, {
  3.737267492037939*^9, 3.737267503027883*^9}, {3.737267588940683*^9, 
  3.737267605060719*^9}},
 ExpressionUUID -> "054b1e0a-82ab-4ba0-9a08-e833790f6560"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Flatten", "[", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"kint", "[", 
     RowBox[{"idx", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}], 
     "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"ii", ",", "1", ",", 
      RowBox[{"Length", "[", "idx", "]"}]}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.737266024798916*^9, 3.737266037595501*^9}, {
  3.7372675292388487`*^9, 3.737267559395239*^9}, {3.737267653558619*^9, 
  3.7372676632038727`*^9}, {3.737267729688732*^9, 3.73726773459692*^9}, {
  3.73726811704949*^9, 3.737268120051981*^9}, {3.737268171045351*^9, 
  3.737268176615512*^9}, {3.7372719536006117`*^9, 3.737271981309986*^9}},
 ExpressionUUID -> "1a3373ed-cd92-44e0-ac7b-5e7f8d46e85b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Alpha]", "[", 
     RowBox[{"0", ",", "1"}], "]"}], "\[Rule]", 
    RowBox[{"B", "[", "1", "]"}]}], ",", 
   RowBox[{
    RowBox[{"\[Alpha]", "[", 
     RowBox[{"0", ",", "2"}], "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"-", 
       RowBox[{"B", "[", "1", "]"}]}], "+", 
      RowBox[{"d", " ", 
       RowBox[{"B", "[", "2", "]"}]}]}], 
     RowBox[{
      RowBox[{"-", "1"}], "+", "d"}]]}], ",", 
   RowBox[{
    RowBox[{"\[Alpha]", "[", 
     RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"B", "[", "1", "]"}], "-", 
      RowBox[{"B", "[", "2", "]"}]}], 
     RowBox[{
      RowBox[{"-", "1"}], "+", "d"}]]}], ",", 
   RowBox[{
    RowBox[{"\[Alpha]", "[", 
     RowBox[{"0", ",", "3"}], "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", "3"}], " ", 
       RowBox[{"B", "[", "2", "]"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"2", "+", "d"}], ")"}], " ", 
       RowBox[{"B", "[", "3", "]"}]}]}], 
     RowBox[{
      RowBox[{"-", "1"}], "+", "d"}]]}], ",", 
   RowBox[{
    RowBox[{"\[Alpha]", "[", 
     RowBox[{"1", ",", "3"}], "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{"3", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"B", "[", "2", "]"}], "-", 
        RowBox[{"B", "[", "3", "]"}]}], ")"}]}], 
     RowBox[{
      RowBox[{"-", "1"}], "+", "d"}]]}], ",", 
   RowBox[{
    RowBox[{"\[Alpha]", "[", 
     RowBox[{"0", ",", "4"}], "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"3", " ", 
       RowBox[{"B", "[", "2", "]"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"2", "+", "d"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "6"}], " ", 
          RowBox[{"B", "[", "3", "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"4", "+", "d"}], ")"}], " ", 
          RowBox[{"B", "[", "4", "]"}]}]}], ")"}]}]}], 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["d", "2"]}]]}], ",", 
   RowBox[{
    RowBox[{"\[Alpha]", "[", 
     RowBox[{"2", ",", "4"}], "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{"3", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"B", "[", "2", "]"}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"B", "[", "3", "]"}]}], "+", 
        RowBox[{"B", "[", "4", "]"}]}], ")"}]}], 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["d", "2"]}]]}], ",", 
   RowBox[{
    RowBox[{"\[Alpha]", "[", 
     RowBox[{"1", ",", "4"}], "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", "6"}], " ", 
       RowBox[{"B", "[", "2", "]"}]}], "+", 
      RowBox[{"6", " ", 
       RowBox[{"(", 
        RowBox[{"3", "+", "d"}], ")"}], " ", 
       RowBox[{"B", "[", "3", "]"}]}], "-", 
      RowBox[{"6", " ", 
       RowBox[{"(", 
        RowBox[{"2", "+", "d"}], ")"}], " ", 
       RowBox[{"B", "[", "4", "]"}]}]}], 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["d", "2"]}]]}], ",", 
   RowBox[{
    RowBox[{"\[Alpha]", "[", 
     RowBox[{"0", ",", "5"}], "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"15", " ", 
       RowBox[{"B", "[", "3", "]"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"4", "+", "d"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "10"}], " ", 
          RowBox[{"B", "[", "4", "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"6", "+", "d"}], ")"}], " ", 
          RowBox[{"B", "[", "5", "]"}]}]}], ")"}]}]}], 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["d", "2"]}]]}], ",", 
   RowBox[{
    RowBox[{"\[Alpha]", "[", 
     RowBox[{"2", ",", "5"}], "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{"15", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"B", "[", "3", "]"}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"B", "[", "4", "]"}]}], "+", 
        RowBox[{"B", "[", "5", "]"}]}], ")"}]}], 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["d", "2"]}]]}], ",", 
   RowBox[{
    RowBox[{"\[Alpha]", "[", 
     RowBox[{"1", ",", "5"}], "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{"10", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "3"}], " ", 
         RowBox[{"B", "[", "3", "]"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"7", "+", "d"}], ")"}], " ", 
         RowBox[{"B", "[", "4", "]"}]}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"4", "+", "d"}], ")"}], " ", 
         RowBox[{"B", "[", "5", "]"}]}]}], ")"}]}], 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["d", "2"]}]]}], ",", 
   RowBox[{
    RowBox[{"\[Alpha]", "[", 
     RowBox[{"0", ",", "6"}], "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", "15"}], " ", 
       RowBox[{"B", "[", "3", "]"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"4", "+", "d"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"45", " ", 
          RowBox[{"B", "[", "4", "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"6", "+", "d"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "15"}], " ", 
             RowBox[{"B", "[", "5", "]"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"8", "+", "d"}], ")"}], " ", 
             RowBox[{"B", "[", "6", "]"}]}]}], ")"}]}]}], ")"}]}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "d"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "d"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", "d"}], ")"}]}]]}], ",", 
   RowBox[{
    RowBox[{"\[Alpha]", "[", 
     RowBox[{"3", ",", "6"}], "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{"15", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"B", "[", "3", "]"}], "-", 
        RowBox[{"3", " ", 
         RowBox[{"B", "[", "4", "]"}]}], "+", 
        RowBox[{"3", " ", 
         RowBox[{"B", "[", "5", "]"}]}], "-", 
        RowBox[{"B", "[", "6", "]"}]}], ")"}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "d"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "d"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", "d"}], ")"}]}]]}], ",", 
   RowBox[{
    RowBox[{"\[Alpha]", "[", 
     RowBox[{"2", ",", "6"}], "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{"45", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"B", "[", "3", "]"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"6", "+", "d"}], ")"}], " ", 
         RowBox[{"B", "[", "4", "]"}]}], "-", 
        RowBox[{"9", " ", 
         RowBox[{"B", "[", "5", "]"}]}], "-", 
        RowBox[{"2", " ", "d", " ", 
         RowBox[{"B", "[", "5", "]"}]}], "+", 
        RowBox[{"4", " ", 
         RowBox[{"B", "[", "6", "]"}]}], "+", 
        RowBox[{"d", " ", 
         RowBox[{"B", "[", "6", "]"}]}]}], ")"}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "d"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "d"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", "d"}], ")"}]}]]}], ",", 
   RowBox[{
    RowBox[{"\[Alpha]", "[", 
     RowBox[{"1", ",", "6"}], "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{"15", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         RowBox[{"B", "[", "3", "]"}]}], "-", 
        RowBox[{"3", " ", 
         RowBox[{"(", 
          RowBox[{"9", "+", 
           RowBox[{"2", " ", "d"}]}], ")"}], " ", 
         RowBox[{"B", "[", "4", "]"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"4", "+", "d"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"12", "+", "d"}], ")"}], " ", 
            RowBox[{"B", "[", "5", "]"}]}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"6", "+", "d"}], ")"}], " ", 
            RowBox[{"B", "[", "6", "]"}]}]}], ")"}]}]}], ")"}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "d"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "d"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", "d"}], ")"}]}]]}], ",", 
   RowBox[{
    RowBox[{"\[Alpha]", "[", 
     RowBox[{"0", ",", "7"}], "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", "105"}], " ", 
       RowBox[{"B", "[", "4", "]"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"6", "+", "d"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"105", " ", 
          RowBox[{"B", "[", "5", "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"8", "+", "d"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "21"}], " ", 
             RowBox[{"B", "[", "6", "]"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"10", "+", "d"}], ")"}], " ", 
             RowBox[{"B", "[", "7", "]"}]}]}], ")"}]}]}], ")"}]}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "d"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "d"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", "d"}], ")"}]}]]}], ",", 
   RowBox[{
    RowBox[{"\[Alpha]", "[", 
     RowBox[{"3", ",", "7"}], "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{"105", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"B", "[", "4", "]"}], "-", 
        RowBox[{"3", " ", 
         RowBox[{"B", "[", "5", "]"}]}], "+", 
        RowBox[{"3", " ", 
         RowBox[{"B", "[", "6", "]"}]}], "-", 
        RowBox[{"B", "[", "7", "]"}]}], ")"}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "d"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "d"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", "d"}], ")"}]}]]}], ",", 
   RowBox[{
    RowBox[{"\[Alpha]", "[", 
     RowBox[{"2", ",", "7"}], "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{"105", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "3"}], " ", 
         RowBox[{"B", "[", "4", "]"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"12", "+", "d"}], ")"}], " ", 
         RowBox[{"B", "[", "5", "]"}]}], "-", 
        RowBox[{"15", " ", 
         RowBox[{"B", "[", "6", "]"}]}], "-", 
        RowBox[{"2", " ", "d", " ", 
         RowBox[{"B", "[", "6", "]"}]}], "+", 
        RowBox[{"6", " ", 
         RowBox[{"B", "[", "7", "]"}]}], "+", 
        RowBox[{"d", " ", 
         RowBox[{"B", "[", "7", "]"}]}]}], ")"}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "d"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "d"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", "d"}], ")"}]}]]}], ",", 
   RowBox[{
    RowBox[{"\[Alpha]", "[", 
     RowBox[{"1", ",", "7"}], "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{"21", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"15", " ", 
         RowBox[{"B", "[", "4", "]"}]}], "-", 
        RowBox[{"5", " ", 
         RowBox[{"(", 
          RowBox[{"15", "+", 
           RowBox[{"2", " ", "d"}]}], ")"}], " ", 
         RowBox[{"B", "[", "5", "]"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"6", "+", "d"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"18", "+", "d"}], ")"}], " ", 
            RowBox[{"B", "[", "6", "]"}]}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"8", "+", "d"}], ")"}], " ", 
            RowBox[{"B", "[", "7", "]"}]}]}], ")"}]}]}], ")"}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "d"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "d"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", "d"}], ")"}]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.737266263073064*^9, {3.737267582623047*^9, 3.737267617450489*^9}, 
   3.737267672778481*^9, 3.737267743409877*^9, 3.737268128659215*^9, 
   3.737268186192539*^9, 3.737271937466202*^9, {3.737271968287979*^9, 
   3.737271990223226*^9}},
 ExpressionUUID -> "3589dd77-8596-4efd-b671-bae752459087"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"105", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"B", "[", "7", "]"}], "-", 
         RowBox[{"3", " ", 
          RowBox[{"B", "[", "6", "]"}]}], "+", 
         RowBox[{"3", " ", 
          RowBox[{"B", "[", "5", "]"}]}], "-", 
         RowBox[{"B", "[", "4", "]"}]}], ")"}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"d", "+", "3"}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["d", "2"], "-", "1"}], ")"}]}]]}], "-", 
    RowBox[{"\[Alpha]", "[", 
     RowBox[{"3", ",", "7"}], "]"}]}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Alpha]", "[", 
      RowBox[{"3", ",", "7"}], "]"}], "\[Rule]", 
     FractionBox[
      RowBox[{"105", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"B", "[", "4", "]"}], "-", 
         RowBox[{"3", " ", 
          RowBox[{"B", "[", "5", "]"}]}], "+", 
         RowBox[{"3", " ", 
          RowBox[{"B", "[", "6", "]"}]}], "-", 
         RowBox[{"B", "[", "7", "]"}]}], ")"}]}], 
      RowBox[{
       RowBox[{"-", "3"}], "-", "d", "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["d", "2"]}], "+", 
       SuperscriptBox["d", "3"]}]]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.737269103595406*^9, 3.7372692549131002`*^9}, {
  3.737269286018358*^9, 3.737269292784103*^9}, {3.737269331242979*^9, 
  3.7372693448527*^9}, {3.737269376020611*^9, 3.7372693917466707`*^9}, {
  3.7372694839047737`*^9, 3.737269546048205*^9}, {3.737269596169338*^9, 
  3.737269640943514*^9}, {3.7372696712668037`*^9, 3.737269686445812*^9}, {
  3.737269738985238*^9, 3.7372698368477383`*^9}, {3.7372698854861927`*^9, 
  3.7372699700815763`*^9}, {3.737270020448799*^9, 3.737270070451496*^9}, {
  3.737270104276718*^9, 3.737270203060178*^9}, {3.737270273582872*^9, 
  3.73727034488463*^9}, {3.7372703969588327`*^9, 3.7372704473055964`*^9}},
 ExpressionUUID -> "a626c42b-96e2-4324-9a31-50b8a81dc669"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.737269115737565*^9, 3.737269147771439*^9}, 
   3.737269191758017*^9, {3.737269230122015*^9, 3.737269255416749*^9}, 
   3.737269293736246*^9, 3.7372693457481728`*^9, {3.737269382519156*^9, 
   3.737269392180633*^9}, {3.737269497236568*^9, 3.737269546661483*^9}, 
   3.7372696092567043`*^9, 3.737269641574628*^9, 3.737269687010006*^9, 
   3.737269770889276*^9, 3.7372698060247183`*^9, 3.73726983770697*^9, 
   3.7372699089183073`*^9, {3.7372699470633097`*^9, 3.737269972654091*^9}, 
   3.737270030553163*^9, 3.737270070786373*^9, {3.7372701392707157`*^9, 
   3.7372701542356853`*^9}, 3.73727020418099*^9, {3.737270289990944*^9, 
   3.737270312542575*^9}, 3.737270345846486*^9, {3.7372704060554256`*^9, 
   3.737270447659112*^9}},
 ExpressionUUID -> "4f908229-f7d6-48f3-91da-5ea6fbdf40b5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Alpha]", "[", 
     RowBox[{"3", ",", "6"}], "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[Alpha]", "[", 
       RowBox[{"3", ",", "6"}], "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{"15", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"B", "[", "3", "]"}], "-", 
          RowBox[{"3", " ", 
           RowBox[{"B", "[", "4", "]"}]}], "+", 
          RowBox[{"3", " ", 
           RowBox[{"B", "[", "5", "]"}]}], "-", 
          RowBox[{"B", "[", "6", "]"}]}], ")"}]}], 
       RowBox[{
        RowBox[{"-", "3"}], "-", "d", "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["d", "2"]}], "+", 
        SuperscriptBox["d", "3"]}]]}], "}"}]}], "/.", 
   RowBox[{"{", 
    RowBox[{"d", "\[Rule]", "3"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.737266245948306*^9, 3.737266245971417*^9}, {
   3.737269425010118*^9, 3.737269449086185*^9}, 3.737269651563403*^9, {
   3.737269751402019*^9, 3.737269753646812*^9}},
 ExpressionUUID -> "042f3c89-9f76-47d1-8263-ffffa48cea4b"],

Cell[BoxData[
 RowBox[{
  FractionBox["5", "16"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"B", "[", "3", "]"}], "-", 
    RowBox[{"3", " ", 
     RowBox[{"B", "[", "4", "]"}]}], "+", 
    RowBox[{"3", " ", 
     RowBox[{"B", "[", "5", "]"}]}], "-", 
    RowBox[{"B", "[", "6", "]"}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.737269439784919*^9, 3.7372694495131207`*^9}, 
   3.737269652552166*^9, 3.737269754002962*^9},
 ExpressionUUID -> "69e43936-2cbf-4c9b-b6f9-dd298258597b"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Function for making traceless tensors", "Title",
 CellChangeTimes->{{3.737304002261785*^9, 3.737304011787223*^9}, {
  3.737304048399817*^9, 
  3.737304073953948*^9}},ExpressionUUID->"b4fe1fe3-fa0f-4066-bd9b-\
716789f297cd"],

Cell[CellGroupData[{

Cell["Function for contracting a tensor", "Subsubsection",
 CellChangeTimes->{{3.737445347185349*^9, 
  3.7374453615045757`*^9}},ExpressionUUID->"5201fe82-7184-4ca0-a918-\
115d1c1dc2e3"],

Cell[BoxData[{
 RowBox[{"Clear", "[", 
  RowBox[{
  "contarctedtensorsingle", ",", "contarctedtensormultiple", ",", 
   "contarctedtensor"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"contarctedtensorsingle", "[", "ex_", "]"}], ":=", 
    RowBox[{"Block", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "pos", ",", "allindices", ",", "repeatedindices", ",", "freeindices", 
        ",", "tensorname", ",", "contractedpart", ",", "idx", ",", 
        "counteachindex", ",", "checkindices", ",", 
        "number$contarctedindices", ",", "uncontarctedindices", ",", 
        "output"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Position", "[", 
           RowBox[{"ex", ",", "List"}], "]"}], "\[Equal]", 
          RowBox[{"{", "}"}]}], ",", 
         RowBox[{"output", "=", "ex"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"pos", "=", 
           RowBox[{"Drop", "[", 
            RowBox[{
             RowBox[{"Position", "[", 
              RowBox[{"ex", ",", "List"}], "]"}], ",", "None", ",", 
             RowBox[{"-", "1"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"allindices", "=", 
           RowBox[{"Tally", "[", 
            RowBox[{"Flatten", "[", 
             RowBox[{"Extract", "[", 
              RowBox[{"ex", ",", "pos"}], "]"}], "]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Max", "[", 
              RowBox[{"allindices", "\[LeftDoubleBracket]", 
               RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], "]"}], 
             ">", "2"}], ",", "\[IndentingNewLine]", 
            RowBox[{"output", "=", 
             RowBox[{"Print", "[", "\"\<\!\(\*
StyleBox[\"Please\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"check\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"the\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"repeated\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"indices\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\".\",
FontColor->RGBColor[1, 0, 0]]\)\>\"", "]"}]}], ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"tensorname", "=", 
              RowBox[{"Head", "[", "ex", "]"}]}], ";", "\[IndentingNewLine]", 
             
             RowBox[{"contractedpart", "=", 
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"Cases", "[", 
                  RowBox[{"ex", ",", "_Integer"}], "]"}], "\[Equal]", 
                 RowBox[{"{", "}"}]}], ",", "0", ",", 
                RowBox[{"First", "[", 
                 RowBox[{"Cases", "[", 
                  RowBox[{"ex", ",", "_Integer"}], "]"}], "]"}]}], "]"}]}], 
             ";", "\[IndentingNewLine]", 
             RowBox[{"freeindices", "=", 
              RowBox[{"Flatten", "[", 
               RowBox[{"Drop", "[", 
                RowBox[{
                 RowBox[{"Select", "[", 
                  RowBox[{"allindices", ",", 
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    "#", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}], "\[Equal]", "1"}], "&"}]}], 
                  "]"}], ",", "None", ",", 
                 RowBox[{"-", "1"}]}], "]"}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"repeatedindices", "=", 
              RowBox[{"Flatten", "[", 
               RowBox[{"Drop", "[", 
                RowBox[{
                 RowBox[{"Select", "[", 
                  RowBox[{"allindices", ",", 
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    "#", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}], "\[Equal]", "2"}], "&"}]}], 
                  "]"}], ",", "None", ",", 
                 RowBox[{"-", "1"}]}], "]"}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"output", "=", 
              RowBox[{"tensorname", "[", 
               RowBox[{
                RowBox[{"contractedpart", "+", 
                 RowBox[{"Length", "[", "repeatedindices", "]"}]}], ",", 
                RowBox[{"Sort", "[", "freeindices", "]"}]}], "]"}]}], ";"}]}],
            "\[IndentingNewLine]", "]"}], ";"}]}], "\[IndentingNewLine]", 
        "]"}], ";", "\[IndentingNewLine]", "output"}]}], 
     "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"contarctedtensormultiple", "[", "ex_", "]"}], ":=", 
    RowBox[{"Block", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "output", ",", "pos", ",", "counttensorindex", ",", "indicesoccurence",
         ",", "list$factorswithpowers", ",", "factors", ",", "theirpowers", 
        ",", "list$tensors", ",", "position$tensors", ",", "power$tensors"}], 
       "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"list$factorswithpowers", "=", 
        RowBox[{"FactorList", "[", "ex", "]"}]}], ";", "\[IndentingNewLine]", 
       
       RowBox[{"factors", "=", 
        RowBox[{"list$factorswithpowers", "\[LeftDoubleBracket]", 
         RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"theirpowers", "=", 
        RowBox[{"list$factorswithpowers", "\[LeftDoubleBracket]", 
         RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", 
        StyleBox[
         RowBox[{
         "condition", " ", "for", " ", "powers", " ", "in", " ", "tensors"}],
         FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
       RowBox[{"list$tensors", "=", 
        RowBox[{"Extract", "[", 
         RowBox[{"factors", ",", 
          RowBox[{"Drop", "[", 
           RowBox[{
            RowBox[{"Complement", "[", 
             RowBox[{
              RowBox[{"Position", "[", 
               RowBox[{"factors", ",", "List"}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"{", "0", "}"}], "}"}]}], "]"}], ",", "None", ",", 
            RowBox[{"-", "1"}]}], "]"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"position$tensors", "=", 
        RowBox[{"Drop", "[", 
         RowBox[{
          RowBox[{"Drop", "[", 
           RowBox[{
            RowBox[{"Complement", "[", 
             RowBox[{
              RowBox[{"Position", "[", 
               RowBox[{"factors", ",", "List"}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"{", "0", "}"}], "}"}]}], "]"}], ",", "None", ",", 
            RowBox[{"-", "1"}]}], "]"}], ",", "None", ",", 
          RowBox[{"-", "1"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"power$tensors", "=", 
        RowBox[{"Extract", "[", 
         RowBox[{"theirpowers", ",", "position$tensors"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Max", "[", "power$tensors", "]"}], ">", "2"}], ",", 
         RowBox[{"output", "=", 
          RowBox[{"Print", "[", "\"\<\!\(\*
StyleBox[\"Please\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"check\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"the\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"exponents\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"on\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"tensors\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\".\",
FontColor->RGBColor[1, 0, 0]]\)\>\"", "]"}]}], ",", 
         RowBox[{
          RowBox[{"indicesoccurence", "=", 
           RowBox[{"Tally", "[", 
            RowBox[{"Flatten", "[", 
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"ConstantArray", "[", 
                RowBox[{
                 RowBox[{
                 "list$tensors", "\[LeftDoubleBracket]", "ii", 
                  "\[RightDoubleBracket]"}], ",", 
                 RowBox[{
                 "power$tensors", "\[LeftDoubleBracket]", "ii", 
                  "\[RightDoubleBracket]"}]}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"ii", ",", 
                 RowBox[{"1", 
                  RowBox[{"Length", "[", "list$tensors", "]"}]}]}], "}"}]}], 
              "]"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Max", "[", 
              RowBox[{"indicesoccurence", "\[LeftDoubleBracket]", 
               RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], "]"}], 
             ">", "2"}], ",", "\[IndentingNewLine]", 
            RowBox[{"output", "=", 
             RowBox[{"Print", "[", "\"\<\!\(\*
StyleBox[\"Please\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"check\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"the\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"repeated\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"indices\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\".\",
FontColor->RGBColor[1, 0, 0]]\)\>\"", "]"}]}], ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"output", "=", 
              RowBox[{"Apply", "[", 
               RowBox[{"Times", ",", 
                RowBox[{"Table", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"contarctedtensorsingle", "[", 
                    RowBox[{
                    "factors", "\[LeftDoubleBracket]", "ii", 
                    "\[RightDoubleBracket]"}], "]"}], "^", 
                   RowBox[{
                   "theirpowers", "\[LeftDoubleBracket]", "ii", 
                    "\[RightDoubleBracket]"}]}], ",", 
                  RowBox[{"{", 
                   RowBox[{"ii", ",", "1", ",", 
                    RowBox[{"Length", "[", "factors", "]"}]}], "}"}]}], 
                 "]"}]}], "]"}]}], ";"}]}], "\[IndentingNewLine]", "]"}], 
          ";"}]}], "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Position", "[", 
             RowBox[{"ex", ",", "List"}], "]"}], "\[Equal]", 
            RowBox[{"{", "}"}]}], ",", 
           RowBox[{"output", "=", "ex"}], ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"pos", "=", 
             RowBox[{"Drop", "[", 
              RowBox[{
               RowBox[{"Position", "[", 
                RowBox[{"ex", ",", "List"}], "]"}], ",", "None", ",", 
               RowBox[{"-", "1"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
            RowBox[{"counteachindex", "=", 
             RowBox[{"Tally", "[", 
              RowBox[{"Flatten", "[", 
               RowBox[{"Extract", "[", 
                RowBox[{"ex", ",", "pos"}], "]"}], "]"}], "]"}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"Max", "[", 
                RowBox[{"counteachindex", "\[LeftDoubleBracket]", 
                 RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], "]"}], 
               ">", "2"}], ",", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"output", "=", 
                RowBox[{"Print", "[", "\"\<\!\(\*
StyleBox[\"Please\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"check\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"the\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"repeated\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"indices\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\".\",
FontColor->RGBColor[1, 0, 0]]\)\>\"", "]"}]}], ";"}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"output", "=", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Head", "[", "ex", "]"}], "===", " ", "Times"}], 
                  ",", 
                  RowBox[{"Apply", "[", 
                   RowBox[{"Times", ",", 
                    RowBox[{"Table", "[", 
                    RowBox[{
                    RowBox[{"contarctedtensorsingle", "[", 
                    RowBox[{
                    "ex", "\[LeftDoubleBracket]", "ii", 
                    "\[RightDoubleBracket]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"ii", ",", "1", ",", 
                    RowBox[{"Length", "[", "ex", "]"}]}], "}"}]}], "]"}]}], 
                   "]"}], ",", 
                  RowBox[{"contarctedtensorsingle", "[", "ex", "]"}]}], 
                 "]"}]}], ";"}]}], "\[IndentingNewLine]", "]"}], ";"}]}], 
          "\[IndentingNewLine]", "]"}], ";"}], "*)"}], "\[IndentingNewLine]", 
       "output"}]}], "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"contarctedtensor", "[", "ex_", "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"output", ",", "ex1"}], "}"}], ",", 
    RowBox[{
     RowBox[{"ex1", "=", 
      RowBox[{"Expand", "[", "ex", "]"}]}], ";", 
     RowBox[{"output", "=", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Head", "[", "ex1", "]"}], "===", " ", "Plus"}], ",", 
        RowBox[{"Apply", "[", 
         RowBox[{"Plus", ",", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"contarctedtensormultiple", "[", 
             RowBox[{
             "ex1", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}], 
             "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"ii", ",", "1", ",", 
              RowBox[{"Length", "[", "ex1", "]"}]}], "}"}]}], "]"}]}], "]"}], 
        ",", 
        RowBox[{"contarctedtensormultiple", "[", "ex1", "]"}]}], "]"}]}], ";",
      "\[IndentingNewLine]", "output"}]}], "\[IndentingNewLine]", 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.7373067847420597`*^9, 3.737306845687756*^9}, {
   3.73730693932476*^9, 3.737306943925753*^9}, {3.737307732434574*^9, 
   3.737307737330307*^9}, {3.737307812314247*^9, 3.73730789265221*^9}, {
   3.737308362765875*^9, 3.73730846144346*^9}, {3.7373084971934233`*^9, 
   3.737308537261639*^9}, {3.737308621386368*^9, 3.73730862177708*^9}, {
   3.737308671706202*^9, 3.737308740258708*^9}, {3.737308833149935*^9, 
   3.737308834196536*^9}, {3.737309696179824*^9, 3.737309702610691*^9}, {
   3.737309736527088*^9, 3.737309926656425*^9}, {3.737353307311985*^9, 
   3.7373533640767527`*^9}, {3.737353955972994*^9, 3.7373539922151213`*^9}, {
   3.73735473452045*^9, 3.737354798086873*^9}, {3.737354923688064*^9, 
   3.737355070094801*^9}, {3.737355246205312*^9, 3.7373552748912582`*^9}, {
   3.737355354828206*^9, 3.7373554173572807`*^9}, {3.737355941807774*^9, 
   3.737355986416884*^9}, 3.737356048212471*^9, {3.7373561190115433`*^9, 
   3.737356157188695*^9}, {3.737356327988091*^9, 3.7373563383213253`*^9}, {
   3.737356374952667*^9, 3.7373564208589497`*^9}, {3.7373566772694063`*^9, 
   3.737356678594577*^9}, {3.7373568135089207`*^9, 3.737356820285232*^9}, {
   3.737357035512478*^9, 3.737357035908517*^9}, {3.737357134695261*^9, 
   3.7373573364072037`*^9}, {3.737357407254107*^9, 3.737357415200259*^9}, {
   3.737357461303514*^9, 3.737357508606369*^9}, {3.737357555067363*^9, 
   3.737357610494637*^9}, {3.737357657501978*^9, 3.737357740774876*^9}, {
   3.737357776394527*^9, 3.737357787593939*^9}, {3.737357881852453*^9, 
   3.737358002270784*^9}, {3.7373580522198887`*^9, 3.73735807573799*^9}, {
   3.737358444834366*^9, 3.7373584965252943`*^9}, {3.737358558029749*^9, 
   3.737358597404949*^9}, 3.737358658847885*^9, {3.737358790397118*^9, 
   3.737358859499847*^9}, {3.737358899807248*^9, 3.737358934588709*^9}, {
   3.737359024941484*^9, 3.737359123613124*^9}, {3.737359248208066*^9, 
   3.737359249271846*^9}, {3.737359281088624*^9, 3.7373593080863037`*^9}, {
   3.737359375700179*^9, 3.73735938043435*^9}, {3.737359546726116*^9, 
   3.737359569812318*^9}, {3.737359691793664*^9, 3.737359716863969*^9}, {
   3.737359913750153*^9, 3.737359927126952*^9}, {3.737359991557061*^9, 
   3.737360057066595*^9}, {3.7373600949633923`*^9, 3.7373601340505753`*^9}, 
   3.73736064249551*^9, {3.7373607434184093`*^9, 3.737360748439577*^9}, 
   3.737360787658482*^9, {3.737361249587199*^9, 3.737361291010128*^9}, {
   3.737361336691976*^9, 3.737361386573201*^9}, {3.737361439871396*^9, 
   3.73736147998297*^9}, {3.7373615567885027`*^9, 3.737361560109888*^9}, {
   3.737361598228786*^9, 3.737361607866694*^9}, 3.737361648274693*^9, {
   3.73736181830634*^9, 3.737361823550358*^9}, 3.737370716785842*^9, {
   3.7373707482698393`*^9, 3.73737093013669*^9}, {3.737372355877223*^9, 
   3.7373725007915287`*^9}, {3.737372558472457*^9, 3.737372566806579*^9}, {
   3.737372611512191*^9, 3.73737269092037*^9}, {3.737373420054227*^9, 
   3.737373475643779*^9}, {3.737373866687354*^9, 3.7373739635183477`*^9}, 
   3.7373740077002153`*^9, {3.737374079714848*^9, 3.737374094911789*^9}, {
   3.73737420723624*^9, 3.737374270613062*^9}, {3.737374311463786*^9, 
   3.737374314001593*^9}, {3.737374346993307*^9, 3.737374462337899*^9}, {
   3.7373745007389297`*^9, 3.7373745545618963`*^9}, {3.737374586386669*^9, 
   3.737374597330714*^9}, {3.737374671605042*^9, 3.7373747942753477`*^9}, {
   3.737374883209215*^9, 3.737374885331951*^9}},
 ExpressionUUID -> "8cfd4115-3756-49d3-b22b-f6795dfa02b4"]
}, Closed]],

Cell[CellGroupData[{

Cell["Function for defining a traceless part of a symmetric tensor", \
"Subsubsection",
 CellChangeTimes->{{3.73744529910393*^9, 3.737445317616681*^9}, {
  3.737445371377437*^9, 3.7374453844968567`*^9}, {3.7375211271986647`*^9, 
  3.7375211382437963`*^9}},
 ExpressionUUID -> "da6ec88e-e2b6-4d2f-a1c8-311700687c73"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Deftracefreetensor1", "[", "ex_", "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "output", ",", "pos", ",", "counttensorindex", ",", "indicesoccurence", 
       ",", "list$factorswithpowers", ",", "factors", ",", "theirpowers", ",",
        "list$tensors", ",", "position$tensors", ",", "power$tensors", ",", 
       "allsingleindices", ",", "num$freeindices", ",", 
       "contractionreplacements", ",", "listdeltas", ",", 
       "tensor\[Delta]combinations", ",", "generalform", ",", "cvalues", ",", 
       
       RowBox[{"list", "=", 
        RowBox[{"{", "}"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"product", "=", "1"}], ",", "c", ",", "d"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"list$factorswithpowers", "=", 
       RowBox[{"FactorList", "[", "ex", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"factors", "=", 
       RowBox[{"list$factorswithpowers", "\[LeftDoubleBracket]", 
        RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"theirpowers", "=", 
       RowBox[{"list$factorswithpowers", "\[LeftDoubleBracket]", 
        RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", 
       StyleBox[
        RowBox[{
        "condition", " ", "for", " ", "powers", " ", "in", " ", "tensors"}],
        FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
      RowBox[{"list$tensors", "=", 
       RowBox[{"Extract", "[", 
        RowBox[{"factors", ",", 
         RowBox[{"Drop", "[", 
          RowBox[{
           RowBox[{"Complement", "[", 
            RowBox[{
             RowBox[{"Position", "[", 
              RowBox[{"factors", ",", "List"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"{", "0", "}"}], "}"}]}], "]"}], ",", "None", ",", 
           RowBox[{"-", "1"}]}], "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"position$tensors", "=", 
       RowBox[{"Drop", "[", 
        RowBox[{
         RowBox[{"Drop", "[", 
          RowBox[{
           RowBox[{"Complement", "[", 
            RowBox[{
             RowBox[{"Position", "[", 
              RowBox[{"factors", ",", "List"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"{", "0", "}"}], "}"}]}], "]"}], ",", "None", ",", 
           RowBox[{"-", "1"}]}], "]"}], ",", "None", ",", 
         RowBox[{"-", "1"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"power$tensors", "=", 
       RowBox[{"Extract", "[", 
        RowBox[{"theirpowers", ",", "position$tensors"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Max", "[", "power$tensors", "]"}], ">", "2"}], ",", 
        RowBox[{"output", "=", 
         RowBox[{"Print", "[", "\"\<\!\(\*
StyleBox[\"Please\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"check\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"the\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"exponents\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"on\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"tensors\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\".\",
FontColor->RGBColor[1, 0, 0]]\)\>\"", "]"}]}], ",", 
        RowBox[{
         RowBox[{"indicesoccurence", "=", 
          RowBox[{"Tally", "[", 
           RowBox[{"Flatten", "[", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"ConstantArray", "[", 
               RowBox[{
                RowBox[{
                "list$tensors", "\[LeftDoubleBracket]", "ii", 
                 "\[RightDoubleBracket]"}], ",", 
                RowBox[{
                "power$tensors", "\[LeftDoubleBracket]", "ii", 
                 "\[RightDoubleBracket]"}]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"ii", ",", 
                RowBox[{"1", 
                 RowBox[{"Length", "[", "list$tensors", "]"}]}]}], "}"}]}], 
             "]"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Max", "[", 
             RowBox[{"indicesoccurence", "\[LeftDoubleBracket]", 
              RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], "]"}], 
            ">", "2"}], ",", "\[IndentingNewLine]", 
           RowBox[{"output", "=", 
            RowBox[{"Print", "[", "\"\<\!\(\*
StyleBox[\"Please\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"check\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"the\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"repeated\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"indices\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\".\",
FontColor->RGBColor[1, 0, 0]]\)\>\"", "]"}]}], ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"allsingleindices", "=", 
             RowBox[{"Sort", "[", 
              RowBox[{
               RowBox[{"Extract", "[", 
                RowBox[{"indicesoccurence", ",", 
                 RowBox[{"Drop", "[", 
                  RowBox[{
                   RowBox[{"Position", "[", 
                    RowBox[{"indicesoccurence", ",", "1"}], "]"}], ",", 
                   "None", ",", 
                   RowBox[{"-", "1"}]}], "]"}]}], "]"}], 
               "\[LeftDoubleBracket]", 
               RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], "]"}]}], 
            ";", "\[IndentingNewLine]", 
            RowBox[{"num$freeindices", "=", 
             RowBox[{"Length", "[", "allsingleindices", "]"}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"contractionreplacements", "=", 
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"list", "=", 
                RowBox[{"Join", "[", 
                 RowBox[{"list", ",", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"allsingleindices", "\[LeftDoubleBracket]", 
                    RowBox[{"2", "ii"}], "\[RightDoubleBracket]"}], "\[Rule]", 
                    RowBox[{"allsingleindices", "\[LeftDoubleBracket]", 
                    RowBox[{
                    RowBox[{"2", "ii"}], "-", "1"}], 
                    "\[RightDoubleBracket]"}]}], "}"}]}], "]"}]}], ",", 
               RowBox[{"{", 
                RowBox[{"ii", ",", 
                 RowBox[{
                  RowBox[{"Length", "[", "allsingleindices", "]"}], "/", 
                  "2"}], ",", "1", ",", 
                 RowBox[{"-", "1"}]}], "}"}]}], "]"}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"listdeltas", "=", 
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"product", "=", 
                RowBox[{"product", "*", 
                 RowBox[{"\[Delta]", "[", 
                  RowBox[{"Sort", "[", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"allsingleindices", "\[LeftDoubleBracket]", 
                    RowBox[{"2", "ii"}], "\[RightDoubleBracket]"}], ",", 
                    RowBox[{"allsingleindices", "\[LeftDoubleBracket]", 
                    RowBox[{
                    RowBox[{"2", "ii"}], "-", "1"}], 
                    "\[RightDoubleBracket]"}]}], "}"}], "]"}], "]"}]}]}], ",", 
               RowBox[{"{", 
                RowBox[{"ii", ",", 
                 RowBox[{
                  RowBox[{"Length", "[", "allsingleindices", "]"}], "/", 
                  "2"}], ",", "1", ",", 
                 RowBox[{"-", "1"}]}], "}"}]}], "]"}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"(*", 
             StyleBox[
              RowBox[{
              "list", " ", "of", " ", "tensors", " ", "formed", " ", "with", 
               " ", "free", " ", "indices", " ", "and", " ", "deltas"}],
              FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
            RowBox[{"tensor\[Delta]combinations", "=", 
             RowBox[{"Join", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"contarctedtensor", "[", 
                 RowBox[{"Einstein", "[", 
                  RowBox[{"Expand", "[", "ex", "]"}], "]"}], "]"}], "}"}], 
               ",", 
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"contarctedtensor", "[", 
                    RowBox[{"Einstein", "[", 
                    RowBox[{"Expand", "[", 
                    RowBox[{"ex", "/.", 
                    RowBox[{
                    "contractionreplacements", "\[LeftDoubleBracket]", "ii", 
                    "\[RightDoubleBracket]"}]}], "]"}], "]"}], "]"}], ")"}], 
                  RowBox[{
                  "listdeltas", "\[LeftDoubleBracket]", "ii", 
                   "\[RightDoubleBracket]"}]}], ",", 
                 RowBox[{"{", 
                  RowBox[{"ii", ",", "1", ",", 
                   RowBox[{"Length", "[", "listdeltas", "]"}]}], "}"}]}], 
                "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
            RowBox[{"generalform", "=", 
             RowBox[{
              RowBox[{"Apply", "[", 
               RowBox[{"Plus", ",", 
                RowBox[{
                 RowBox[{"Table", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"c", "[", 
                    RowBox[{"num$freeindices", ",", 
                    RowBox[{"ii", "-", "1"}]}], "]"}], 
                    RowBox[{"Simplify", "[", 
                    RowBox[{"sym", "[", 
                    RowBox[{
                    "tensor\[Delta]combinations", "\[LeftDoubleBracket]", 
                    "ii", "\[RightDoubleBracket]"}], "]"}], "]"}]}], ",", 
                   RowBox[{"{", 
                    RowBox[{"ii", ",", "1", ",", 
                    RowBox[{
                    "Length", "[", "tensor\[Delta]combinations", "]"}]}], 
                    "}"}]}], "]"}], "/.", 
                 RowBox[{
                  RowBox[{"c", "[", 
                   RowBox[{"num$freeindices", ",", "0"}], "]"}], "\[Rule]", 
                  "1"}]}]}], "]"}], "/.", 
              RowBox[{"Table", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"c", "[", 
                  RowBox[{"num$freeindices", ",", "k"}], "]"}], "\[Rule]", 
                 FractionBox[
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{"-", "1"}], ")"}], "k"], 
                  RowBox[{
                   UnderoverscriptBox["\[Product]", 
                    RowBox[{"j", "=", "0"}], 
                    RowBox[{"k", "-", "1"}]], 
                   RowBox[{"(", 
                    RowBox[{"d", "+", 
                    RowBox[{"2", "num$freeindices"}], "-", "4", "-", 
                    RowBox[{"2", "j"}]}], ")"}]}]]}], ",", 
                RowBox[{"{", 
                 RowBox[{"k", ",", "1", ",", 
                  FractionBox["num$freeindices", "2"]}], "}"}]}], "]"}]}]}], 
            ";", " ", 
            RowBox[{"(*", 
             StyleBox[
              RowBox[{
              "These", " ", "coefficients", " ", "can", " ", "be", " ", 
               "computed", " ", "separately", " ", "using", " ", "the", " ", 
               "function", " ", 
               RowBox[{"coeff$symtracefreetensor", "."}]}],
              FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
            RowBox[{"(*", 
             RowBox[{
              RowBox[{"cvalues", "=", 
               RowBox[{
                RowBox[{"Solve", "[", 
                 RowBox[{
                  RowBox[{"Table", "[", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"contarctedtensor", "[", 
                    RowBox[{"Einstein", "[", 
                    RowBox[{"generalform", "/.", 
                    RowBox[{
                    "contractionreplacements", "\[LeftDoubleBracket]", "ii", 
                    "\[RightDoubleBracket]"}]}], "]"}], "]"}], "\[Equal]", 
                    "0"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"ii", ",", "1", ",", 
                    RowBox[{"Length", "[", "contractionreplacements", "]"}]}],
                     "}"}]}], "]"}], ",", 
                  RowBox[{"Complement", "[", 
                   RowBox[{
                    RowBox[{"Table", "[", 
                    RowBox[{
                    RowBox[{"c", "[", "ii", "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"ii", ",", "1", ",", 
                    RowBox[{
                    "Length", "[", "tensor\[Delta]combinations", "]"}]}], 
                    "}"}]}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"c", "[", "1", "]"}], "}"}]}], "]"}]}], "]"}], 
                "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], ";",
               "\[IndentingNewLine]", 
              RowBox[{"output", "=", 
               RowBox[{"generalform", "/.", "cvalues"}]}], ";"}], "*)"}], 
            "\[IndentingNewLine]", 
            RowBox[{"output", "=", "generalform"}], ";"}]}], 
          "\[IndentingNewLine]", "]"}], ";"}]}], "\[IndentingNewLine]", "]"}],
       ";", "\[IndentingNewLine]", "output"}]}], "\[IndentingNewLine]", 
    "]"}]}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Deftracefreetensor", "[", "ex_", "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"output", ",", "ex1"}], "}"}], ",", 
    RowBox[{
     RowBox[{"ex1", "=", 
      RowBox[{"Expand", "[", "ex", "]"}]}], ";", 
     RowBox[{"output", "=", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Head", "[", "ex1", "]"}], "===", " ", "Plus"}], ",", 
        RowBox[{"Apply", "[", 
         RowBox[{"Plus", ",", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"Deftracefreetensor1", "[", 
             RowBox[{
             "ex1", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}], 
             "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"ii", ",", "1", ",", 
              RowBox[{"Length", "[", "ex1", "]"}]}], "}"}]}], "]"}]}], "]"}], 
        ",", 
        RowBox[{"Deftracefreetensor1", "[", "ex1", "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", "output"}]}], "\[IndentingNewLine]", 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.7373898075617027`*^9, 3.737389848088016*^9}, {
   3.737390747017433*^9, 3.737390783410701*^9}, {3.7373909218924437`*^9, 
   3.7373909571964684`*^9}, {3.737391581147747*^9, 3.737391863768633*^9}, {
   3.737391940270989*^9, 3.7373919487255783`*^9}, 3.7373921694970827`*^9, {
   3.7373924108898697`*^9, 3.7373924215206842`*^9}, {3.7373924716415358`*^9, 
   3.73739247895188*^9}, {3.73739263105202*^9, 3.7373926560021133`*^9}, {
   3.737392716046008*^9, 3.737392718037957*^9}, {3.737392759120242*^9, 
   3.7373928386483*^9}, {3.737392875537838*^9, 3.737392933496498*^9}, {
   3.737393127464574*^9, 3.737393134950301*^9}, {3.737393199951563*^9, 
   3.737393315070085*^9}, {3.7373933473438663`*^9, 3.73739341946835*^9}, {
   3.737393600269292*^9, 3.7373936463543787`*^9}, {3.737393690473794*^9, 
   3.737393691936407*^9}, {3.7373938601732063`*^9, 3.737393891885086*^9}, {
   3.737394062848123*^9, 3.737394068797803*^9}, {3.7373941052084846`*^9, 
   3.737394111150548*^9}, {3.737394173895423*^9, 3.7373942003353167`*^9}, 
   3.7373943238490143`*^9, 3.737394386971182*^9, {3.737394428833026*^9, 
   3.737394436544656*^9}, 3.737394493685444*^9, {3.737394558801825*^9, 
   3.737394562712968*^9}, {3.737394870948062*^9, 3.7373949362599382`*^9}, {
   3.737394997166273*^9, 3.737395001070047*^9}, {3.7374446250081587`*^9, 
   3.737444645011342*^9}, {3.737445021510281*^9, 3.7374450229220457`*^9}, {
   3.737445069430604*^9, 3.73744510833783*^9}, {3.7374597715314207`*^9, 
   3.7374597985171537`*^9}, {3.7375212041170464`*^9, 
   3.7375212096939707`*^9}, {3.73760163422828*^9, 3.737601667124991*^9}, {
   3.737601738048499*^9, 3.737601768513637*^9}, {3.737601993862471*^9, 
   3.737602101518778*^9}, 3.7376021364059143`*^9, {3.737602254300578*^9, 
   3.737602259313821*^9}, {3.737602310776073*^9, 3.737602322312333*^9}, {
   3.737602417530241*^9, 3.737602420583943*^9}, {3.737602556226366*^9, 
   3.737602570678252*^9}, {3.7376026722945642`*^9, 3.7376026783736258`*^9}, {
   3.7376027820423517`*^9, 3.737602782577059*^9}},
 ExpressionUUID -> "f4ddad0b-5304-417d-9e9f-85a31941015d"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellChangeTimes->{{3.737445398225095*^9, 
  3.737445400081222*^9}},ExpressionUUID->"188cf4fe-18bc-46f1-b1b5-\
a5f20086a276"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   StyleBox[
    RowBox[{"Examples", " ", "on", " ", "contracting", " ", "tensors"}],
    FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"ex", "[", "0", "]"}], "=", 
     RowBox[{
      FractionBox["1", "6"], 
      RowBox[{"A", "[", 
       RowBox[{"{", 
        RowBox[{"i1", ",", "i1"}], "}"}], "]"}], 
      RowBox[{"B", "[", 
       RowBox[{"{", 
        RowBox[{"i2", ",", "i3"}], "}"}], "]"}], 
      RowBox[{"B", "[", 
       RowBox[{"{", 
        RowBox[{"i2", ",", "i3"}], "}"}], "]"}], 
      SuperscriptBox["x", "2"], 
      SuperscriptBox[
       RowBox[{"k", "[", "2", "]"}], "3"]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ex", "[", "1", "]"}], "=", 
     RowBox[{
      FractionBox["1", "6"], 
      RowBox[{"A", "[", 
       RowBox[{"{", 
        RowBox[{"i1", ",", "i1"}], "}"}], "]"}], 
      RowBox[{"B", "[", 
       RowBox[{"{", 
        RowBox[{"i2", ",", "i3"}], "}"}], "]"}], 
      RowBox[{"B", "[", 
       RowBox[{"{", 
        RowBox[{"i2", ",", "i3"}], "}"}], "]"}], 
      RowBox[{"B", "[", 
       RowBox[{"{", 
        RowBox[{"i2", ",", "i3"}], "}"}], "]"}], 
      SuperscriptBox["x", "2"], 
      SuperscriptBox[
       RowBox[{"k", "[", "2", "]"}], "3"]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ex", "[", "2", "]"}], "=", 
     RowBox[{
      FractionBox["1", "6"], 
      RowBox[{"A", "[", 
       RowBox[{"{", 
        RowBox[{"i1", ",", "i1"}], "}"}], "]"}], 
      RowBox[{"A", "[", 
       RowBox[{"{", 
        RowBox[{"i1", ",", "i1"}], "}"}], "]"}], 
      RowBox[{"B", "[", 
       RowBox[{"{", 
        RowBox[{"i2", ",", "i3"}], "}"}], "]"}], 
      RowBox[{"B", "[", 
       RowBox[{"{", 
        RowBox[{"i2", ",", "i3"}], "}"}], "]"}], 
      SuperscriptBox["x", "2"], 
      SuperscriptBox[
       RowBox[{"k", "[", "2", "]"}], "3"]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ex", "[", "3", "]"}], "=", 
     RowBox[{
      RowBox[{"7", 
       RowBox[{"A", "[", 
        RowBox[{"{", "i", "}"}], "]"}], 
       RowBox[{"A", "[", 
        RowBox[{"{", "i", "}"}], "]"}], 
       RowBox[{"B", "[", 
        RowBox[{"{", "j", "}"}], "]"}], 
       RowBox[{"B", "[", 
        RowBox[{"{", "k", "}"}], "]"}]}], "+", 
      RowBox[{"8", 
       SuperscriptBox["x", "2"], 
       RowBox[{"A", "[", 
        RowBox[{"{", 
         RowBox[{"i1", ",", "i1"}], "}"}], "]"}], 
       RowBox[{"B", "[", 
        RowBox[{"{", 
         RowBox[{"i2", ",", "i3"}], "}"}], "]"}], 
       RowBox[{"B", "[", 
        RowBox[{"{", 
         RowBox[{"i2", ",", "i3"}], "}"}], "]"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ex", "[", "4", "]"}], "=", 
     RowBox[{"8", 
      RowBox[{"A", "[", 
       RowBox[{"{", 
        RowBox[{"i1", ",", "i1"}], "}"}], "]"}], 
      RowBox[{"B", "[", 
       RowBox[{"{", 
        RowBox[{"i2", ",", "i3"}], "}"}], "]"}], 
      RowBox[{"B", "[", 
       RowBox[{"{", 
        RowBox[{"i4", ",", "i3"}], "}"}], "]"}], 
      RowBox[{"A", "[", 
       RowBox[{"{", "i5", "}"}], "]"}], 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"i6", ",", "i7", ",", "i0"}], "}"}], "]"}], 
      SuperscriptBox["x", "2"], 
      SuperscriptBox[
       RowBox[{"k", "[", "2", "]"}], "3"], 
      RowBox[{"A", "[", 
       RowBox[{"{", "i8", "}"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ex", "[", "5", "]"}], "=", 
     RowBox[{
      RowBox[{"A", "[", 
       RowBox[{"{", "i", "}"}], "]"}], 
      RowBox[{"B", "[", 
       RowBox[{"{", "j", "}"}], "]"}], 
      RowBox[{"F", "[", 
       RowBox[{"{", "k", "}"}], "]"}], 
      RowBox[{"Y", "[", 
       RowBox[{"{", "l", "}"}], "]"}], 
      RowBox[{"Y", "[", 
       RowBox[{"{", "m", "}"}], "]"}], 
      RowBox[{"Y", "[", 
       RowBox[{"{", "m", "}"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ex", "[", "6", "]"}], "=", 
     RowBox[{"A", "[", 
      RowBox[{"4", ",", 
       RowBox[{"{", 
        RowBox[{"i1", ",", "i2", ",", "i3", ",", "i4", ",", "i5", ",", "i5"}],
         "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"contarctedtensor", "[", 
       RowBox[{"ex", "[", "ii", "]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"ii", ",", "0", ",", "6"}], "}"}]}], "]"}], "//", 
    "TableForm"}]}]}]], "Input",
 CellChangeTimes->{{3.7373691525626*^9, 3.73736916620849*^9}, {
  3.73736945251611*^9, 3.7373694553461123`*^9}, {3.73736959640558*^9, 
  3.73736959899459*^9}, {3.737369695526411*^9, 3.7373696987394*^9}, {
  3.737374132238474*^9, 3.7373741424026623`*^9}, {3.737374816994177*^9, 
  3.737374817973929*^9}, {3.7373886493364487`*^9, 3.737388725634396*^9}, {
  3.7373888277202387`*^9, 3.7373888592901163`*^9}, {3.737389051308626*^9, 
  3.7373890800048113`*^9}, {3.7373895218844643`*^9, 3.737389528926162*^9}, {
  3.73744540373221*^9, 3.73744541230724*^9}, {3.7374455788029203`*^9, 
  3.737445610263279*^9}, {3.737445762902358*^9, 3.7374457713484097`*^9}},
 ExpressionUUID -> "102c02cd-8e72-4d70-9c42-2d74f803ace6"],

Cell[CellGroupData[{

Cell[BoxData["\<\"\\!\\(\\*\\nStyleBox[\\\"Please\\\",\\nFontColor->RGBColor[\
1, 0, 0]]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"check\\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"the\\\",\\nFontColor->RGBColor[1, 0, 0]]\\)\\!\
\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"exponents\\\",\\nFontColor->RGBColor[1, 0, 0]]\
\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"on\\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"tensors\\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\".\\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\"\>"], "Print",
 CellChangeTimes->{{3.737445605271164*^9, 3.7374456110246973`*^9}, 
   3.737445771856567*^9, 3.7376022688017597`*^9},
 ExpressionUUID -> "9370f751-789f-4aa2-8da7-816656a5f4fe"],

Cell[BoxData["\<\"\\!\\(\\*\\nStyleBox[\\\"Please\\\",\\nFontColor->RGBColor[\
1, 0, 0]]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"check\\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"the\\\",\\nFontColor->RGBColor[1, 0, 0]]\\)\\!\
\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"repeated\\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"indices\\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\".\\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\"\>"], "Print",
 CellChangeTimes->{{3.737445605271164*^9, 3.7374456110246973`*^9}, 
   3.737445771856567*^9, 3.7376022688141117`*^9},
 ExpressionUUID -> "9370f751-789f-4aa2-8da7-816656a5f4fe"]
}, Open  ]],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      RowBox[{
       FractionBox["1", "6"], " ", 
       SuperscriptBox["x", "2"], " ", 
       RowBox[{"A", "[", 
        RowBox[{"1", ",", 
         RowBox[{"{", "}"}]}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{"B", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", 
           RowBox[{"i2", ",", "i3"}], "}"}]}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"k", "[", "2", "]"}], "3"]}]},
     {"Null"},
     {"Null"},
     {
      RowBox[{
       RowBox[{"7", " ", 
        SuperscriptBox[
         RowBox[{"A", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "i", "}"}]}], "]"}], "2"], " ", 
        RowBox[{"B", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "j", "}"}]}], "]"}], " ", 
        RowBox[{"B", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "k", "}"}]}], "]"}]}], "+", 
       RowBox[{"8", " ", 
        SuperscriptBox["x", "2"], " ", 
        RowBox[{"A", "[", 
         RowBox[{"1", ",", 
          RowBox[{"{", "}"}]}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{"B", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i3"}], "}"}]}], "]"}], "2"]}]}]},
     {
      RowBox[{"8", " ", 
       SuperscriptBox["x", "2"], " ", 
       RowBox[{"A", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "i5", "}"}]}], "]"}], " ", 
       RowBox[{"A", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "i8", "}"}]}], "]"}], " ", 
       RowBox[{"A", "[", 
        RowBox[{"1", ",", 
         RowBox[{"{", "}"}]}], "]"}], " ", 
       RowBox[{"B", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"i2", ",", "i3"}], "}"}]}], "]"}], " ", 
       RowBox[{"B", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"i3", ",", "i4"}], "}"}]}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{"k", "[", "2", "]"}], "3"], " ", 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"i0", ",", "i6", ",", "i7"}], "}"}]}], "]"}]}]},
     {
      RowBox[{
       RowBox[{"A", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "i", "}"}]}], "]"}], " ", 
       RowBox[{"B", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "j", "}"}]}], "]"}], " ", 
       RowBox[{"F", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "k", "}"}]}], "]"}], " ", 
       RowBox[{"Y", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "l", "}"}]}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{"Y", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "m", "}"}]}], "]"}], "2"]}]},
     {
      RowBox[{"A", "[", 
       RowBox[{"5", ",", 
        RowBox[{"{", 
         RowBox[{"i1", ",", "i2", ",", "i3", ",", "i4"}], "}"}]}], "]"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.5599999999999999]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   Column],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.737445605275734*^9, 3.737445611030652*^9}, 
   3.737445771862442*^9, 3.737602268829721*^9},
 ExpressionUUID -> "7c765338-46ba-453e-9ff7-2bd25d3d7df1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   StyleBox[
    RowBox[{"Examples", " ", "of", " ", "traceless", " ", "tensors"}],
    FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Clear", "[", "ex", "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ex", "[", "0", "]"}], "=", 
     RowBox[{
      FractionBox["1", "6"], 
      RowBox[{"A", "[", 
       RowBox[{"{", 
        RowBox[{"i1", ",", "i1"}], "}"}], "]"}], 
      RowBox[{"B", "[", 
       RowBox[{"{", 
        RowBox[{"i2", ",", "i3"}], "}"}], "]"}], 
      RowBox[{"B", "[", 
       RowBox[{"{", 
        RowBox[{"i2", ",", "i3"}], "}"}], "]"}], 
      SuperscriptBox["x", "2"], 
      SuperscriptBox[
       RowBox[{"k", "[", "2", "]"}], "3"]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ex", "[", "1", "]"}], "=", 
     RowBox[{
      FractionBox["1", "6"], 
      RowBox[{"A", "[", 
       RowBox[{"{", 
        RowBox[{"i1", ",", "i1"}], "}"}], "]"}], 
      RowBox[{"B", "[", 
       RowBox[{"{", 
        RowBox[{"i2", ",", "i3"}], "}"}], "]"}], 
      RowBox[{"B", "[", 
       RowBox[{"{", 
        RowBox[{"i2", ",", "i3"}], "}"}], "]"}], 
      RowBox[{"B", "[", 
       RowBox[{"{", 
        RowBox[{"i2", ",", "i3"}], "}"}], "]"}], 
      SuperscriptBox["x", "2"], 
      SuperscriptBox[
       RowBox[{"k", "[", "2", "]"}], "3"]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ex", "[", "2", "]"}], "=", 
     RowBox[{
      FractionBox["1", "6"], 
      RowBox[{"A", "[", 
       RowBox[{"{", 
        RowBox[{"i1", ",", "i1"}], "}"}], "]"}], 
      RowBox[{"A", "[", 
       RowBox[{"{", 
        RowBox[{"i1", ",", "i1"}], "}"}], "]"}], 
      RowBox[{"B", "[", 
       RowBox[{"{", 
        RowBox[{"i2", ",", "i3"}], "}"}], "]"}], 
      RowBox[{"B", "[", 
       RowBox[{"{", 
        RowBox[{"i2", ",", "i3"}], "}"}], "]"}], 
      SuperscriptBox["x", "2"], 
      SuperscriptBox[
       RowBox[{"k", "[", "2", "]"}], "3"]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ex", "[", "3", "]"}], "=", 
     RowBox[{
      RowBox[{"7", 
       RowBox[{"A", "[", 
        RowBox[{"{", "i", "}"}], "]"}], 
       RowBox[{"A", "[", 
        RowBox[{"{", "i", "}"}], "]"}], 
       RowBox[{"B", "[", 
        RowBox[{"{", "j", "}"}], "]"}], 
       RowBox[{"B", "[", 
        RowBox[{"{", "k", "}"}], "]"}]}], "+", 
      RowBox[{"8", 
       SuperscriptBox["x", "2"], 
       RowBox[{"A", "[", 
        RowBox[{"{", 
         RowBox[{"i1", ",", "i1"}], "}"}], "]"}], 
       RowBox[{"B", "[", 
        RowBox[{"{", 
         RowBox[{"i2", ",", "i3"}], "}"}], "]"}], 
       RowBox[{"B", "[", 
        RowBox[{"{", 
         RowBox[{"i2", ",", "i3"}], "}"}], "]"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ex", "[", "4", "]"}], "=", 
     RowBox[{
      RowBox[{"A", "[", 
       RowBox[{"{", "i", "}"}], "]"}], 
      RowBox[{"A", "[", 
       RowBox[{"{", "j", "}"}], "]"}], 
      RowBox[{"A", "[", 
       RowBox[{"{", "k", "}"}], "]"}], 
      RowBox[{"A", "[", 
       RowBox[{"{", "l", "}"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ex", "[", "5", "]"}], "=", 
     RowBox[{"A", "[", 
      RowBox[{"{", 
       RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ex", "[", "6", "]"}], "=", 
     RowBox[{"A", "[", 
      RowBox[{"4", ",", 
       RowBox[{"{", 
        RowBox[{"i1", ",", "i2", ",", "i3", ",", "i4", ",", "i5", ",", "i5"}],
         "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ex", "[", "7", "]"}], "=", 
     RowBox[{"A", "[", 
      RowBox[{"2", ",", 
       RowBox[{"{", 
        RowBox[{"i1", ",", "i2", ",", "i3", ",", "i4", ",", "i5", ",", "i6"}],
         "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ex", "[", "8", "]"}], "=", 
     RowBox[{
      RowBox[{"A", "[", 
       RowBox[{"{", "i", "}"}], "]"}], 
      RowBox[{"B", "[", 
       RowBox[{"{", "j", "}"}], "]"}], 
      RowBox[{"F", "[", 
       RowBox[{"{", "k", "}"}], "]"}], 
      RowBox[{"Y", "[", 
       RowBox[{"{", "l", "}"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"Deftracefreetensor", "[", 
       RowBox[{"ex", "[", "ii", "]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"ii", ",", "0", ",", "8"}], "}"}]}], "]"}], "//", 
    "TableForm"}]}]}]], "Input",
 CellChangeTimes->{{3.7373691525626*^9, 3.73736916620849*^9}, {
   3.73736945251611*^9, 3.7373694553461123`*^9}, {3.73736959640558*^9, 
   3.73736959899459*^9}, {3.737369695526411*^9, 3.7373696987394*^9}, {
   3.737374132238474*^9, 3.7373741424026623`*^9}, {3.737374816994177*^9, 
   3.737374817973929*^9}, {3.7373886493364487`*^9, 3.737388725634396*^9}, {
   3.7373888277202387`*^9, 3.7373888592901163`*^9}, {3.737389051308626*^9, 
   3.7373890800048113`*^9}, {3.7373895218844643`*^9, 3.737389528926162*^9}, {
   3.73744474814159*^9, 3.7374447817411346`*^9}, {3.737445465304863*^9, 
   3.737445477826214*^9}, {3.7374455344986057`*^9, 3.737445536067367*^9}, {
   3.737445791960108*^9, 3.737445802677148*^9}, 3.737446356492975*^9, {
   3.7374580562816057`*^9, 3.7374580612720613`*^9}, {3.737458145437759*^9, 
   3.7374581669209003`*^9}, {3.7376025864905787`*^9, 3.737602586993412*^9}},
 ExpressionUUID -> "af962f22-3a9b-47ef-85fa-26b5fd0f4f9f"],

Cell[CellGroupData[{

Cell[BoxData["\<\"\\!\\(\\*\\nStyleBox[\\\"Please\\\",\\nFontColor->RGBColor[\
1, 0, 0]]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"check\\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"the\\\",\\nFontColor->RGBColor[1, 0, 0]]\\)\\!\
\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"exponents\\\",\\nFontColor->RGBColor[1, 0, 0]]\
\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"on\\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"tensors\\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\".\\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\"\>"], "Print",
 CellChangeTimes->{3.737458062079239*^9, 3.737458168091425*^9, 
  3.7376021615947247`*^9, 3.7376022778829813`*^9, 3.737602338168866*^9, 
  3.7376024421803513`*^9, 3.737602588802977*^9, 3.737602690529464*^9},
 ExpressionUUID -> "3142f3ab-bb51-4d33-8cd7-0513e12138bf"],

Cell[BoxData["\<\"\\!\\(\\*\\nStyleBox[\\\"Please\\\",\\nFontColor->RGBColor[\
1, 0, 0]]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"check\\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"the\\\",\\nFontColor->RGBColor[1, 0, 0]]\\)\\!\
\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"repeated\\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"indices\\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\".\\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\"\>"], "Print",
 CellChangeTimes->{3.737458062079239*^9, 3.737458168091425*^9, 
  3.7376021615947247`*^9, 3.7376022778829813`*^9, 3.737602338168866*^9, 
  3.7376024421803513`*^9, 3.737602588802977*^9, 3.737602690538669*^9},
 ExpressionUUID -> "3142f3ab-bb51-4d33-8cd7-0513e12138bf"]
}, Open  ]],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      RowBox[{
       FractionBox["1", "6"], " ", 
       SuperscriptBox["x", "2"], " ", 
       RowBox[{"A", "[", 
        RowBox[{"1", ",", 
         RowBox[{"{", "}"}]}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{"B", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", 
           RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"k", "[", "2", "]"}], "3"]}]},
     {"Null"},
     {"Null"},
     {
      RowBox[{
       RowBox[{"7", " ", 
        SuperscriptBox[
         RowBox[{"A", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
        RowBox[{"B", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "j", "}"}]}], "]"}], " ", 
        RowBox[{"B", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "k", "}"}]}], "]"}]}], "+", 
       RowBox[{"8", " ", 
        SuperscriptBox["x", "2"], " ", 
        RowBox[{"A", "[", 
         RowBox[{"1", ",", 
          RowBox[{"{", "}"}]}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{"B", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", 
            RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], "2"]}], "-", 
       FractionBox[
        RowBox[{"7", " ", 
         SuperscriptBox[
          RowBox[{"A", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"B", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "p1", "}"}]}], "]"}], "2"], " ", 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "d"]}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "i", "}"}]}], "]"}], " ", 
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "j", "}"}]}], "]"}], " ", 
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "k", "}"}]}], "]"}], " ", 
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "l", "}"}]}], "]"}]}], "+", 
       FractionBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"A", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"A", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "p1", "}"}]}], "]"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "l"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "k"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"k", ",", "l"}], "}"}], "]"}]}]}], ")"}]}], 
        RowBox[{"3", " ", 
         RowBox[{"(", 
          RowBox[{"2", "+", "d"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"4", "+", "d"}], ")"}]}]], "-", 
       FractionBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"A", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "i", "}"}]}], "]"}], " ", 
            RowBox[{"A", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "l", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "k", "}"}]}], "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"A", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", "l", "}"}]}], "]"}], " ", 
               RowBox[{"\[Delta]", "[", 
                RowBox[{"{", 
                 RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{"A", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", "j", "}"}]}], "]"}], " ", 
               RowBox[{"\[Delta]", "[", 
                RowBox[{"{", 
                 RowBox[{"i", ",", "l"}], "}"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{"A", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", "i", "}"}]}], "]"}], " ", 
               RowBox[{"\[Delta]", "[", 
                RowBox[{"{", 
                 RowBox[{"j", ",", "l"}], "}"}], "]"}]}]}], ")"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "j", "}"}]}], "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"A", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", "l", "}"}]}], "]"}], " ", 
               RowBox[{"\[Delta]", "[", 
                RowBox[{"{", 
                 RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{"A", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", "i", "}"}]}], "]"}], " ", 
               RowBox[{"\[Delta]", "[", 
                RowBox[{"{", 
                 RowBox[{"k", ",", "l"}], "}"}], "]"}]}]}], ")"}]}]}], 
          ")"}]}], 
        RowBox[{"6", " ", 
         RowBox[{"(", 
          RowBox[{"4", "+", "d"}], ")"}]}]]}]},
     {
      RowBox[{
       RowBox[{"A", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}]}], "]"}], "-", 
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"1", ",", 
            RowBox[{"{", 
             RowBox[{"k", ",", "l"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"1", ",", 
            RowBox[{"{", 
             RowBox[{"j", ",", "l"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"1", ",", 
            RowBox[{"{", 
             RowBox[{"j", ",", "k"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i", ",", "l"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"1", ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "l"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"1", ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "k"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"1", ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "j"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"k", ",", "l"}], "}"}], "]"}]}]}], 
        RowBox[{"6", " ", 
         RowBox[{"(", 
          RowBox[{"4", "+", "d"}], ")"}]}]], "+", 
       FractionBox[
        RowBox[{
         RowBox[{"A", "[", 
          RowBox[{"2", ",", 
           RowBox[{"{", "}"}]}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "l"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "k"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"k", ",", "l"}], "}"}], "]"}]}]}], ")"}]}], 
        RowBox[{"3", " ", 
         RowBox[{"(", 
          RowBox[{"2", "+", "d"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"4", "+", "d"}], ")"}]}]]}]},
     {
      RowBox[{
       RowBox[{"A", "[", 
        RowBox[{"5", ",", 
         RowBox[{"{", 
          RowBox[{"i1", ",", "i2", ",", "i3", ",", "i4"}], "}"}]}], "]"}], 
       "-", 
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"6", ",", 
            RowBox[{"{", 
             RowBox[{"i3", ",", "i4"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i2"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"6", ",", 
            RowBox[{"{", 
             RowBox[{"i2", ",", "i4"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i3"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"6", ",", 
            RowBox[{"{", 
             RowBox[{"i2", ",", "i3"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i4"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"6", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i4"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i3"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"6", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i3"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i4"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"6", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i2"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i3", ",", "i4"}], "}"}], "]"}]}]}], 
        RowBox[{"6", " ", 
         RowBox[{"(", 
          RowBox[{"4", "+", "d"}], ")"}]}]], "+", 
       FractionBox[
        RowBox[{
         RowBox[{"A", "[", 
          RowBox[{"7", ",", 
           RowBox[{"{", "}"}]}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i1", ",", "i4"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i2", ",", "i3"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i1", ",", "i3"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i2", ",", "i4"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i1", ",", "i2"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i3", ",", "i4"}], "}"}], "]"}]}]}], ")"}]}], 
        RowBox[{"3", " ", 
         RowBox[{"(", 
          RowBox[{"2", "+", "d"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"4", "+", "d"}], ")"}]}]]}]},
     {
      RowBox[{
       RowBox[{"A", "[", 
        RowBox[{"2", ",", 
         RowBox[{"{", 
          RowBox[{
          "i1", ",", "i2", ",", "i3", ",", "i4", ",", "i5", ",", "i6"}], 
          "}"}]}], "]"}], "-", 
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"3", ",", 
            RowBox[{"{", 
             RowBox[{"i3", ",", "i4", ",", "i5", ",", "i6"}], "}"}]}], "]"}], 
          " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i2"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"3", ",", 
            RowBox[{"{", 
             RowBox[{"i2", ",", "i4", ",", "i5", ",", "i6"}], "}"}]}], "]"}], 
          " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i3"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"3", ",", 
            RowBox[{"{", 
             RowBox[{"i2", ",", "i3", ",", "i5", ",", "i6"}], "}"}]}], "]"}], 
          " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i4"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"3", ",", 
            RowBox[{"{", 
             RowBox[{"i2", ",", "i3", ",", "i4", ",", "i6"}], "}"}]}], "]"}], 
          " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i5"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"3", ",", 
            RowBox[{"{", 
             RowBox[{"i2", ",", "i3", ",", "i4", ",", "i5"}], "}"}]}], "]"}], 
          " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i6"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"3", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i4", ",", "i5", ",", "i6"}], "}"}]}], "]"}], 
          " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i3"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"3", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i3", ",", "i5", ",", "i6"}], "}"}]}], "]"}], 
          " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i4"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"3", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i3", ",", "i4", ",", "i6"}], "}"}]}], "]"}], 
          " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i5"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"3", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i3", ",", "i4", ",", "i5"}], "}"}]}], "]"}], 
          " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i6"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"3", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i2", ",", "i5", ",", "i6"}], "}"}]}], "]"}], 
          " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i3", ",", "i4"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"3", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i2", ",", "i4", ",", "i6"}], "}"}]}], "]"}], 
          " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i3", ",", "i5"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"3", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i2", ",", "i4", ",", "i5"}], "}"}]}], "]"}], 
          " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i3", ",", "i6"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"3", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i2", ",", "i3", ",", "i6"}], "}"}]}], "]"}], 
          " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i4", ",", "i5"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"3", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i2", ",", "i3", ",", "i5"}], "}"}]}], "]"}], 
          " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i4", ",", "i6"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"3", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i2", ",", "i3", ",", "i4"}], "}"}]}], "]"}], 
          " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i5", ",", "i6"}], "}"}], "]"}]}]}], 
        RowBox[{"15", " ", 
         RowBox[{"(", 
          RowBox[{"8", "+", "d"}], ")"}]}]], "+", 
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i4", ",", "i5"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i6"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i3"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i3", ",", "i6"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i5"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i4"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i3", ",", "i5"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i6"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i4"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i3", ",", "i6"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i4"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i5"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i3", ",", "i4"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i6"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i5"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i4", ",", "i5"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i3"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i6"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i3", ",", "i5"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i4"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i6"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i3", ",", "i4"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i5"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i6"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i2", ",", "i6"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i5"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i3", ",", "i4"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i2", ",", "i5"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i6"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i3", ",", "i4"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i6"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i5"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i3", ",", "i4"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i5"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i6"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i3", ",", "i4"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i5", ",", "i6"}], "}"}]}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i1", ",", "i4"}], "}"}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i2", ",", "i3"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i1", ",", "i3"}], "}"}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i2", ",", "i4"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i1", ",", "i2"}], "}"}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i3", ",", "i4"}], "}"}], "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i2", ",", "i6"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i4"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i3", ",", "i5"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i2", ",", "i4"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i6"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i3", ",", "i5"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i6"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i4"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i3", ",", "i5"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i4"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i6"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i3", ",", "i5"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i4", ",", "i6"}], "}"}]}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i1", ",", "i5"}], "}"}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i2", ",", "i3"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i1", ",", "i3"}], "}"}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i2", ",", "i5"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i1", ",", "i2"}], "}"}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i3", ",", "i5"}], "}"}], "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i4", ",", "i5"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i2"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i3", ",", "i6"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i2", ",", "i5"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i4"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i3", ",", "i6"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i2", ",", "i4"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i5"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i3", ",", "i6"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i5"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i4"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i3", ",", "i6"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i4"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i5"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i3", ",", "i6"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i3", ",", "i6"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i2"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i4", ",", "i5"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i2", ",", "i6"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i3"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i4", ",", "i5"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i2", ",", "i3"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i6"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i4", ",", "i5"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i6"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i3"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i4", ",", "i5"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i3"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i6"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i4", ",", "i5"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i2"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i3", ",", "i6"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i4", ",", "i5"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i3", ",", "i5"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i2"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i4", ",", "i6"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i2", ",", "i5"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i3"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i4", ",", "i6"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i2", ",", "i3"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i5"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i4", ",", "i6"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i5"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i3"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i4", ",", "i6"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i3"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i5"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i4", ",", "i6"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i2"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i3", ",", "i5"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i4", ",", "i6"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i3", ",", "i4"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i2"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i5", ",", "i6"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i2", ",", "i4"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i3"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i5", ",", "i6"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i2", ",", "i3"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i4"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i5", ",", "i6"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i4"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i3"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i5", ",", "i6"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i3"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i4"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i5", ",", "i6"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i2"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i3", ",", "i4"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i5", ",", "i6"}], "}"}], "]"}]}]}], 
        RowBox[{"45", " ", 
         RowBox[{"(", 
          RowBox[{"6", "+", "d"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"8", "+", "d"}], ")"}]}]], "-", 
       FractionBox[
        RowBox[{
         RowBox[{"A", "[", 
          RowBox[{"5", ",", 
           RowBox[{"{", "}"}]}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i1", ",", "i4"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i2", ",", "i6"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i3", ",", "i5"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i1", ",", "i4"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i2", ",", "i5"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i3", ",", "i6"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i1", ",", "i3"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i2", ",", "i6"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i4", ",", "i5"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i1", ",", "i2"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i3", ",", "i6"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i4", ",", "i5"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i1", ",", "i6"}], "}"}], "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"\[Delta]", "[", 
                RowBox[{"{", 
                 RowBox[{"i2", ",", "i5"}], "}"}], "]"}], " ", 
               RowBox[{"\[Delta]", "[", 
                RowBox[{"{", 
                 RowBox[{"i3", ",", "i4"}], "}"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{"\[Delta]", "[", 
                RowBox[{"{", 
                 RowBox[{"i2", ",", "i4"}], "}"}], "]"}], " ", 
               RowBox[{"\[Delta]", "[", 
                RowBox[{"{", 
                 RowBox[{"i3", ",", "i5"}], "}"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{"\[Delta]", "[", 
                RowBox[{"{", 
                 RowBox[{"i2", ",", "i3"}], "}"}], "]"}], " ", 
               RowBox[{"\[Delta]", "[", 
                RowBox[{"{", 
                 RowBox[{"i4", ",", "i5"}], "}"}], "]"}]}]}], ")"}]}], "+", 
           RowBox[{
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i1", ",", "i3"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i2", ",", "i5"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i4", ",", "i6"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i1", ",", "i2"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i3", ",", "i5"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i4", ",", "i6"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i1", ",", "i5"}], "}"}], "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"\[Delta]", "[", 
                RowBox[{"{", 
                 RowBox[{"i2", ",", "i6"}], "}"}], "]"}], " ", 
               RowBox[{"\[Delta]", "[", 
                RowBox[{"{", 
                 RowBox[{"i3", ",", "i4"}], "}"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{"\[Delta]", "[", 
                RowBox[{"{", 
                 RowBox[{"i2", ",", "i4"}], "}"}], "]"}], " ", 
               RowBox[{"\[Delta]", "[", 
                RowBox[{"{", 
                 RowBox[{"i3", ",", "i6"}], "}"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{"\[Delta]", "[", 
                RowBox[{"{", 
                 RowBox[{"i2", ",", "i3"}], "}"}], "]"}], " ", 
               RowBox[{"\[Delta]", "[", 
                RowBox[{"{", 
                 RowBox[{"i4", ",", "i6"}], "}"}], "]"}]}]}], ")"}]}], "+", 
           RowBox[{
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i1", ",", "i4"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i2", ",", "i3"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i5", ",", "i6"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i1", ",", "i3"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i2", ",", "i4"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i5", ",", "i6"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i1", ",", "i2"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i3", ",", "i4"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i5", ",", "i6"}], "}"}], "]"}]}]}], ")"}]}], 
        RowBox[{"15", " ", 
         RowBox[{"(", 
          RowBox[{"4", "+", "d"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"6", "+", "d"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"8", "+", "d"}], ")"}]}]]}]},
     {
      RowBox[{
       RowBox[{
        FractionBox["1", "24"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"A", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "j", "}"}]}], "]"}], " ", 
           RowBox[{"B", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "l", "}"}]}], "]"}], " ", 
           RowBox[{"F", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "k", "}"}]}], "]"}], " ", 
           RowBox[{"Y", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "i", "}"}]}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"A", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "j", "}"}]}], "]"}], " ", 
           RowBox[{"B", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "k", "}"}]}], "]"}], " ", 
           RowBox[{"F", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "l", "}"}]}], "]"}], " ", 
           RowBox[{"Y", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "i", "}"}]}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"A", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "i", "}"}]}], "]"}], " ", 
           RowBox[{"B", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "l", "}"}]}], "]"}], " ", 
           RowBox[{"F", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "k", "}"}]}], "]"}], " ", 
           RowBox[{"Y", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "j", "}"}]}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"A", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "i", "}"}]}], "]"}], " ", 
           RowBox[{"B", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "k", "}"}]}], "]"}], " ", 
           RowBox[{"F", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "l", "}"}]}], "]"}], " ", 
           RowBox[{"Y", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "j", "}"}]}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"A", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "j", "}"}]}], "]"}], " ", 
           RowBox[{"B", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "l", "}"}]}], "]"}], " ", 
           RowBox[{"F", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "i", "}"}]}], "]"}], " ", 
           RowBox[{"Y", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "k", "}"}]}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"A", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "i", "}"}]}], "]"}], " ", 
           RowBox[{"B", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "l", "}"}]}], "]"}], " ", 
           RowBox[{"F", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "j", "}"}]}], "]"}], " ", 
           RowBox[{"Y", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "k", "}"}]}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"A", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "j", "}"}]}], "]"}], " ", 
           RowBox[{"B", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "i", "}"}]}], "]"}], " ", 
           RowBox[{"F", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "l", "}"}]}], "]"}], " ", 
           RowBox[{"Y", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "k", "}"}]}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"A", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "i", "}"}]}], "]"}], " ", 
           RowBox[{"B", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "j", "}"}]}], "]"}], " ", 
           RowBox[{"F", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "l", "}"}]}], "]"}], " ", 
           RowBox[{"Y", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "k", "}"}]}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"A", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "l", "}"}]}], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"B", "[", 
               RowBox[{"0", ",", 
                RowBox[{"{", "k", "}"}]}], "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"F", "[", 
                  RowBox[{"0", ",", 
                   RowBox[{"{", "j", "}"}]}], "]"}], " ", 
                 RowBox[{"Y", "[", 
                  RowBox[{"0", ",", 
                   RowBox[{"{", "i", "}"}]}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{"F", "[", 
                  RowBox[{"0", ",", 
                   RowBox[{"{", "i", "}"}]}], "]"}], " ", 
                 RowBox[{"Y", "[", 
                  RowBox[{"0", ",", 
                   RowBox[{"{", "j", "}"}]}], "]"}]}]}], ")"}]}], "+", 
             RowBox[{
              RowBox[{"B", "[", 
               RowBox[{"0", ",", 
                RowBox[{"{", "j", "}"}]}], "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"F", "[", 
                  RowBox[{"0", ",", 
                   RowBox[{"{", "k", "}"}]}], "]"}], " ", 
                 RowBox[{"Y", "[", 
                  RowBox[{"0", ",", 
                   RowBox[{"{", "i", "}"}]}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{"F", "[", 
                  RowBox[{"0", ",", 
                   RowBox[{"{", "i", "}"}]}], "]"}], " ", 
                 RowBox[{"Y", "[", 
                  RowBox[{"0", ",", 
                   RowBox[{"{", "k", "}"}]}], "]"}]}]}], ")"}]}], "+", 
             RowBox[{
              RowBox[{"B", "[", 
               RowBox[{"0", ",", 
                RowBox[{"{", "i", "}"}]}], "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"F", "[", 
                  RowBox[{"0", ",", 
                   RowBox[{"{", "k", "}"}]}], "]"}], " ", 
                 RowBox[{"Y", "[", 
                  RowBox[{"0", ",", 
                   RowBox[{"{", "j", "}"}]}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{"F", "[", 
                  RowBox[{"0", ",", 
                   RowBox[{"{", "j", "}"}]}], "]"}], " ", 
                 RowBox[{"Y", "[", 
                  RowBox[{"0", ",", 
                   RowBox[{"{", "k", "}"}]}], "]"}]}]}], ")"}]}]}], ")"}]}], 
          "+", 
          RowBox[{
           RowBox[{"A", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "j", "}"}]}], "]"}], " ", 
           RowBox[{"B", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "k", "}"}]}], "]"}], " ", 
           RowBox[{"F", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "i", "}"}]}], "]"}], " ", 
           RowBox[{"Y", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "l", "}"}]}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"A", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "i", "}"}]}], "]"}], " ", 
           RowBox[{"B", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "k", "}"}]}], "]"}], " ", 
           RowBox[{"F", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "j", "}"}]}], "]"}], " ", 
           RowBox[{"Y", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "l", "}"}]}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"A", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "j", "}"}]}], "]"}], " ", 
           RowBox[{"B", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "i", "}"}]}], "]"}], " ", 
           RowBox[{"F", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "k", "}"}]}], "]"}], " ", 
           RowBox[{"Y", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "l", "}"}]}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"A", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "i", "}"}]}], "]"}], " ", 
           RowBox[{"B", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "j", "}"}]}], "]"}], " ", 
           RowBox[{"F", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "k", "}"}]}], "]"}], " ", 
           RowBox[{"Y", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "l", "}"}]}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"A", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "k", "}"}]}], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"B", "[", 
               RowBox[{"0", ",", 
                RowBox[{"{", "l", "}"}]}], "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"F", "[", 
                  RowBox[{"0", ",", 
                   RowBox[{"{", "j", "}"}]}], "]"}], " ", 
                 RowBox[{"Y", "[", 
                  RowBox[{"0", ",", 
                   RowBox[{"{", "i", "}"}]}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{"F", "[", 
                  RowBox[{"0", ",", 
                   RowBox[{"{", "i", "}"}]}], "]"}], " ", 
                 RowBox[{"Y", "[", 
                  RowBox[{"0", ",", 
                   RowBox[{"{", "j", "}"}]}], "]"}]}]}], ")"}]}], "+", 
             RowBox[{
              RowBox[{"B", "[", 
               RowBox[{"0", ",", 
                RowBox[{"{", "j", "}"}]}], "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"F", "[", 
                  RowBox[{"0", ",", 
                   RowBox[{"{", "l", "}"}]}], "]"}], " ", 
                 RowBox[{"Y", "[", 
                  RowBox[{"0", ",", 
                   RowBox[{"{", "i", "}"}]}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{"F", "[", 
                  RowBox[{"0", ",", 
                   RowBox[{"{", "i", "}"}]}], "]"}], " ", 
                 RowBox[{"Y", "[", 
                  RowBox[{"0", ",", 
                   RowBox[{"{", "l", "}"}]}], "]"}]}]}], ")"}]}], "+", 
             RowBox[{
              RowBox[{"B", "[", 
               RowBox[{"0", ",", 
                RowBox[{"{", "i", "}"}]}], "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"F", "[", 
                  RowBox[{"0", ",", 
                   RowBox[{"{", "l", "}"}]}], "]"}], " ", 
                 RowBox[{"Y", "[", 
                  RowBox[{"0", ",", 
                   RowBox[{"{", "j", "}"}]}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{"F", "[", 
                  RowBox[{"0", ",", 
                   RowBox[{"{", "j", "}"}]}], "]"}], " ", 
                 RowBox[{"Y", "[", 
                  RowBox[{"0", ",", 
                   RowBox[{"{", "l", "}"}]}], "]"}]}]}], ")"}]}]}], ")"}]}]}],
          ")"}]}], "-", 
       FractionBox[
        RowBox[{
         RowBox[{"F", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
         RowBox[{"Y", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "j", "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "l", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "j", "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "k", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "l"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "i", "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "l", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "l", "}"}]}], "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"B", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", "k", "}"}]}], "]"}], " ", 
               RowBox[{"\[Delta]", "[", 
                RowBox[{"{", 
                 RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{"B", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", "j", "}"}]}], "]"}], " ", 
               RowBox[{"\[Delta]", "[", 
                RowBox[{"{", 
                 RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{"B", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", "i", "}"}]}], "]"}], " ", 
               RowBox[{"\[Delta]", "[", 
                RowBox[{"{", 
                 RowBox[{"j", ",", "k"}], "}"}], "]"}]}]}], ")"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "i", "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "k", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "k", "}"}]}], "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"B", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", "l", "}"}]}], "]"}], " ", 
               RowBox[{"\[Delta]", "[", 
                RowBox[{"{", 
                 RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{"B", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", "j", "}"}]}], "]"}], " ", 
               RowBox[{"\[Delta]", "[", 
                RowBox[{"{", 
                 RowBox[{"i", ",", "l"}], "}"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{"B", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", "i", "}"}]}], "]"}], " ", 
               RowBox[{"\[Delta]", "[", 
                RowBox[{"{", 
                 RowBox[{"j", ",", "l"}], "}"}], "]"}]}]}], ")"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "j", "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "i", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"k", ",", "l"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "i", "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "j", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"k", ",", "l"}], "}"}], "]"}]}]}], ")"}]}], 
        RowBox[{"12", " ", 
         RowBox[{"(", 
          RowBox[{"4", "+", "d"}], ")"}]}]], "+", 
       FractionBox[
        RowBox[{
         RowBox[{"A", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
         RowBox[{"B", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
         RowBox[{"F", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p1", "}"}]}], "]"}], " ", 
         RowBox[{"Y", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p1", "}"}]}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "l"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "k"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"k", ",", "l"}], "}"}], "]"}]}]}], ")"}]}], 
        RowBox[{"3", " ", 
         RowBox[{"(", 
          RowBox[{"2", "+", "d"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"4", "+", "d"}], ")"}]}]]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.5599999999999999]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   Column],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.7374581683836603`*^9, 3.737602161926199*^9, 
  3.737602278154113*^9, 3.737602338498192*^9, 3.737602442487584*^9, 
  3.737602589151716*^9, 3.737602692527748*^9},
 ExpressionUUID -> "64f57dab-99ab-4f64-8782-0ef3761aca65"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Deftracefreetensor", "[", 
  RowBox[{"ex", "[", "8", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.737458078950643*^9, 3.737458137003479*^9}, {
  3.737458194330328*^9, 3.737458195367167*^9}},
 ExpressionUUID -> "5088315e-5772-47b6-9283-d92da2273486"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "24"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"A", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "j", "}"}]}], "]"}], " ", 
      RowBox[{"B", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "l", "}"}]}], "]"}], " ", 
      RowBox[{"F", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "k", "}"}]}], "]"}], " ", 
      RowBox[{"Y", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "i", "}"}]}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"A", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "j", "}"}]}], "]"}], " ", 
      RowBox[{"B", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "k", "}"}]}], "]"}], " ", 
      RowBox[{"F", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "l", "}"}]}], "]"}], " ", 
      RowBox[{"Y", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "i", "}"}]}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"A", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "i", "}"}]}], "]"}], " ", 
      RowBox[{"B", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "l", "}"}]}], "]"}], " ", 
      RowBox[{"F", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "k", "}"}]}], "]"}], " ", 
      RowBox[{"Y", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "j", "}"}]}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"A", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "i", "}"}]}], "]"}], " ", 
      RowBox[{"B", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "k", "}"}]}], "]"}], " ", 
      RowBox[{"F", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "l", "}"}]}], "]"}], " ", 
      RowBox[{"Y", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "j", "}"}]}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"A", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "j", "}"}]}], "]"}], " ", 
      RowBox[{"B", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "l", "}"}]}], "]"}], " ", 
      RowBox[{"F", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "i", "}"}]}], "]"}], " ", 
      RowBox[{"Y", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "k", "}"}]}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"A", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "i", "}"}]}], "]"}], " ", 
      RowBox[{"B", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "l", "}"}]}], "]"}], " ", 
      RowBox[{"F", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "j", "}"}]}], "]"}], " ", 
      RowBox[{"Y", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "k", "}"}]}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"A", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "j", "}"}]}], "]"}], " ", 
      RowBox[{"B", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "i", "}"}]}], "]"}], " ", 
      RowBox[{"F", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "l", "}"}]}], "]"}], " ", 
      RowBox[{"Y", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "k", "}"}]}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"A", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "i", "}"}]}], "]"}], " ", 
      RowBox[{"B", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "j", "}"}]}], "]"}], " ", 
      RowBox[{"F", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "l", "}"}]}], "]"}], " ", 
      RowBox[{"Y", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "k", "}"}]}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"A", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "l", "}"}]}], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"B", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "k", "}"}]}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"F", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "j", "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "i", "}"}]}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"F", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "i", "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "j", "}"}]}], "]"}]}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"B", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "j", "}"}]}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"F", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "k", "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "i", "}"}]}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"F", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "i", "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "k", "}"}]}], "]"}]}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"B", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "i", "}"}]}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"F", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "k", "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "j", "}"}]}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"F", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "j", "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "k", "}"}]}], "]"}]}]}], ")"}]}]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"A", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "j", "}"}]}], "]"}], " ", 
      RowBox[{"B", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "k", "}"}]}], "]"}], " ", 
      RowBox[{"F", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "i", "}"}]}], "]"}], " ", 
      RowBox[{"Y", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "l", "}"}]}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"A", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "i", "}"}]}], "]"}], " ", 
      RowBox[{"B", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "k", "}"}]}], "]"}], " ", 
      RowBox[{"F", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "j", "}"}]}], "]"}], " ", 
      RowBox[{"Y", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "l", "}"}]}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"A", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "j", "}"}]}], "]"}], " ", 
      RowBox[{"B", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "i", "}"}]}], "]"}], " ", 
      RowBox[{"F", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "k", "}"}]}], "]"}], " ", 
      RowBox[{"Y", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "l", "}"}]}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"A", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "i", "}"}]}], "]"}], " ", 
      RowBox[{"B", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "j", "}"}]}], "]"}], " ", 
      RowBox[{"F", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "k", "}"}]}], "]"}], " ", 
      RowBox[{"Y", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "l", "}"}]}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"A", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "k", "}"}]}], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"B", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "l", "}"}]}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"F", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "j", "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "i", "}"}]}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"F", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "i", "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "j", "}"}]}], "]"}]}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"B", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "j", "}"}]}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"F", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "l", "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "i", "}"}]}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"F", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "i", "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "l", "}"}]}], "]"}]}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"B", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "i", "}"}]}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"F", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "l", "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "j", "}"}]}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"F", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "j", "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "l", "}"}]}], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
    ")"}]}], "-", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"12", " ", 
     RowBox[{"(", 
      RowBox[{"4", "+", "d"}], ")"}]}]], 
   RowBox[{
    RowBox[{"F", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
    RowBox[{"Y", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"A", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "j", "}"}]}], "]"}], " ", 
       RowBox[{"B", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "l", "}"}]}], "]"}], " ", 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"A", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "j", "}"}]}], "]"}], " ", 
       RowBox[{"B", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "k", "}"}]}], "]"}], " ", 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"i", ",", "l"}], "}"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"A", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "i", "}"}]}], "]"}], " ", 
       RowBox[{"B", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "l", "}"}]}], "]"}], " ", 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"A", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "l", "}"}]}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"B", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "k", "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"B", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "j", "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"B", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "i", "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"j", ",", "k"}], "}"}], "]"}]}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"A", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "i", "}"}]}], "]"}], " ", 
       RowBox[{"B", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "k", "}"}]}], "]"}], " ", 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"A", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "k", "}"}]}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"B", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "l", "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"B", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "j", "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i", ",", "l"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"B", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "i", "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"j", ",", "l"}], "}"}], "]"}]}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"A", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "j", "}"}]}], "]"}], " ", 
       RowBox[{"B", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "i", "}"}]}], "]"}], " ", 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"k", ",", "l"}], "}"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"A", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "i", "}"}]}], "]"}], " ", 
       RowBox[{"B", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "j", "}"}]}], "]"}], " ", 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"k", ",", "l"}], "}"}], "]"}]}]}], ")"}]}]}], "+", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"3", " ", 
     RowBox[{"(", 
      RowBox[{"2", "+", "d"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"4", "+", "d"}], ")"}]}]], 
   RowBox[{
    RowBox[{"A", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
    RowBox[{"B", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
    RowBox[{"F", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", "p1", "}"}]}], "]"}], " ", 
    RowBox[{"Y", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", "p1", "}"}]}], "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"i", ",", "l"}], "}"}], "]"}], " ", 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"i", ",", "k"}], "}"}], "]"}], " ", 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"k", ",", "l"}], "}"}], "]"}]}]}], ")"}]}]}]}]], "Output",
 CellChangeTimes->{{3.73745808794444*^9, 3.7374581373279657`*^9}, 
   3.7374581962124567`*^9, 3.737602172040668*^9, 3.737602483161737*^9, 
   3.737602601560563*^9, 3.737602710154039*^9},
 ExpressionUUID -> "2d17a786-9d3e-446d-a900-6f3bf8a459ff"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pos", "=", 
  RowBox[{"Flatten", "[", 
   RowBox[{"Extract", "[", 
    RowBox[{"ex", ",", 
     RowBox[{"Drop", "[", 
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{"ex", ",", "List"}], "]"}], ",", "None", ",", 
       RowBox[{"-", "1"}]}], "]"}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.737458672541046*^9, 3.7374586783459377`*^9}, {
  3.7374587828151207`*^9, 3.737458794346673*^9}},
 ExpressionUUID -> "f12a4388-76e1-4276-972e-6d5258f36ba2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}]], "Output",
 CellChangeTimes->{{3.7374587831756496`*^9, 3.737458811525392*^9}, 
   3.737459401838822*^9},
 ExpressionUUID -> "89336556-9a97-4a79-aa09-e121fe63e2bd"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"order2", "=", 
  RowBox[{"Subsets", "[", 
   RowBox[{"pos", ",", 
    RowBox[{"{", "2", "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.737458984798307*^9, 3.7374589930828133`*^9}, {
  3.737459032658799*^9, 3.737459037515923*^9}, {3.737459111182674*^9, 
  3.737459113820127*^9}, {3.7374593733142233`*^9, 3.737459393693948*^9}},
 ExpressionUUID -> "d76406a3-d7d3-4897-be04-f1e8cd715aad"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"i", ",", "j"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "k"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "l"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "k"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "l"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"k", ",", "l"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7374589935651617`*^9, 3.737459038864447*^9, 3.7374591165704603`*^9, {
   3.737459380305407*^9, 3.737459404246129*^9}},
 ExpressionUUID -> "e9f48d7b-7acf-4ff3-b757-ad0cfc65949b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Apply", "[", 
  RowBox[{"Plus", ",", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"Einstein", "[", 
        RowBox[{"ex", "/.", 
         RowBox[{
          RowBox[{"order2", "\[LeftDoubleBracket]", 
           RowBox[{"ii", ",", "2"}], "\[RightDoubleBracket]"}], "\[Rule]", 
          RowBox[{"order2", "\[LeftDoubleBracket]", 
           RowBox[{"ii", ",", "1"}], "\[RightDoubleBracket]"}]}]}], "]"}], 
       ")"}], 
      RowBox[{"DeltaTensor", "[", 
       RowBox[{
       "order2", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}], 
       "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"ii", ",", "1", ",", 
       RowBox[{"Length", "[", "order2", "]"}]}], "}"}]}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.7374591222871237`*^9, 3.737459266429467*^9}, {
  3.7374594183048363`*^9, 3.737459428318386*^9}, {3.7374603381508923`*^9, 
  3.7374603439761887`*^9}},
 ExpressionUUID -> "20a26c25-e9de-4976-9165-6a999ce8ee6a"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"A", "[", 
    RowBox[{"{", "s0", "}"}], "]"}], " ", 
   RowBox[{"B", "[", 
    RowBox[{"{", "s0", "}"}], "]"}], " ", 
   RowBox[{"X", "[", 
    RowBox[{"{", "k", "}"}], "]"}], " ", 
   RowBox[{"Y", "[", 
    RowBox[{"{", "l", "}"}], "]"}], " ", 
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"A", "[", 
    RowBox[{"{", "s0", "}"}], "]"}], " ", 
   RowBox[{"B", "[", 
    RowBox[{"{", "j", "}"}], "]"}], " ", 
   RowBox[{"X", "[", 
    RowBox[{"{", "s0", "}"}], "]"}], " ", 
   RowBox[{"Y", "[", 
    RowBox[{"{", "l", "}"}], "]"}], " ", 
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"A", "[", 
    RowBox[{"{", "s0", "}"}], "]"}], " ", 
   RowBox[{"B", "[", 
    RowBox[{"{", "j", "}"}], "]"}], " ", 
   RowBox[{"X", "[", 
    RowBox[{"{", "k", "}"}], "]"}], " ", 
   RowBox[{"Y", "[", 
    RowBox[{"{", "s0", "}"}], "]"}], " ", 
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"i", ",", "l"}], "}"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"A", "[", 
    RowBox[{"{", "i", "}"}], "]"}], " ", 
   RowBox[{"B", "[", 
    RowBox[{"{", "s0", "}"}], "]"}], " ", 
   RowBox[{"X", "[", 
    RowBox[{"{", "s0", "}"}], "]"}], " ", 
   RowBox[{"Y", "[", 
    RowBox[{"{", "l", "}"}], "]"}], " ", 
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"A", "[", 
    RowBox[{"{", "i", "}"}], "]"}], " ", 
   RowBox[{"B", "[", 
    RowBox[{"{", "s0", "}"}], "]"}], " ", 
   RowBox[{"X", "[", 
    RowBox[{"{", "k", "}"}], "]"}], " ", 
   RowBox[{"Y", "[", 
    RowBox[{"{", "s0", "}"}], "]"}], " ", 
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"A", "[", 
    RowBox[{"{", "i", "}"}], "]"}], " ", 
   RowBox[{"B", "[", 
    RowBox[{"{", "j", "}"}], "]"}], " ", 
   RowBox[{"X", "[", 
    RowBox[{"{", "s0", "}"}], "]"}], " ", 
   RowBox[{"Y", "[", 
    RowBox[{"{", "s0", "}"}], "]"}], " ", 
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"k", ",", "l"}], "}"}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.737462365541643*^9},
 ExpressionUUID -> "678ead82-647f-47ee-b7b8-424594da7296"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "5", "]"}], "=", 
   RowBox[{
    RowBox[{"A", "[", 
     RowBox[{"{", "i", "}"}], "]"}], 
    RowBox[{"B", "[", 
     RowBox[{"{", "j", "}"}], "]"}], 
    RowBox[{"F", "[", 
     RowBox[{"{", "k", "}"}], "]"}], 
    RowBox[{"Y", "[", 
     RowBox[{"{", "l", "}"}], "]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.737446141629819*^9, {3.737446388200335*^9, 3.737446389976081*^9}},
 ExpressionUUID -> "f1c6ccda-d418-4ad3-9c75-72a978d4ea44"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Deftracefreetensor", "[", 
   RowBox[{"ex", "[", "5", "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{
  3.737445876483593*^9, {3.737446064214365*^9, 3.737446067300617*^9}, {
   3.737446154999424*^9, 3.737446159845129*^9}, {3.737446277095166*^9, 
   3.737446303068288*^9}},
 ExpressionUUID -> "6f4c2dc8-15f1-4566-a465-6645de01cd23"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "0", "]"}], "=", "2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "1", "]"}], "=", 
   RowBox[{"A", "[", 
    RowBox[{"1", ",", 
     RowBox[{"{", "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "2", "]"}], "=", 
   RowBox[{"A", "[", 
    RowBox[{"{", "i", "}"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "3", "]"}], "=", 
   RowBox[{"A", "[", 
    RowBox[{"4", ",", 
     RowBox[{"{", 
      RowBox[{"i1", ",", "i2", ",", "i3", ",", "i4"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "4", "]"}], "=", 
   RowBox[{
    RowBox[{"A", "[", 
     RowBox[{"{", 
      RowBox[{"i", ",", "j"}], "}"}], "]"}], 
    RowBox[{"B", "[", 
     RowBox[{"{", 
      RowBox[{"k", ",", "l"}], "}"}], "]"}], 
    RowBox[{"B", "[", 
     RowBox[{"{", 
      RowBox[{"k", ",", "l"}], "}"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "5", "]"}], "=", 
   RowBox[{
    RowBox[{"A", "[", 
     RowBox[{"{", "i", "}"}], "]"}], 
    RowBox[{"B", "[", 
     RowBox[{"{", "j", "}"}], "]"}], 
    RowBox[{"F", "[", 
     RowBox[{"{", "k", "}"}], "]"}], 
    RowBox[{"Y", "[", 
     RowBox[{"{", "l", "}"}], "]"}], 
    RowBox[{"Y", "[", 
     RowBox[{"{", "m", "}"}], "]"}], 
    RowBox[{"Y", "[", 
     RowBox[{"{", "m", "}"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "6", "]"}], "=", 
   RowBox[{"A", "[", 
    RowBox[{"4", ",", 
     RowBox[{"{", 
      RowBox[{"i1", ",", "i2", ",", "i3", ",", "i4", ",", "i5", ",", "i5"}], 
      "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]"}], "Input",ExpressionUUID\
->"48b7f842-b3df-42c1-bae9-a04d034fb518"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ex0", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ex1", "=", 
   RowBox[{"A", "[", 
    RowBox[{"{", 
     RowBox[{"i1", ",", "i2"}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ex2", "=", 
   RowBox[{"A", "[", 
    RowBox[{"{", 
     RowBox[{"i1", ",", "i1"}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ex3", "=", 
   RowBox[{"A", "[", 
    RowBox[{"5", ",", 
     RowBox[{"{", 
      RowBox[{"i0", ",", "i0", ",", "i5", ",", "i4", ",", "i5", ",", "i3"}], 
      "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ex4", "=", 
   RowBox[{
    FractionBox["1", "6"], 
    RowBox[{"A", "[", 
     RowBox[{"{", 
      RowBox[{"i0", ",", "i0"}], "}"}], "]"}], 
    RowBox[{"\[Delta]", "[", 
     RowBox[{"5", ",", 
      RowBox[{"{", 
       RowBox[{"i0", ",", "i0", ",", "i5", ",", "i4", ",", "i5", ",", "i3"}], 
       "}"}]}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ex5", "=", 
   RowBox[{
    FractionBox["1", "6"], 
    RowBox[{"A", "[", 
     RowBox[{"{", 
      RowBox[{"i0", ",", "i0"}], "}"}], "]"}], 
    RowBox[{"B", "[", 
     RowBox[{"5", ",", 
      RowBox[{"{", 
       RowBox[{"k0", ",", "k0", ",", "i5", ",", "i4", ",", "i5", ",", "i3"}], 
       "}"}]}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ex6", "=", 
   RowBox[{
    FractionBox["1", "6"], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"A", "[", 
        RowBox[{"{", 
         RowBox[{"i0", ",", "i0"}], "}"}], "]"}], 
       RowBox[{"B", "[", 
        RowBox[{"5", ",", 
         RowBox[{"{", 
          RowBox[{
          "i0", ",", "k0", ",", "i5", ",", "i4", ",", "i5", ",", "i3"}], 
          "}"}]}], "]"}]}], "+", 
      RowBox[{"B", "[", 
       RowBox[{"{", 
        RowBox[{"i1", ",", "i1"}], "}"}], "]"}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ex7", "=", 
   RowBox[{
    FractionBox["1", "6"], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"A", "[", 
        RowBox[{"{", 
         RowBox[{"i0", ",", "i0"}], "}"}], "]"}], 
       RowBox[{"B", "[", 
        RowBox[{"5", ",", 
         RowBox[{"{", 
          RowBox[{
          "k0", ",", "k0", ",", "i5", ",", "i4", ",", "i5", ",", "i3"}], 
          "}"}]}], "]"}]}], "+", 
      RowBox[{"B", "[", 
       RowBox[{"{", 
        RowBox[{"i1", ",", "i1"}], "}"}], "]"}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ex8", "=", 
   RowBox[{
    RowBox[{"F", "[", 
     RowBox[{"{", 
      RowBox[{"i1", ",", "i2"}], "}"}], "]"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"A", "[", 
        RowBox[{"{", 
         RowBox[{"i0", ",", "i0"}], "}"}], "]"}], 
       RowBox[{"B", "[", 
        RowBox[{"5", ",", 
         RowBox[{"{", 
          RowBox[{
          "k0", ",", "k0", ",", "i5", ",", "i4", ",", "i5", ",", "i3"}], 
          "}"}]}], "]"}]}], "+", 
      RowBox[{"B", "[", 
       RowBox[{"{", 
        RowBox[{"i5", ",", "i5"}], "}"}], "]"}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.737356700626026*^9, 3.73735670758298*^9}, 
   3.7373568476016283`*^9, {3.737357106449404*^9, 3.737357116305105*^9}, {
   3.737357801494697*^9, 3.737357859381054*^9}, {3.737358376329124*^9, 
   3.7373584131786823`*^9}, {3.737358512363284*^9, 3.737358514039806*^9}, {
   3.7373586127476892`*^9, 3.737358614088758*^9}, {3.737358687168057*^9, 
   3.737358719768911*^9}, {3.73735933175765*^9, 3.737359341804775*^9}, {
   3.7373594127027597`*^9, 3.7373594282368107`*^9}, {3.737360241092972*^9, 
   3.73736040598617*^9}, {3.737360834557612*^9, 3.737360859637496*^9}, {
   3.737360903751594*^9, 3.7373609081651993`*^9}},
 ExpressionUUID -> "3d1170fa-e2a9-45e9-88e2-177549b6fbae"],

Cell[BoxData[
 RowBox[{
  RowBox[{"listtoreplacementlist", "[", "list_", "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"list1", "=", 
      RowBox[{"{", "}"}]}], "}"}], ",", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"EvenQ", "[", 
       RowBox[{"Length", "[", "list", "]"}], "]"}], ",", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"list", "\[LeftDoubleBracket]", 
          RowBox[{"ii", "+", "1"}], "\[RightDoubleBracket]"}], "\[Rule]", 
         RowBox[{
         "list", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}]}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"ii", ",", "1", ",", 
          RowBox[{"Length", "[", "list", "]"}], ",", "2"}], "}"}]}], "]"}]}], 
     "]"}]}], "\[IndentingNewLine]", "]"}]}]], "Input"],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.737475186282144*^9, 3.737475205997394*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ex", "=", 
   RowBox[{"A", "[", 
    RowBox[{"4", ",", 
     RowBox[{"{", 
      RowBox[{"i1", ",", "i2", ",", "i3", ",", "i4", ",", "i5", ",", "i6"}], 
      "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7375212958908587`*^9, 3.737521308826329*^9}}],

Cell[BoxData[
 RowBox[{"Deftracefreetensor", "[", "ex", "]"}]], "Input",
 CellChangeTimes->{{3.737521311494884*^9, 
  3.737521328091299*^9}},ExpressionUUID->"b054ade7-4fa6-4591-8d83-\
bccb6e9d33d3"]
}, Closed]],

Cell[CellGroupData[{

Cell["Grad 26- and G29-moment distribution function", "Section",
 CellChangeTimes->{{3.678792653535986*^9, 3.6787926788881273`*^9}, {
  3.678796356671401*^9, 3.6787963577598133`*^9}, {3.7391976719749928`*^9, 
  3.739197674532752*^9}, {3.739201373219129*^9, 3.739201376472238*^9}, {
  3.7430755512746143`*^9, 3.7430755665987263`*^9}},
 ExpressionUUID -> "7763fd7f-9b63-4880-a28c-6fadc0d81a2d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"gammareplacements", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Gamma", "[", 
       RowBox[{"10", "+", 
        FractionBox["d", "2"]}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"9", "+", 
         FractionBox["d", "2"]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"8", "+", 
         FractionBox["d", "2"]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"7", "+", 
         FractionBox["d", "2"]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"6", "+", 
         FractionBox["d", "2"]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"5", "+", 
         FractionBox["d", "2"]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"4", "+", 
         FractionBox["d", "2"]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"3", "+", 
         FractionBox["d", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"2", "+", 
         FractionBox["d", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         FractionBox["d", "2"]}], ")"}], 
       FractionBox["d", "2"], 
       RowBox[{"Gamma", "[", 
        FractionBox["d", "2"], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"Gamma", "[", 
       RowBox[{"9", "+", 
        FractionBox["d", "2"]}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"8", "+", 
         FractionBox["d", "2"]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"7", "+", 
         FractionBox["d", "2"]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"6", "+", 
         FractionBox["d", "2"]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"5", "+", 
         FractionBox["d", "2"]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"4", "+", 
         FractionBox["d", "2"]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"3", "+", 
         FractionBox["d", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"2", "+", 
         FractionBox["d", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         FractionBox["d", "2"]}], ")"}], 
       FractionBox["d", "2"], 
       RowBox[{"Gamma", "[", 
        FractionBox["d", "2"], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"Gamma", "[", 
       RowBox[{"8", "+", 
        FractionBox["d", "2"]}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"7", "+", 
         FractionBox["d", "2"]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"6", "+", 
         FractionBox["d", "2"]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"5", "+", 
         FractionBox["d", "2"]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"4", "+", 
         FractionBox["d", "2"]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"3", "+", 
         FractionBox["d", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"2", "+", 
         FractionBox["d", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         FractionBox["d", "2"]}], ")"}], 
       FractionBox["d", "2"], 
       RowBox[{"Gamma", "[", 
        FractionBox["d", "2"], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"Gamma", "[", 
       RowBox[{"7", "+", 
        FractionBox["d", "2"]}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"6", "+", 
         FractionBox["d", "2"]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"5", "+", 
         FractionBox["d", "2"]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"4", "+", 
         FractionBox["d", "2"]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"3", "+", 
         FractionBox["d", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"2", "+", 
         FractionBox["d", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         FractionBox["d", "2"]}], ")"}], 
       FractionBox["d", "2"], 
       RowBox[{"Gamma", "[", 
        FractionBox["d", "2"], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"Gamma", "[", 
       RowBox[{"6", "+", 
        FractionBox["d", "2"]}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"5", "+", 
         FractionBox["d", "2"]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"4", "+", 
         FractionBox["d", "2"]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"3", "+", 
         FractionBox["d", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"2", "+", 
         FractionBox["d", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         FractionBox["d", "2"]}], ")"}], 
       FractionBox["d", "2"], 
       RowBox[{"Gamma", "[", 
        FractionBox["d", "2"], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"Gamma", "[", 
       RowBox[{"5", "+", 
        FractionBox["d", "2"]}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"4", "+", 
         FractionBox["d", "2"]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"3", "+", 
         FractionBox["d", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"2", "+", 
         FractionBox["d", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         FractionBox["d", "2"]}], ")"}], 
       FractionBox["d", "2"], 
       RowBox[{"Gamma", "[", 
        FractionBox["d", "2"], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"Gamma", "[", 
       RowBox[{"4", "+", 
        FractionBox["d", "2"]}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"3", "+", 
         FractionBox["d", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"2", "+", 
         FractionBox["d", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         FractionBox["d", "2"]}], ")"}], 
       FractionBox["d", "2"], 
       RowBox[{"Gamma", "[", 
        FractionBox["d", "2"], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"Gamma", "[", 
       RowBox[{"3", "+", 
        FractionBox["d", "2"]}], "]"}], "\[Rule]", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"2", "+", 
         FractionBox["d", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         FractionBox["d", "2"]}], ")"}], 
       FractionBox["d", "2"], 
       RowBox[{"Gamma", "[", 
        FractionBox["d", "2"], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"Gamma", "[", 
       RowBox[{"2", "+", 
        FractionBox["d", "2"]}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         FractionBox["d", "2"]}], ")"}], 
       FractionBox["d", "2"], 
       RowBox[{"Gamma", "[", 
        FractionBox["d", "2"], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"Gamma", "[", 
       RowBox[{"1", "+", 
        FractionBox["d", "2"]}], "]"}], "\[Rule]", 
      RowBox[{
       FractionBox["d", "2"], 
       RowBox[{"Gamma", "[", 
        FractionBox["d", "2"], "]"}]}]}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{3.739198007588985*^9},
 ExpressionUUID -> "c35675c9-8c10-4a59-b20a-9cbd54761de5"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Unprotect", "[", "C", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"$Assumptions", "=", 
   RowBox[{
    RowBox[{"\[Theta]", ">", "0"}], " ", "&&", " ", 
    RowBox[{"\[Rho]", ">", "0"}], "&&", 
    RowBox[{"d", ">", "0"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fM", "=", 
   RowBox[{
    FractionBox["\[Rho]", "m"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["1", 
       RowBox[{"2", "\[Pi]", " ", "\[Theta]"}]], ")"}], 
     RowBox[{"d", "/", "2"}]], 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       SuperscriptBox["C", "2"], 
       RowBox[{"2", "\[Theta]"}]]}]]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.6430224897153673`*^9, 3.64302259629286*^9}, {
  3.643022824362217*^9, 3.643022837601315*^9}, {3.6430228683935013`*^9, 
  3.643022873787084*^9}, {3.643022910898*^9, 3.64302294398289*^9}, {
  3.739197705258206*^9, 3.739197706104534*^9}, {3.739198017471814*^9, 
  3.7391980213197393`*^9}},
 ExpressionUUID -> "f5138127-6e7a-4976-b368-b84ee4d90ba7"],

Cell[CellGroupData[{

Cell["G26", "Subsection",
 CellChangeTimes->{{3.7430755371394253`*^9, 3.743075538073835*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"fGradpart1", "=", 
    RowBox[{"fM", 
     RowBox[{"(", 
      RowBox[{"\[Lambda]0", "+", 
       RowBox[{"\[Lambda]1", " ", 
        FractionBox[
         SuperscriptBox["C", "2"], "\[Theta]"]}], "+", 
       RowBox[{"\[Lambda]2", " ", 
        FractionBox[
         SuperscriptBox["C", "4"], 
         SuperscriptBox["\[Theta]", "2"]]}]}], ")"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"cons1", "=", 
  RowBox[{"Expand", "[", 
   RowBox[{"Factor", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Rho]", "\[Equal]", 
           RowBox[{
            FractionBox[
             RowBox[{"2", " ", 
              SuperscriptBox["\[Pi]", 
               RowBox[{"d", "/", "2"}]]}], 
             RowBox[{"Gamma", "[", 
              FractionBox["d", "2"], "]"}]], " ", "m", 
            RowBox[{
             SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], 
             RowBox[{"fGradpart1", " ", 
              SuperscriptBox["C", 
               RowBox[{"d", "-", "1"}]], 
              RowBox[{"\[DifferentialD]", "C"}]}]}]}]}], " ", ",", 
          RowBox[{
           RowBox[{
            FractionBox["d", "2"], "\[Rho]", " ", "\[Theta]"}], "\[Equal]", 
           RowBox[{
            FractionBox[
             RowBox[{"2", " ", 
              SuperscriptBox["\[Pi]", 
               RowBox[{"d", "/", "2"}]]}], 
             RowBox[{"Gamma", "[", 
              FractionBox["d", "2"], "]"}]], " ", "m", 
            FractionBox["1", "2"], 
            RowBox[{
             SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], 
             RowBox[{"fGradpart1", " ", 
              SuperscriptBox["C", 
               RowBox[{"d", "+", "1"}]], 
              RowBox[{"\[DifferentialD]", "C"}]}]}]}]}], ",", 
          RowBox[{"w2", "\[Equal]", 
           RowBox[{
            FractionBox[
             RowBox[{"2", " ", 
              SuperscriptBox["\[Pi]", 
               RowBox[{"d", "/", "2"}]]}], 
             RowBox[{"Gamma", "[", 
              FractionBox["d", "2"], "]"}]], " ", "m", 
            RowBox[{
             SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"fGradpart1", "-", "fM"}], ")"}], " ", 
              SuperscriptBox["C", 
               RowBox[{"d", "+", "3"}]], 
              RowBox[{"\[DifferentialD]", "C"}]}]}]}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Lambda]0", ",", "\[Lambda]1", " ", ",", "\[Lambda]2"}], 
         "}"}]}], "]"}], "\[LeftDoubleBracket]", "1", 
      "\[RightDoubleBracket]"}], "/.", "gammareplacements"}], "]"}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.643022631456072*^9, 3.643022694347024*^9}, 
   3.678780868875546*^9, {3.67878096658149*^9, 3.678780967982998*^9}, {
   3.739197853456102*^9, 3.739197925625435*^9}, {3.739198040094521*^9, 
   3.739198092529138*^9}, {3.739198129465219*^9, 3.739198160836739*^9}, {
   3.739198190966324*^9, 3.739198192615296*^9}, {3.73919827487267*^9, 
   3.7391982886376143`*^9}, {3.739198360304781*^9, 3.739198474108562*^9}, {
   3.739198504234962*^9, 3.739198511359004*^9}, {3.7392012324365063`*^9, 
   3.739201238347423*^9}},ExpressionUUID->"518d37cd-a1d7-4d61-a597-\
1c91554f09ef"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Lambda]0", "\[Rule]", 
    RowBox[{"1", "+", 
     FractionBox["w2", 
      RowBox[{"8", " ", 
       SuperscriptBox["\[Theta]", "2"], " ", "\[Rho]"}]]}]}], ",", 
   RowBox[{"\[Lambda]1", "\[Rule]", 
    RowBox[{"-", 
     FractionBox["w2", 
      RowBox[{"4", " ", "d", " ", 
       SuperscriptBox["\[Theta]", "2"], " ", "\[Rho]"}]]}]}], ",", 
   RowBox[{"\[Lambda]2", "\[Rule]", 
    FractionBox["w2", 
     RowBox[{"8", " ", "d", " ", 
      RowBox[{"(", 
       RowBox[{"2", "+", "d"}], ")"}], " ", 
      SuperscriptBox["\[Theta]", "2"], " ", "\[Rho]"}]]}]}], "}"}]], "Output",\

 CellChangeTimes->{
  3.678780969383113*^9, 3.678791009016076*^9, 3.739198105861693*^9, {
   3.739198138477847*^9, 3.739198165941189*^9}, 3.739198197655972*^9, 
   3.739198295873763*^9, {3.7391983921014338`*^9, 3.7391984397277393`*^9}, 
   3.7391984806319113`*^9, 3.739198518282157*^9, {3.73920122114679*^9, 
   3.739201243455297*^9}},ExpressionUUID->"6d222e35-892d-4e5e-bb41-\
e513ce44ea23"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"fGradpart2", "=", 
   RowBox[{"fM", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Lambda]0", "[", 
        RowBox[{"{", "j", "}"}], "]"}], " ", 
       FractionBox[
        RowBox[{"C", "[", 
         RowBox[{"{", "j", "}"}], "]"}], 
        SqrtBox["\[Theta]"]]}], "+", 
      RowBox[{
       RowBox[{"\[Lambda]1", "[", 
        RowBox[{"{", "j", "}"}], "]"}], " ", 
       FractionBox[
        SuperscriptBox["C", "2"], "\[Theta]"], 
       FractionBox[
        RowBox[{"C", "[", 
         RowBox[{"{", "j", "}"}], "]"}], 
        SqrtBox["\[Theta]"]]}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"fGradpart2$integrand", "=", 
    RowBox[{"Einstein", "[", 
     RowBox[{
      RowBox[{"Expand", "[", 
       RowBox[{"fGradpart2", " ", 
        RowBox[{"C", "[", 
         RowBox[{"{", "i", "}"}], "]"}]}], "]"}], "/.", 
      RowBox[{
       RowBox[{
        RowBox[{"C", "[", 
         RowBox[{"{", "i", "}"}], "]"}], " ", 
        RowBox[{"C", "[", 
         RowBox[{"{", "j", "}"}], "]"}]}], "\[Rule]", 
       RowBox[{
        FractionBox["1", "d"], 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i", ",", "j"}], "}"}], "]"}], 
        SuperscriptBox["C", "2"]}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"cons2", "=", 
  RowBox[{"Factor", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0", "\[Equal]", 
          RowBox[{
           FractionBox[
            RowBox[{"2", " ", 
             SuperscriptBox["\[Pi]", 
              RowBox[{"d", "/", "2"}]]}], 
            RowBox[{"Gamma", "[", 
             FractionBox["d", "2"], "]"}]], " ", "m", 
           RowBox[{
            SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], 
            RowBox[{"fGradpart2$integrand", " ", 
             SuperscriptBox["C", 
              RowBox[{"d", "-", "1"}]], 
             RowBox[{"\[DifferentialD]", "C"}]}]}]}]}], " ", ",", 
         RowBox[{
          RowBox[{"2", "qi"}], "\[Equal]", 
          RowBox[{
           FractionBox[
            RowBox[{"2", " ", 
             SuperscriptBox["\[Pi]", 
              RowBox[{"d", "/", "2"}]]}], 
            RowBox[{"Gamma", "[", 
             FractionBox["d", "2"], "]"}]], " ", "m", 
           RowBox[{
            SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], 
            RowBox[{"fGradpart2$integrand", " ", 
             SuperscriptBox["C", 
              RowBox[{"d", "+", "1"}]], 
             RowBox[{"\[DifferentialD]", "C"}]}]}]}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\[Lambda]0", "[", 
          RowBox[{"{", "i", "}"}], "]"}], ",", 
         RowBox[{"\[Lambda]1", "[", 
          RowBox[{"{", "i", "}"}], "]"}]}], " ", "}"}]}], "]"}], 
     "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "/.", 
    "gammareplacements"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.7391985525119534`*^9, 3.73919868974585*^9}, {
  3.739198834126672*^9, 3.739199015059579*^9}, {3.7391997352860622`*^9, 
  3.739199894642144*^9}, {3.7391999666970043`*^9, 
  3.739199967056983*^9}},ExpressionUUID->"5cdd75b0-1bf8-453f-bc93-\
4a81a4c55b15"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Lambda]0", "[", 
     RowBox[{"{", "i", "}"}], "]"}], "\[Rule]", 
    RowBox[{"-", 
     FractionBox["qi", 
      RowBox[{
       SuperscriptBox["\[Theta]", 
        RowBox[{"3", "/", "2"}]], " ", "\[Rho]"}]]}]}], ",", 
   RowBox[{
    RowBox[{"\[Lambda]1", "[", 
     RowBox[{"{", "i", "}"}], "]"}], "\[Rule]", 
    FractionBox["qi", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2", "+", "d"}], ")"}], " ", 
      SuperscriptBox["\[Theta]", 
       RowBox[{"3", "/", "2"}]], " ", "\[Rho]"}]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7391999705780354`*^9, 
  3.739201251232379*^9},ExpressionUUID->"ada18c35-add7-47bf-abf5-\
ff39e2e72714"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"fGradpart3", "=", 
   RowBox[{"fM", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Lambda]0", "[", 
        RowBox[{"{", 
         RowBox[{"k", ",", "l"}], "}"}], "]"}], " ", 
       FractionBox[
        RowBox[{
         RowBox[{"C", "[", 
          RowBox[{"{", "k", "}"}], "]"}], 
         RowBox[{"C", "[", 
          RowBox[{"{", "l", "}"}], "]"}]}], "\[Theta]"]}], "+", 
      RowBox[{
       RowBox[{"\[Lambda]1", "[", 
        RowBox[{"{", 
         RowBox[{"k", ",", "l"}], "}"}], "]"}], " ", 
       FractionBox[
        SuperscriptBox["C", "2"], "\[Theta]"], 
       FractionBox[
        RowBox[{
         RowBox[{"C", "[", 
          RowBox[{"{", "k", "}"}], "]"}], 
         RowBox[{"C", "[", 
          RowBox[{"{", "l", "}"}], "]"}]}], "\[Theta]"]}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fGradpart3$integrand", "=", 
   RowBox[{
    RowBox[{"Einstein", "[", 
     RowBox[{"Expand", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Expand", "[", 
         RowBox[{"fGradpart3", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"C", "[", 
              RowBox[{"{", "i", "}"}], "]"}], 
             RowBox[{"C", "[", 
              RowBox[{"{", "j", "}"}], "]"}]}], "-", 
            RowBox[{
             FractionBox["1", "d"], 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "j"}], "}"}], "]"}], 
             SuperscriptBox["C", "2"]}]}], ")"}]}], "]"}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"C", "[", 
            RowBox[{"{", "i", "}"}], "]"}], " ", 
           RowBox[{"C", "[", 
            RowBox[{"{", "j", "}"}], "]"}], " ", 
           RowBox[{"C", "[", 
            RowBox[{"{", "k", "}"}], "]"}], " ", 
           RowBox[{"C", "[", 
            RowBox[{"{", "l", "}"}], "]"}]}], "\[Rule]", 
          RowBox[{
           FractionBox["3", 
            RowBox[{"d", 
             RowBox[{"(", 
              RowBox[{"d", "+", "2"}], ")"}]}]], 
           RowBox[{"sym", "[", 
            RowBox[{
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "j"}], "}"}], "]"}], 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"k", ",", "l"}], "}"}], "]"}]}], "]"}], 
           SuperscriptBox["C", "4"]}]}], "}"}]}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"C", "[", 
           RowBox[{"{", "k", "}"}], "]"}], " ", 
          RowBox[{"C", "[", 
           RowBox[{"{", "l", "}"}], "]"}]}], "\[Rule]", 
         RowBox[{
          FractionBox["1", "d"], 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"k", ",", "l"}], "}"}], "]"}], 
          SuperscriptBox["C", "2"]}]}], "}"}]}], "]"}], "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Lambda]0", "[", 
        RowBox[{"{", 
         RowBox[{"s_", ",", "s_"}], "}"}], "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"\[Lambda]1", "[", 
        RowBox[{"{", 
         RowBox[{"s_", ",", "s_"}], "}"}], "]"}], "\[Rule]", "0"}]}], 
     "}"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"cons3", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\[Sigma]ij", "\[Equal]", 
          RowBox[{
           FractionBox[
            RowBox[{"2", " ", 
             SuperscriptBox["\[Pi]", 
              RowBox[{"d", "/", "2"}]]}], 
            RowBox[{"Gamma", "[", 
             FractionBox["d", "2"], "]"}]], " ", "m", 
           RowBox[{
            SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], 
            RowBox[{"fGradpart3$integrand", " ", 
             SuperscriptBox["C", 
              RowBox[{"d", "-", "1"}]], 
             RowBox[{"\[DifferentialD]", "C"}]}]}]}]}], " ", ",", 
         RowBox[{"u1ij", "\[Equal]", 
          RowBox[{
           FractionBox[
            RowBox[{"2", " ", 
             SuperscriptBox["\[Pi]", 
              RowBox[{"d", "/", "2"}]]}], 
            RowBox[{"Gamma", "[", 
             FractionBox["d", "2"], "]"}]], " ", "m", 
           RowBox[{
            SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], 
            RowBox[{"fGradpart3$integrand", " ", 
             SuperscriptBox["C", 
              RowBox[{"d", "+", "1"}]], 
             RowBox[{"\[DifferentialD]", "C"}]}]}]}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\[Lambda]0", "[", 
          RowBox[{"{", 
           RowBox[{"i", ",", "j"}], "}"}], "]"}], ",", 
         RowBox[{"\[Lambda]1", "[", 
          RowBox[{"{", 
           RowBox[{"i", ",", "j"}], "}"}], "]"}]}], " ", "}"}]}], "]"}], 
     "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "/.", 
    "gammareplacements"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.739199974881411*^9, 3.7391999753038683`*^9}, {
  3.7392000119710407`*^9, 3.73920014201821*^9}, {3.739200199922544*^9, 
  3.739200447839488*^9}, {3.739200566507942*^9, 
  3.739200574907557*^9}},ExpressionUUID->"827abc93-af46-43d0-91c2-\
0deef6e1c524"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Lambda]0", "[", 
     RowBox[{"{", 
      RowBox[{"i", ",", "j"}], "}"}], "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"-", "u1ij"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"6", "+", "d"}], ")"}], " ", "\[Theta]", " ", 
       "\[Sigma]ij"}]}], 
     RowBox[{"4", " ", 
      SuperscriptBox["\[Theta]", "2"], " ", "\[Rho]"}]]}], ",", 
   RowBox[{
    RowBox[{"\[Lambda]1", "[", 
     RowBox[{"{", 
      RowBox[{"i", ",", "j"}], "}"}], "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{"u1ij", "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"4", "+", "d"}], ")"}], " ", "\[Theta]", " ", 
       "\[Sigma]ij"}]}], 
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{"4", "+", "d"}], ")"}], " ", 
      SuperscriptBox["\[Theta]", "2"], " ", "\[Rho]"}]]}]}], "}"}]], "Output",\

 CellChangeTimes->{
  3.7392001446188517`*^9, {3.739200332566472*^9, 3.7392003686912518`*^9}, {
   3.739200399868422*^9, 3.739200448858156*^9}, 3.739200577271246*^9, 
   3.739201259749814*^9},ExpressionUUID->"f0cfac30-cdfb-46d1-9125-\
d5284cfbd87b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"fGradpart4", "=", 
   RowBox[{"fM", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Lambda]0", "[", 
       RowBox[{"{", 
        RowBox[{"l", ",", "r", ",", "s"}], "}"}], "]"}], " ", 
      FractionBox[
       RowBox[{
        RowBox[{"C", "[", 
         RowBox[{"{", "l", "}"}], "]"}], 
        RowBox[{"C", "[", 
         RowBox[{"{", "r", "}"}], "]"}], 
        RowBox[{"C", "[", 
         RowBox[{"{", "s", "}"}], "]"}]}], 
       RowBox[{"\[Theta]", 
        SqrtBox["\[Theta]"]}]]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"fGradpart4$integrand", "=", 
    RowBox[{
     RowBox[{"Einstein", "[", 
      RowBox[{"Expand", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Expand", "[", 
          RowBox[{"fGradpart4", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"C", "[", 
               RowBox[{"{", "i", "}"}], "]"}], 
              RowBox[{"C", "[", 
               RowBox[{"{", "j", "}"}], "]"}], 
              RowBox[{"C", "[", 
               RowBox[{"{", "k", "}"}], "]"}]}], "-", 
             RowBox[{
              FractionBox["1", 
               RowBox[{"d", "+", "2"}]], 
              SuperscriptBox["C", "2"], 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"C", "[", 
                  RowBox[{"{", "i", "}"}], "]"}], 
                 RowBox[{"\[Delta]", "[", 
                  RowBox[{"{", 
                   RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{"C", "[", 
                  RowBox[{"{", "j", "}"}], "]"}], 
                 RowBox[{"\[Delta]", "[", 
                  RowBox[{"{", 
                   RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{"C", "[", 
                  RowBox[{"{", "k", "}"}], "]"}], 
                 RowBox[{"\[Delta]", "[", 
                  RowBox[{"{", 
                   RowBox[{"i", ",", "j"}], "}"}], "]"}]}]}], ")"}]}]}], 
            ")"}]}], "]"}], "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"C", "[", 
             RowBox[{"{", "i", "}"}], "]"}], " ", 
            RowBox[{"C", "[", 
             RowBox[{"{", "j", "}"}], "]"}], " ", 
            RowBox[{"C", "[", 
             RowBox[{"{", "k", "}"}], "]"}], " ", 
            RowBox[{"C", "[", 
             RowBox[{"{", "l", "}"}], "]"}], " ", 
            RowBox[{"C", "[", 
             RowBox[{"{", "r", "}"}], "]"}], " ", 
            RowBox[{"C", "[", 
             RowBox[{"{", "s", "}"}], "]"}]}], "\[Rule]", 
           RowBox[{
            FractionBox["15", 
             RowBox[{"d", 
              RowBox[{"(", 
               RowBox[{"d", "+", "2"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"d", "+", "4"}], ")"}]}]], 
            RowBox[{"sym", "[", 
             RowBox[{
              RowBox[{"\[Delta]", "[", 
               RowBox[{"{", 
                RowBox[{"i", ",", "j"}], "}"}], "]"}], 
              RowBox[{"\[Delta]", "[", 
               RowBox[{"{", 
                RowBox[{"k", ",", "l"}], "}"}], "]"}], 
              RowBox[{"\[Delta]", "[", 
               RowBox[{"{", 
                RowBox[{"r", ",", "s"}], "}"}], "]"}]}], "]"}], 
            SuperscriptBox["C", "6"]}]}], "}"}]}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"C", "[", 
            RowBox[{"{", "i_", "}"}], "]"}], " ", 
           RowBox[{"C", "[", 
            RowBox[{"{", "j_", "}"}], "]"}], " ", 
           RowBox[{"C", "[", 
            RowBox[{"{", "k_", "}"}], "]"}], " ", 
           RowBox[{"C", "[", 
            RowBox[{"{", "l_", "}"}], "]"}]}], "\[Rule]", 
          RowBox[{
           FractionBox["3", 
            RowBox[{"d", 
             RowBox[{"(", 
              RowBox[{"d", "+", "2"}], ")"}]}]], 
           RowBox[{"sym", "[", 
            RowBox[{
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "j"}], "}"}], "]"}], 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"k", ",", "l"}], "}"}], "]"}]}], "]"}], 
           SuperscriptBox["C", "4"]}]}], "}"}]}], "]"}], "]"}], "/.", 
     RowBox[{
      RowBox[{"\[Lambda]0", "[", 
       RowBox[{"{", 
        RowBox[{"_", ",", "s_", ",", "s_"}], "}"}], "]"}], "\[Rule]", 
      "0"}]}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"cons4", "=", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"u0ijk", "\[Equal]", 
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", 
         SuperscriptBox["\[Pi]", 
          RowBox[{"d", "/", "2"}]]}], 
        RowBox[{"Gamma", "[", 
         FractionBox["d", "2"], "]"}]], " ", "m", 
       RowBox[{
        SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], 
        RowBox[{"fGradpart4$integrand", " ", 
         SuperscriptBox["C", 
          RowBox[{"d", "-", "1"}]], 
         RowBox[{"\[DifferentialD]", "C"}]}]}]}]}], ",", 
     RowBox[{"\[Lambda]0", "[", 
      RowBox[{"{", 
       RowBox[{"i", ",", "j", ",", "k"}], "}"}], "]"}]}], "]"}], 
   "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}]}], "Input",
 CellChangeTimes->{{3.739200610043229*^9, 3.739200610553692*^9}, {
  3.739200678040907*^9, 3.739200848940813*^9}, {3.739201086785733*^9, 
  3.739201089024394*^9}, {3.739201147425002*^9, 
  3.7392011873550587`*^9}},ExpressionUUID->"60936ece-f0ac-4517-a042-\
c91cf16b3d5d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Lambda]0", "[", 
    RowBox[{"{", 
     RowBox[{"i", ",", "j", ",", "k"}], "}"}], "]"}], "\[Rule]", 
   FractionBox["u0ijk", 
    RowBox[{"6", " ", 
     SuperscriptBox["\[Theta]", 
      RowBox[{"3", "/", "2"}]], " ", "\[Rho]"}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.739201148329261*^9, 3.7392011881059313`*^9}, 
   3.739201268572762*^9},ExpressionUUID->"85ebcf2b-c035-432d-a4c7-\
be32acc0f9c7"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["G29", "Subsection",
 CellChangeTimes->{{3.7430755371394253`*^9, 3.743075538073835*^9}, {
  3.7430755876251183`*^9, 3.743075588375391*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"fGradpart1", "=", 
    RowBox[{"fM", 
     RowBox[{"(", 
      RowBox[{"\[Lambda]0", "+", 
       RowBox[{"\[Lambda]1", " ", 
        FractionBox[
         SuperscriptBox["C", "2"], "\[Theta]"]}], "+", 
       RowBox[{"\[Lambda]2", " ", 
        FractionBox[
         SuperscriptBox["C", "4"], 
         SuperscriptBox["\[Theta]", "2"]]}]}], ")"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"cons1", "=", 
  RowBox[{"Expand", "[", 
   RowBox[{"Factor", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Rho]", "\[Equal]", 
           RowBox[{
            FractionBox[
             RowBox[{"2", " ", 
              SuperscriptBox["\[Pi]", 
               RowBox[{"d", "/", "2"}]]}], 
             RowBox[{"Gamma", "[", 
              FractionBox["d", "2"], "]"}]], " ", "m", 
            RowBox[{
             SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], 
             RowBox[{"fGradpart1", " ", 
              SuperscriptBox["C", 
               RowBox[{"d", "-", "1"}]], 
              RowBox[{"\[DifferentialD]", "C"}]}]}]}]}], " ", ",", 
          RowBox[{
           RowBox[{
            FractionBox["d", "2"], "\[Rho]", " ", "\[Theta]"}], "\[Equal]", 
           RowBox[{
            FractionBox[
             RowBox[{"2", " ", 
              SuperscriptBox["\[Pi]", 
               RowBox[{"d", "/", "2"}]]}], 
             RowBox[{"Gamma", "[", 
              FractionBox["d", "2"], "]"}]], " ", "m", 
            FractionBox["1", "2"], 
            RowBox[{
             SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], 
             RowBox[{"fGradpart1", " ", 
              SuperscriptBox["C", 
               RowBox[{"d", "+", "1"}]], 
              RowBox[{"\[DifferentialD]", "C"}]}]}]}]}], ",", 
          RowBox[{"w2", "\[Equal]", 
           RowBox[{
            FractionBox[
             RowBox[{"2", " ", 
              SuperscriptBox["\[Pi]", 
               RowBox[{"d", "/", "2"}]]}], 
             RowBox[{"Gamma", "[", 
              FractionBox["d", "2"], "]"}]], " ", "m", 
            RowBox[{
             SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"fGradpart1", "-", "fM"}], ")"}], " ", 
              SuperscriptBox["C", 
               RowBox[{"d", "+", "3"}]], 
              RowBox[{"\[DifferentialD]", "C"}]}]}]}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Lambda]0", ",", "\[Lambda]1", " ", ",", "\[Lambda]2"}], 
         "}"}]}], "]"}], "\[LeftDoubleBracket]", "1", 
      "\[RightDoubleBracket]"}], "/.", "gammareplacements"}], "]"}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.643022631456072*^9, 3.643022694347024*^9}, 
   3.678780868875546*^9, {3.67878096658149*^9, 3.678780967982998*^9}, {
   3.739197853456102*^9, 3.739197925625435*^9}, {3.739198040094521*^9, 
   3.739198092529138*^9}, {3.739198129465219*^9, 3.739198160836739*^9}, {
   3.739198190966324*^9, 3.739198192615296*^9}, {3.73919827487267*^9, 
   3.7391982886376143`*^9}, {3.739198360304781*^9, 3.739198474108562*^9}, {
   3.739198504234962*^9, 3.739198511359004*^9}, {3.7392012324365063`*^9, 
   3.739201238347423*^9}},
 ExpressionUUID -> "518d37cd-a1d7-4d61-a597-1c91554f09ef"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Lambda]0", "\[Rule]", 
    RowBox[{"1", "+", 
     FractionBox["w2", 
      RowBox[{"8", " ", 
       SuperscriptBox["\[Theta]", "2"], " ", "\[Rho]"}]]}]}], ",", 
   RowBox[{"\[Lambda]1", "\[Rule]", 
    RowBox[{"-", 
     FractionBox["w2", 
      RowBox[{"4", " ", "d", " ", 
       SuperscriptBox["\[Theta]", "2"], " ", "\[Rho]"}]]}]}], ",", 
   RowBox[{"\[Lambda]2", "\[Rule]", 
    FractionBox["w2", 
     RowBox[{"8", " ", "d", " ", 
      RowBox[{"(", 
       RowBox[{"2", "+", "d"}], ")"}], " ", 
      SuperscriptBox["\[Theta]", "2"], " ", "\[Rho]"}]]}]}], "}"}]], "Output",\

 CellChangeTimes->{
  3.678780969383113*^9, 3.678791009016076*^9, 3.739198105861693*^9, {
   3.739198138477847*^9, 3.739198165941189*^9}, 3.739198197655972*^9, 
   3.739198295873763*^9, {3.7391983921014338`*^9, 3.7391984397277393`*^9}, 
   3.7391984806319113`*^9, 3.739198518282157*^9, {3.73920122114679*^9, 
   3.739201243455297*^9}, 3.743075601121522*^9},
 ExpressionUUID -> "6d222e35-892d-4e5e-bb41-e513ce44ea23"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"fGradpart2", "=", 
   RowBox[{"fM", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Lambda]0", "[", 
        RowBox[{"{", "j", "}"}], "]"}], " ", 
       FractionBox[
        RowBox[{"C", "[", 
         RowBox[{"{", "j", "}"}], "]"}], 
        SqrtBox["\[Theta]"]]}], "+", 
      RowBox[{
       RowBox[{"\[Lambda]1", "[", 
        RowBox[{"{", "j", "}"}], "]"}], " ", 
       FractionBox[
        SuperscriptBox["C", "2"], "\[Theta]"], 
       FractionBox[
        RowBox[{"C", "[", 
         RowBox[{"{", "j", "}"}], "]"}], 
        SqrtBox["\[Theta]"]]}], "+", 
      RowBox[{
       RowBox[{"\[Lambda]2", "[", 
        RowBox[{"{", "j", "}"}], "]"}], " ", 
       FractionBox[
        SuperscriptBox["C", "4"], "\[Theta]"], 
       FractionBox[
        RowBox[{"C", "[", 
         RowBox[{"{", "j", "}"}], "]"}], 
        SqrtBox["\[Theta]"]]}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"fGradpart2$integrand", "=", 
    RowBox[{"Einstein", "[", 
     RowBox[{
      RowBox[{"Expand", "[", 
       RowBox[{"fGradpart2", " ", 
        RowBox[{"C", "[", 
         RowBox[{"{", "i", "}"}], "]"}]}], "]"}], "/.", 
      RowBox[{
       RowBox[{
        RowBox[{"C", "[", 
         RowBox[{"{", "i", "}"}], "]"}], " ", 
        RowBox[{"C", "[", 
         RowBox[{"{", "j", "}"}], "]"}]}], "\[Rule]", 
       RowBox[{
        FractionBox["1", "d"], 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i", ",", "j"}], "}"}], "]"}], 
        SuperscriptBox["C", "2"]}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"cons2", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0", "\[Equal]", 
          RowBox[{
           FractionBox[
            RowBox[{"2", " ", 
             SuperscriptBox["\[Pi]", 
              RowBox[{"d", "/", "2"}]]}], 
            RowBox[{"Gamma", "[", 
             FractionBox["d", "2"], "]"}]], " ", "m", 
           RowBox[{
            SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], 
            RowBox[{"fGradpart2$integrand", " ", 
             SuperscriptBox["C", 
              RowBox[{"d", "-", "1"}]], 
             RowBox[{"\[DifferentialD]", "C"}]}]}]}]}], ",", 
         RowBox[{
          RowBox[{"2", "qi"}], "\[Equal]", 
          RowBox[{
           FractionBox[
            RowBox[{"2", " ", 
             SuperscriptBox["\[Pi]", 
              RowBox[{"d", "/", "2"}]]}], 
            RowBox[{"Gamma", "[", 
             FractionBox["d", "2"], "]"}]], " ", "m", 
           RowBox[{
            SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], 
            RowBox[{"fGradpart2$integrand", " ", 
             SuperscriptBox["C", 
              RowBox[{"d", "+", "1"}]], 
             RowBox[{"\[DifferentialD]", "C"}]}]}]}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"ui2", "\[Equal]", 
          RowBox[{
           FractionBox[
            RowBox[{"2", " ", 
             SuperscriptBox["\[Pi]", 
              RowBox[{"d", "/", "2"}]]}], 
            RowBox[{"Gamma", "[", 
             FractionBox["d", "2"], "]"}]], " ", "m", 
           RowBox[{
            SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], 
            RowBox[{"fGradpart2$integrand", " ", 
             SuperscriptBox["C", 
              RowBox[{"d", "+", "3"}]], 
             RowBox[{"\[DifferentialD]", "C"}]}]}]}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\[Lambda]0", "[", 
          RowBox[{"{", "i", "}"}], "]"}], ",", 
         RowBox[{"\[Lambda]1", "[", 
          RowBox[{"{", "i", "}"}], "]"}], ",", 
         RowBox[{"\[Lambda]2", "[", 
          RowBox[{"{", "i", "}"}], "]"}]}], " ", "}"}]}], "]"}], 
     "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "/.", 
    "gammareplacements"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.7391985525119534`*^9, 3.73919868974585*^9}, {
  3.739198834126672*^9, 3.739199015059579*^9}, {3.7391997352860622`*^9, 
  3.739199894642144*^9}, {3.7391999666970043`*^9, 3.739199967056983*^9}, {
  3.743075700624404*^9, 3.74307577145885*^9}, {3.743075848517219*^9, 
  3.7430758799863443`*^9}},
 ExpressionUUID -> "5cdd75b0-1bf8-453f-bc93-4a81a4c55b15"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Lambda]0", "[", 
     RowBox[{"{", "i", "}"}], "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{"ui2", "-", 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{"6", "+", "d"}], ")"}], " ", "qi", " ", "\[Theta]"}]}], 
     RowBox[{"8", " ", 
      SuperscriptBox["\[Theta]", 
       RowBox[{"5", "/", "2"}]], " ", "\[Rho]"}]]}], ",", 
   RowBox[{
    RowBox[{"\[Lambda]1", "[", 
     RowBox[{"{", "i", "}"}], "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"-", "ui2"}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{"5", "+", "d"}], ")"}], " ", "qi", " ", "\[Theta]"}]}], 
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{"2", "+", "d"}], ")"}], " ", 
      SuperscriptBox["\[Theta]", 
       RowBox[{"5", "/", "2"}]], " ", "\[Rho]"}]]}], ",", 
   RowBox[{
    RowBox[{"\[Lambda]2", "[", 
     RowBox[{"{", "i", "}"}], "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{"ui2", "-", 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{"4", "+", "d"}], ")"}], " ", "qi", " ", "\[Theta]"}]}], 
     RowBox[{"8", " ", 
      RowBox[{"(", 
       RowBox[{"2", "+", "d"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"4", "+", "d"}], ")"}], " ", 
      SuperscriptBox["\[Theta]", 
       RowBox[{"7", "/", "2"}]], " ", "\[Rho]"}]]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7391999705780354`*^9, 3.739201251232379*^9, 3.743075729331285*^9, {
   3.743075854794132*^9, 3.7430758827422457`*^9}},
 ExpressionUUID -> "ada18c35-add7-47bf-abf5-ff39e2e72714"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", 
  StyleBox["check",
   FontColor->RGBColor[1, 0, 0]], "*)"}]], "Input",
 CellChangeTimes->{{3.743075932005451*^9, 3.743075938298524*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"\[Lambda]0", "[", 
          RowBox[{"{", "i", "}"}], "]"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"d", "+", "2"}], ")"}], 
          RowBox[{"\[Lambda]1", "[", 
           RowBox[{"{", "i", "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"d", "+", "2"}], ")"}], 
          RowBox[{"(", 
           RowBox[{"d", "+", "4"}], ")"}], 
          RowBox[{"\[Lambda]2", "[", 
           RowBox[{"{", "i", "}"}], "]"}]}]}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"d", "+", "2"}], ")"}], 
          RowBox[{"\[Lambda]0", "[", 
           RowBox[{"{", "i", "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"d", "+", "2"}], ")"}], 
          RowBox[{"(", 
           RowBox[{"d", "+", "4"}], ")"}], 
          RowBox[{"\[Lambda]1", "[", 
           RowBox[{"{", "i", "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"d", "+", "2"}], ")"}], 
          RowBox[{"(", 
           RowBox[{"d", "+", "4"}], ")"}], 
          RowBox[{"(", 
           RowBox[{"d", "+", "6"}], ")"}], 
          RowBox[{"\[Lambda]2", "[", 
           RowBox[{"{", "i", "}"}], "]"}]}]}], "\[Equal]", 
        RowBox[{"2", "qi"}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"d", "+", "2"}], ")"}], 
          RowBox[{"(", 
           RowBox[{"d", "+", "4"}], ")"}], 
          RowBox[{"\[Lambda]0", "[", 
           RowBox[{"{", "i", "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"d", "+", "2"}], ")"}], 
          RowBox[{"(", 
           RowBox[{"d", "+", "4"}], ")"}], 
          RowBox[{"(", 
           RowBox[{"d", "+", "6"}], ")"}], 
          RowBox[{"\[Lambda]1", "[", 
           RowBox[{"{", "i", "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"d", "+", "2"}], ")"}], 
          RowBox[{"(", 
           RowBox[{"d", "+", "4"}], ")"}], 
          RowBox[{"(", 
           RowBox[{"d", "+", "6"}], ")"}], 
          RowBox[{"(", 
           RowBox[{"d", "+", "8"}], ")"}], 
          RowBox[{"\[Lambda]2", "[", 
           RowBox[{"{", "i", "}"}], "]"}]}]}], "\[Equal]", "ui2"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Lambda]0", "[", 
        RowBox[{"{", "i", "}"}], "]"}], ",", 
       RowBox[{"\[Lambda]1", "[", 
        RowBox[{"{", "i", "}"}], "]"}], ",", 
       RowBox[{"\[Lambda]2", "[", 
        RowBox[{"{", "i", "}"}], "]"}]}], " ", "}"}]}], "]"}], "]"}], 
  "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], "Input",
 CellChangeTimes->{{3.7430760100975037`*^9, 3.743076124448234*^9}, {
  3.7430761604836493`*^9, 3.743076202962513*^9}, {3.743076241800323*^9, 
  3.743076243741406*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Lambda]0", "[", 
     RowBox[{"{", "i", "}"}], "]"}], "\[Rule]", 
    RowBox[{
     FractionBox["1", "8"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "4"}], " ", 
        RowBox[{"(", 
         RowBox[{"6", "+", "d"}], ")"}], " ", "qi"}], "+", "ui2"}], ")"}]}]}],
    ",", 
   RowBox[{
    RowBox[{"\[Lambda]1", "[", 
     RowBox[{"{", "i", "}"}], "]"}], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", "4"}], " ", 
        RowBox[{"(", 
         RowBox[{"5", "+", "d"}], ")"}], " ", "qi"}], "+", "ui2"}], 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{"2", "+", "d"}], ")"}]}]]}]}], ",", 
   RowBox[{
    RowBox[{"\[Lambda]2", "[", 
     RowBox[{"{", "i", "}"}], "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", "4"}], " ", 
       RowBox[{"(", 
        RowBox[{"4", "+", "d"}], ")"}], " ", "qi"}], "+", "ui2"}], 
     RowBox[{"8", " ", 
      RowBox[{"(", 
       RowBox[{"2", "+", "d"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"4", "+", "d"}], ")"}]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7430761858807297`*^9, 3.743076203656842*^9}, 
   3.743076244722662*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"fGradpart3", "=", 
   RowBox[{"fM", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Lambda]0", "[", 
        RowBox[{"{", 
         RowBox[{"k", ",", "l"}], "}"}], "]"}], " ", 
       FractionBox[
        RowBox[{
         RowBox[{"C", "[", 
          RowBox[{"{", "k", "}"}], "]"}], 
         RowBox[{"C", "[", 
          RowBox[{"{", "l", "}"}], "]"}]}], "\[Theta]"]}], "+", 
      RowBox[{
       RowBox[{"\[Lambda]1", "[", 
        RowBox[{"{", 
         RowBox[{"k", ",", "l"}], "}"}], "]"}], " ", 
       FractionBox[
        SuperscriptBox["C", "2"], "\[Theta]"], 
       FractionBox[
        RowBox[{
         RowBox[{"C", "[", 
          RowBox[{"{", "k", "}"}], "]"}], 
         RowBox[{"C", "[", 
          RowBox[{"{", "l", "}"}], "]"}]}], "\[Theta]"]}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fGradpart3$integrand", "=", 
   RowBox[{
    RowBox[{"Einstein", "[", 
     RowBox[{"Expand", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Expand", "[", 
         RowBox[{"fGradpart3", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"C", "[", 
              RowBox[{"{", "i", "}"}], "]"}], 
             RowBox[{"C", "[", 
              RowBox[{"{", "j", "}"}], "]"}]}], "-", 
            RowBox[{
             FractionBox["1", "d"], 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "j"}], "}"}], "]"}], 
             SuperscriptBox["C", "2"]}]}], ")"}]}], "]"}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"C", "[", 
            RowBox[{"{", "i", "}"}], "]"}], " ", 
           RowBox[{"C", "[", 
            RowBox[{"{", "j", "}"}], "]"}], " ", 
           RowBox[{"C", "[", 
            RowBox[{"{", "k", "}"}], "]"}], " ", 
           RowBox[{"C", "[", 
            RowBox[{"{", "l", "}"}], "]"}]}], "\[Rule]", 
          RowBox[{
           FractionBox["3", 
            RowBox[{"d", 
             RowBox[{"(", 
              RowBox[{"d", "+", "2"}], ")"}]}]], 
           RowBox[{"sym", "[", 
            RowBox[{
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "j"}], "}"}], "]"}], 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"k", ",", "l"}], "}"}], "]"}]}], "]"}], 
           SuperscriptBox["C", "4"]}]}], "}"}]}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"C", "[", 
           RowBox[{"{", "k", "}"}], "]"}], " ", 
          RowBox[{"C", "[", 
           RowBox[{"{", "l", "}"}], "]"}]}], "\[Rule]", 
         RowBox[{
          FractionBox["1", "d"], 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"k", ",", "l"}], "}"}], "]"}], 
          SuperscriptBox["C", "2"]}]}], "}"}]}], "]"}], "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Lambda]0", "[", 
        RowBox[{"{", 
         RowBox[{"s_", ",", "s_"}], "}"}], "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"\[Lambda]1", "[", 
        RowBox[{"{", 
         RowBox[{"s_", ",", "s_"}], "}"}], "]"}], "\[Rule]", "0"}]}], 
     "}"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"cons3", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\[Sigma]ij", "\[Equal]", 
          RowBox[{
           FractionBox[
            RowBox[{"2", " ", 
             SuperscriptBox["\[Pi]", 
              RowBox[{"d", "/", "2"}]]}], 
            RowBox[{"Gamma", "[", 
             FractionBox["d", "2"], "]"}]], " ", "m", 
           RowBox[{
            SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], 
            RowBox[{"fGradpart3$integrand", " ", 
             SuperscriptBox["C", 
              RowBox[{"d", "-", "1"}]], 
             RowBox[{"\[DifferentialD]", "C"}]}]}]}]}], " ", ",", 
         RowBox[{"u1ij", "\[Equal]", 
          RowBox[{
           FractionBox[
            RowBox[{"2", " ", 
             SuperscriptBox["\[Pi]", 
              RowBox[{"d", "/", "2"}]]}], 
            RowBox[{"Gamma", "[", 
             FractionBox["d", "2"], "]"}]], " ", "m", 
           RowBox[{
            SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], 
            RowBox[{"fGradpart3$integrand", " ", 
             SuperscriptBox["C", 
              RowBox[{"d", "+", "1"}]], 
             RowBox[{"\[DifferentialD]", "C"}]}]}]}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\[Lambda]0", "[", 
          RowBox[{"{", 
           RowBox[{"i", ",", "j"}], "}"}], "]"}], ",", 
         RowBox[{"\[Lambda]1", "[", 
          RowBox[{"{", 
           RowBox[{"i", ",", "j"}], "}"}], "]"}]}], " ", "}"}]}], "]"}], 
     "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "/.", 
    "gammareplacements"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.739199974881411*^9, 3.7391999753038683`*^9}, {
  3.7392000119710407`*^9, 3.73920014201821*^9}, {3.739200199922544*^9, 
  3.739200447839488*^9}, {3.739200566507942*^9, 3.739200574907557*^9}},
 ExpressionUUID -> "827abc93-af46-43d0-91c2-0deef6e1c524"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Lambda]0", "[", 
     RowBox[{"{", 
      RowBox[{"i", ",", "j"}], "}"}], "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"-", "u1ij"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"6", "+", "d"}], ")"}], " ", "\[Theta]", " ", 
       "\[Sigma]ij"}]}], 
     RowBox[{"4", " ", 
      SuperscriptBox["\[Theta]", "2"], " ", "\[Rho]"}]]}], ",", 
   RowBox[{
    RowBox[{"\[Lambda]1", "[", 
     RowBox[{"{", 
      RowBox[{"i", ",", "j"}], "}"}], "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{"u1ij", "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"4", "+", "d"}], ")"}], " ", "\[Theta]", " ", 
       "\[Sigma]ij"}]}], 
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{"4", "+", "d"}], ")"}], " ", 
      SuperscriptBox["\[Theta]", "2"], " ", "\[Rho]"}]]}]}], "}"}]], "Output",\

 CellChangeTimes->{
  3.7392001446188517`*^9, {3.739200332566472*^9, 3.7392003686912518`*^9}, {
   3.739200399868422*^9, 3.739200448858156*^9}, 3.739200577271246*^9, 
   3.739201259749814*^9, 3.743075903445792*^9},
 ExpressionUUID -> "f0cfac30-cdfb-46d1-9125-d5284cfbd87b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"fGradpart4", "=", 
   RowBox[{"fM", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Lambda]0", "[", 
       RowBox[{"{", 
        RowBox[{"l", ",", "r", ",", "s"}], "}"}], "]"}], " ", 
      FractionBox[
       RowBox[{
        RowBox[{"C", "[", 
         RowBox[{"{", "l", "}"}], "]"}], 
        RowBox[{"C", "[", 
         RowBox[{"{", "r", "}"}], "]"}], 
        RowBox[{"C", "[", 
         RowBox[{"{", "s", "}"}], "]"}]}], 
       RowBox[{"\[Theta]", 
        SqrtBox["\[Theta]"]}]]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"fGradpart4$integrand", "=", 
    RowBox[{
     RowBox[{"Einstein", "[", 
      RowBox[{"Expand", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Expand", "[", 
          RowBox[{"fGradpart4", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"C", "[", 
               RowBox[{"{", "i", "}"}], "]"}], 
              RowBox[{"C", "[", 
               RowBox[{"{", "j", "}"}], "]"}], 
              RowBox[{"C", "[", 
               RowBox[{"{", "k", "}"}], "]"}]}], "-", 
             RowBox[{
              FractionBox["1", 
               RowBox[{"d", "+", "2"}]], 
              SuperscriptBox["C", "2"], 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"C", "[", 
                  RowBox[{"{", "i", "}"}], "]"}], 
                 RowBox[{"\[Delta]", "[", 
                  RowBox[{"{", 
                   RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{"C", "[", 
                  RowBox[{"{", "j", "}"}], "]"}], 
                 RowBox[{"\[Delta]", "[", 
                  RowBox[{"{", 
                   RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{"C", "[", 
                  RowBox[{"{", "k", "}"}], "]"}], 
                 RowBox[{"\[Delta]", "[", 
                  RowBox[{"{", 
                   RowBox[{"i", ",", "j"}], "}"}], "]"}]}]}], ")"}]}]}], 
            ")"}]}], "]"}], "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"C", "[", 
             RowBox[{"{", "i", "}"}], "]"}], " ", 
            RowBox[{"C", "[", 
             RowBox[{"{", "j", "}"}], "]"}], " ", 
            RowBox[{"C", "[", 
             RowBox[{"{", "k", "}"}], "]"}], " ", 
            RowBox[{"C", "[", 
             RowBox[{"{", "l", "}"}], "]"}], " ", 
            RowBox[{"C", "[", 
             RowBox[{"{", "r", "}"}], "]"}], " ", 
            RowBox[{"C", "[", 
             RowBox[{"{", "s", "}"}], "]"}]}], "\[Rule]", 
           RowBox[{
            FractionBox["15", 
             RowBox[{"d", 
              RowBox[{"(", 
               RowBox[{"d", "+", "2"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"d", "+", "4"}], ")"}]}]], 
            RowBox[{"sym", "[", 
             RowBox[{
              RowBox[{"\[Delta]", "[", 
               RowBox[{"{", 
                RowBox[{"i", ",", "j"}], "}"}], "]"}], 
              RowBox[{"\[Delta]", "[", 
               RowBox[{"{", 
                RowBox[{"k", ",", "l"}], "}"}], "]"}], 
              RowBox[{"\[Delta]", "[", 
               RowBox[{"{", 
                RowBox[{"r", ",", "s"}], "}"}], "]"}]}], "]"}], 
            SuperscriptBox["C", "6"]}]}], "}"}]}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"C", "[", 
            RowBox[{"{", "i_", "}"}], "]"}], " ", 
           RowBox[{"C", "[", 
            RowBox[{"{", "j_", "}"}], "]"}], " ", 
           RowBox[{"C", "[", 
            RowBox[{"{", "k_", "}"}], "]"}], " ", 
           RowBox[{"C", "[", 
            RowBox[{"{", "l_", "}"}], "]"}]}], "\[Rule]", 
          RowBox[{
           FractionBox["3", 
            RowBox[{"d", 
             RowBox[{"(", 
              RowBox[{"d", "+", "2"}], ")"}]}]], 
           RowBox[{"sym", "[", 
            RowBox[{
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "j"}], "}"}], "]"}], 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"k", ",", "l"}], "}"}], "]"}]}], "]"}], 
           SuperscriptBox["C", "4"]}]}], "}"}]}], "]"}], "]"}], "/.", 
     RowBox[{
      RowBox[{"\[Lambda]0", "[", 
       RowBox[{"{", 
        RowBox[{"_", ",", "s_", ",", "s_"}], "}"}], "]"}], "\[Rule]", 
      "0"}]}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"cons4", "=", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"u0ijk", "\[Equal]", 
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", 
         SuperscriptBox["\[Pi]", 
          RowBox[{"d", "/", "2"}]]}], 
        RowBox[{"Gamma", "[", 
         FractionBox["d", "2"], "]"}]], " ", "m", 
       RowBox[{
        SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], 
        RowBox[{"fGradpart4$integrand", " ", 
         SuperscriptBox["C", 
          RowBox[{"d", "-", "1"}]], 
         RowBox[{"\[DifferentialD]", "C"}]}]}]}]}], ",", 
     RowBox[{"\[Lambda]0", "[", 
      RowBox[{"{", 
       RowBox[{"i", ",", "j", ",", "k"}], "}"}], "]"}]}], "]"}], 
   "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}]}], "Input",
 CellChangeTimes->{{3.739200610043229*^9, 3.739200610553692*^9}, {
  3.739200678040907*^9, 3.739200848940813*^9}, {3.739201086785733*^9, 
  3.739201089024394*^9}, {3.739201147425002*^9, 3.7392011873550587`*^9}},
 ExpressionUUID -> "60936ece-f0ac-4517-a042-c91cf16b3d5d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Lambda]0", "[", 
    RowBox[{"{", 
     RowBox[{"i", ",", "j", ",", "k"}], "}"}], "]"}], "\[Rule]", 
   FractionBox["u0ijk", 
    RowBox[{"6", " ", 
     SuperscriptBox["\[Theta]", 
      RowBox[{"3", "/", "2"}]], " ", "\[Rho]"}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.739201148329261*^9, 3.7392011881059313`*^9}, 
   3.739201268572762*^9, 3.743075912021908*^9},
 ExpressionUUID -> "85ebcf2b-c035-432d-a4c7-be32acc0f9c7"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Unknown variables in the moment systems", "Subsection",
 CellChangeTimes->{{3.73920158956443*^9, 
  3.73920162003659*^9}},ExpressionUUID->"f1e68f26-1781-47c4-87b4-\
aee6efe075f3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Unprotect", "[", "C", "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.7395514992550497`*^9, 
  3.739551508338293*^9}},ExpressionUUID->"ae4a6f5f-22ad-491e-a174-\
51360cae0ccf"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   StyleBox[
    RowBox[{"Only", " ", "for", " ", "13", " ", "moment", " ", 
     RowBox[{"equations", ".", " ", "It"}], " ", "shows", " ", "that", " ", 
     "w2", " ", "vanishes", " ", "for", " ", "G13", " ", "distribution", " ", 
     
     RowBox[{"function", "."}]}],
    FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"f13$u2", "=", 
     RowBox[{"fM", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{
         FractionBox["1", "2"], 
         FractionBox[
          RowBox[{"\[Sigma]", "[", 
           RowBox[{"{", 
            RowBox[{"i", ",", "j"}], "}"}], "]"}], 
          RowBox[{"\[Rho]", " ", 
           SuperscriptBox["\[Theta]", "2"]}]], 
         RowBox[{"C", "[", 
          RowBox[{"{", "i", "}"}], "]"}], 
         RowBox[{"C", "[", 
          RowBox[{"{", "j", "}"}], "]"}]}]}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"integrandw2", "=", 
    RowBox[{
     RowBox[{"Einstein", "[", 
      RowBox[{
       RowBox[{"Expand", "[", 
        RowBox[{
         SuperscriptBox["C", "4"], 
         RowBox[{"(", 
          RowBox[{"f13$u2", "-", "fM"}], ")"}]}], "]"}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"C", "[", 
           RowBox[{"{", "k_", "}"}], "]"}], " ", 
          RowBox[{"C", "[", 
           RowBox[{"{", "l_", "}"}], "]"}]}], "\[Rule]", 
         RowBox[{
          FractionBox["1", "d"], 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"k", ",", "l"}], "}"}], "]"}], 
          SuperscriptBox["C", "2"]}]}], "}"}]}], "]"}], "/.", 
     RowBox[{
      RowBox[{"\[Sigma]", "[", 
       RowBox[{"{", 
        RowBox[{"s_", ",", "s_"}], "}"}], "]"}], "\[Rule]", 
      "0"}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.73920278869116*^9, 3.739202811467599*^9}, {
  3.739202855266958*^9, 3.739202911833761*^9}, {3.739203055712322*^9, 
  3.739203116951414*^9}, {3.739203159772407*^9, 3.739203288628858*^9}, {
  3.73920332241712*^9, 3.7392033250222483`*^9}},
 ExpressionUUID -> "5b6a373b-c6bf-4c25-acec-074f2fead606"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.7392031923975573`*^9, 3.739203207146048*^9}, 
   3.739203238398973*^9, 
   3.739203329771982*^9},ExpressionUUID->"3daa19aa-de21-40b2-8f28-\
5ad5b4c49a3a"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"integrandu2", "=", 
   RowBox[{
    RowBox[{"Einstein", "[", 
     RowBox[{
      RowBox[{"Expand", "[", 
       RowBox[{
        SuperscriptBox["C", "4"], 
        RowBox[{"(", "f13$u2", ")"}]}], "]"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"C", "[", 
          RowBox[{"{", "k_", "}"}], "]"}], " ", 
         RowBox[{"C", "[", 
          RowBox[{"{", "l_", "}"}], "]"}]}], "\[Rule]", 
        RowBox[{
         FractionBox["1", "d"], 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"k", ",", "l"}], "}"}], "]"}], 
         SuperscriptBox["C", "2"]}]}], "}"}]}], "]"}], "/.", 
    RowBox[{
     RowBox[{"\[Sigma]", "[", 
      RowBox[{"{", 
       RowBox[{"s_", ",", "s_"}], "}"}], "]"}], "\[Rule]", "0"}]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.739203341095648*^9, 
  3.7392033554638968`*^9}},ExpressionUUID->"b7653b45-bcaf-450c-9fed-\
bd6993520677"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"u2G13", "\[Rule]", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox["\[Pi]", 
        RowBox[{"d", "/", "2"}]]}], 
      RowBox[{"Gamma", "[", 
       FractionBox["d", "2"], "]"}]], " ", "m", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], 
      RowBox[{"integrandu2", " ", 
       SuperscriptBox["C", 
        RowBox[{"d", "-", "1"}]], 
       RowBox[{"\[DifferentialD]", "C"}]}]}]}], "/.", "gammareplacements"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.7392034027598886`*^9, 
  3.739203414764962*^9}},ExpressionUUID->"a417b84a-6782-4b08-8894-\
ee10f36addfe"],

Cell[BoxData[
 RowBox[{"u2G13", "\[Rule]", 
  RowBox[{"d", " ", 
   RowBox[{"(", 
    RowBox[{"2", "+", "d"}], ")"}], " ", 
   SuperscriptBox["\[Theta]", "2"], " ", "\[Rho]"}]}]], "Output",
 CellChangeTimes->{
  3.739203416458345*^9},ExpressionUUID->"3694eb0e-4332-4a02-9b90-\
56d307563f82"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"u2fM", "\[Rule]", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox["\[Pi]", 
        RowBox[{"d", "/", "2"}]]}], 
      RowBox[{"Gamma", "[", 
       FractionBox["d", "2"], "]"}]], " ", "m", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], 
      RowBox[{
       SuperscriptBox["C", "4"], "fM", " ", 
       SuperscriptBox["C", 
        RowBox[{"d", "-", "1"}]], 
       RowBox[{"\[DifferentialD]", "C"}]}]}]}], "/.", "gammareplacements"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.739203452103773*^9, 
  3.739203468727709*^9}},ExpressionUUID->"f5dbbf96-38f3-423f-9c11-\
3224863dddec"],

Cell[BoxData[
 RowBox[{"u2fM", "\[Rule]", 
  RowBox[{"d", " ", 
   RowBox[{"(", 
    RowBox[{"2", "+", "d"}], ")"}], " ", 
   SuperscriptBox["\[Theta]", "2"], " ", "\[Rho]"}]}]], "Output",
 CellChangeTimes->{{3.739203461442812*^9, 
  3.739203469959257*^9}},ExpressionUUID->"1d094a6e-e181-415c-9f0f-\
5310ba62aa96"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   StyleBox[
    RowBox[{
     RowBox[{"Only", " ", "for", " ", "14"}], "-", 
     RowBox[{"moment", " ", 
      RowBox[{"equations", ".", " ", "It"}], " ", "shows", " ", "that", " ", 
      "w2", " ", "vanishes", " ", "for", " ", "G13", " ", "distribution", " ", 
      RowBox[{"function", "."}]}]}],
    FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"f14$u2", "=", 
     RowBox[{"fM", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{
         FractionBox["w2", 
          RowBox[{"8", "\[Rho]", " ", 
           SuperscriptBox["\[Theta]", "2"]}]], 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"2", " ", 
            FractionBox[
             SuperscriptBox["C", "2"], 
             RowBox[{"d", " ", "\[Theta]"}]]}], "+", 
           FractionBox[
            SuperscriptBox["C", "4"], 
            RowBox[{"d", 
             RowBox[{"(", 
              RowBox[{"d", "+", "2"}], ")"}], 
             SuperscriptBox["\[Theta]", "2"]}]]}], ")"}]}], "+", 
        RowBox[{
         FractionBox["1", "2"], 
         FractionBox[
          RowBox[{"\[Sigma]", "[", 
           RowBox[{"{", 
            RowBox[{"i", ",", "j"}], "}"}], "]"}], 
          RowBox[{"\[Rho]", " ", 
           SuperscriptBox["\[Theta]", "2"]}]], 
         RowBox[{"C", "[", 
          RowBox[{"{", "i", "}"}], "]"}], 
         RowBox[{"C", "[", 
          RowBox[{"{", "j", "}"}], "]"}]}]}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"integrandw2", "=", 
     RowBox[{
      RowBox[{"Einstein", "[", 
       RowBox[{
        RowBox[{"Expand", "[", 
         RowBox[{
          SuperscriptBox["C", "4"], 
          RowBox[{"(", 
           RowBox[{"f14$u2", "-", "fM"}], ")"}]}], "]"}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"C", "[", 
            RowBox[{"{", "k_", "}"}], "]"}], " ", 
           RowBox[{"C", "[", 
            RowBox[{"{", "l_", "}"}], "]"}]}], "\[Rule]", 
          RowBox[{
           FractionBox["1", "d"], 
           RowBox[{"\[Delta]", "[", 
            RowBox[{"{", 
             RowBox[{"k", ",", "l"}], "}"}], "]"}], 
           SuperscriptBox["C", "2"]}]}], "}"}]}], "]"}], "/.", 
      RowBox[{
       RowBox[{"\[Sigma]", "[", 
        RowBox[{"{", 
         RowBox[{"s_", ",", "s_"}], "}"}], "]"}], "\[Rule]", "0"}]}]}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.73920278869116*^9, 3.739202811467599*^9}, {
   3.739202855266958*^9, 3.739202911833761*^9}, {3.739203055712322*^9, 
   3.739203116951414*^9}, {3.739203159772407*^9, 3.739203288628858*^9}, {
   3.73920332241712*^9, 3.7392033250222483`*^9}, {3.739551405747636*^9, 
   3.739551484143415*^9}, {3.7395515206189327`*^9, 3.739551525681678*^9}, {
   3.739551939402355*^9, 3.73955194978509*^9}, 3.7395520442508783`*^9, 
   3.739552194490363*^9},
 ExpressionUUID -> "5b6a373b-c6bf-4c25-acec-074f2fead606"],

Cell[BoxData[
 RowBox[{
  RowBox[{"integrandu2", "=", 
   RowBox[{
    RowBox[{"Einstein", "[", 
     RowBox[{
      RowBox[{"Expand", "[", 
       RowBox[{
        SuperscriptBox["C", "4"], 
        RowBox[{"(", "f14$u2", ")"}]}], "]"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"C", "[", 
          RowBox[{"{", "k_", "}"}], "]"}], " ", 
         RowBox[{"C", "[", 
          RowBox[{"{", "l_", "}"}], "]"}]}], "\[Rule]", 
        RowBox[{
         FractionBox["1", "d"], 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"k", ",", "l"}], "}"}], "]"}], 
         SuperscriptBox["C", "2"]}]}], "}"}]}], "]"}], "/.", 
    RowBox[{
     RowBox[{"\[Sigma]", "[", 
      RowBox[{"{", 
       RowBox[{"s_", ",", "s_"}], "}"}], "]"}], "\[Rule]", "0"}]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.739203341095648*^9, 3.7392033554638968`*^9}, {
   3.73955168267985*^9, 3.7395516888480377`*^9}, 3.739552189939386*^9},
 ExpressionUUID -> "b7653b45-bcaf-450c-9fed-bd6993520677"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"u2G14", "\[Rule]", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"2", " ", 
        SuperscriptBox["\[Pi]", 
         RowBox[{"d", "/", "2"}]]}], 
       RowBox[{"Gamma", "[", 
        FractionBox["d", "2"], "]"}]], " ", "m", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], 
       RowBox[{"integrandu2", " ", 
        SuperscriptBox["C", 
         RowBox[{"d", "-", "1"}]], 
        RowBox[{"\[DifferentialD]", "C"}]}]}]}], "/.", "gammareplacements"}], 
    ",", "w2", ",", "Simplify"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7392034027598886`*^9, 3.739203414764962*^9}, {
  3.739551697534575*^9, 3.7395516977327747`*^9}, {3.739551834100195*^9, 
  3.739551843644272*^9}},
 ExpressionUUID -> "a417b84a-6782-4b08-8894-ee10f36addfe"],

Cell[BoxData[
 RowBox[{"u2G14", "\[Rule]", 
  RowBox[{"w2", "+", 
   RowBox[{"d", " ", 
    RowBox[{"(", 
     RowBox[{"2", "+", "d"}], ")"}], " ", 
    SuperscriptBox["\[Theta]", "2"], " ", "\[Rho]"}]}]}]], "Output",
 CellChangeTimes->{
  3.7395517484124928`*^9, {3.739551819202148*^9, 3.7395518476026297`*^9}, 
   3.739551981975181*^9, 
   3.739552067408452*^9},ExpressionUUID->"b035427f-19cf-4795-b1a1-\
c347600b3bbb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"w2G14", "\[Rule]", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"2", " ", 
        SuperscriptBox["\[Pi]", 
         RowBox[{"d", "/", "2"}]]}], 
       RowBox[{"Gamma", "[", 
        FractionBox["d", "2"], "]"}]], " ", "m", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], 
       RowBox[{"integrandw2", " ", 
        SuperscriptBox["C", 
         RowBox[{"d", "-", "1"}]], 
        RowBox[{"\[DifferentialD]", "C"}]}]}]}], "/.", "gammareplacements"}], 
    ",", "w2", ",", "Simplify"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7395520847825603`*^9, 
  3.739552103618411*^9}},ExpressionUUID->"9f084038-919d-4f06-ab48-\
f5585a9d2e91"],

Cell[BoxData[
 RowBox[{"w2G14", "\[Rule]", "w2"}]], "Output",
 CellChangeTimes->{
  3.739552106233255*^9},ExpressionUUID->"740bc495-5c46-4f06-af82-\
84e7b5d1cced"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"u2fM", "\[Rule]", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox["\[Pi]", 
        RowBox[{"d", "/", "2"}]]}], 
      RowBox[{"Gamma", "[", 
       FractionBox["d", "2"], "]"}]], " ", "m", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], 
      RowBox[{
       SuperscriptBox["C", "4"], "fM", " ", 
       SuperscriptBox["C", 
        RowBox[{"d", "-", "1"}]], 
       RowBox[{"\[DifferentialD]", "C"}]}]}]}], "/.", "gammareplacements"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.739203452103773*^9, 3.739203468727709*^9}},
 ExpressionUUID -> "f5dbbf96-38f3-423f-9c11-3224863dddec"],

Cell[BoxData[
 RowBox[{"u2fM", "\[Rule]", 
  RowBox[{"d", " ", 
   RowBox[{"(", 
    RowBox[{"2", "+", "d"}], ")"}], " ", 
   SuperscriptBox["\[Theta]", "2"], " ", "\[Rho]"}]}]], "Output",
 CellChangeTimes->{
  3.739551857561488*^9},ExpressionUUID->"83b7da14-d854-468f-8938-\
45334fc1c84f"]
}, Open  ]],

Cell[CellGroupData[{

Cell["G14 equations", "Subsubsection",
 CellChangeTimes->{{3.73920163649277*^9, 
  3.7392016439731007`*^9}},ExpressionUUID->"f671aa57-2f73-4d4e-82c2-\
d492830850d7"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"f14", "=", 
   RowBox[{"fM", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{
       FractionBox["1", "8"], 
       FractionBox["w2", 
        RowBox[{"\[Rho]", " ", 
         SuperscriptBox["\[Theta]", "2"]}]], 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{
          FractionBox["2", "d"], 
          FractionBox[
           SuperscriptBox["C", "2"], "\[Theta]"]}], "+", 
         RowBox[{
          FractionBox["1", 
           RowBox[{"d", 
            RowBox[{"(", 
             RowBox[{"d", "+", "2"}], ")"}]}]], 
          FractionBox[
           SuperscriptBox["C", "4"], 
           SuperscriptBox["\[Theta]", "2"]]}]}], ")"}]}], "+", 
      RowBox[{
       FractionBox["1", "2"], 
       FractionBox[
        RowBox[{"\[Sigma]", "[", 
         RowBox[{"{", 
          RowBox[{"i", ",", "j"}], "}"}], "]"}], 
        RowBox[{"\[Rho]", " ", 
         SuperscriptBox["\[Theta]", "2"]}]], 
       RowBox[{"C", "[", 
        RowBox[{"{", "i", "}"}], "]"}], 
       RowBox[{"C", "[", 
        RowBox[{"{", "j", "}"}], "]"}]}], "+", 
      RowBox[{
       FractionBox[
        RowBox[{"q", "[", 
         RowBox[{"{", "i", "}"}], "]"}], 
        RowBox[{"\[Rho]", " ", 
         SuperscriptBox["\[Theta]", "2"]}]], 
       RowBox[{"C", "[", 
        RowBox[{"{", "i", "}"}], "]"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          FractionBox["1", 
           RowBox[{"d", "+", "2"}]], 
          FractionBox[
           SuperscriptBox["C", "2"], "\[Theta]"]}], "-", "1"}], ")"}]}]}], 
     ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"f14$u0ijk", "=", 
   RowBox[{"fM", " ", 
    FractionBox[
     RowBox[{"q", "[", 
      RowBox[{"{", "l", "}"}], "]"}], 
     RowBox[{"\[Rho]", " ", 
      SuperscriptBox["\[Theta]", "2"]}]], 
    RowBox[{"C", "[", 
     RowBox[{"{", "l", "}"}], "]"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       FractionBox["1", 
        RowBox[{"d", "+", "2"}]], 
       FractionBox[
        SuperscriptBox["C", "2"], "\[Theta]"]}], "-", "1"}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"integrandu0ijk", "=", 
  RowBox[{"Expand", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Expand", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"C", "[", 
           RowBox[{"{", "i", "}"}], "]"}], 
          RowBox[{"C", "[", 
           RowBox[{"{", "j", "}"}], "]"}], 
          RowBox[{"C", "[", 
           RowBox[{"{", "k", "}"}], "]"}]}], "-", 
         RowBox[{
          FractionBox["3", 
           RowBox[{"d", "+", "2"}]], 
          SuperscriptBox["C", "2"], 
          RowBox[{"sym", "[", 
           RowBox[{
            RowBox[{"C", "[", 
             RowBox[{"{", "i", "}"}], "]"}], 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "]"}]}]}], ")"}], 
       "f14$u0ijk"}], "]"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"C", "[", 
         RowBox[{"{", "i_", "}"}], "]"}], " ", 
        RowBox[{"C", "[", 
         RowBox[{"{", "j_", "}"}], "]"}], " ", 
        RowBox[{"C", "[", 
         RowBox[{"{", "k_", "}"}], "]"}], " ", 
        RowBox[{"C", "[", 
         RowBox[{"{", "l_", "}"}], "]"}]}], "\[Rule]", 
       RowBox[{
        FractionBox["3", 
         RowBox[{"d", 
          RowBox[{"(", 
           RowBox[{"d", "+", "2"}], ")"}]}]], 
        RowBox[{"sym", "[", 
         RowBox[{
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i", ",", "j"}], "}"}], "]"}], 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"k", ",", "l"}], "}"}], "]"}]}], "]"}], 
        SuperscriptBox["C", "4"]}]}], "}"}]}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"C", "[", 
        RowBox[{"{", "k_", "}"}], "]"}], " ", 
       RowBox[{"C", "[", 
        RowBox[{"{", "l_", "}"}], "]"}]}], "\[Rule]", 
      RowBox[{
       FractionBox["1", "d"], 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"k", ",", "l"}], "}"}], "]"}], 
       SuperscriptBox["C", "2"]}]}], "}"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.7392016705251083`*^9, 3.739201764894866*^9}, {
  3.739201802688751*^9, 3.739201856127891*^9}, {3.739201910051856*^9, 
  3.739202148568431*^9}, {3.739202186762775*^9, 3.739202303992701*^9}, {
  3.739202337327539*^9, 3.739202342708406*^9}, {3.7430934020411997`*^9, 
  3.743093402527027*^9}, {3.74309504748365*^9, 3.743095049590024*^9}},
 ExpressionUUID -> "f950dd12-2abe-4971-abf0-77554dcb000d"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.739202223277038*^9, 3.739202243973258*^9}, 
   3.739202309521023*^9, {3.739202343363471*^9, 3.7392023492852993`*^9}, 
   3.7430934077953053`*^9, 3.743095052349584*^9},
 ExpressionUUID -> "dd6ed0e7-d6e9-4d11-a32b-b046bae8a6c0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"f14$u1ij", "=", 
   RowBox[{"fM", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{
       FractionBox["1", "8"], 
       FractionBox["w2", 
        RowBox[{"\[Rho]", " ", 
         SuperscriptBox["\[Theta]", "2"]}]], 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{
          FractionBox["2", "d"], 
          FractionBox[
           SuperscriptBox["C", "2"], "\[Theta]"]}], "+", 
         RowBox[{
          FractionBox["1", 
           RowBox[{"d", 
            RowBox[{"(", 
             RowBox[{"d", "+", "2"}], ")"}]}]], 
          FractionBox[
           SuperscriptBox["C", "4"], 
           SuperscriptBox["\[Theta]", "2"]]}]}], ")"}]}], "+", 
      RowBox[{
       FractionBox["1", "2"], 
       FractionBox[
        RowBox[{"\[Sigma]", "[", 
         RowBox[{"{", 
          RowBox[{"k", ",", "l"}], "}"}], "]"}], 
        RowBox[{"\[Rho]", " ", 
         SuperscriptBox["\[Theta]", "2"]}]], 
       RowBox[{"C", "[", 
        RowBox[{"{", "k", "}"}], "]"}], 
       RowBox[{"C", "[", 
        RowBox[{"{", "l", "}"}], "]"}]}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"integrandu1ij", "=", 
    RowBox[{
     RowBox[{"Einstein", "[", 
      RowBox[{"Expand", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Expand", "[", 
          RowBox[{
           SuperscriptBox["C", "2"], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"C", "[", 
               RowBox[{"{", "i", "}"}], "]"}], 
              RowBox[{"C", "[", 
               RowBox[{"{", "j", "}"}], "]"}]}], "-", 
             RowBox[{
              FractionBox["1", "d"], 
              RowBox[{"\[Delta]", "[", 
               RowBox[{"{", 
                RowBox[{"i", ",", "j"}], "}"}], "]"}], 
              SuperscriptBox["C", "2"]}]}], ")"}], "f14$u1ij"}], "]"}], "/.", 
         
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"C", "[", 
             RowBox[{"{", "i_", "}"}], "]"}], " ", 
            RowBox[{"C", "[", 
             RowBox[{"{", "j_", "}"}], "]"}], " ", 
            RowBox[{"C", "[", 
             RowBox[{"{", "k_", "}"}], "]"}], " ", 
            RowBox[{"C", "[", 
             RowBox[{"{", "l_", "}"}], "]"}]}], "\[Rule]", 
           RowBox[{
            FractionBox["3", 
             RowBox[{"d", 
              RowBox[{"(", 
               RowBox[{"d", "+", "2"}], ")"}]}]], 
            RowBox[{"sym", "[", 
             RowBox[{
              RowBox[{"\[Delta]", "[", 
               RowBox[{"{", 
                RowBox[{"i", ",", "j"}], "}"}], "]"}], 
              RowBox[{"\[Delta]", "[", 
               RowBox[{"{", 
                RowBox[{"k", ",", "l"}], "}"}], "]"}]}], "]"}], 
            SuperscriptBox["C", "4"]}]}], "}"}]}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"C", "[", 
            RowBox[{"{", "k_", "}"}], "]"}], " ", 
           RowBox[{"C", "[", 
            RowBox[{"{", "l_", "}"}], "]"}]}], "\[Rule]", 
          RowBox[{
           FractionBox["1", "d"], 
           RowBox[{"\[Delta]", "[", 
            RowBox[{"{", 
             RowBox[{"k", ",", "l"}], "}"}], "]"}], 
           SuperscriptBox["C", "2"]}]}], "}"}]}], "]"}], "]"}], "/.", 
     RowBox[{
      RowBox[{"\[Sigma]", "[", 
       RowBox[{"{", 
        RowBox[{"i_", ",", "i_"}], "}"}], "]"}], "\[Rule]", "0"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"u1", "[", 
   RowBox[{"{", 
    RowBox[{"i", ",", "j"}], "}"}], "]"}], "\[Rule]", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox["\[Pi]", 
        RowBox[{"d", "/", "2"}]]}], 
      RowBox[{"Gamma", "[", 
       FractionBox["d", "2"], "]"}]], " ", "m", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], 
      RowBox[{"integrandu1ij", " ", 
       SuperscriptBox["C", 
        RowBox[{"d", "-", "1"}]], 
       RowBox[{"\[DifferentialD]", "C"}]}]}]}], "/.", "gammareplacements"}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.7392023961073027`*^9, 3.739202605909925*^9}, {
   3.739202721166814*^9, 3.739202722379615*^9}, {3.743093451524823*^9, 
   3.743093451957111*^9}, 3.743095066892067*^9},
 ExpressionUUID -> "0647a71a-cbb4-4230-a18c-d1f1441c0467"],

Cell[BoxData[
 RowBox[{
  RowBox[{"u1", "[", 
   RowBox[{"{", 
    RowBox[{"i", ",", "j"}], "}"}], "]"}], "\[Rule]", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"4", "+", "d"}], ")"}], " ", "\[Theta]", " ", 
   RowBox[{"\[Sigma]", "[", 
    RowBox[{"{", 
     RowBox[{"i", ",", "j"}], "}"}], "]"}]}]}]], "Output",
 CellChangeTimes->{{3.73920247889192*^9, 3.7392026000506287`*^9}, 
   3.739202728044145*^9, 3.74309345791735*^9, 3.74309506840406*^9},
 ExpressionUUID -> "a3a9301a-61a6-47a9-b1d3-c64790bfd42e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"f14u2i", "=", 
   RowBox[{"fM", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{"q", "[", 
        RowBox[{"{", "j", "}"}], "]"}], 
       RowBox[{"\[Rho]", " ", 
        SuperscriptBox["\[Theta]", "2"]}]], 
      RowBox[{"C", "[", 
       RowBox[{"{", "j", "}"}], "]"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FractionBox["1", 
          RowBox[{"d", "+", "2"}]], 
         FractionBox[
          SuperscriptBox["C", "2"], "\[Theta]"]}], "-", "1"}], ")"}]}], 
     ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"integrandu2i", "=", 
   RowBox[{"Einstein", "[", 
    RowBox[{
     RowBox[{
      SuperscriptBox["C", "4"], 
      RowBox[{"C", "[", 
       RowBox[{"{", "i", "}"}], "]"}], "f14u2i"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"C", "[", 
         RowBox[{"{", "k_", "}"}], "]"}], " ", 
        RowBox[{"C", "[", 
         RowBox[{"{", "l_", "}"}], "]"}]}], "\[Rule]", 
       RowBox[{
        FractionBox["1", "d"], 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"k", ",", "l"}], "}"}], "]"}], 
        SuperscriptBox["C", "2"]}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"u2", "[", 
   RowBox[{"{", "i", "}"}], "]"}], "\[Rule]", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox["\[Pi]", 
        RowBox[{"d", "/", "2"}]]}], 
      RowBox[{"Gamma", "[", 
       FractionBox["d", "2"], "]"}]], " ", "m", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], 
      RowBox[{"integrandu2i", " ", 
       SuperscriptBox["C", 
        RowBox[{"d", "-", "1"}]], 
       RowBox[{"\[DifferentialD]", "C"}]}]}]}], "/.", "gammareplacements"}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.739203501995183*^9, 3.739203648278881*^9}},
 ExpressionUUID -> "d2d04e98-16db-4172-a18d-80bc83d001c0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"u2", "[", 
   RowBox[{"{", "i", "}"}], "]"}], "\[Rule]", 
  RowBox[{"4", " ", 
   RowBox[{"(", 
    RowBox[{"4", "+", "d"}], ")"}], " ", "\[Theta]", " ", 
   RowBox[{"q", "[", 
    RowBox[{"{", "i", "}"}], "]"}]}]}]], "Output",
 CellChangeTimes->{{3.739203573226038*^9, 3.739203611948299*^9}, 
   3.7392036503501883`*^9, 3.743093474852168*^9},
 ExpressionUUID -> "574fbb1e-3f7c-44e1-a0b4-3a59bb110721"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["G26 equations", "Subsubsection",
 CellChangeTimes->{{3.73920163649277*^9, 3.7392016439731007`*^9}, {
  3.739203695483931*^9, 
  3.739203696794433*^9}},ExpressionUUID->"445d06b9-c126-4c91-810e-\
fbdc2a1a6833"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"f26", "=", 
    RowBox[{"fM", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{
        FractionBox["1", "8"], 
        FractionBox["w2", 
         RowBox[{"\[Rho]", " ", 
          SuperscriptBox["\[Theta]", "2"]}]], 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{
           FractionBox["2", "d"], 
           FractionBox[
            SuperscriptBox["C", "2"], "\[Theta]"]}], "+", 
          RowBox[{
           FractionBox["1", 
            RowBox[{"d", 
             RowBox[{"(", 
              RowBox[{"d", "+", "2"}], ")"}]}]], 
           FractionBox[
            SuperscriptBox["C", "4"], 
            SuperscriptBox["\[Theta]", "2"]]}]}], ")"}]}], "+", 
       RowBox[{
        FractionBox["1", "2"], 
        FractionBox[
         RowBox[{"\[Sigma]", "[", 
          RowBox[{"{", 
           RowBox[{"r", ",", "s"}], "}"}], "]"}], 
         RowBox[{"\[Rho]", " ", 
          SuperscriptBox["\[Theta]", "2"]}]], 
        RowBox[{"C", "[", 
         RowBox[{"{", "r", "}"}], "]"}], 
        RowBox[{"C", "[", 
         RowBox[{"{", "s", "}"}], "]"}]}], "+", 
       RowBox[{
        FractionBox[
         RowBox[{"q", "[", 
          RowBox[{"{", "r", "}"}], "]"}], 
         RowBox[{"\[Rho]", " ", 
          SuperscriptBox["\[Theta]", "2"]}]], 
        RowBox[{"C", "[", 
         RowBox[{"{", "r", "}"}], "]"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["1", 
            RowBox[{"d", "+", "2"}]], 
           FractionBox[
            SuperscriptBox["C", "2"], "\[Theta]"]}], "-", "1"}], ")"}]}], "+", 
       FractionBox[
        RowBox[{
         RowBox[{"u0", "[", 
          RowBox[{"{", 
           RowBox[{"l", ",", "r", ",", "s"}], "}"}], "]"}], 
         RowBox[{"C", "[", 
          RowBox[{"{", "l", "}"}], "]"}], 
         RowBox[{"C", "[", 
          RowBox[{"{", "r", "}"}], "]"}], 
         RowBox[{"C", "[", 
          RowBox[{"{", "s", "}"}], "]"}]}], 
        RowBox[{"6", "\[Rho]", " ", 
         SuperscriptBox["\[Theta]", "3"]}]], "+", 
       RowBox[{
        FractionBox["1", "4"], 
        FractionBox[
         RowBox[{
          RowBox[{"u1", "[", 
           RowBox[{"{", 
            RowBox[{"r", ",", "s"}], "}"}], "]"}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"d", "+", "4"}], ")"}], "\[Theta]", " ", 
           RowBox[{"\[Sigma]", "[", 
            RowBox[{"{", 
             RowBox[{"r", ",", "s"}], "}"}], "]"}]}]}], 
         RowBox[{"\[Rho]", " ", 
          SuperscriptBox["\[Theta]", "2"]}]], 
        FractionBox[
         RowBox[{
          RowBox[{"C", "[", 
           RowBox[{"{", "r", "}"}], "]"}], 
          RowBox[{"C", "[", 
           RowBox[{"{", "s", "}"}], "]"}]}], "\[Theta]"], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["1", 
            RowBox[{"d", "+", "4"}]], 
           FractionBox[
            SuperscriptBox["C", "2"], "\[Theta]"]}], "-", "1"}], ")"}]}]}], 
      ")"}]}]}], ";"}], "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.743093479892271*^9, 3.7430934802522097`*^9}, 
   3.7430950760762978`*^9},
 ExpressionUUID -> "f9d0fc88-02c4-4639-ac44-0541a5eceb3c"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"f26$u0ijkl", "=", 
    RowBox[{"fM", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{
        FractionBox["1", "8"], 
        FractionBox["w2", 
         RowBox[{"\[Rho]", " ", 
          SuperscriptBox["\[Theta]", "2"]}]], 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{
           FractionBox["2", "d"], 
           FractionBox[
            SuperscriptBox["C", "2"], "\[Theta]"]}], "+", 
          RowBox[{
           FractionBox["1", 
            RowBox[{"d", 
             RowBox[{"(", 
              RowBox[{"d", "+", "2"}], ")"}]}]], 
           FractionBox[
            SuperscriptBox["C", "4"], 
            SuperscriptBox["\[Theta]", "2"]]}]}], ")"}]}], "+", 
       RowBox[{
        FractionBox["1", "2"], 
        FractionBox[
         RowBox[{"\[Sigma]", "[", 
          RowBox[{"{", 
           RowBox[{"r", ",", "s"}], "}"}], "]"}], 
         RowBox[{"\[Rho]", " ", 
          SuperscriptBox["\[Theta]", "2"]}]], 
        RowBox[{"C", "[", 
         RowBox[{"{", "r", "}"}], "]"}], 
        RowBox[{"C", "[", 
         RowBox[{"{", "s", "}"}], "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "4"], 
        FractionBox[
         RowBox[{
          RowBox[{"u1", "[", 
           RowBox[{"{", 
            RowBox[{"r", ",", "s"}], "}"}], "]"}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"d", "+", "4"}], ")"}], "\[Theta]", " ", 
           RowBox[{"\[Sigma]", "[", 
            RowBox[{"{", 
             RowBox[{"r", ",", "s"}], "}"}], "]"}]}]}], 
         RowBox[{"\[Rho]", " ", 
          SuperscriptBox["\[Theta]", "2"]}]], 
        FractionBox[
         RowBox[{
          RowBox[{"C", "[", 
           RowBox[{"{", "r", "}"}], "]"}], 
          RowBox[{"C", "[", 
           RowBox[{"{", "s", "}"}], "]"}]}], "\[Theta]"], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["1", 
            RowBox[{"d", "+", "4"}]], 
           FractionBox[
            SuperscriptBox["C", "2"], "\[Theta]"]}], "-", "1"}], ")"}]}]}], 
      ")"}]}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"integrandu0ijkl", "=", 
    RowBox[{"Einstein", "[", 
     RowBox[{"Expand", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Expand", "[", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"C", "[", 
               RowBox[{"{", "i", "}"}], "]"}], 
              RowBox[{"C", "[", 
               RowBox[{"{", "j", "}"}], "]"}], 
              RowBox[{"C", "[", 
               RowBox[{"{", "k", "}"}], "]"}], 
              RowBox[{"C", "[", 
               RowBox[{"{", "l", "}"}], "]"}]}], "-", 
             RowBox[{
              FractionBox["1", 
               RowBox[{"4", "+", "d"}]], 
              SuperscriptBox["C", "2"], 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"C", "[", 
                  RowBox[{"{", "k", "}"}], "]"}], 
                 RowBox[{"C", "[", 
                  RowBox[{"{", "l", "}"}], "]"}], 
                 RowBox[{"\[Delta]", "[", 
                  RowBox[{"{", 
                   RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{"C", "[", 
                  RowBox[{"{", "j", "}"}], "]"}], 
                 RowBox[{"C", "[", 
                  RowBox[{"{", "l", "}"}], "]"}], 
                 RowBox[{"\[Delta]", "[", 
                  RowBox[{"{", 
                   RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{"C", "[", 
                  RowBox[{"{", "j", "}"}], "]"}], 
                 RowBox[{"C", "[", 
                  RowBox[{"{", "k", "}"}], "]"}], 
                 RowBox[{"\[Delta]", "[", 
                  RowBox[{"{", 
                   RowBox[{"i", ",", "l"}], "}"}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{"C", "[", 
                  RowBox[{"{", "i", "}"}], "]"}], 
                 RowBox[{"C", "[", 
                  RowBox[{"{", "l", "}"}], "]"}], 
                 RowBox[{"\[Delta]", "[", 
                  RowBox[{"{", 
                   RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{"C", "[", 
                  RowBox[{"{", "i", "}"}], "]"}], 
                 RowBox[{"C", "[", 
                  RowBox[{"{", "k", "}"}], "]"}], 
                 RowBox[{"\[Delta]", "[", 
                  RowBox[{"{", 
                   RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{"C", "[", 
                  RowBox[{"{", "i", "}"}], "]"}], 
                 RowBox[{"C", "[", 
                  RowBox[{"{", "j", "}"}], "]"}], 
                 RowBox[{"\[Delta]", "[", 
                  RowBox[{"{", 
                   RowBox[{"k", ",", "l"}], "}"}], "]"}]}]}], ")"}]}], "+", 
             RowBox[{
              FractionBox["1", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"2", "+", "d"}], ")"}], 
                RowBox[{"(", 
                 RowBox[{"4", "+", "d"}], ")"}]}]], 
              SuperscriptBox["C", "4"], 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"\[Delta]", "[", 
                  RowBox[{"{", 
                   RowBox[{"i", ",", "l"}], "}"}], "]"}], 
                 RowBox[{"\[Delta]", "[", 
                  RowBox[{"{", 
                   RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{"\[Delta]", "[", 
                  RowBox[{"{", 
                   RowBox[{"i", ",", "k"}], "}"}], "]"}], 
                 RowBox[{"\[Delta]", "[", 
                  RowBox[{"{", 
                   RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{"\[Delta]", "[", 
                  RowBox[{"{", 
                   RowBox[{"i", ",", "j"}], "}"}], "]"}], 
                 RowBox[{"\[Delta]", "[", 
                  RowBox[{"{", 
                   RowBox[{"k", ",", "l"}], "}"}], "]"}]}]}], ")"}]}]}], 
            ")"}], "f26$u0ijkl"}], "]"}], "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"C", "[", 
             RowBox[{"{", "i_", "}"}], "]"}], " ", 
            RowBox[{"C", "[", 
             RowBox[{"{", "j_", "}"}], "]"}], " ", 
            RowBox[{"C", "[", 
             RowBox[{"{", "k_", "}"}], "]"}], " ", 
            RowBox[{"C", "[", 
             RowBox[{"{", "l_", "}"}], "]"}], " ", 
            RowBox[{"C", "[", 
             RowBox[{"{", "r_", "}"}], "]"}], " ", 
            RowBox[{"C", "[", 
             RowBox[{"{", "s_", "}"}], "]"}]}], "\[Rule]", 
           RowBox[{
            FractionBox["15", 
             RowBox[{"d", 
              RowBox[{"(", 
               RowBox[{"d", "+", "2"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"d", "+", "4"}], ")"}]}]], 
            RowBox[{"sym", "[", 
             RowBox[{
              RowBox[{"\[Delta]", "[", 
               RowBox[{"{", 
                RowBox[{"i", ",", "j"}], "}"}], "]"}], 
              RowBox[{"\[Delta]", "[", 
               RowBox[{"{", 
                RowBox[{"k", ",", "l"}], "}"}], "]"}], 
              RowBox[{"\[Delta]", "[", 
               RowBox[{"{", 
                RowBox[{"r", ",", "s"}], "}"}], "]"}]}], "]"}], 
            SuperscriptBox["C", "6"]}]}], "}"}]}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"C", "[", 
            RowBox[{"{", "i_", "}"}], "]"}], " ", 
           RowBox[{"C", "[", 
            RowBox[{"{", "j_", "}"}], "]"}], " ", 
           RowBox[{"C", "[", 
            RowBox[{"{", "k_", "}"}], "]"}], " ", 
           RowBox[{"C", "[", 
            RowBox[{"{", "l_", "}"}], "]"}]}], "\[Rule]", 
          RowBox[{
           FractionBox["3", 
            RowBox[{"d", 
             RowBox[{"(", 
              RowBox[{"d", "+", "2"}], ")"}]}]], 
           RowBox[{"sym", "[", 
            RowBox[{
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "j"}], "}"}], "]"}], 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"k", ",", "l"}], "}"}], "]"}]}], "]"}], 
           SuperscriptBox["C", "4"]}]}], "}"}]}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"C", "[", 
           RowBox[{"{", "k_", "}"}], "]"}], " ", 
          RowBox[{"C", "[", 
           RowBox[{"{", "l_", "}"}], "]"}]}], "\[Rule]", 
         RowBox[{
          FractionBox["1", "d"], 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"k", ",", "l"}], "}"}], "]"}], 
          SuperscriptBox["C", "2"]}]}], "}"}]}], "]"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"u0", "[", 
   RowBox[{"{", 
    RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}], "]"}], "\[Rule]", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox["\[Pi]", 
        RowBox[{"d", "/", "2"}]]}], 
      RowBox[{"Gamma", "[", 
       FractionBox["d", "2"], "]"}]], " ", "m", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], 
      RowBox[{"integrandu0ijkl", " ", 
       SuperscriptBox["C", 
        RowBox[{"d", "-", "1"}]], 
       RowBox[{"\[DifferentialD]", "C"}]}]}]}], "/.", "gammareplacements"}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.739204379091963*^9, 3.739204418765747*^9}, {
   3.739204510283558*^9, 3.7392045259868793`*^9}, {3.739204761293642*^9, 
   3.7392047852049103`*^9}, 3.7392048334098787`*^9, {3.7392048685708027`*^9, 
   3.7392048791215973`*^9}, 3.7392049404079313`*^9, {3.7392050715075483`*^9, 
   3.739205073569521*^9}, {3.7430934939178762`*^9, 3.743093494286002*^9}, 
   3.743095081444564*^9},
 ExpressionUUID -> "1e348c5a-83e7-4a32-81c4-44cd579fd7b5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"u0", "[", 
   RowBox[{"{", 
    RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}], "]"}], "\[Rule]", 
  "0"}]], "Output",
 CellChangeTimes->{3.7392050781209993`*^9, 3.74309350345343*^9, 
  3.743095085921268*^9},
 ExpressionUUID -> "959c7d1c-157a-4d64-9003-9bba5a328da4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"f26$u1ijk", "=", 
   RowBox[{"fM", " ", 
    FractionBox[
     RowBox[{
      RowBox[{"u0", "[", 
       RowBox[{"{", 
        RowBox[{"l", ",", "r", ",", "s"}], "}"}], "]"}], 
      RowBox[{"C", "[", 
       RowBox[{"{", "l", "}"}], "]"}], 
      RowBox[{"C", "[", 
       RowBox[{"{", "r", "}"}], "]"}], 
      RowBox[{"C", "[", 
       RowBox[{"{", "s", "}"}], "]"}]}], 
     RowBox[{"6", "\[Rho]", " ", 
      SuperscriptBox["\[Theta]", "3"]}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"integrandu1ijk", "=", 
    RowBox[{
     RowBox[{"Einstein", "[", 
      RowBox[{"Expand", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Expand", "[", 
           RowBox[{
            SuperscriptBox["C", "2"], 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"C", "[", 
                RowBox[{"{", "i", "}"}], "]"}], 
               RowBox[{"C", "[", 
                RowBox[{"{", "j", "}"}], "]"}], 
               RowBox[{"C", "[", 
                RowBox[{"{", "k", "}"}], "]"}]}], "-", 
              RowBox[{
               FractionBox["3", 
                RowBox[{"d", "+", "2"}]], 
               SuperscriptBox["C", "2"], 
               RowBox[{"sym", "[", 
                RowBox[{
                 RowBox[{"C", "[", 
                  RowBox[{"{", "i", "}"}], "]"}], 
                 RowBox[{"\[Delta]", "[", 
                  RowBox[{"{", 
                   RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "]"}]}]}], ")"}], 
            "f26$u1ijk"}], "]"}], "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"C", "[", 
              RowBox[{"{", "i_", "}"}], "]"}], " ", 
             RowBox[{"C", "[", 
              RowBox[{"{", "j_", "}"}], "]"}], " ", 
             RowBox[{"C", "[", 
              RowBox[{"{", "k_", "}"}], "]"}], " ", 
             RowBox[{"C", "[", 
              RowBox[{"{", "l_", "}"}], "]"}], " ", 
             RowBox[{"C", "[", 
              RowBox[{"{", "r_", "}"}], "]"}], " ", 
             RowBox[{"C", "[", 
              RowBox[{"{", "s_", "}"}], "]"}]}], "\[Rule]", 
            RowBox[{
             FractionBox["15", 
              RowBox[{"d", 
               RowBox[{"(", 
                RowBox[{"d", "+", "2"}], ")"}], 
               RowBox[{"(", 
                RowBox[{"d", "+", "4"}], ")"}]}]], 
             RowBox[{"sym", "[", 
              RowBox[{
               RowBox[{"\[Delta]", "[", 
                RowBox[{"{", 
                 RowBox[{"i", ",", "j"}], "}"}], "]"}], 
               RowBox[{"\[Delta]", "[", 
                RowBox[{"{", 
                 RowBox[{"k", ",", "l"}], "}"}], "]"}], 
               RowBox[{"\[Delta]", "[", 
                RowBox[{"{", 
                 RowBox[{"r", ",", "s"}], "}"}], "]"}]}], "]"}], 
             SuperscriptBox["C", "6"]}]}], "}"}]}], "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"C", "[", 
             RowBox[{"{", "i_", "}"}], "]"}], " ", 
            RowBox[{"C", "[", 
             RowBox[{"{", "j_", "}"}], "]"}], " ", 
            RowBox[{"C", "[", 
             RowBox[{"{", "k_", "}"}], "]"}], " ", 
            RowBox[{"C", "[", 
             RowBox[{"{", "l_", "}"}], "]"}]}], "\[Rule]", 
           RowBox[{
            FractionBox["3", 
             RowBox[{"d", 
              RowBox[{"(", 
               RowBox[{"d", "+", "2"}], ")"}]}]], 
            RowBox[{"sym", "[", 
             RowBox[{
              RowBox[{"\[Delta]", "[", 
               RowBox[{"{", 
                RowBox[{"i", ",", "j"}], "}"}], "]"}], 
              RowBox[{"\[Delta]", "[", 
               RowBox[{"{", 
                RowBox[{"k", ",", "l"}], "}"}], "]"}]}], "]"}], 
            SuperscriptBox["C", "4"]}]}], "}"}]}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"C", "[", 
            RowBox[{"{", "k_", "}"}], "]"}], " ", 
           RowBox[{"C", "[", 
            RowBox[{"{", "l_", "}"}], "]"}]}], "\[Rule]", 
          RowBox[{
           FractionBox["1", "d"], 
           RowBox[{"\[Delta]", "[", 
            RowBox[{"{", 
             RowBox[{"k", ",", "l"}], "}"}], "]"}], 
           SuperscriptBox["C", "2"]}]}], "}"}]}], "]"}], "]"}], "/.", 
     RowBox[{
      RowBox[{"u0", "[", 
       RowBox[{"{", 
        RowBox[{"_", ",", "s_", ",", "s_"}], "}"}], "]"}], "\[Rule]", 
      "0"}]}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"u1", "[", 
   RowBox[{"{", 
    RowBox[{"i", ",", "j", ",", "k"}], "}"}], "]"}], "\[Rule]", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox["\[Pi]", 
        RowBox[{"d", "/", "2"}]]}], 
      RowBox[{"Gamma", "[", 
       FractionBox["d", "2"], "]"}]], " ", "m", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], 
      RowBox[{"integrandu1ijk", " ", 
       SuperscriptBox["C", 
        RowBox[{"d", "-", "1"}]], 
       RowBox[{"\[DifferentialD]", "C"}]}]}]}], "/.", "gammareplacements"}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.739203728021545*^9, 3.739203737364406*^9}, {
   3.739203780404459*^9, 3.739204017883246*^9}, {3.73920408863614*^9, 
   3.7392041206189127`*^9}, {3.739204160234613*^9, 3.739204237841651*^9}, {
   3.739204268603713*^9, 3.739204284660245*^9}, 3.7392043618733807`*^9},
 ExpressionUUID -> "09d812f2-8f8a-47de-b69c-8ad8bb1cf5d6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"u1", "[", 
   RowBox[{"{", 
    RowBox[{"i", ",", "j", ",", "k"}], "}"}], "]"}], "\[Rule]", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"6", "+", "d"}], ")"}], " ", "\[Theta]", " ", 
   RowBox[{"u0", "[", 
    RowBox[{"{", 
     RowBox[{"i", ",", "j", ",", "k"}], "}"}], "]"}]}]}]], "Output",
 CellChangeTimes->{{3.73920418775884*^9, 3.73920420612777*^9}, 
   3.73920423959272*^9, 3.739204286619048*^9, 3.7430935123754387`*^9},
 ExpressionUUID -> "a0519d42-faa4-4efa-a76c-06cab4561f4d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"f26u2i", "=", 
   RowBox[{"fM", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{"q", "[", 
         RowBox[{"{", "r", "}"}], "]"}], 
        RowBox[{"\[Rho]", " ", 
         SuperscriptBox["\[Theta]", "2"]}]], 
       RowBox[{"C", "[", 
        RowBox[{"{", "r", "}"}], "]"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          FractionBox["1", 
           RowBox[{"d", "+", "2"}]], 
          FractionBox[
           SuperscriptBox["C", "2"], "\[Theta]"]}], "-", "1"}], ")"}]}], "+", 
      
      FractionBox[
       RowBox[{
        RowBox[{"u0", "[", 
         RowBox[{"{", 
          RowBox[{"l", ",", "r", ",", "s"}], "}"}], "]"}], 
        RowBox[{"C", "[", 
         RowBox[{"{", "l", "}"}], "]"}], 
        RowBox[{"C", "[", 
         RowBox[{"{", "r", "}"}], "]"}], 
        RowBox[{"C", "[", 
         RowBox[{"{", "s", "}"}], "]"}]}], 
       RowBox[{"6", "\[Rho]", " ", 
        SuperscriptBox["\[Theta]", "3"]}]]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"integrandu2iG26", "=", 
   RowBox[{
    RowBox[{"Einstein", "[", 
     RowBox[{"Expand", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Expand", "[", 
         RowBox[{
          SuperscriptBox["C", "4"], 
          RowBox[{"C", "[", 
           RowBox[{"{", "i", "}"}], "]"}], "f26u2i"}], "]"}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"C", "[", 
            RowBox[{"{", "i_", "}"}], "]"}], " ", 
           RowBox[{"C", "[", 
            RowBox[{"{", "j_", "}"}], "]"}], " ", 
           RowBox[{"C", "[", 
            RowBox[{"{", "k_", "}"}], "]"}], " ", 
           RowBox[{"C", "[", 
            RowBox[{"{", "l_", "}"}], "]"}]}], "\[Rule]", 
          RowBox[{
           FractionBox["3", 
            RowBox[{"d", 
             RowBox[{"(", 
              RowBox[{"d", "+", "2"}], ")"}]}]], 
           RowBox[{"sym", "[", 
            RowBox[{
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "j"}], "}"}], "]"}], 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"k", ",", "l"}], "}"}], "]"}]}], "]"}], 
           SuperscriptBox["C", "4"]}]}], "}"}]}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"C", "[", 
           RowBox[{"{", "k_", "}"}], "]"}], " ", 
          RowBox[{"C", "[", 
           RowBox[{"{", "l_", "}"}], "]"}]}], "\[Rule]", 
         RowBox[{
          FractionBox["1", "d"], 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"k", ",", "l"}], "}"}], "]"}], 
          SuperscriptBox["C", "2"]}]}], "}"}]}], "]"}], "]"}], "/.", 
    RowBox[{
     RowBox[{"u0", "[", 
      RowBox[{"{", 
       RowBox[{"_", ",", "s_", ",", "s_"}], "}"}], "]"}], "\[Rule]", 
     "0"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"u2", "[", 
   RowBox[{"{", "i", "}"}], "]"}], "\[Rule]", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox["\[Pi]", 
        RowBox[{"d", "/", "2"}]]}], 
      RowBox[{"Gamma", "[", 
       FractionBox["d", "2"], "]"}]], " ", "m", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], 
      RowBox[{"integrandu2iG26", " ", 
       SuperscriptBox["C", 
        RowBox[{"d", "-", "1"}]], 
       RowBox[{"\[DifferentialD]", "C"}]}]}]}], "/.", "gammareplacements"}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.73920510106326*^9, 3.739205166022681*^9}, {
  3.7392052723069077`*^9, 3.7392052929852953`*^9}},
 ExpressionUUID -> "4d708e44-8b02-4757-a2b2-1c73ffa22616"],

Cell[BoxData[
 RowBox[{
  RowBox[{"u2", "[", 
   RowBox[{"{", "i", "}"}], "]"}], "\[Rule]", 
  RowBox[{"4", " ", 
   RowBox[{"(", 
    RowBox[{"4", "+", "d"}], ")"}], " ", "\[Theta]", " ", 
   RowBox[{"q", "[", 
    RowBox[{"{", "i", "}"}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.739205295429494*^9, 3.743093522577983*^9},
 ExpressionUUID -> "77ae1538-e197-4f60-86e2-9bae56df7168"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["G29 equations", "Subsubsection",
 CellChangeTimes->{{3.73920163649277*^9, 3.7392016439731007`*^9}, {
  3.739203695483931*^9, 3.739203696794433*^9}, {3.743092736373781*^9, 
  3.7430927367559423`*^9}},
 ExpressionUUID -> "445d06b9-c126-4c91-810e-fbdc2a1a6833"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"f29", "=", 
    RowBox[{"fM", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{
        FractionBox["1", "8"], 
        FractionBox["w2", 
         RowBox[{"\[Rho]", " ", 
          SuperscriptBox["\[Theta]", "2"]}]], 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{
           FractionBox["2", "d"], 
           FractionBox[
            SuperscriptBox["C", "2"], "\[Theta]"]}], "+", 
          RowBox[{
           FractionBox["1", 
            RowBox[{"d", 
             RowBox[{"(", 
              RowBox[{"d", "+", "2"}], ")"}]}]], 
           FractionBox[
            SuperscriptBox["C", "4"], 
            SuperscriptBox["\[Theta]", "2"]]}]}], ")"}]}], "+", 
       RowBox[{
        FractionBox["1", "2"], 
        FractionBox[
         RowBox[{"\[Sigma]", "[", 
          RowBox[{"{", 
           RowBox[{"r", ",", "s"}], "}"}], "]"}], 
         RowBox[{"\[Rho]", " ", 
          SuperscriptBox["\[Theta]", "2"]}]], 
        RowBox[{"C", "[", 
         RowBox[{"{", "r", "}"}], "]"}], 
        RowBox[{"C", "[", 
         RowBox[{"{", "s", "}"}], "]"}]}], "+", 
       RowBox[{
        FractionBox[
         RowBox[{"q", "[", 
          RowBox[{"{", "r", "}"}], "]"}], 
         RowBox[{"\[Rho]", " ", 
          SuperscriptBox["\[Theta]", "2"]}]], 
        RowBox[{"C", "[", 
         RowBox[{"{", "r", "}"}], "]"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["1", 
            RowBox[{"d", "+", "2"}]], 
           FractionBox[
            SuperscriptBox["C", "2"], "\[Theta]"]}], "-", "1"}], ")"}]}], "+", 
       FractionBox[
        RowBox[{
         RowBox[{"u0", "[", 
          RowBox[{"{", 
           RowBox[{"l", ",", "r", ",", "s"}], "}"}], "]"}], 
         RowBox[{"C", "[", 
          RowBox[{"{", "l", "}"}], "]"}], 
         RowBox[{"C", "[", 
          RowBox[{"{", "r", "}"}], "]"}], 
         RowBox[{"C", "[", 
          RowBox[{"{", "s", "}"}], "]"}]}], 
        RowBox[{"6", "\[Rho]", " ", 
         SuperscriptBox["\[Theta]", "3"]}]], "+", 
       RowBox[{
        FractionBox["1", "4"], 
        FractionBox[
         RowBox[{
          RowBox[{"u1", "[", 
           RowBox[{"{", 
            RowBox[{"r", ",", "s"}], "}"}], "]"}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"d", "+", "4"}], ")"}], "\[Theta]", " ", 
           RowBox[{"\[Sigma]", "[", 
            RowBox[{"{", 
             RowBox[{"r", ",", "s"}], "}"}], "]"}]}]}], 
         RowBox[{"\[Rho]", " ", 
          SuperscriptBox["\[Theta]", "2"]}]], 
        FractionBox[
         RowBox[{
          RowBox[{"C", "[", 
           RowBox[{"{", "r", "}"}], "]"}], 
          RowBox[{"C", "[", 
           RowBox[{"{", "s", "}"}], "]"}]}], "\[Theta]"], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["1", 
            RowBox[{"d", "+", "4"}]], 
           FractionBox[
            SuperscriptBox["C", "2"], "\[Theta]"]}], "-", "1"}], ")"}]}], "+", 
       RowBox[{
        FractionBox["1", "8"], 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"ui2", "[", 
             RowBox[{"{", "r", "}"}], "]"}], "-", 
            RowBox[{"4", 
             RowBox[{"(", 
              RowBox[{"d", "+", "4"}], ")"}], "\[Theta]", " ", 
             RowBox[{"q", "[", 
              RowBox[{"{", "r", "}"}], "]"}]}]}], ")"}], 
          RowBox[{"C", "[", 
           RowBox[{"{", "r", "}"}], "]"}]}], 
         RowBox[{"\[Rho]", " ", 
          SuperscriptBox["\[Theta]", "3"]}]], 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{
           FractionBox["2", 
            RowBox[{"d", "+", "2"}]], 
           FractionBox[
            SuperscriptBox["C", "2"], "\[Theta]"]}], "+", 
          RowBox[{
           FractionBox["1", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"d", "+", "2"}], ")"}], 
             RowBox[{"(", 
              RowBox[{"d", "+", "4"}], ")"}]}]], 
           FractionBox[
            SuperscriptBox["C", "4"], 
            SuperscriptBox["\[Theta]", "2"]]}]}], ")"}]}]}], ")"}]}]}], ";"}],
   "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.7430930796059837`*^9, 3.743093100043049*^9}, {
   3.743093165647614*^9, 3.743093253032196*^9}, {3.74309328505212*^9, 
   3.743093306602683*^9}, 3.743095099684681*^9},
 ExpressionUUID -> "f9d0fc88-02c4-4639-ac44-0541a5eceb3c"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"f29$u0ijkl", "=", 
    RowBox[{"fM", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{
        FractionBox["1", "8"], 
        FractionBox["w2", 
         RowBox[{"\[Rho]", " ", 
          SuperscriptBox["\[Theta]", "2"]}]], 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{
           FractionBox["2", "d"], 
           FractionBox[
            SuperscriptBox["C", "2"], "\[Theta]"]}], "+", 
          RowBox[{
           FractionBox["1", 
            RowBox[{"d", 
             RowBox[{"(", 
              RowBox[{"d", "+", "2"}], ")"}]}]], 
           FractionBox[
            SuperscriptBox["C", "4"], "\[Theta]"]}]}], ")"}]}], "+", 
       RowBox[{
        FractionBox["1", "2"], 
        FractionBox[
         RowBox[{"\[Sigma]", "[", 
          RowBox[{"{", 
           RowBox[{"r", ",", "s"}], "}"}], "]"}], 
         RowBox[{"\[Rho]", " ", 
          SuperscriptBox["\[Theta]", "2"]}]], 
        RowBox[{"C", "[", 
         RowBox[{"{", "r", "}"}], "]"}], 
        RowBox[{"C", "[", 
         RowBox[{"{", "s", "}"}], "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "4"], 
        FractionBox[
         RowBox[{
          RowBox[{"u1", "[", 
           RowBox[{"{", 
            RowBox[{"r", ",", "s"}], "}"}], "]"}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"d", "+", "4"}], ")"}], "\[Theta]", " ", 
           RowBox[{"\[Sigma]", "[", 
            RowBox[{"{", 
             RowBox[{"r", ",", "s"}], "}"}], "]"}]}]}], 
         RowBox[{"\[Rho]", " ", 
          SuperscriptBox["\[Theta]", "2"]}]], 
        FractionBox[
         RowBox[{
          RowBox[{"C", "[", 
           RowBox[{"{", "r", "}"}], "]"}], 
          RowBox[{"C", "[", 
           RowBox[{"{", "s", "}"}], "]"}]}], "\[Theta]"], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["1", 
            RowBox[{"d", "+", "4"}]], 
           FractionBox[
            SuperscriptBox["C", "2"], "\[Theta]"]}], "-", "1"}], ")"}]}]}], 
      ")"}]}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"integrandu0ijkl", "=", 
    RowBox[{"Einstein", "[", 
     RowBox[{"Expand", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Expand", "[", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"C", "[", 
               RowBox[{"{", "i", "}"}], "]"}], 
              RowBox[{"C", "[", 
               RowBox[{"{", "j", "}"}], "]"}], 
              RowBox[{"C", "[", 
               RowBox[{"{", "k", "}"}], "]"}], 
              RowBox[{"C", "[", 
               RowBox[{"{", "l", "}"}], "]"}]}], "-", 
             RowBox[{
              FractionBox["1", 
               RowBox[{"4", "+", "d"}]], 
              SuperscriptBox["C", "2"], 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"C", "[", 
                  RowBox[{"{", "k", "}"}], "]"}], 
                 RowBox[{"C", "[", 
                  RowBox[{"{", "l", "}"}], "]"}], 
                 RowBox[{"\[Delta]", "[", 
                  RowBox[{"{", 
                   RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{"C", "[", 
                  RowBox[{"{", "j", "}"}], "]"}], 
                 RowBox[{"C", "[", 
                  RowBox[{"{", "l", "}"}], "]"}], 
                 RowBox[{"\[Delta]", "[", 
                  RowBox[{"{", 
                   RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{"C", "[", 
                  RowBox[{"{", "j", "}"}], "]"}], 
                 RowBox[{"C", "[", 
                  RowBox[{"{", "k", "}"}], "]"}], 
                 RowBox[{"\[Delta]", "[", 
                  RowBox[{"{", 
                   RowBox[{"i", ",", "l"}], "}"}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{"C", "[", 
                  RowBox[{"{", "i", "}"}], "]"}], 
                 RowBox[{"C", "[", 
                  RowBox[{"{", "l", "}"}], "]"}], 
                 RowBox[{"\[Delta]", "[", 
                  RowBox[{"{", 
                   RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{"C", "[", 
                  RowBox[{"{", "i", "}"}], "]"}], 
                 RowBox[{"C", "[", 
                  RowBox[{"{", "k", "}"}], "]"}], 
                 RowBox[{"\[Delta]", "[", 
                  RowBox[{"{", 
                   RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{"C", "[", 
                  RowBox[{"{", "i", "}"}], "]"}], 
                 RowBox[{"C", "[", 
                  RowBox[{"{", "j", "}"}], "]"}], 
                 RowBox[{"\[Delta]", "[", 
                  RowBox[{"{", 
                   RowBox[{"k", ",", "l"}], "}"}], "]"}]}]}], ")"}]}], "+", 
             RowBox[{
              FractionBox["1", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"2", "+", "d"}], ")"}], 
                RowBox[{"(", 
                 RowBox[{"4", "+", "d"}], ")"}]}]], 
              SuperscriptBox["C", "4"], 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"\[Delta]", "[", 
                  RowBox[{"{", 
                   RowBox[{"i", ",", "l"}], "}"}], "]"}], 
                 RowBox[{"\[Delta]", "[", 
                  RowBox[{"{", 
                   RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{"\[Delta]", "[", 
                  RowBox[{"{", 
                   RowBox[{"i", ",", "k"}], "}"}], "]"}], 
                 RowBox[{"\[Delta]", "[", 
                  RowBox[{"{", 
                   RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{"\[Delta]", "[", 
                  RowBox[{"{", 
                   RowBox[{"i", ",", "j"}], "}"}], "]"}], 
                 RowBox[{"\[Delta]", "[", 
                  RowBox[{"{", 
                   RowBox[{"k", ",", "l"}], "}"}], "]"}]}]}], ")"}]}]}], 
            ")"}], "f29$u0ijkl"}], "]"}], "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"C", "[", 
             RowBox[{"{", "i_", "}"}], "]"}], " ", 
            RowBox[{"C", "[", 
             RowBox[{"{", "j_", "}"}], "]"}], " ", 
            RowBox[{"C", "[", 
             RowBox[{"{", "k_", "}"}], "]"}], " ", 
            RowBox[{"C", "[", 
             RowBox[{"{", "l_", "}"}], "]"}], " ", 
            RowBox[{"C", "[", 
             RowBox[{"{", "r_", "}"}], "]"}], " ", 
            RowBox[{"C", "[", 
             RowBox[{"{", "s_", "}"}], "]"}]}], "\[Rule]", 
           RowBox[{
            FractionBox["15", 
             RowBox[{"d", 
              RowBox[{"(", 
               RowBox[{"d", "+", "2"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"d", "+", "4"}], ")"}]}]], 
            RowBox[{"sym", "[", 
             RowBox[{
              RowBox[{"\[Delta]", "[", 
               RowBox[{"{", 
                RowBox[{"i", ",", "j"}], "}"}], "]"}], 
              RowBox[{"\[Delta]", "[", 
               RowBox[{"{", 
                RowBox[{"k", ",", "l"}], "}"}], "]"}], 
              RowBox[{"\[Delta]", "[", 
               RowBox[{"{", 
                RowBox[{"r", ",", "s"}], "}"}], "]"}]}], "]"}], 
            SuperscriptBox["C", "6"]}]}], "}"}]}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"C", "[", 
            RowBox[{"{", "i_", "}"}], "]"}], " ", 
           RowBox[{"C", "[", 
            RowBox[{"{", "j_", "}"}], "]"}], " ", 
           RowBox[{"C", "[", 
            RowBox[{"{", "k_", "}"}], "]"}], " ", 
           RowBox[{"C", "[", 
            RowBox[{"{", "l_", "}"}], "]"}]}], "\[Rule]", 
          RowBox[{
           FractionBox["3", 
            RowBox[{"d", 
             RowBox[{"(", 
              RowBox[{"d", "+", "2"}], ")"}]}]], 
           RowBox[{"sym", "[", 
            RowBox[{
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "j"}], "}"}], "]"}], 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"k", ",", "l"}], "}"}], "]"}]}], "]"}], 
           SuperscriptBox["C", "4"]}]}], "}"}]}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"C", "[", 
           RowBox[{"{", "k_", "}"}], "]"}], " ", 
          RowBox[{"C", "[", 
           RowBox[{"{", "l_", "}"}], "]"}]}], "\[Rule]", 
         RowBox[{
          FractionBox["1", "d"], 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"k", ",", "l"}], "}"}], "]"}], 
          SuperscriptBox["C", "2"]}]}], "}"}]}], "]"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"u0", "[", 
   RowBox[{"{", 
    RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}], "]"}], "\[Rule]", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox["\[Pi]", 
        RowBox[{"d", "/", "2"}]]}], 
      RowBox[{"Gamma", "[", 
       FractionBox["d", "2"], "]"}]], " ", "m", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], 
      RowBox[{"integrandu0ijkl", " ", 
       SuperscriptBox["C", 
        RowBox[{"d", "-", "1"}]], 
       RowBox[{"\[DifferentialD]", "C"}]}]}]}], "/.", "gammareplacements"}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.739204379091963*^9, 3.739204418765747*^9}, {
   3.739204510283558*^9, 3.7392045259868793`*^9}, {3.739204761293642*^9, 
   3.7392047852049103`*^9}, 3.7392048334098787`*^9, {3.7392048685708027`*^9, 
   3.7392048791215973`*^9}, 3.7392049404079313`*^9, {3.7392050715075483`*^9, 
   3.739205073569521*^9}, {3.743093577011078*^9, 3.743093577016749*^9}, 
   3.743095109221057*^9},
 ExpressionUUID -> "1e348c5a-83e7-4a32-81c4-44cd579fd7b5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"u0", "[", 
   RowBox[{"{", 
    RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}], "]"}], "\[Rule]", 
  "0"}]], "Output",
 CellChangeTimes->{3.7392050781209993`*^9, 3.743093787572167*^9, 
  3.743095113761565*^9},
 ExpressionUUID -> "959c7d1c-157a-4d64-9003-9bba5a328da4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"f29$u1ijk", "=", 
   RowBox[{"fM", " ", 
    FractionBox[
     RowBox[{
      RowBox[{"u0", "[", 
       RowBox[{"{", 
        RowBox[{"l", ",", "r", ",", "s"}], "}"}], "]"}], 
      RowBox[{"C", "[", 
       RowBox[{"{", "l", "}"}], "]"}], 
      RowBox[{"C", "[", 
       RowBox[{"{", "r", "}"}], "]"}], 
      RowBox[{"C", "[", 
       RowBox[{"{", "s", "}"}], "]"}]}], 
     RowBox[{"6", "\[Rho]", " ", 
      SuperscriptBox["\[Theta]", "3"]}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"integrandu1ijk", "=", 
    RowBox[{
     RowBox[{"Einstein", "[", 
      RowBox[{"Expand", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Expand", "[", 
           RowBox[{
            SuperscriptBox["C", "2"], 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"C", "[", 
                RowBox[{"{", "i", "}"}], "]"}], 
               RowBox[{"C", "[", 
                RowBox[{"{", "j", "}"}], "]"}], 
               RowBox[{"C", "[", 
                RowBox[{"{", "k", "}"}], "]"}]}], "-", 
              RowBox[{
               FractionBox["3", 
                RowBox[{"d", "+", "2"}]], 
               SuperscriptBox["C", "2"], 
               RowBox[{"sym", "[", 
                RowBox[{
                 RowBox[{"C", "[", 
                  RowBox[{"{", "i", "}"}], "]"}], 
                 RowBox[{"\[Delta]", "[", 
                  RowBox[{"{", 
                   RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "]"}]}]}], ")"}], 
            "f29$u1ijk"}], "]"}], "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"C", "[", 
              RowBox[{"{", "i_", "}"}], "]"}], " ", 
             RowBox[{"C", "[", 
              RowBox[{"{", "j_", "}"}], "]"}], " ", 
             RowBox[{"C", "[", 
              RowBox[{"{", "k_", "}"}], "]"}], " ", 
             RowBox[{"C", "[", 
              RowBox[{"{", "l_", "}"}], "]"}], " ", 
             RowBox[{"C", "[", 
              RowBox[{"{", "r_", "}"}], "]"}], " ", 
             RowBox[{"C", "[", 
              RowBox[{"{", "s_", "}"}], "]"}]}], "\[Rule]", 
            RowBox[{
             FractionBox["15", 
              RowBox[{"d", 
               RowBox[{"(", 
                RowBox[{"d", "+", "2"}], ")"}], 
               RowBox[{"(", 
                RowBox[{"d", "+", "4"}], ")"}]}]], 
             RowBox[{"sym", "[", 
              RowBox[{
               RowBox[{"\[Delta]", "[", 
                RowBox[{"{", 
                 RowBox[{"i", ",", "j"}], "}"}], "]"}], 
               RowBox[{"\[Delta]", "[", 
                RowBox[{"{", 
                 RowBox[{"k", ",", "l"}], "}"}], "]"}], 
               RowBox[{"\[Delta]", "[", 
                RowBox[{"{", 
                 RowBox[{"r", ",", "s"}], "}"}], "]"}]}], "]"}], 
             SuperscriptBox["C", "6"]}]}], "}"}]}], "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"C", "[", 
             RowBox[{"{", "i_", "}"}], "]"}], " ", 
            RowBox[{"C", "[", 
             RowBox[{"{", "j_", "}"}], "]"}], " ", 
            RowBox[{"C", "[", 
             RowBox[{"{", "k_", "}"}], "]"}], " ", 
            RowBox[{"C", "[", 
             RowBox[{"{", "l_", "}"}], "]"}]}], "\[Rule]", 
           RowBox[{
            FractionBox["3", 
             RowBox[{"d", 
              RowBox[{"(", 
               RowBox[{"d", "+", "2"}], ")"}]}]], 
            RowBox[{"sym", "[", 
             RowBox[{
              RowBox[{"\[Delta]", "[", 
               RowBox[{"{", 
                RowBox[{"i", ",", "j"}], "}"}], "]"}], 
              RowBox[{"\[Delta]", "[", 
               RowBox[{"{", 
                RowBox[{"k", ",", "l"}], "}"}], "]"}]}], "]"}], 
            SuperscriptBox["C", "4"]}]}], "}"}]}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"C", "[", 
            RowBox[{"{", "k_", "}"}], "]"}], " ", 
           RowBox[{"C", "[", 
            RowBox[{"{", "l_", "}"}], "]"}]}], "\[Rule]", 
          RowBox[{
           FractionBox["1", "d"], 
           RowBox[{"\[Delta]", "[", 
            RowBox[{"{", 
             RowBox[{"k", ",", "l"}], "}"}], "]"}], 
           SuperscriptBox["C", "2"]}]}], "}"}]}], "]"}], "]"}], "/.", 
     RowBox[{
      RowBox[{"u0", "[", 
       RowBox[{"{", 
        RowBox[{"_", ",", "s_", ",", "s_"}], "}"}], "]"}], "\[Rule]", 
      "0"}]}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"u1", "[", 
   RowBox[{"{", 
    RowBox[{"i", ",", "j", ",", "k"}], "}"}], "]"}], "\[Rule]", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox["\[Pi]", 
        RowBox[{"d", "/", "2"}]]}], 
      RowBox[{"Gamma", "[", 
       FractionBox["d", "2"], "]"}]], " ", "m", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], 
      RowBox[{"integrandu1ijk", " ", 
       SuperscriptBox["C", 
        RowBox[{"d", "-", "1"}]], 
       RowBox[{"\[DifferentialD]", "C"}]}]}]}], "/.", "gammareplacements"}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.739203728021545*^9, 3.739203737364406*^9}, {
   3.739203780404459*^9, 3.739204017883246*^9}, {3.73920408863614*^9, 
   3.7392041206189127`*^9}, {3.739204160234613*^9, 3.739204237841651*^9}, {
   3.739204268603713*^9, 3.739204284660245*^9}, 3.7392043618733807`*^9, {
   3.743093577023212*^9, 3.7430935770284986`*^9}},
 ExpressionUUID -> "09d812f2-8f8a-47de-b69c-8ad8bb1cf5d6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"u1", "[", 
   RowBox[{"{", 
    RowBox[{"i", ",", "j", ",", "k"}], "}"}], "]"}], "\[Rule]", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"6", "+", "d"}], ")"}], " ", "\[Theta]", " ", 
   RowBox[{"u0", "[", 
    RowBox[{"{", 
     RowBox[{"i", ",", "j", ",", "k"}], "}"}], "]"}]}]}]], "Output",
 CellChangeTimes->{{3.73920418775884*^9, 3.73920420612777*^9}, 
   3.73920423959272*^9, 3.739204286619048*^9, 3.743093859376892*^9},
 ExpressionUUID -> "a0519d42-faa4-4efa-a76c-06cab4561f4d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"f29u2ij", "=", 
   RowBox[{"fM", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{
       FractionBox["1", "8"], 
       FractionBox["w2", 
        RowBox[{"\[Rho]", " ", 
         SuperscriptBox["\[Theta]", "2"]}]], 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{
          FractionBox["2", "d"], 
          FractionBox[
           SuperscriptBox["C", "2"], "\[Theta]"]}], "+", 
         RowBox[{
          FractionBox["1", 
           RowBox[{"d", 
            RowBox[{"(", 
             RowBox[{"d", "+", "2"}], ")"}]}]], 
          FractionBox[
           SuperscriptBox["C", "4"], 
           SuperscriptBox["\[Theta]", "2"]]}]}], ")"}]}], "+", 
      RowBox[{
       FractionBox["1", "2"], 
       FractionBox[
        RowBox[{"\[Sigma]", "[", 
         RowBox[{"{", 
          RowBox[{"r", ",", "s"}], "}"}], "]"}], 
        RowBox[{"\[Rho]", " ", 
         SuperscriptBox["\[Theta]", "2"]}]], 
       RowBox[{"C", "[", 
        RowBox[{"{", "r", "}"}], "]"}], 
       RowBox[{"C", "[", 
        RowBox[{"{", "s", "}"}], "]"}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], 
       FractionBox[
        RowBox[{
         RowBox[{"u1", "[", 
          RowBox[{"{", 
           RowBox[{"r", ",", "s"}], "}"}], "]"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"d", "+", "4"}], ")"}], "\[Theta]", " ", 
          RowBox[{"\[Sigma]", "[", 
           RowBox[{"{", 
            RowBox[{"r", ",", "s"}], "}"}], "]"}]}]}], 
        RowBox[{"\[Rho]", " ", 
         SuperscriptBox["\[Theta]", "2"]}]], 
       FractionBox[
        RowBox[{
         RowBox[{"C", "[", 
          RowBox[{"{", "r", "}"}], "]"}], 
         RowBox[{"C", "[", 
          RowBox[{"{", "s", "}"}], "]"}]}], "\[Theta]"], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          FractionBox["1", 
           RowBox[{"d", "+", "4"}]], 
          FractionBox[
           SuperscriptBox["C", "2"], "\[Theta]"]}], "-", "1"}], ")"}]}]}], 
     ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"integrandu2ijG29", "=", 
   RowBox[{
    RowBox[{"Einstein", "[", 
     RowBox[{"Expand", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Expand", "[", 
         RowBox[{
          SuperscriptBox["C", "4"], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"C", "[", 
              RowBox[{"{", "i", "}"}], "]"}], 
             RowBox[{"C", "[", 
              RowBox[{"{", "j", "}"}], "]"}]}], "-", 
            RowBox[{
             FractionBox["1", "d"], 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "j"}], "}"}], "]"}], 
             SuperscriptBox["C", "2"]}]}], ")"}], "f29u2ij"}], "]"}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"C", "[", 
            RowBox[{"{", "i_", "}"}], "]"}], " ", 
           RowBox[{"C", "[", 
            RowBox[{"{", "j_", "}"}], "]"}], " ", 
           RowBox[{"C", "[", 
            RowBox[{"{", "k_", "}"}], "]"}], " ", 
           RowBox[{"C", "[", 
            RowBox[{"{", "l_", "}"}], "]"}]}], "\[Rule]", 
          RowBox[{
           FractionBox["3", 
            RowBox[{"d", 
             RowBox[{"(", 
              RowBox[{"d", "+", "2"}], ")"}]}]], 
           RowBox[{"sym", "[", 
            RowBox[{
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "j"}], "}"}], "]"}], 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"k", ",", "l"}], "}"}], "]"}]}], "]"}], 
           SuperscriptBox["C", "4"]}]}], "}"}]}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"C", "[", 
           RowBox[{"{", "k_", "}"}], "]"}], " ", 
          RowBox[{"C", "[", 
           RowBox[{"{", "l_", "}"}], "]"}]}], "\[Rule]", 
         RowBox[{
          FractionBox["1", "d"], 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"k", ",", "l"}], "}"}], "]"}], 
          SuperscriptBox["C", "2"]}]}], "}"}]}], "]"}], "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Sigma]", "[", 
        RowBox[{"{", 
         RowBox[{"i_", ",", "i_"}], "}"}], "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"u1", "[", 
        RowBox[{"{", 
         RowBox[{"i_", ",", "i_"}], "}"}], "]"}], "\[Rule]", "0"}]}], 
     "}"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"u2", "[", 
   RowBox[{"{", 
    RowBox[{"i", ",", "j"}], "}"}], "]"}], "\[Rule]", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox["\[Pi]", 
        RowBox[{"d", "/", "2"}]]}], 
      RowBox[{"Gamma", "[", 
       FractionBox["d", "2"], "]"}]], " ", "m", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], 
      RowBox[{"integrandu2ijG29", " ", 
       SuperscriptBox["C", 
        RowBox[{"d", "-", "1"}]], 
       RowBox[{"\[DifferentialD]", "C"}]}]}]}], "/.", "gammareplacements"}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.73920510106326*^9, 3.739205166022681*^9}, {
   3.7392052723069077`*^9, 3.7392052929852953`*^9}, {3.743093577035377*^9, 
   3.743093577048415*^9}, 3.743093873086761*^9, {3.743093950932382*^9, 
   3.7430939959546967`*^9}, {3.7430940586155453`*^9, 3.743094106640428*^9}, {
   3.7430941519931927`*^9, 3.7430941716460133`*^9}, 3.743095122445546*^9},
 ExpressionUUID -> "4d708e44-8b02-4757-a2b2-1c73ffa22616"],

Cell[BoxData[
 RowBox[{
  RowBox[{"u2", "[", 
   RowBox[{"{", 
    RowBox[{"i", ",", "j"}], "}"}], "]"}], "\[Rule]", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"(", 
     RowBox[{"6", "+", "d"}], ")"}]}], " ", "\[Theta]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"u1", "[", 
       RowBox[{"{", 
        RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4", "+", "d"}], ")"}], " ", "\[Theta]", " ", 
      RowBox[{"\[Sigma]", "[", 
       RowBox[{"{", 
        RowBox[{"i", ",", "j"}], "}"}], "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.739205295429494*^9, 3.74309412735347*^9, 
  3.743094175748829*^9, 3.743095125727404*^9},
 ExpressionUUID -> "77ae1538-e197-4f60-86e2-9bae56df7168"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"f29u3", "=", 
   RowBox[{"fM", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{
       FractionBox["1", "8"], 
       FractionBox["w2", 
        RowBox[{"\[Rho]", " ", 
         SuperscriptBox["\[Theta]", "2"]}]], 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{
          FractionBox["2", "d"], 
          FractionBox[
           SuperscriptBox["C", "2"], "\[Theta]"]}], "+", 
         RowBox[{
          FractionBox["1", 
           RowBox[{"d", 
            RowBox[{"(", 
             RowBox[{"d", "+", "2"}], ")"}]}]], 
          FractionBox[
           SuperscriptBox["C", "4"], 
           SuperscriptBox["\[Theta]", "2"]]}]}], ")"}]}], "+", 
      RowBox[{
       FractionBox["1", "2"], 
       FractionBox[
        RowBox[{"\[Sigma]", "[", 
         RowBox[{"{", 
          RowBox[{"r", ",", "s"}], "}"}], "]"}], 
        RowBox[{"\[Rho]", " ", 
         SuperscriptBox["\[Theta]", "2"]}]], 
       RowBox[{"C", "[", 
        RowBox[{"{", "r", "}"}], "]"}], 
       RowBox[{"C", "[", 
        RowBox[{"{", "s", "}"}], "]"}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], 
       FractionBox[
        RowBox[{
         RowBox[{"u1", "[", 
          RowBox[{"{", 
           RowBox[{"r", ",", "s"}], "}"}], "]"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"d", "+", "4"}], ")"}], "\[Theta]", " ", 
          RowBox[{"\[Sigma]", "[", 
           RowBox[{"{", 
            RowBox[{"r", ",", "s"}], "}"}], "]"}]}]}], 
        RowBox[{"\[Rho]", " ", 
         SuperscriptBox["\[Theta]", "2"]}]], 
       FractionBox[
        RowBox[{
         RowBox[{"C", "[", 
          RowBox[{"{", "r", "}"}], "]"}], 
         RowBox[{"C", "[", 
          RowBox[{"{", "s", "}"}], "]"}]}], "\[Theta]"], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          FractionBox["1", 
           RowBox[{"d", "+", "4"}]], 
          FractionBox[
           SuperscriptBox["C", "2"], "\[Theta]"]}], "-", "1"}], ")"}]}]}], 
     ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"integrandu3G29", "=", 
   RowBox[{
    RowBox[{"Einstein", "[", 
     RowBox[{"Expand", "[", 
      RowBox[{
       RowBox[{"Expand", "[", 
        RowBox[{
         SuperscriptBox["C", "6"], "f29u3"}], "]"}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"C", "[", 
           RowBox[{"{", "k_", "}"}], "]"}], " ", 
          RowBox[{"C", "[", 
           RowBox[{"{", "l_", "}"}], "]"}]}], "\[Rule]", 
         RowBox[{
          FractionBox["1", "d"], 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"k", ",", "l"}], "}"}], "]"}], 
          SuperscriptBox["C", "2"]}]}], "}"}]}], "]"}], "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Sigma]", "[", 
        RowBox[{"{", 
         RowBox[{"i_", ",", "i_"}], "}"}], "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"u1", "[", 
        RowBox[{"{", 
         RowBox[{"i_", ",", "i_"}], "}"}], "]"}], "\[Rule]", "0"}]}], 
     "}"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"u3", "\[Rule]", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox["\[Pi]", 
        RowBox[{"d", "/", "2"}]]}], 
      RowBox[{"Gamma", "[", 
       FractionBox["d", "2"], "]"}]], " ", "m", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], 
      RowBox[{"integrandu3G29", " ", 
       SuperscriptBox["C", 
        RowBox[{"d", "-", "1"}]], 
       RowBox[{"\[DifferentialD]", "C"}]}]}]}], "/.", "gammareplacements"}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.73920510106326*^9, 3.739205166022681*^9}, {
   3.7392052723069077`*^9, 3.7392052929852953`*^9}, {3.743093577035377*^9, 
   3.743093577048415*^9}, 3.743093873086761*^9, {3.743093950932382*^9, 
   3.7430939959546967`*^9}, {3.7430940586155453`*^9, 3.743094106640428*^9}, {
   3.7430941519931927`*^9, 3.7430941716460133`*^9}, {3.743094314043881*^9, 
   3.743094355206525*^9}, {3.743094415644444*^9, 3.743094477365847*^9}, 
   3.743094517337902*^9, {3.7430945655387287`*^9, 3.7430945669505367`*^9}, {
   3.743094988035305*^9, 3.74309499028664*^9}},
 ExpressionUUID -> "4d708e44-8b02-4757-a2b2-1c73ffa22616"],

Cell[BoxData[
 RowBox[{"u3", "\[Rule]", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"4", "+", "d"}], ")"}], " ", "\[Theta]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"3", " ", "w2"}], "+", 
     RowBox[{"d", " ", 
      RowBox[{"(", 
       RowBox[{"2", "+", "d"}], ")"}], " ", 
      SuperscriptBox["\[Theta]", "2"], " ", "\[Rho]"}]}], ")"}]}]}]], "Output",\

 CellChangeTimes->{
  3.739205295429494*^9, 3.74309412735347*^9, 3.743094175748829*^9, {
   3.7430945004879713`*^9, 3.74309452284509*^9}, 3.7430945709989433`*^9, 
   3.74309499707016*^9, 3.743095138240127*^9},
 ExpressionUUID -> "77ae1538-e197-4f60-86e2-9bae56df7168"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Useful for computing Grad distribution function", "Section",
 CellChangeTimes->{{3.7391741852678432`*^9, 
  3.7391742094276342`*^9}},ExpressionUUID->"bb8739c9-2fa8-40aa-977f-\
9e0c3469f434"],

Cell[BoxData[
 RowBox[{
  RowBox[{"$Assumptions", "=", 
   RowBox[{
    RowBox[{"\[Theta]", ">", "0"}], "&&", 
    RowBox[{"d", ">", "0"}], "&&", 
    RowBox[{"m", ">", "0"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.739257428720859*^9, 3.7392574506225367`*^9}},
 ExpressionUUID -> "7ebbe3b1-92d0-4781-90c3-1e8c40d6999d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubsuperscriptBox["\[Integral]", "0", "\[Pi]"], 
  RowBox[{
   SuperscriptBox[
    RowBox[{"Sin", "[", "\[Theta]", "]"}], "n"], 
   RowBox[{"\[DifferentialD]", "\[Theta]"}]}]}]], "Input",
 CellChangeTimes->{{3.739009807558908*^9, 
  3.7390098337073097`*^9}},ExpressionUUID->"1e4aa640-a0d5-44dd-81fa-\
529b9f8e5cdc"],

Cell[BoxData[
 RowBox[{"ConditionalExpression", "[", 
  RowBox[{
   FractionBox[
    RowBox[{
     SqrtBox["\[Pi]"], " ", 
     RowBox[{"Gamma", "[", 
      FractionBox[
       RowBox[{"1", "+", "n"}], "2"], "]"}]}], 
    RowBox[{"Gamma", "[", 
     RowBox[{"1", "+", 
      FractionBox["n", "2"]}], "]"}]], ",", 
   RowBox[{
    RowBox[{"Re", "[", "n", "]"}], ">", 
    RowBox[{"-", "1"}]}]}], "]"}]], "Output",
 CellChangeTimes->{3.739174223919956*^9},
 ExpressionUUID -> "4ea31f4e-6256-4cd6-b8c1-f77d9bb8f2dc"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubsuperscriptBox["\[Integral]", "0", 
   RowBox[{"2", "\[Pi]"}]], 
  RowBox[{
   SuperscriptBox[
    RowBox[{"Sin", "[", "\[Theta]", "]"}], "n"], 
   RowBox[{"\[DifferentialD]", "\[Theta]"}]}]}]], "Input",
 CellChangeTimes->{3.739012280787959*^9},
 ExpressionUUID -> "690d4eb7-4cfa-4dd0-ab98-b0dc1b1011f5"],

Cell[BoxData[
 RowBox[{"ConditionalExpression", "[", 
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], "n"]}], ")"}], " ", 
     SqrtBox["\[Pi]"], " ", 
     RowBox[{"Gamma", "[", 
      FractionBox[
       RowBox[{"1", "+", "n"}], "2"], "]"}]}], 
    RowBox[{"Gamma", "[", 
     RowBox[{"1", "+", 
      FractionBox["n", "2"]}], "]"}]], ",", 
   RowBox[{
    RowBox[{"Re", "[", "n", "]"}], ">", 
    RowBox[{"-", "1"}]}]}], "]"}]], "Output",
 CellChangeTimes->{3.739174252030766*^9},
 ExpressionUUID -> "f1914270-71eb-4e9b-b077-5894f39c9a62"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      SuperscriptBox["c", "2"], "2"]}]], 
   SuperscriptBox["c", 
    RowBox[{"d", "+", "7"}]], 
   RowBox[{"\[DifferentialD]", "c"}]}]}]], "Input",
 CellChangeTimes->{{3.739014198670601*^9, 3.7390142531188297`*^9}, 
   3.739014455730012*^9, 3.7390145280830383`*^9, {3.739015645799958*^9, 
   3.739015645989667*^9}, {3.739016087514626*^9, 3.739016087896678*^9}, {
   3.7390835684228354`*^9, 3.739083568948707*^9}, {3.7391753159479313`*^9, 
   3.7391753164584217`*^9}, {3.7391856433857803`*^9, 
   3.739185644150916*^9}},ExpressionUUID->"eb641681-6be1-4444-94dd-\
33451869b0fc"],

Cell[BoxData[
 RowBox[{"ConditionalExpression", "[", 
  RowBox[{
   RowBox[{
    SuperscriptBox["2", 
     RowBox[{"3", "+", 
      FractionBox["d", "2"]}]], " ", 
    RowBox[{"Gamma", "[", 
     RowBox[{"4", "+", 
      FractionBox["d", "2"]}], "]"}]}], ",", 
   RowBox[{
    RowBox[{"Re", "[", "d", "]"}], ">", 
    RowBox[{"-", "8"}]}]}], "]"}]], "Output",
 CellChangeTimes->{3.739174252381899*^9, 3.7391753182292128`*^9, 
  3.739185644904213*^9},
 ExpressionUUID -> "b775d162-ac2c-432e-a0b8-cfd35297d7ef"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      SuperscriptBox["c", "2"], 
      RowBox[{"2", "\[Theta]"}]]}]], 
   SuperscriptBox["c", 
    RowBox[{"d", "+", "5"}]], 
   RowBox[{"\[DifferentialD]", "c"}]}]}]], "Input",
 CellChangeTimes->{{3.739257480735199*^9, 3.739257488212166*^9}},
 ExpressionUUID -> "67765118-aad0-4e6b-bc8d-cbe760d69b8b"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["2", 
   RowBox[{"2", "+", 
    FractionBox["d", "2"]}]], " ", 
  SuperscriptBox["\[Theta]", 
   RowBox[{"3", "+", 
    FractionBox["d", "2"]}]], " ", 
  RowBox[{"Gamma", "[", 
   RowBox[{"3", "+", 
    FractionBox["d", "2"]}], "]"}]}]], "Output",
 CellChangeTimes->{3.7392574904422503`*^9},
 ExpressionUUID -> "60c140b1-a8ff-40e9-ae5e-54bbb426b261"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      SuperscriptBox["c", "2"], 
      RowBox[{"2", "\[Theta]"}]]}]], 
   SuperscriptBox["c", 
    RowBox[{"d", "+", "7"}]], 
   RowBox[{"\[DifferentialD]", "c"}]}]}]], "Input",
 CellChangeTimes->{{3.739259262872871*^9, 3.7392592632567253`*^9}},
 ExpressionUUID -> "a1571290-e13c-4c99-8c39-d0f7e2576b3c"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["2", 
   RowBox[{"3", "+", 
    FractionBox["d", "2"]}]], " ", 
  SuperscriptBox["\[Theta]", 
   RowBox[{"4", "+", 
    FractionBox["d", "2"]}]], " ", 
  RowBox[{"Gamma", "[", 
   RowBox[{"4", "+", 
    FractionBox["d", "2"]}], "]"}]}]], "Output",
 CellChangeTimes->{3.7392592643889923`*^9},
 ExpressionUUID -> "abaf1b6e-494c-43f3-aebd-1d3e2be5373b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Lambda]0", "+", 
       RowBox[{"d", " ", "\[Lambda]1"}], "+", 
       RowBox[{"d", 
        RowBox[{"(", 
         RowBox[{"d", "+", "2"}], ")"}], "\[Lambda]2"}]}], "\[Equal]", "1"}], 
     ",", 
     RowBox[{
      RowBox[{"\[Lambda]0", "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"d", "+", "2"}], ")"}], " ", "\[Lambda]1"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"d", "+", "2"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"d", "+", "4"}], ")"}], "\[Lambda]2"}]}], "\[Equal]", "1"}], 
     ",", 
     RowBox[{
      RowBox[{"\[Lambda]0", "-", "1", "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"d", "+", "4"}], ")"}], " ", "\[Lambda]1"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"d", "+", "4"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"d", "+", "6"}], ")"}], "\[Lambda]2"}]}], "\[Equal]", 
      FractionBox["w2", 
       RowBox[{"d", 
        RowBox[{"(", 
         RowBox[{"d", "+", "2"}], ")"}]}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Lambda]0", ",", " ", "\[Lambda]1", ",", "\[Lambda]2"}], 
    "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7390838041480827`*^9, 3.7390839339826508`*^9}},
 ExpressionUUID -> "596291c7-d3a9-45a0-9a75-3d8ac8baae34"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"\[Lambda]0", "\[Rule]", 
     FractionBox[
      RowBox[{"8", "+", "w2"}], "8"]}], ",", 
    RowBox[{"\[Lambda]1", "\[Rule]", 
     RowBox[{"-", 
      FractionBox["w2", 
       RowBox[{"4", " ", "d"}]]}]}], ",", 
    RowBox[{"\[Lambda]2", "\[Rule]", 
     FractionBox["w2", 
      RowBox[{"8", " ", "d", " ", 
       RowBox[{"(", 
        RowBox[{"2", "+", "d"}], ")"}]}]]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.739174252407995*^9},
 ExpressionUUID -> "525cb0b5-7dda-41f0-bbd6-f8e86b9d13e0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Einstein", "[", 
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{"\[Lambda]", "[", 
      RowBox[{"{", 
       RowBox[{"l", ",", "r", ",", "s"}], "}"}], "]"}], 
     RowBox[{"sym", "[", 
      RowBox[{
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"i", ",", "j"}], "}"}], "]"}], 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"k", ",", "l"}], "}"}], "]"}], 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"r", ",", "s"}], "}"}], "]"}]}], "]"}]}], "]"}], "]"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"\[Lambda]", "[", 
     RowBox[{"{", 
      RowBox[{"_", ",", "s0", ",", "s0"}], "}"}], "]"}], "\[Rule]", "0"}], 
   "}"}]}]], "Input",
 ExpressionUUID -> "eec1a304-28c6-4e5d-a1a3-c123026ce794"],

Cell[BoxData[
 RowBox[{
  FractionBox["2", "5"], " ", 
  RowBox[{"\[Lambda]", "[", 
   RowBox[{"{", 
    RowBox[{"i", ",", "j", ",", "k"}], "}"}], "]"}]}]], "Output",
 CellChangeTimes->{3.739174316079537*^9},
 ExpressionUUID -> "6531d8d0-0105-41c5-a51f-3b1237142f41"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"2", "\[Lambda]ij0"}], " ", "+", 
        RowBox[{"2", 
         RowBox[{"(", 
          RowBox[{"d", "+", "4"}], ")"}], "\[Lambda]ij1"}]}], "\[Equal]", 
       "\[Sigma]"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"2", 
         RowBox[{"(", 
          RowBox[{"d", "+", "4"}], ")"}], "\[Lambda]ij0"}], " ", "+", 
        RowBox[{"2", 
         RowBox[{"(", 
          RowBox[{"d", "+", "4"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"d", "+", "6"}], ")"}], "\[Lambda]ij1"}]}], "\[Equal]", 
       "u1"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\[Lambda]ij0", ",", "\[Lambda]ij1"}], "}"}]}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.739186344685313*^9, 3.7391864364280453`*^9}},
 ExpressionUUID -> "9f79c08e-d04d-4143-90d5-e80dc74e66c8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"\[Lambda]ij0", "\[Rule]", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "u1"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"6", "+", "d"}], ")"}], " ", "\[Sigma]"}]}], ")"}]}]}], ",", 
    RowBox[{"\[Lambda]ij1", "\[Rule]", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox["u1", 
         RowBox[{"4", "+", "d"}]], "-", "\[Sigma]"}], ")"}]}]}]}], "}"}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.739186414038762*^9, 3.7391864368543177`*^9}},
 ExpressionUUID -> "ee3f752a-31e8-454d-99c5-ffda724d253e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Einstein", "[", 
  RowBox[{"Expand", "[", 
   RowBox[{
    RowBox[{"\[Lambda]", "[", 
     RowBox[{"{", 
      RowBox[{"l", ",", "r", ",", "s"}], "}"}], "]"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"sym", "[", 
        RowBox[{
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"i", ",", "l"}], "}"}], "]"}], 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"r", ",", "s"}], "}"}], "]"}]}], "]"}], 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"sym", "[", 
        RowBox[{
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"j", ",", "l"}], "}"}], "]"}], 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"r", ",", "s"}], "}"}], "]"}]}], "]"}], 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"sym", "[", 
        RowBox[{
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"k", ",", "l"}], "}"}], "]"}], 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"r", ",", "s"}], "}"}], "]"}]}], "]"}], 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"i", ",", "j"}], "}"}], "]"}]}]}], ")"}]}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.739174814247889*^9, 
  3.739174898569776*^9}},ExpressionUUID->"70b0ef21-01b3-48c5-9080-\
7c6c309d107d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"j", ",", "k"}], "}"}], "]"}], " ", 
   RowBox[{"\[Lambda]", "[", 
    RowBox[{"{", 
     RowBox[{"i", ",", "s0", ",", "s0"}], "}"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"i", ",", "k"}], "}"}], "]"}], " ", 
   RowBox[{"\[Lambda]", "[", 
    RowBox[{"{", 
     RowBox[{"j", ",", "s0", ",", "s0"}], "}"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
   RowBox[{"\[Lambda]", "[", 
    RowBox[{"{", 
     RowBox[{"k", ",", "s0", ",", "s0"}], "}"}], "]"}]}]}]], "Output",
 CellChangeTimes->{{3.7391748192713003`*^9, 3.739174832038349*^9}, {
  3.739174875007373*^9, 3.7391748990667*^9}},
 CellLabel->"Out[15]=",ExpressionUUID->"2221c108-9f8d-4d4a-8fe4-7d98333b17f7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Expand", "[", 
  RowBox[{
   RowBox[{
    FractionBox["15", 
     RowBox[{"d", 
      RowBox[{"(", 
       RowBox[{"d", "+", "2"}], ")"}], 
      RowBox[{"(", 
       RowBox[{"d", "+", "4"}], ")"}]}]], 
    RowBox[{"sym", "[", 
     RowBox[{
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"i", ",", "j"}], "}"}], "]"}], 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"k", ",", "l"}], "}"}], "]"}], 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"r", ",", "s"}], "}"}], "]"}]}], "]"}]}], "-", 
   RowBox[{
    FractionBox["3", 
     RowBox[{"d", 
      RowBox[{"(", 
       RowBox[{"d", "+", "2"}], ")"}], 
      RowBox[{"(", 
       RowBox[{"d", "+", "4"}], ")"}]}]], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"sym", "[", 
        RowBox[{
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"i", ",", "j"}], "}"}], "]"}], 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"r", ",", "s"}], "}"}], "]"}]}], "]"}], 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"k", ",", "l"}], "}"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"sym", "[", 
        RowBox[{
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"i", ",", "k"}], "}"}], "]"}], 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"r", ",", "s"}], "}"}], "]"}]}], "]"}], 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"sym", "[", 
        RowBox[{
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"i", ",", "l"}], "}"}], "]"}], 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"r", ",", "s"}], "}"}], "]"}]}], "]"}], 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"sym", "[", 
        RowBox[{
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"j", ",", "k"}], "}"}], "]"}], 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"r", ",", "s"}], "}"}], "]"}]}], "]"}], 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"i", ",", "l"}], "}"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"sym", "[", 
        RowBox[{
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"j", ",", "l"}], "}"}], "]"}], 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"r", ",", "s"}], "}"}], "]"}]}], "]"}], 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"sym", "[", 
        RowBox[{
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"k", ",", "l"}], "}"}], "]"}], 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"r", ",", "s"}], "}"}], "]"}]}], "]"}], 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"i", ",", "j"}], "}"}], "]"}]}]}], ")"}]}], "+", 
   RowBox[{
    FractionBox["3", 
     RowBox[{"d", 
      RowBox[{"(", 
       RowBox[{"d", "+", "2"}], ")"}], 
      RowBox[{"(", 
       RowBox[{"d", "+", "4"}], ")"}]}]], 
    RowBox[{"sym", "[", 
     RowBox[{
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"i", ",", "j"}], "}"}], "]"}], 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"k", ",", "l"}], "}"}], "]"}]}], "]"}], 
    RowBox[{"\[Delta]", "[", 
     RowBox[{"{", 
      RowBox[{"r", ",", "s"}], "}"}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7392626470270643`*^9, 3.739262888692679*^9}},
 CellLabel->"In[21]:=",ExpressionUUID->"e4f04ec6-e818-45c9-b373-487647422db3"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.739262875522682*^9, 3.7392628892590513`*^9}},
 CellLabel->"Out[21]=",ExpressionUUID->"d16ffa75-a0f3-463b-984c-71f50cf6f55d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Einstein", "[", 
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{"u0", "[", 
      RowBox[{"{", 
       RowBox[{"l", ",", "r", ",", "s"}], "}"}], "]"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FractionBox["15", 
         RowBox[{"d", 
          RowBox[{"(", 
           RowBox[{"d", "+", "2"}], ")"}], 
          RowBox[{"(", 
           RowBox[{"d", "+", "4"}], ")"}]}]], 
        RowBox[{"sym", "[", 
         RowBox[{
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i", ",", "j"}], "}"}], "]"}], 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"k", ",", "l"}], "}"}], "]"}], 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"r", ",", "s"}], "}"}], "]"}]}], "]"}]}], "-", 
       RowBox[{
        FractionBox["3", 
         RowBox[{"d", 
          RowBox[{"(", 
           RowBox[{"d", "+", "2"}], ")"}]}]], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"sym", "[", 
            RowBox[{
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "l"}], "}"}], "]"}], 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"r", ",", "s"}], "}"}], "]"}]}], "]"}], 
           RowBox[{"\[Delta]", "[", 
            RowBox[{"{", 
             RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"sym", "[", 
            RowBox[{
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"j", ",", "l"}], "}"}], "]"}], 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"r", ",", "s"}], "}"}], "]"}]}], "]"}], 
           RowBox[{"\[Delta]", "[", 
            RowBox[{"{", 
             RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"sym", "[", 
            RowBox[{
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"k", ",", "l"}], "}"}], "]"}], 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"r", ",", "s"}], "}"}], "]"}]}], "]"}], 
           RowBox[{"\[Delta]", "[", 
            RowBox[{"{", 
             RowBox[{"i", ",", "j"}], "}"}], "]"}]}]}], ")"}]}]}], ")"}]}], 
    "]"}], "]"}], "/.", 
  RowBox[{
   RowBox[{"u0", "[", 
    RowBox[{"{", 
     RowBox[{"_", ",", "s_", ",", "s_"}], "}"}], "]"}], "\[Rule]", "0", 
   " "}]}]], "Input",
 CellChangeTimes->{{3.739267519021296*^9, 3.739267713579528*^9}},
 CellLabel->"In[26]:=",ExpressionUUID->"e785cd82-13c8-4db8-a110-02e11ded4b1c"],

Cell[BoxData[
 FractionBox[
  RowBox[{"6", " ", 
   RowBox[{"u0", "[", 
    RowBox[{"{", 
     RowBox[{"i", ",", "j", ",", "k"}], "}"}], "]"}]}], 
  RowBox[{"d", " ", 
   RowBox[{"(", 
    RowBox[{"2", "+", "d"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"4", "+", "d"}], ")"}]}]]], "Output",
 CellChangeTimes->{{3.739267641949687*^9, 3.739267684125173*^9}, 
   3.739267714789126*^9},
 CellLabel->"Out[26]=",ExpressionUUID->"1a174054-8071-4b46-9f32-61675fedbb98"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Some useful functions", "Section",
 CellChangeTimes->{{3.737480355440259*^9, 
  3.7374803624789762`*^9}},ExpressionUUID->"7e6f4299-acce-45c8-b19c-\
bd8d2569c3af"],

Cell[BoxData[
 RowBox[{
  RowBox[{"listtoreplacementlist", "[", "list_", "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"list1", "=", 
      RowBox[{"{", "}"}]}], "}"}], ",", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"EvenQ", "[", 
       RowBox[{"Length", "[", "list", "]"}], "]"}], ",", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"list", "\[LeftDoubleBracket]", 
          RowBox[{"ii", "+", "1"}], "\[RightDoubleBracket]"}], "\[Rule]", 
         RowBox[{
         "list", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}]}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"ii", ",", "1", ",", 
          RowBox[{"Length", "[", "list", "]"}], ",", "2"}], "}"}]}], "]"}]}], 
     "]"}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 ExpressionUUID -> "93d20c04-6452-472c-896f-af0aeebaf05c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"contractedsymtensor", "[", 
   RowBox[{"ex_", ",", "num$contractedidx_"}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"pos", ",", "indicesfortrace"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"pos", "=", 
      RowBox[{"Sort", "[", 
       RowBox[{"Flatten", "[", 
        RowBox[{"Extract", "[", 
         RowBox[{"ex", ",", 
          RowBox[{"Drop", "[", 
           RowBox[{
            RowBox[{"Position", "[", 
             RowBox[{"ex", ",", "List"}], "]"}], ",", "None", ",", 
            RowBox[{"-", "1"}]}], "]"}]}], "]"}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"num$contractedidx", ">", 
        RowBox[{"Length", "[", "pos", "]"}]}], ",", 
       RowBox[{
       "Print", "[", 
        "\"\<\!\(\*StyleBox[\"Wrong\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"number\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\
\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"of\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"contractions\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"!\",FontColor->RGBColor[1, 0, 0]]\)\>\"", "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"indicesfortrace", "=", 
         RowBox[{"Subsets", "[", 
          RowBox[{"pos", ",", 
           RowBox[{"{", "num$contractedidx", "}"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"atermwith\[Delta]s", "=", 
         RowBox[{"Apply", "[", 
          RowBox[{"Plus", ",", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"Einstein", "[", 
                 RowBox[{"Expand", "[", 
                  RowBox[{
                   RowBox[{"sym", "[", "ex", "]"}], "/.", 
                   RowBox[{"listtoreplacementlist", "[", 
                    RowBox[{
                    "indicesfortrace", "\[LeftDoubleBracket]", "ii", 
                    "\[RightDoubleBracket]"}], "]"}]}], "]"}], "]"}], "/.", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"s0", "\[Rule]", "\[CurlyKappa]0"}], ",", 
                  RowBox[{"s1", "\[Rule]", "\[CurlyKappa]1"}], ",", 
                  RowBox[{"s2", "\[Rule]", "\[CurlyKappa]2"}], ",", 
                  RowBox[{"s3", "\[Rule]", "\[CurlyKappa]3"}], ",", 
                  RowBox[{"s4", "\[Rule]", "\[CurlyKappa]4"}], ",", 
                  RowBox[{"s5", "\[Rule]", "\[CurlyKappa]5"}], ",", 
                  RowBox[{"s6", "\[Rule]", "\[CurlyKappa]6"}], ",", 
                  RowBox[{"s7", "\[Rule]", "\[CurlyKappa]7"}], ",", 
                  RowBox[{"s8", "\[Rule]", "\[CurlyKappa]8"}], ",", 
                  RowBox[{"s9", "\[Rule]", "\[CurlyKappa]9"}]}], "}"}]}], 
               ")"}], 
              RowBox[{"DeltaTensor", "[", 
               RowBox[{
               "indicesfortrace", "\[LeftDoubleBracket]", "ii", 
                "\[RightDoubleBracket]"}], "]"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"ii", ",", "1", ",", 
               RowBox[{"Length", "[", "indicesfortrace", "]"}]}], "}"}]}], 
            "]"}]}], "]"}]}]}]}], "\[IndentingNewLine]", "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.73747587117127*^9, 3.7374759554722233`*^9}, {
   3.737476011114135*^9, 3.737476027592705*^9}, {3.7374760716257687`*^9, 
   3.737476218794716*^9}, {3.737476267765482*^9, 3.737476305835268*^9}, {
   3.737476346923399*^9, 3.7374763527292757`*^9}, {3.737476400139915*^9, 
   3.737476426357102*^9}, {3.737516576008923*^9, 3.7375165829857187`*^9}, {
   3.73751673706919*^9, 3.737516751669647*^9}, {3.737517521882299*^9, 
   3.737517529442267*^9}, {3.737518422064479*^9, 3.737518425351272*^9}, {
   3.7375186054669027`*^9, 3.737518660281618*^9}, 3.737519804105269*^9, {
   3.737523344276915*^9, 3.737523385232967*^9}, {3.737523415303733*^9, 
   3.73752349808595*^9}, {3.7375236523196783`*^9, 
   3.737523660128787*^9}},ExpressionUUID->"963e6eaf-7c70-4a8d-a1d7-\
4e921f2807fa"],

Cell[BoxData[
 RowBox[{
  RowBox[{"contractedsymtensor", "[", "ex_", "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "pos", ",", "list$numof\[Delta]s", ",", "num$contractedidx", ",", 
      "indicesfortrace", ",", "atermwith\[Delta]s", ",", 
      RowBox[{"sum", "=", 
       RowBox[{"sym", "[", "ex", "]"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"pos", "=", 
      RowBox[{"Sort", "[", 
       RowBox[{"Flatten", "[", 
        RowBox[{"Extract", "[", 
         RowBox[{"ex", ",", 
          RowBox[{"Drop", "[", 
           RowBox[{
            RowBox[{"Position", "[", 
             RowBox[{"ex", ",", "List"}], "]"}], ",", "None", ",", 
            RowBox[{"-", "1"}]}], "]"}]}], "]"}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"list$numof\[Delta]s", "=", 
      RowBox[{"2", 
       RowBox[{"Range", "[", 
        RowBox[{
         RowBox[{"Length", "[", "pos", "]"}], "/", "2"}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"num$contractedidx", "=", 
         RowBox[{
         "list$numof\[Delta]s", "\[LeftDoubleBracket]", "kk", 
          "\[RightDoubleBracket]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"indicesfortrace", "=", 
         RowBox[{"Subsets", "[", 
          RowBox[{"pos", ",", 
           RowBox[{"{", "num$contractedidx", "}"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"atermwith\[Delta]s", "=", 
         RowBox[{"Apply", "[", 
          RowBox[{"Plus", ",", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"Einstein", "[", 
                 RowBox[{"Expand", "[", 
                  RowBox[{
                   RowBox[{"sym", "[", "ex", "]"}], "/.", 
                   RowBox[{"listtoreplacementlist", "[", 
                    RowBox[{
                    "indicesfortrace", "\[LeftDoubleBracket]", "ii", 
                    "\[RightDoubleBracket]"}], "]"}]}], "]"}], "]"}], "/.", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"s0", "\[Rule]", "\[CurlyKappa]0"}], ",", 
                  RowBox[{"s1", "\[Rule]", "\[CurlyKappa]1"}], ",", 
                  RowBox[{"s2", "\[Rule]", "\[CurlyKappa]2"}], ",", 
                  RowBox[{"s3", "\[Rule]", "\[CurlyKappa]3"}], ",", 
                  RowBox[{"s4", "\[Rule]", "\[CurlyKappa]4"}], ",", 
                  RowBox[{"s5", "\[Rule]", "\[CurlyKappa]5"}], ",", 
                  RowBox[{"s6", "\[Rule]", "\[CurlyKappa]6"}], ",", 
                  RowBox[{"s7", "\[Rule]", "\[CurlyKappa]7"}], ",", 
                  RowBox[{"s8", "\[Rule]", "\[CurlyKappa]8"}], ",", 
                  RowBox[{"s9", "\[Rule]", "\[CurlyKappa]9"}]}], "}"}]}], 
               ")"}], 
              RowBox[{"DeltaTensor", "[", 
               RowBox[{
               "indicesfortrace", "\[LeftDoubleBracket]", "ii", 
                "\[RightDoubleBracket]"}], "]"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"ii", ",", "1", ",", 
               RowBox[{"Length", "[", "indicesfortrace", "]"}]}], "}"}]}], 
            "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{"sum", "+=", 
         RowBox[{
          RowBox[{"c", "[", "kk", "]"}], "atermwith\[Delta]s"}]}], ";"}], 
       "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{
          RowBox[{"sym", "[", "ex", "]"}], "+", 
          RowBox[{"Apply", "[", 
           RowBox[{"Plus", ",", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"c", "[", "jj", "]"}], 
               RowBox[{"atermwith\[Delta]s", "[", 
                RowBox[{"ex", ",", 
                 RowBox[{
                 "list$numof\[Delta]s", "\[LeftDoubleBracket]", "jj", 
                  "\[RightDoubleBracket]"}]}], "]"}]}], ",", 
              RowBox[{"{", 
               RowBox[{"jj", ",", "1", ",", 
                RowBox[{"Length", "[", "list$numof\[Delta]s", "]"}]}], 
               "}"}]}], "]"}]}], "]"}]}], ";"}], "*)"}], 
       "\[IndentingNewLine]", ",", 
       RowBox[{"{", 
        RowBox[{"kk", ",", 
         RowBox[{"Length", "[", "list$numof\[Delta]s", "]"}]}], "}"}]}], 
      "]"}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", "sum"}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.73747587117127*^9, 3.7374759554722233`*^9}, {
   3.737476011114135*^9, 3.737476027592705*^9}, {3.7374760716257687`*^9, 
   3.737476218794716*^9}, {3.737476267765482*^9, 3.737476305835268*^9}, {
   3.737476346923399*^9, 3.7374763527292757`*^9}, {3.737476400139915*^9, 
   3.737476426357102*^9}, {3.737516576008923*^9, 3.7375165829857187`*^9}, {
   3.73751673706919*^9, 3.737516751669647*^9}, {3.737517521882299*^9, 
   3.737517529442267*^9}, {3.737518422064479*^9, 3.737518425351272*^9}, {
   3.7375186054669027`*^9, 3.737518660281618*^9}, 3.737519804105269*^9, {
   3.737523344276915*^9, 3.737523385232967*^9}, {3.737523415303733*^9, 
   3.73752349808595*^9}, {3.7375236523196783`*^9, 3.737523660128787*^9}, {
   3.737523840537224*^9, 3.737523898291198*^9}, {3.737523929433486*^9, 
   3.7375239776259003`*^9}, {3.7375240426540728`*^9, 
   3.7375240748179913`*^9}, {3.737524119632876*^9, 3.737524144056184*^9}, {
   3.737524219430228*^9, 3.737524256848556*^9}, {3.737524291200849*^9, 
   3.737524321720175*^9}, {3.737524366148511*^9, 3.737524376544066*^9}, {
   3.737524419663376*^9, 3.7375244599300203`*^9}, {3.7375246029992332`*^9, 
   3.7375246263448553`*^9}, {3.737524757955763*^9, 3.737524761627483*^9}},
 ExpressionUUID -> "0b674ee6-e6b0-4782-8cd3-c09651da650b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ex", "=", 
   RowBox[{
    RowBox[{"A", "[", 
     RowBox[{"{", "i1", "}"}], "]"}], 
    RowBox[{"B", "[", 
     RowBox[{"{", "i2", "}"}], "]"}], 
    RowBox[{"X", "[", 
     RowBox[{"{", "i3", "}"}], "]"}], 
    RowBox[{"Y", "[", 
     RowBox[{"{", "i4", "}"}], "]"}], 
    RowBox[{"Z", "[", 
     RowBox[{"{", "i5", "}"}], "]"}], 
    RowBox[{"L", "[", 
     RowBox[{"{", "i6", "}"}], "]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.737524674249761*^9, 3.737524695287359*^9}, {
  3.7375248167375298`*^9, 
  3.7375248351040077`*^9}},ExpressionUUID->"ccebaa0a-b1b8-4009-a8df-\
b14ada2bd037"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ex", "=", 
   RowBox[{"A", "[", 
    RowBox[{"{", 
     RowBox[{"i1", ",", "i2", ",", "i3", ",", "i4"}], "}"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.7375248707282257`*^9, 
  3.737524882826495*^9}},ExpressionUUID->"9ce6550b-3bea-4e9d-98d6-\
25f2b473045c"],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.737558545733811*^9, 3.737558584791411*^9}, {
   3.7375586719428377`*^9, 3.737558715262845*^9}, 
   3.7375589718462877`*^9},ExpressionUUID->"731e2b16-3d9b-4ded-8976-\
055185926dbc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ex", "=", 
   RowBox[{
    RowBox[{"A", "[", 
     RowBox[{"{", "i1", "}"}], "]"}], 
    RowBox[{"B", "[", 
     RowBox[{"{", "i2", "}"}], "]"}], 
    RowBox[{"X", "[", 
     RowBox[{"{", "i3", "}"}], "]"}], 
    RowBox[{"Y", "[", 
     RowBox[{"{", "i4", "}"}], "]"}], 
    RowBox[{"Q", "[", 
     RowBox[{"{", "i5", "}"}], "]"}], 
    RowBox[{"S", "[", 
     RowBox[{"{", "i6", "}"}], "]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.737520672531024*^9, 3.737520691209538*^9}, {
  3.73760072348228*^9, 
  3.737600725183268*^9}},ExpressionUUID->"01463a2e-c117-480d-b7c1-\
b85c267ccc52"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ex", "=", 
    RowBox[{
     RowBox[{"A", "[", 
      RowBox[{"{", "i1", "}"}], "]"}], 
     RowBox[{"B", "[", 
      RowBox[{"{", "i2", "}"}], "]"}], 
     RowBox[{"X", "[", 
      RowBox[{"{", "i3", "}"}], "]"}], 
     RowBox[{"Y", "[", 
      RowBox[{"{", "i4", "}"}], "]"}]}]}], ";"}], 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.737515738115232*^9, 3.7375158251298*^9}, {
   3.737516782397437*^9, 3.7375167828850603`*^9}, 
   3.737520665147637*^9},ExpressionUUID->"6ee2ca61-dbe1-4309-b498-\
dedf3ea0b5b5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tensorwithoutconstfactor", "[", "ex_", "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"position$tensors", ",", "dummy", ",", "ex1"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ex1", "=", 
      RowBox[{"dummy", " ", "ex"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"position$tensors", "=", 
      RowBox[{"Partition", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Position", "[", 
          RowBox[{"ex1", ",", "List"}], "]"}], "\[LeftDoubleBracket]", 
         RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", "1"}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Apply", "[", 
      RowBox[{"Times", ",", 
       RowBox[{"Extract", "[", 
        RowBox[{"ex1", ",", "position$tensors"}], "]"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.737711166073648*^9, 3.737711304218445*^9}, 
   3.737711370782329*^9, 3.737711408510408*^9, {3.737711553530703*^9, 
   3.737711564015501*^9}, {3.7377124348641367`*^9, 3.737712499566338*^9}, {
   3.737712695263837*^9, 3.737712758799972*^9}, {3.737712846498941*^9, 
   3.737712881840274*^9}},
 ExpressionUUID -> "6cc68fff-d9dc-47d8-a496-0d9596b6f966"],

Cell[BoxData[
 RowBox[{
  RowBox[{"fullytracefreeform1", "[", "ex_", "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "list$factorswithpowers", ",", "factors", ",", "theirpowers", ",", 
      "list$tensors", ",", "list$nonrepeatedtensor", ",", "position$tensors", 
      ",", "power$tensors", ",", "output", ",", "indicesoccurence", ",", 
      "allsingleindices", ",", "contractionreplacements", ",", 
      RowBox[{"list", "=", 
       RowBox[{"{", "}"}]}], ",", "deftracefree", ",", "constantfactor", ",", 
      "ex1", ",", "originaltensor", ",", "headoftensors"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"list$factorswithpowers", "=", 
      RowBox[{"FactorList", "[", "ex", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"factors", "=", 
      RowBox[{"list$factorswithpowers", "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"theirpowers", "=", 
      RowBox[{"list$factorswithpowers", "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"constantfactor", "=", 
      RowBox[{
       RowBox[{"list$factorswithpowers", "\[LeftDoubleBracket]", 
        RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], "^", 
       RowBox[{"list$factorswithpowers", "\[LeftDoubleBracket]", 
        RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      StyleBox[
       RowBox[{
       "condition", " ", "for", " ", "powers", " ", "in", " ", "tensors"}],
       FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
     RowBox[{"list$tensors", "=", 
      RowBox[{"Extract", "[", 
       RowBox[{"factors", ",", 
        RowBox[{"Drop", "[", 
         RowBox[{
          RowBox[{"Complement", "[", 
           RowBox[{
            RowBox[{"Position", "[", 
             RowBox[{"factors", ",", "List"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"{", "0", "}"}], "}"}]}], "]"}], ",", "None", ",", 
          RowBox[{"-", "1"}]}], "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"list$nonrepeatedtensor", "=", 
      RowBox[{
       RowBox[{"Cases", "[", 
        RowBox[{
         RowBox[{"Drop", "[", 
          RowBox[{"list$factorswithpowers", ",", "1"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"_", ",", "1"}], "}"}]}], "]"}], "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Length", "[", 
         RowBox[{"DeleteDuplicates", "[", 
          RowBox[{"Head", "/@", "list$nonrepeatedtensor"}], "]"}], "]"}], "!=",
         "1"}], ",", 
       RowBox[{"output", "=", 
        RowBox[{"Print", "[", "\"\<\!\(\*
StyleBox[\"Input\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"tensor\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"contains\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"multiple\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"heads\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\".\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"This\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"function\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"is\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"not\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"capable\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"of\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"producing\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"the\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"traceless\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"tensor\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"in\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"fully\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"tracefree\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"form\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\".\",
FontColor->RGBColor[1, 0, 0]]\)\>\"", "]"}]}], ",", 
       RowBox[{
        RowBox[{"headoftensors", "=", 
         RowBox[{"Head", "[", 
          RowBox[{
          "list$nonrepeatedtensor", "\[LeftDoubleBracket]", "1", 
           "\[RightDoubleBracket]"}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"position$tensors", "=", 
         RowBox[{"Drop", "[", 
          RowBox[{
           RowBox[{"Drop", "[", 
            RowBox[{
             RowBox[{"Complement", "[", 
              RowBox[{
               RowBox[{"Position", "[", 
                RowBox[{"factors", ",", "List"}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"{", "0", "}"}], "}"}]}], "]"}], ",", "None", ",", 
             RowBox[{"-", "1"}]}], "]"}], ",", "None", ",", 
           RowBox[{"-", "1"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"power$tensors", "=", 
         RowBox[{"Extract", "[", 
          RowBox[{"theirpowers", ",", "position$tensors"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Max", "[", "power$tensors", "]"}], ">", "2"}], ",", 
          RowBox[{"output", "=", 
           RowBox[{"Print", "[", "\"\<\!\(\*
StyleBox[\"Please\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"check\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"the\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"exponents\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"on\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"tensors\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\".\",
FontColor->RGBColor[1, 0, 0]]\)\>\"", "]"}]}], ",", 
          RowBox[{
           RowBox[{"indicesoccurence", "=", 
            RowBox[{"Tally", "[", 
             RowBox[{"Flatten", "[", 
              RowBox[{"Table", "[", 
               RowBox[{
                RowBox[{"ConstantArray", "[", 
                 RowBox[{
                  RowBox[{
                  "list$tensors", "\[LeftDoubleBracket]", "ii", 
                   "\[RightDoubleBracket]"}], ",", 
                  RowBox[{
                  "power$tensors", "\[LeftDoubleBracket]", "ii", 
                   "\[RightDoubleBracket]"}]}], "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"ii", ",", 
                  RowBox[{"1", 
                   RowBox[{"Length", "[", "list$tensors", "]"}]}]}], "}"}]}], 
               "]"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Max", "[", 
               RowBox[{"indicesoccurence", "\[LeftDoubleBracket]", 
                RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], "]"}], 
              ">", "2"}], ",", "\[IndentingNewLine]", 
             RowBox[{"output", "=", 
              RowBox[{"Print", "[", "\"\<\!\(\*
StyleBox[\"Please\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"check\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"the\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"repeated\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"indices\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\".\",
FontColor->RGBColor[1, 0, 0]]\)\>\"", "]"}]}], ",", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"allsingleindices", "=", 
               RowBox[{"Sort", "[", 
                RowBox[{
                 RowBox[{"Extract", "[", 
                  RowBox[{"indicesoccurence", ",", 
                   RowBox[{"Drop", "[", 
                    RowBox[{
                    RowBox[{"Position", "[", 
                    RowBox[{"indicesoccurence", ",", "1"}], "]"}], ",", 
                    "None", ",", 
                    RowBox[{"-", "1"}]}], "]"}]}], "]"}], 
                 "\[LeftDoubleBracket]", 
                 RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], 
                "]"}]}], ";", "\[IndentingNewLine]", 
              RowBox[{"contractionreplacements", "=", 
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"list", "=", 
                  RowBox[{"Join", "[", 
                   RowBox[{"list", ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"allsingleindices", "\[LeftDoubleBracket]", 
                    RowBox[{"2", "ii"}], "\[RightDoubleBracket]"}], "\[Rule]", 
                    RowBox[{"allsingleindices", "\[LeftDoubleBracket]", 
                    RowBox[{
                    RowBox[{"2", "ii"}], "-", "1"}], 
                    "\[RightDoubleBracket]"}]}], "}"}]}], "]"}]}], ",", 
                 RowBox[{"{", 
                  RowBox[{"ii", ",", 
                   RowBox[{
                    RowBox[{"Length", "[", "allsingleindices", "]"}], "/", 
                    "2"}], ",", "1", ",", 
                   RowBox[{"-", "1"}]}], "}"}]}], "]"}]}], ";", 
              "\[IndentingNewLine]", 
              RowBox[{"ex1", "=", 
               RowBox[{"ex", "/", "constantfactor"}]}], ";", " ", 
              RowBox[{"(*", 
               StyleBox[
                RowBox[{
                "divison", " ", "by", " ", "constant", " ", "coefficient"}],
                FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
              
              RowBox[{"deftracefree", "=", 
               RowBox[{"Deftracefreetensor", "[", "ex1", "]"}]}], ";", 
              "\[IndentingNewLine]", 
              RowBox[{"(*", 
               RowBox[{
               "\[CapitalKoppa]", " ", "denotes", " ", "traceless", " ", 
                "tensor"}], "*)"}], "\[IndentingNewLine]", 
              RowBox[{"(*", 
               RowBox[{
                RowBox[{"output", "=", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Solve", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"contractedtensor", "[", 
                    RowBox[{"sym", "[", "ex1", "]"}], "]"}], "/.", 
                    RowBox[{"{", 
                    RowBox[{"headoftensors", "\[Rule]", "\[CapitalUpsilon]"}],
                     "}"}]}], ")"}], "\[Equal]", 
                    RowBox[{"(", 
                    RowBox[{"deftracefree", "/.", 
                    RowBox[{
                    RowBox[{"contractedtensor", "[", 
                    RowBox[{"sym", "[", "ex1", "]"}], "]"}], "\[Rule]", 
                    "originaltensor"}]}], ")"}]}], ",", "originaltensor"}], 
                    "]"}], "\[LeftDoubleBracket]", "1", 
                   "\[RightDoubleBracket]"}], "/.", 
                  RowBox[{"originaltensor", "\[Rule]", 
                   RowBox[{"contractedtensor", "[", 
                    RowBox[{"sym", "[", "ex1", "]"}], "]"}]}]}]}], ";"}], 
               "*)"}], "\[IndentingNewLine]", 
              RowBox[{"output", "=", "deftracefree"}], ";"}]}], 
            "\[IndentingNewLine]", "]"}], ";"}]}], "\[IndentingNewLine]", 
         "]"}], ";"}]}], "\[IndentingNewLine]", "]"}], ";", 
     "\[IndentingNewLine]", "output"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.737649725787002*^9, 3.737649794804452*^9}, {
   3.737649865571088*^9, 3.737649886985256*^9}, {3.737649928288878*^9, 
   3.737650077278027*^9}, {3.737650208177122*^9, 3.737650229705217*^9}, {
   3.737650271081646*^9, 3.737650273681531*^9}, {3.7376506145769997`*^9, 
   3.737650641053269*^9}, {3.737650694781361*^9, 3.7376507213880663`*^9}, {
   3.737650771575509*^9, 3.737650788910133*^9}, {3.73765165597478*^9, 
   3.7376517696041403`*^9}, {3.737651805775999*^9, 3.737651810454616*^9}, {
   3.7376518846130743`*^9, 3.737651937697381*^9}, {3.73765226647575*^9, 
   3.737652303642414*^9}, {3.7376543163188133`*^9, 3.737654332358873*^9}, {
   3.737654534806251*^9, 3.73765455642763*^9}, {3.737654638662271*^9, 
   3.737654711661703*^9}, {3.737654752757811*^9, 3.737654791711769*^9}, 
   3.7376548981770573`*^9, {3.737654947971787*^9, 3.737654951673275*^9}, {
   3.737655011954914*^9, 3.737655063201701*^9}, {3.737700322686281*^9, 
   3.737700325019425*^9}, {3.737700781703013*^9, 3.737700796373307*^9}, {
   3.737700847620089*^9, 3.737700895329212*^9}, {3.7377103188630123`*^9, 
   3.737710332503723*^9}, {3.737713391618162*^9, 3.737713394542843*^9}},
 ExpressionUUID -> "e893c1cc-0865-45fb-85c7-7c23011b3c8c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tensorattributes", "[", "1", "]"}]], "Input",
 CellChangeTimes->{{3.737995164746607*^9, 
  3.737995165130471*^9}},ExpressionUUID->"4dc10deb-c72d-4199-acd0-\
1d0c3c79a342"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"constantfactor", "\[Rule]", "1"}], ",", 
   RowBox[{"tensorialpart", "\[Rule]", "1"}], ",", 
   RowBox[{"freeindices", "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{"tensorialparthavingfreeindices", "\[Rule]", "1"}], ",", 
   RowBox[{"tensornames$havingfreeindices", "\[Rule]", 
    RowBox[{"{", "}"}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.737995165783114*^9},ExpressionUUID->"f4d5f4ae-560f-4e35-8861-\
7ee1e8dbce26"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"ex", "[", "4", "]"}]], "Input",
 CellChangeTimes->{{3.7379959722413588`*^9, 
  3.73799597283912*^9}},ExpressionUUID->"1cc03e75-e2ae-4c60-b3e0-\
1b93e4e4b2f6"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "25", "]"}], "=", 
   RowBox[{
    RowBox[{"-", "1.305`"}], " ", 
    RowBox[{"A", "[", 
     RowBox[{"{", "i", "}"}], "]"}], " ", 
    RowBox[{"A", "[", 
     RowBox[{"{", "j", "}"}], "]"}], 
    RowBox[{"A", "[", 
     RowBox[{"{", "k", "}"}], "]"}], " ", 
    RowBox[{"A", "[", 
     RowBox[{"{", "\[Alpha]", "}"}], "]"}], 
    SuperscriptBox[
     RowBox[{"X", "[", 
      RowBox[{"{", "l", "}"}], "]"}], "2"]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.73799602685211*^9, 3.737996036564657*^9}, {
  3.737996884341979*^9, 3.7379969101939287`*^9}, {3.7379969535143223`*^9, 
  3.737996958546369*^9}},ExpressionUUID->"98056e0e-fdd5-4d9f-8e9d-\
e5b853ec1f0e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ex", "[", "26", "]"}], "=", 
  RowBox[{
   RowBox[{"-", "1.305`"}], " ", 
   RowBox[{"B", "[", 
    RowBox[{"{", 
     RowBox[{"i", ",", "l"}], "}"}], "]"}], 
   RowBox[{"B", "[", 
    RowBox[{"{", "l", "}"}], "]"}], " ", 
   RowBox[{"A", "[", 
    RowBox[{"{", "j", "}"}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{"X", "[", 
     RowBox[{"{", "k", "}"}], "]"}], "2"]}]}]], "Input",
 CellChangeTimes->{{3.737996172439636*^9, 3.737996190078076*^9}, {
  3.737996239390527*^9, 
  3.737996240164628*^9}},ExpressionUUID->"76205382-fca4-455b-9528-\
4778dca2338e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "1.305`"}], " ", 
  RowBox[{"A", "[", 
   RowBox[{"{", "j", "}"}], "]"}], " ", 
  RowBox[{"B", "[", 
   RowBox[{"{", "l", "}"}], "]"}], " ", 
  RowBox[{"B", "[", 
   RowBox[{"{", 
    RowBox[{"i", ",", "l"}], "}"}], "]"}], " ", 
  SuperscriptBox[
   RowBox[{"X", "[", 
    RowBox[{"{", "k", "}"}], "]"}], "2"]}]], "Output",
 CellChangeTimes->{
  3.7379962412305193`*^9},ExpressionUUID->"654ee451-656c-45bf-b17d-\
4a6f0893c1ed"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fullytracefreeform1", "[", 
  RowBox[{"ex", "[", "25", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.737995889745945*^9, 3.737995890384473*^9}, {
  3.737995931586668*^9, 3.7379959388424892`*^9}, {3.737995977769237*^9, 
  3.737995978007235*^9}, {3.737996041902849*^9, 3.73799604279678*^9}, {
  3.737996203454925*^9, 3.7379962037981052`*^9}, {3.737996838454247*^9, 
  3.737996839108488*^9}},ExpressionUUID->"4d2065ce-3ec2-41ae-8783-\
98e194d42850"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"A", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", "i", "}"}]}], "]"}], " ", 
    RowBox[{"A", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", "j", "}"}]}], "]"}], " ", 
    RowBox[{"A", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", "k", "}"}]}], "]"}], " ", 
    RowBox[{"A", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", "\[Alpha]", "}"}]}], "]"}], " ", 
    SuperscriptBox[
     RowBox[{"X", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", "p0", "}"}]}], "]"}], "2"]}], "\[Rule]", 
   RowBox[{
    RowBox[{
     FractionBox["1", 
      RowBox[{"4", "+", "d"}]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "k", "}"}]}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{"A", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "\[Alpha]", "}"}]}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{"X", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p1", "}"}]}], "]"}], "2"], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "j", "}"}]}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{"A", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "\[Alpha]", "}"}]}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{"X", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p1", "}"}]}], "]"}], "2"], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "j", "}"}]}], "]"}], " ", 
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "k", "}"}]}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{"A", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"X", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p1", "}"}]}], "]"}], "2"], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i", ",", "\[Alpha]"}], "}"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "i", "}"}]}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{"A", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "\[Alpha]", "}"}]}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{"X", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p1", "}"}]}], "]"}], "2"], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "i", "}"}]}], "]"}], " ", 
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "k", "}"}]}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{"A", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"X", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p1", "}"}]}], "]"}], "2"], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"j", ",", "\[Alpha]"}], "}"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "i", "}"}]}], "]"}], " ", 
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "j", "}"}]}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{"A", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"X", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p1", "}"}]}], "]"}], "2"], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"k", ",", "\[Alpha]"}], "}"}], "]"}]}]}], ")"}]}], "-", 
    RowBox[{
     FractionBox["1", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"2", "+", "d"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"4", "+", "d"}], ")"}]}]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"A", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"A", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p1", "}"}]}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"X", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p2", "}"}]}], "]"}], "2"], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i", ",", "\[Alpha]"}], "}"}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"A", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"A", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p1", "}"}]}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"X", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p2", "}"}]}], "]"}], "2"], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i", ",", "k"}], "}"}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"j", ",", "\[Alpha]"}], "}"}], "]"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"A", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"A", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p1", "}"}]}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"X", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p2", "}"}]}], "]"}], "2"], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"k", ",", "\[Alpha]"}], "}"}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"X", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
     RowBox[{"\[CapitalUpsilon]", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", "i", "}"}]}], "]"}], " ", 
     RowBox[{"\[CapitalUpsilon]", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", "j", "}"}]}], "]"}], " ", 
     RowBox[{"\[CapitalUpsilon]", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", "k", "}"}]}], "]"}], " ", 
     RowBox[{"\[CapitalUpsilon]", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", "\[Alpha]", "}"}]}], "]"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7379959337371807`*^9, 3.7379959794355087`*^9}, 
   3.737996044166913*^9, 3.737996157399098*^9, {3.737996198483222*^9, 
   3.7379962438031387`*^9}, {3.7379968364088287`*^9, 
   3.7379968400618668`*^9}, {3.737996899338099*^9, 3.737996920329851*^9}, 
   3.737996961974531*^9, 
   3.737997066620702*^9},ExpressionUUID->"718167c5-96ce-4fff-a07c-\
25a258f1ddee"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"list", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "11"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "7"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"4", ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"7", ",", "9"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "2"}], ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", "10"}], "}"}]}], "}"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{"Select", "[", 
   RowBox[{"list", ",", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "[", 
       RowBox[{"[", "2", "]"}], "]"}], ">", "8"}], "&"}]}], "]"}], "[", 
  RowBox[{"[", 
   RowBox[{"All", ",", "1"}], "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.737995802863041*^9, 
  3.737995802864263*^9}},ExpressionUUID->"dc906987-74e6-4ce4-a88b-\
e3769486b0c0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"contractedtensor", "[", 
  RowBox[{"sym", "[", "ex", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.737650725069322*^9, 
  3.737650752587241*^9}},ExpressionUUID->"18ba1a78-5b24-48fa-950b-\
e15f111b278d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"A", "[", 
   RowBox[{"0", ",", 
    RowBox[{"{", "i3", "}"}]}], "]"}], " ", 
  RowBox[{"A", "[", 
   RowBox[{"0", ",", 
    RowBox[{"{", "i4", "}"}]}], "]"}], " ", 
  RowBox[{"A", "[", 
   RowBox[{"0", ",", 
    RowBox[{"{", "i5", "}"}]}], "]"}], " ", 
  RowBox[{"A", "[", 
   RowBox[{"0", ",", 
    RowBox[{"{", "i6", "}"}]}], "]"}], " ", 
  SuperscriptBox[
   RowBox[{"A", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", "p0", "}"}]}], "]"}], "2"]}]], "Output",
 CellChangeTimes->{{3.737650730186673*^9, 3.737650753149068*^9}, 
   3.737654820212676*^9},ExpressionUUID->"c0297ba4-a596-4b2c-9945-\
2ee2c5afec51"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ex", "=", 
   RowBox[{
    FractionBox["1", "6"], 
    RowBox[{"A", "[", 
     RowBox[{"{", "i1", "}"}], "]"}], 
    RowBox[{"A", "[", 
     RowBox[{"{", "i1", "}"}], "]"}], 
    RowBox[{"A", "[", 
     RowBox[{"{", "i3", "}"}], "]"}], 
    RowBox[{"A", "[", 
     RowBox[{"{", "i4", "}"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"fullytracefreeform1", "[", "ex", "]"}]}], "Input",
 CellChangeTimes->{{3.737700681672535*^9, 3.737700697993322*^9}, 
   3.737700909214697*^9},
 ExpressionUUID -> "db01d082-345a-47e6-9fee-acde0354ca5d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"A", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", "i3", "}"}]}], "]"}], " ", 
    RowBox[{"A", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", "i4", "}"}]}], "]"}], " ", 
    SuperscriptBox[
     RowBox[{"A", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", "p0", "}"}]}], "]"}], "2"]}], "\[Rule]", 
   FractionBox[
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"A", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"A", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "p1", "}"}]}], "]"}], "2"], " ", 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"i3", ",", "i4"}], "}"}], "]"}]}], "+", 
     RowBox[{"d", " ", 
      RowBox[{"\[CapitalUpsilon]", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "i3", "}"}]}], "]"}], " ", 
      RowBox[{"\[CapitalUpsilon]", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "i4", "}"}]}], "]"}], " ", 
      SuperscriptBox[
       RowBox[{"\[CapitalUpsilon]", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "p0", "}"}]}], "]"}], "2"]}]}], "d"]}], "}"}]], "Output",\

 CellChangeTimes->{3.7377009100715322`*^9},
 ExpressionUUID -> "04ea3022-1da7-425f-bba2-9feed23bc4ab"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ex", "=", 
   RowBox[{
    FractionBox["1", "6"], 
    RowBox[{"A", "[", 
     RowBox[{"{", "i1", "}"}], "]"}], 
    RowBox[{"A", "[", 
     RowBox[{"{", "i1", "}"}], "]"}], 
    RowBox[{"A", "[", 
     RowBox[{"{", "i3", "}"}], "]"}], 
    RowBox[{"A", "[", 
     RowBox[{"{", "i4", "}"}], "]"}], 
    RowBox[{"A", "[", 
     RowBox[{"{", "i5", "}"}], "]"}], 
    RowBox[{"A", "[", 
     RowBox[{"{", "i6", "}"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Collect", "[", 
  RowBox[{
   RowBox[{"fullytracefreeform1", "[", "ex", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"i3", ",", "i4"}], "}"}], "]"}], " ", 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"i5", ",", "i6"}], "}"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"i3", ",", "i5"}], "}"}], "]"}], " ", 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"i4", ",", "i6"}], "}"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"i3", ",", "i6"}], "}"}], "]"}], " ", 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"i4", ",", "i5"}], "}"}], "]"}]}]}], "}"}], ",", "Simplify"}],
   "]"}]}], "Input",
 CellChangeTimes->{{3.737650112181814*^9, 3.737650171760022*^9}, {
  3.737650284816618*^9, 3.737650314296647*^9}, {3.737650480940132*^9, 
  3.737650516283557*^9}, {3.7376520164368973`*^9, 3.737652074075238*^9}, {
  3.737652125075117*^9, 3.737652181002882*^9}},
 ExpressionUUID -> "f4f96a4d-d306-4dbb-81ed-5cce73e264fa"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"A", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", "i3", "}"}]}], "]"}], " ", 
    RowBox[{"A", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", "i4", "}"}]}], "]"}], " ", 
    RowBox[{"A", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", "i5", "}"}]}], "]"}], " ", 
    RowBox[{"A", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", "i6", "}"}]}], "]"}], " ", 
    SuperscriptBox[
     RowBox[{"A", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", "p0", "}"}]}], "]"}], "2"]}], "\[Rule]", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "p1", "}"}]}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "p2", "}"}]}], "]"}], "2"], " ", 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"i3", ",", "i6"}], "}"}], "]"}], " ", 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"i4", ",", "i5"}], "}"}], "]"}]}], 
      RowBox[{"8", "+", 
       RowBox[{"6", " ", "d"}], "+", 
       SuperscriptBox["d", "2"]}]]}], "-", 
    FractionBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"A", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"A", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "p1", "}"}]}], "]"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"A", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "p2", "}"}]}], "]"}], "2"], " ", 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"i3", ",", "i5"}], "}"}], "]"}], " ", 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"i4", ",", "i6"}], "}"}], "]"}]}], 
     RowBox[{"8", "+", 
      RowBox[{"6", " ", "d"}], "+", 
      SuperscriptBox["d", "2"]}]], "-", 
    FractionBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"A", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"A", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "p1", "}"}]}], "]"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"A", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "p2", "}"}]}], "]"}], "2"], " ", 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"i3", ",", "i4"}], "}"}], "]"}], " ", 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"i5", ",", "i6"}], "}"}], "]"}]}], 
     RowBox[{"8", "+", 
      RowBox[{"6", " ", "d"}], "+", 
      SuperscriptBox["d", "2"]}]], "+", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"4", "+", "d"}]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "i3", "}"}]}], "]"}], " ", 
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "i6", "}"}]}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{"A", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"A", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p1", "}"}]}], "]"}], "2"], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i4", ",", "i5"}], "}"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "i5", "}"}]}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{"A", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"A", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p1", "}"}]}], "]"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"A", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "i6", "}"}]}], "]"}], " ", 
           RowBox[{"\[Delta]", "[", 
            RowBox[{"{", 
             RowBox[{"i3", ",", "i4"}], "}"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"A", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "i4", "}"}]}], "]"}], " ", 
           RowBox[{"\[Delta]", "[", 
            RowBox[{"{", 
             RowBox[{"i3", ",", "i6"}], "}"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"A", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "i3", "}"}]}], "]"}], " ", 
           RowBox[{"\[Delta]", "[", 
            RowBox[{"{", 
             RowBox[{"i4", ",", "i6"}], "}"}], "]"}]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "i4", "}"}]}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{"A", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"A", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p1", "}"}]}], "]"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"A", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "i6", "}"}]}], "]"}], " ", 
           RowBox[{"\[Delta]", "[", 
            RowBox[{"{", 
             RowBox[{"i3", ",", "i5"}], "}"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"A", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "i3", "}"}]}], "]"}], " ", 
           RowBox[{"\[Delta]", "[", 
            RowBox[{"{", 
             RowBox[{"i5", ",", "i6"}], "}"}], "]"}]}]}], ")"}]}], "+", 
       RowBox[{"4", " ", 
        RowBox[{"\[CapitalUpsilon]", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "i3", "}"}]}], "]"}], " ", 
        RowBox[{"\[CapitalUpsilon]", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "i4", "}"}]}], "]"}], " ", 
        RowBox[{"\[CapitalUpsilon]", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "i5", "}"}]}], "]"}], " ", 
        RowBox[{"\[CapitalUpsilon]", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "i6", "}"}]}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{"\[CapitalUpsilon]", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p0", "}"}]}], "]"}], "2"]}], "+", 
       RowBox[{"d", " ", 
        RowBox[{"\[CapitalUpsilon]", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "i3", "}"}]}], "]"}], " ", 
        RowBox[{"\[CapitalUpsilon]", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "i4", "}"}]}], "]"}], " ", 
        RowBox[{"\[CapitalUpsilon]", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "i5", "}"}]}], "]"}], " ", 
        RowBox[{"\[CapitalUpsilon]", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "i6", "}"}]}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{"\[CapitalUpsilon]", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p0", "}"}]}], "]"}], "2"]}]}], ")"}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.737650134418805*^9, 3.737650172278028*^9}, {
   3.737650238433848*^9, 3.737650315300563*^9}, {3.737650484954458*^9, 
   3.737650512606029*^9}, 3.737650646518424*^9, 3.7376507950313053`*^9, 
   3.737651331287822*^9, 3.737651819636437*^9, 3.737651944554525*^9, {
   3.7376520211892242`*^9, 3.737652038279133*^9}, {3.737652126283951*^9, 
   3.7376521817993793`*^9}, 3.737652310472101*^9, 3.737654826431946*^9, 
   3.7376549144623823`*^9, 3.73765495738066*^9, 3.737655073186633*^9, 
   3.737700418607349*^9, 3.737700558545586*^9},
 ExpressionUUID -> "93374768-4c3e-4aed-8955-225a8b3d6ac1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fullytracefreeform1", "[", "ex", "]"}]], "Input",
 CellChangeTimes->{{3.7376504223389187`*^9, 3.737650427801914*^9}, 
   3.737654863038616*^9},
 ExpressionUUID -> "60545603-9fac-4823-ab3e-dfb3ce8259b1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"A", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}]}], "]"}], "\[Rule]", 
   
   RowBox[{
    RowBox[{
     FractionBox["1", 
      RowBox[{"4", "+", "d"}]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"1", ",", 
          RowBox[{"{", 
           RowBox[{"k", ",", "l"}], "}"}]}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"1", ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "l"}], "}"}]}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"1", ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "k"}], "}"}]}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i", ",", "l"}], "}"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"1", ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "l"}], "}"}]}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"1", ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "k"}], "}"}]}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"1", ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "j"}], "}"}]}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"k", ",", "l"}], "}"}], "]"}]}]}], ")"}]}], "-", 
    RowBox[{
     FractionBox["1", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"2", "+", "d"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"4", "+", "d"}], ")"}]}]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"2", ",", 
          RowBox[{"{", "}"}]}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i", ",", "l"}], "}"}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"2", ",", 
          RowBox[{"{", "}"}]}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i", ",", "k"}], "}"}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"2", ",", 
          RowBox[{"{", "}"}]}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"k", ",", "l"}], "}"}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{"\[CapitalUpsilon]", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}]}], "]"}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.737650428631847*^9, 3.737650488167501*^9, 
  3.73765052200397*^9, 3.7376548644255342`*^9, 3.737654932533465*^9, 
  3.7376549813407497`*^9, 3.737655076967619*^9, 3.7377099953240023`*^9},
 ExpressionUUID -> "af5957ec-2315-4324-8719-6e0e18814c03"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fullytracefreeform1", "[", 
  RowBox[{"ex", "[", "17", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.738047340283539*^9, 3.7380473439332647`*^9}},
 ExpressionUUID -> "53034233-af2e-48be-9ad2-1792e3a39af2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"A", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", "j", "}"}]}], "]"}], " ", 
     RowBox[{"A", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "p0"}], "}"}]}], "]"}], " ", 
     RowBox[{"X", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", "p0", "}"}]}], "]"}]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"A", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", "i", "}"}]}], "]"}], " ", 
     RowBox[{"A", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "p0"}], "}"}]}], "]"}], " ", 
     RowBox[{"X", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", "p0", "}"}]}], "]"}]}]}], "\[Rule]", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"2", " ", "d"}]], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{"A", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
       RowBox[{"A", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
       RowBox[{"X", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "p1", "}"}]}], "]"}], " ", 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
      RowBox[{"d", " ", 
       RowBox[{"X", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
       RowBox[{"\[CapitalUpsilon]", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "j", "}"}]}], "]"}], " ", 
       RowBox[{"\[CapitalUpsilon]", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "p0"}], "}"}]}], "]"}]}], "+", 
      RowBox[{"d", " ", 
       RowBox[{"X", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
       RowBox[{"\[CapitalUpsilon]", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "i", "}"}]}], "]"}], " ", 
       RowBox[{"\[CapitalUpsilon]", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "p0"}], "}"}]}], "]"}]}]}], ")"}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.7380473447200727`*^9},
 ExpressionUUID -> "83daf406-7e2b-4f08-b8c5-fd906b8ea296"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{"Clear", "[", "ex", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "0", "]"}], "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "1", "]"}], "=", 
   RowBox[{"k", "[", "2", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "2", "]"}], "=", 
   RowBox[{"A", "[", 
    RowBox[{"{", "i", "}"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "3", "]"}], "=", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["17", "9"]}], 
    RowBox[{"A", "[", 
     RowBox[{"{", "i", "}"}], "]"}], 
    RowBox[{"B", "[", 
     RowBox[{"{", "j", "}"}], "]"}], 
    RowBox[{"X", "[", 
     RowBox[{"{", "k", "}"}], "]"}], 
    RowBox[{"Y", "[", 
     RowBox[{"{", "k", "}"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "4", "]"}], "=", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["7.83", "6"]}], 
    RowBox[{"A", "[", 
     RowBox[{"{", "i", "}"}], "]"}], 
    RowBox[{"B", "[", 
     RowBox[{"{", "j", "}"}], "]"}], 
    RowBox[{"X", "[", 
     RowBox[{"{", "k", "}"}], "]"}], 
    RowBox[{"X", "[", 
     RowBox[{"{", "k", "}"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "5", "]"}], "=", 
   RowBox[{"3.01", " ", 
    RowBox[{"A", "[", 
     RowBox[{"{", 
      RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "6", "]"}], "=", 
   RowBox[{"3", " ", 
    RowBox[{"A", "[", 
     RowBox[{"{", 
      RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}], "]"}], 
    RowBox[{"B", "[", 
     RowBox[{"{", "k", "}"}], "]"}], 
    RowBox[{"Y", "[", 
     RowBox[{"{", "k", "}"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "7", "]"}], "=", 
   RowBox[{"7", 
    RowBox[{"A", "[", 
     RowBox[{"{", "i", "}"}], "]"}], 
    RowBox[{"B", "[", 
     RowBox[{"{", "j", "}"}], "]"}], 
    RowBox[{"X", "[", 
     RowBox[{"{", "k", "}"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "8", "]"}], "=", 
   RowBox[{
    FractionBox["2", "3"], 
    RowBox[{"A", "[", 
     RowBox[{"{", "i", "}"}], "]"}], 
    RowBox[{"B", "[", 
     RowBox[{"{", "j", "}"}], "]"}], 
    SuperscriptBox[
     RowBox[{"X", "[", 
      RowBox[{"{", "k", "}"}], "]"}], "3"]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "9", "]"}], "=", 
   RowBox[{"3", " ", 
    RowBox[{"A", "[", 
     RowBox[{"{", 
      RowBox[{"i", ",", "j"}], "}"}], "]"}], 
    RowBox[{"B", "[", 
     RowBox[{"{", 
      RowBox[{"k", ",", "l"}], "}"}], "]"}], 
    RowBox[{"Y", "[", 
     RowBox[{"{", "k", "}"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "10", "]"}], "=", 
   RowBox[{"4", 
    RowBox[{"j", "[", 
     RowBox[{"2", ",", "1"}], "]"}], 
    RowBox[{"\[Alpha]", "[", "3", "]"}], 
    RowBox[{"A", "[", 
     RowBox[{"{", 
      RowBox[{
      "e", ",", "i", ",", "j", ",", "k", ",", "l", ",", "m", ",", "n", ",", 
       "o", ",", "p"}], "}"}], "]"}], 
    RowBox[{"B", "[", 
     RowBox[{"{", 
      RowBox[{"m", ",", "l"}], "}"}], "]"}], 
    RowBox[{"Y", "[", 
     RowBox[{"{", "o", "}"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "11", "]"}], "=", 
   RowBox[{"9", 
    SuperscriptBox[
     RowBox[{"A", "[", 
      RowBox[{"{", "i", "}"}], "]"}], "2"]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "12", "]"}], "=", 
   RowBox[{"59", 
    RowBox[{"A", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", "i", "}"}]}], "]"}], 
    RowBox[{"B", "[", 
     RowBox[{"1", ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "k"}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "13", "]"}], "=", 
   RowBox[{
    RowBox[{"-", "4"}], 
    SuperscriptBox[
     RowBox[{"A", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", "i", "}"}]}], "]"}], "2"], 
    SuperscriptBox[
     RowBox[{"B", "[", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "k"}], "}"}]}], "]"}], "2"]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "14", "]"}], "=", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["4", "7"]}], 
    SuperscriptBox[
     RowBox[{"A", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", "i", "}"}]}], "]"}], "3"], 
    SuperscriptBox[
     RowBox[{"B", "[", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "k"}], "}"}]}], "]"}], "2"]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "15", "]"}], "=", 
   RowBox[{"A", "[", 
    RowBox[{"1", ",", 
     RowBox[{"{", "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "16", "]"}], "=", 
   RowBox[{"A", "[", 
    RowBox[{"2", ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "k"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "17", "]"}], "=", 
   RowBox[{"23", 
    RowBox[{"A", "[", 
     RowBox[{"{", "i", "}"}], "]"}], 
    RowBox[{"A", "[", 
     RowBox[{"{", 
      RowBox[{"j", ",", "k"}], "}"}], "]"}], 
    RowBox[{"X", "[", 
     RowBox[{"{", "k", "}"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "18", "]"}], "=", 
   RowBox[{
    RowBox[{"V", "[", 
     RowBox[{"{", "i1", "}"}], "]"}], 
    RowBox[{"V", "[", 
     RowBox[{"{", "i2", "}"}], "]"}], 
    RowBox[{"V", "[", 
     RowBox[{"{", "i2", "}"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "19", "]"}], "=", 
   RowBox[{
    RowBox[{"V", "[", 
     RowBox[{"{", "i1", "}"}], "]"}], 
    SuperscriptBox[
     RowBox[{"V", "[", 
      RowBox[{"{", "i2", "}"}], "]"}], "2"], 
    SuperscriptBox[
     RowBox[{"V", "[", 
      RowBox[{"{", "i3", "}"}], "]"}], "2"]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.737892735149995*^9, 3.737892736612054*^9}, 
   3.737893943544862*^9, {3.73789398034558*^9, 3.73789406099951*^9}, {
   3.737895098048336*^9, 3.737895181115974*^9}, {3.737895339521645*^9, 
   3.737895351389059*^9}, {3.737957341130851*^9, 3.737957371834449*^9}, {
   3.737957641165019*^9, 3.7379576791162453`*^9}, {3.737957742492796*^9, 
   3.7379577488450003`*^9}, {3.737960165983613*^9, 3.737960215929529*^9}, {
   3.738042824788301*^9, 3.738042865202031*^9}, {3.7380469392311907`*^9, 
   3.738046976332068*^9}, {3.738341362329399*^9, 3.738341378586492*^9}, {
   3.738364642836412*^9, 3.738364683654894*^9}},
 ExpressionUUID -> "b77e978c-99db-48ab-96ef-97e536ae412a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tensorattributes", "[", 
  RowBox[{"ex", "[", "19", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.738363617683817*^9, 3.738363629501193*^9}, {
   3.738363695564487*^9, 3.7383636971917973`*^9}, 3.738363736331189*^9, {
   3.738363869287471*^9, 3.7383640189524517`*^9}, {3.7383640539857616`*^9, 
   3.738364055040906*^9}, {3.738364091903117*^9, 3.7383640927581043`*^9}, {
   3.738364128443495*^9, 3.738364234389596*^9}, {3.7383643558143253`*^9, 
   3.738364356923821*^9}, {3.738364690471238*^9, 
   3.73836469136629*^9}},ExpressionUUID->"ee00e443-e679-4db7-86e0-\
e31f09835dd7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"constantfactor", "\[Rule]", "1"}], ",", 
   RowBox[{"tensorialpart", "\[Rule]", 
    RowBox[{
     RowBox[{"V", "[", 
      RowBox[{"{", "i1", "}"}], "]"}], " ", 
     SuperscriptBox[
      RowBox[{"V", "[", 
       RowBox[{"{", "i2", "}"}], "]"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"V", "[", 
       RowBox[{"{", "i3", "}"}], "]"}], "2"]}]}], ",", 
   RowBox[{"freeindices", "\[Rule]", 
    RowBox[{"{", "i1", "}"}]}], ",", 
   RowBox[{"tensorialparthavingfreeindices", "\[Rule]", 
    RowBox[{"V", "[", 
     RowBox[{"{", "i1", "}"}], "]"}]}], ",", 
   RowBox[{"tensorialpartNOThavingfreeindices", "\[Rule]", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"V", "[", 
       RowBox[{"{", "i2", "}"}], "]"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"V", "[", 
       RowBox[{"{", "i3", "}"}], "]"}], "2"]}]}], ",", 
   RowBox[{"tensornames$havingfreeindices", "\[Rule]", 
    RowBox[{"{", "V", "}"}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.738363630836712*^9, {3.738363698198892*^9, 3.738363737734933*^9}, {
   3.738363859229958*^9, 3.738364019961218*^9}, 3.738364055848824*^9, 
   3.738364094099522*^9, {3.7383641396537237`*^9, 3.738364235429668*^9}, {
   3.738364338336691*^9, 3.738364358203156*^9}, 
   3.7383646924626017`*^9},ExpressionUUID->"f1115afe-72ce-4b5f-9434-\
2508d89a9693"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tracefreerepresentation", "[", 
  RowBox[{"ex", "[", "18", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.738364623691484*^9, 
  3.738364631169771*^9}},ExpressionUUID->"9f2ecdc4-bba2-4522-9bfd-\
63c1c42cf809"],

Cell[BoxData[
 RowBox[{
  RowBox[{"V", "[", 
   RowBox[{"0", ",", 
    RowBox[{"{", "i1", "}"}]}], "]"}], " ", 
  SuperscriptBox[
   RowBox[{"V", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", "p0", "}"}]}], "]"}], "2"]}]], "Output",
 CellChangeTimes->{3.7383646324374447`*^9, 
  3.738364704016118*^9},ExpressionUUID->"64ff30c0-8114-4e46-873f-\
b3abbc23fbfd"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Apply", "[", 
  RowBox[{"Times", ",", "%"}], "]"}]], "Input",
 CellChangeTimes->{{3.738363742941752*^9, 
  3.738363769725678*^9}},ExpressionUUID->"650cabc5-1c41-4ebc-86a4-\
ee45fa612552"],

Cell[BoxData[
 RowBox[{"A", "[", 
  RowBox[{"{", 
   RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}], "]"}]], "Output",
 CellChangeTimes->{
  3.738363770808679*^9},ExpressionUUID->"20753403-4354-4743-89ad-\
9338aa41c64c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tracefreerepresentation", "[", 
  RowBox[{"ex", "[", "18", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.7380601261185827`*^9, 3.738060134918418*^9}, {
  3.7383635880267677`*^9, 3.738363590303557*^9}},
 ExpressionUUID -> "833e2a56-91bc-4f24-9d75-f44fec6adf1a"],

Cell[BoxData["A"], "Output",
 CellChangeTimes->{3.738060135438054*^9},
 ExpressionUUID -> "01381dd7-6144-4333-9e3a-8f5f595651e7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fullytracefreeform1", "[", 
  RowBox[{
   RowBox[{"A", "[", 
    RowBox[{"{", "i", "}"}], "]"}], 
   RowBox[{"A", "[", 
    RowBox[{"{", "j", "}"}], "]"}], 
   RowBox[{"A", "[", 
    RowBox[{"{", "k", "}"}], "]"}], 
   RowBox[{"A", "[", 
    RowBox[{"{", "l", "}"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.738059722420171*^9, 3.738059756824195*^9}, {
   3.738059964253128*^9, 3.738059972277796*^9}, {3.738060006634677*^9, 
   3.738060019622506*^9}, 3.7380604134066467`*^9, {3.7380604733060007`*^9, 
   3.738060481311386*^9}},
 ExpressionUUID -> "939d8bbc-f101-414f-8137-0cc869806819"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"A", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", "i", "}"}]}], "]"}], " ", 
    RowBox[{"A", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", "j", "}"}]}], "]"}], " ", 
    RowBox[{"A", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", "k", "}"}]}], "]"}], " ", 
    RowBox[{"A", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", "l", "}"}]}], "]"}]}], "\[Rule]", 
   RowBox[{
    RowBox[{
     FractionBox["1", 
      RowBox[{"4", "+", "d"}]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "k", "}"}]}], "]"}], " ", 
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "l", "}"}]}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{"A", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "j", "}"}]}], "]"}], " ", 
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "l", "}"}]}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{"A", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "j", "}"}]}], "]"}], " ", 
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "k", "}"}]}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{"A", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i", ",", "l"}], "}"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "i", "}"}]}], "]"}], " ", 
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "l", "}"}]}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{"A", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "i", "}"}]}], "]"}], " ", 
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "k", "}"}]}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{"A", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "i", "}"}]}], "]"}], " ", 
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "j", "}"}]}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{"A", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"k", ",", "l"}], "}"}], "]"}]}]}], ")"}]}], "-", 
    RowBox[{
     FractionBox["1", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"2", "+", "d"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"4", "+", "d"}], ")"}]}]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"A", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"A", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p1", "}"}]}], "]"}], "2"], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i", ",", "l"}], "}"}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"A", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"A", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p1", "}"}]}], "]"}], "2"], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i", ",", "k"}], "}"}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"A", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"A", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p1", "}"}]}], "]"}], "2"], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"k", ",", "l"}], "}"}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"\[CapitalUpsilon]", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", "i", "}"}]}], "]"}], " ", 
     RowBox[{"\[CapitalUpsilon]", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", "j", "}"}]}], "]"}], " ", 
     RowBox[{"\[CapitalUpsilon]", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", "k", "}"}]}], "]"}], " ", 
     RowBox[{"\[CapitalUpsilon]", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", "l", "}"}]}], "]"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.738060083343783*^9, 3.738060118656414*^9}, 
   3.7380604143338223`*^9, {3.738060474184984*^9, 3.738060481812277*^9}},
 ExpressionUUID -> "e6b63add-14a3-4888-918b-9abe58914f47"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.738059744263851*^9, 3.73805974789246*^9}},
 ExpressionUUID -> "f40a7fef-b983-4684-a4d4-0621b0968258"],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{{3.73805974892824*^9, 3.738059759596121*^9}},
 ExpressionUUID -> "3dbb2981-9882-45cc-a867-cb639b209e9d"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"ii", ",", 
     RowBox[{"fullytracefreeform1", "[", 
      RowBox[{"ex", "[", "ii", "]"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"ii", ",", "0", ",", "17"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7380513032346478`*^9, 3.738051355797001*^9}, {
  3.738051518394212*^9, 3.738051518549962*^9}},
 ExpressionUUID -> "88543a08-733c-40f5-a158-af52173aa17d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"ii", ",", 
      RowBox[{"fullytracefreeform1", "[", 
       RowBox[{"ex", "[", "ii", "]"}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"ii", ",", 
      RowBox[{"{", 
       RowBox[{
       "0", ",", "1", ",", "2", ",", "5", ",", "13", ",", "15", ",", "16"}], 
       "}"}]}], "}"}]}], "]"}], "//", "TableForm"}]], "Input",
 CellChangeTimes->{{3.738051599270122*^9, 3.7380516207244043`*^9}},
 ExpressionUUID -> "c5ba4bb8-e5c0-454e-8385-ba782630d946"],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {"0", 
     RowBox[{"1", "\[Rule]", "1"}]},
    {"1", 
     RowBox[{"1", "\[Rule]", "1"}]},
    {"2", GridBox[{
       {
        RowBox[{
         RowBox[{"A", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "i", "}"}]}], "]"}], "\[Rule]", 
         RowBox[{"\[CapitalUpsilon]", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "i", "}"}]}], "]"}]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}]},
    {"5", GridBox[{
       {
        RowBox[{
         RowBox[{"A", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}]}], "]"}], 
         "\[Rule]", 
         RowBox[{
          FractionBox[
           RowBox[{
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"1", ",", 
               RowBox[{"{", 
                RowBox[{"k", ",", "l"}], "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"1", ",", 
               RowBox[{"{", 
                RowBox[{"j", ",", "l"}], "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"1", ",", 
               RowBox[{"{", 
                RowBox[{"j", ",", "k"}], "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "l"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"1", ",", 
               RowBox[{"{", 
                RowBox[{"i", ",", "l"}], "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"1", ",", 
               RowBox[{"{", 
                RowBox[{"i", ",", "k"}], "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"1", ",", 
               RowBox[{"{", 
                RowBox[{"i", ",", "j"}], "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"k", ",", "l"}], "}"}], "]"}]}]}], 
           RowBox[{"4", "+", "d"}]], "-", 
          FractionBox[
           RowBox[{
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"2", ",", 
               RowBox[{"{", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "l"}], "}"}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"2", ",", 
               RowBox[{"{", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "k"}], "}"}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"2", ",", 
               RowBox[{"{", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"k", ",", "l"}], "}"}], "]"}]}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"2", "+", "d"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"4", "+", "d"}], ")"}]}]], "+", 
          RowBox[{"\[CapitalUpsilon]", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}]}], "]"}]}]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}]},
    {"13", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"B", "[", 
         RowBox[{"1", ",", 
          RowBox[{"{", 
           RowBox[{"p1", ",", "p2"}], "}"}]}], "]"}], "2"]}], "\[Rule]", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"B", "[", 
         RowBox[{"1", ",", 
          RowBox[{"{", 
           RowBox[{"p1", ",", "p2"}], "}"}]}], "]"}], "2"]}]}]},
    {"15", 
     RowBox[{
      RowBox[{"A", "[", 
       RowBox[{"1", ",", 
        RowBox[{"{", "}"}]}], "]"}], "\[Rule]", 
      RowBox[{"A", "[", 
       RowBox[{"1", ",", 
        RowBox[{"{", "}"}]}], "]"}]}]},
    {"16", 
     RowBox[{
      RowBox[{"A", "[", 
       RowBox[{"3", ",", 
        RowBox[{"{", "}"}]}], "]"}], "\[Rule]", 
      RowBox[{"A", "[", 
       RowBox[{"3", ",", 
        RowBox[{"{", "}"}]}], "]"}]}]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  TableForm[{{0, 1 -> 1}, {1, 1 -> 1}, {
    2, {$CellContext`A[0, {$CellContext`i}] -> $CellContext`\[CapitalUpsilon][
       0, {$CellContext`i}]}}, {
    5, {$CellContext`A[
       0, {$CellContext`i, $CellContext`j, $CellContext`k, $CellContext`l}] -> \
(4 + $CellContext`d)^(-1) ($CellContext`A[
           1, {$CellContext`k, $CellContext`l}] \
$CellContext`\[Delta][{$CellContext`i, $CellContext`j}] + $CellContext`A[
           1, {$CellContext`j, $CellContext`l}] \
$CellContext`\[Delta][{$CellContext`i, $CellContext`k}] + $CellContext`A[
           1, {$CellContext`j, $CellContext`k}] \
$CellContext`\[Delta][{$CellContext`i, $CellContext`l}] + $CellContext`A[
           1, {$CellContext`i, $CellContext`l}] \
$CellContext`\[Delta][{$CellContext`j, $CellContext`k}] + $CellContext`A[
           1, {$CellContext`i, $CellContext`k}] \
$CellContext`\[Delta][{$CellContext`j, $CellContext`l}] + $CellContext`A[
           1, {$CellContext`i, $CellContext`j}] \
$CellContext`\[Delta][{$CellContext`k, $CellContext`l}]) - ((
          2 + $CellContext`d)^(-1)/(
        4 + $CellContext`d)) (($CellContext`A[
           2, {}] $CellContext`\[Delta][{$CellContext`i, $CellContext`l}]) \
$CellContext`\[Delta][{$CellContext`j, $CellContext`k}] + ($CellContext`A[
           2, {}] $CellContext`\[Delta][{$CellContext`i, $CellContext`k}]) \
$CellContext`\[Delta][{$CellContext`j, $CellContext`l}] + ($CellContext`A[
           2, {}] $CellContext`\[Delta][{$CellContext`i, $CellContext`j}]) \
$CellContext`\[Delta][{$CellContext`k, $CellContext`l}]) + $CellContext`\
\[CapitalUpsilon][
        0, {$CellContext`i, $CellContext`j, $CellContext`k, \
$CellContext`l}]}}, {
    13, $CellContext`A[0, {$CellContext`p0}]^2 $CellContext`B[
        1, {$CellContext`p1, $CellContext`p2}]^2 -> $CellContext`A[
        0, {$CellContext`p0}]^2 $CellContext`B[
        1, {$CellContext`p1, $CellContext`p2}]^2}, {
    15, $CellContext`A[1, {}] -> $CellContext`A[1, {}]}, {
    16, $CellContext`A[3, {}] -> $CellContext`A[3, {}]}}]]], "Output",
 CellChangeTimes->{
  3.738051356973568*^9, 3.738051519514763*^9, {3.7380516146495647`*^9, 
   3.7380516219196377`*^9}},
 ExpressionUUID -> "95f2e77e-6ad5-425c-8755-b347de98a15b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fullytracefreeform1", "[", 
  RowBox[{"ex", "[", "11", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.738049191211969*^9, 3.738049199816636*^9}, {
   3.738050038277409*^9, 3.738050040733369*^9}, 3.7380507201173553`*^9, {
   3.738051183944065*^9, 3.7380512098487167`*^9}, {3.738051240936123*^9, 
   3.738051283604048*^9}},
 ExpressionUUID -> "a322db7f-82ef-4fcf-8c63-191eb3504b03"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox[
   RowBox[{"A", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", "p0", "}"}]}], "]"}], "2"], "\[Rule]", 
  SuperscriptBox[
   RowBox[{"A", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", "p0", "}"}]}], "]"}], "2"]}]], "Output",
 CellChangeTimes->{
  3.738050562072015*^9, 3.738050619158811*^9, 3.738050654081815*^9, 
   3.738050720760269*^9, 3.738050888605818*^9, 3.738050935036388*^9, 
   3.738050969772283*^9, 3.73805111282749*^9, {3.738051184658196*^9, 
   3.738051210274828*^9}, {3.738051241275971*^9, 3.738051283928834*^9}},
 ExpressionUUID -> "1da0aa00-6d68-41ab-9119-a5310387fb55"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\"\<\!\(\*StyleBox[\"Free\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"indices\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, 0]]\)\>\"", "<>", 
  RowBox[{"ToString", "[", "freeindices", "]"}], "<>", 
  "\"\<\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"in\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"the\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"given\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"expression\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"belong\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\
\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"to\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"more\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"than\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"one\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"tensor\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\
\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"head\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\".\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"This\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"function\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"is\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"not\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"capable\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"of\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"representing\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\"the\
\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, \
0, 0]]\)\!\(\*StyleBox[\"given\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"tensor\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\
\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"in\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"terms\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"of\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"traceless\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"tensors\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"completely\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\";\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"sorry\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\".\",FontColor->RGBColor[1, 0, 0]]\)\>\""}]], "Input",
 CellChangeTimes->{{3.738051039957821*^9, 
  3.738051095173908*^9}},ExpressionUUID->"fb782d0c-6847-408d-b7d9-\
e1859e3be7d2"],

Cell[BoxData[
 RowBox[{"\"\<\!\(\*StyleBox[\"Free\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"indices\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"\\\"\",FontColor->RGBColor[1, 0, 0]]\)", 
  StyleBox["<>",
   FontColor->RGBColor[1, 0, 0]], 
  "\!\(\*StyleBox[\"\\\"\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"in\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"the\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"given\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"expression\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"belong\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\
\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"to\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"more\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"than\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"one\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"tensor\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\
\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"head\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\".\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"This\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"function\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"is\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"not\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"capable\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"of\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"representing\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\"the\
\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, \
0, 0]]\)\!\(\*StyleBox[\"given\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"tensor\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\
\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"in\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"terms\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"of\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"traceless\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"tensors\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"completely\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\";\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"sorry\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\".\",FontColor->RGBColor[1, 0, 0]]\)\>\""}]], "Input",Exp\
ressionUUID->"168340f8-7e32-4321-ad85-956b27a3ad46"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"tensorialparthavingfreeindices", "=", 
  RowBox[{"a", " ", 
   RowBox[{"A", "[", 
    RowBox[{"2", ",", 
     RowBox[{"{", 
      RowBox[{
      "e", ",", "i", ",", "j", ",", "k", ",", "l", ",", "m", ",", "n", ",", 
       "o", ",", "p"}], "}"}]}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"tensorialpartnothavingfreeindices", "=", 
  RowBox[{
   RowBox[{"B", "[", 
    RowBox[{"{", 
     RowBox[{"m", ",", "l"}], "}"}], "]"}], " ", 
   RowBox[{"Y", "[", 
    RowBox[{"{", "o", "}"}], "]"}]}]}]}], "Input",
 CellChangeTimes->{{3.7380493098662243`*^9, 3.738049329451095*^9}, {
  3.738049392175503*^9, 3.738049392891271*^9}, {3.738049445199211*^9, 
  3.7380494453390903`*^9}},
 CellLabel->
  "In[206]:=",ExpressionUUID->"e6e13ca4-5090-4c2c-bb94-38d751dc47d8"],

Cell[BoxData[
 RowBox[{"a", " ", 
  RowBox[{"A", "[", 
   RowBox[{"2", ",", 
    RowBox[{"{", 
     RowBox[{
     "e", ",", "i", ",", "j", ",", "k", ",", "l", ",", "m", ",", "n", ",", 
      "o", ",", "p"}], "}"}]}], "]"}]}]], "Output",
 CellChangeTimes->{{3.73804931065893*^9, 3.738049330248946*^9}, 
   3.7380493934620247`*^9, 3.738049445921198*^9},
 CellLabel->
  "Out[206]=",ExpressionUUID->"3d2ccf0e-f50c-456d-841e-defdd11e668f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"B", "[", 
   RowBox[{"{", 
    RowBox[{"m", ",", "l"}], "}"}], "]"}], " ", 
  RowBox[{"Y", "[", 
   RowBox[{"{", "o", "}"}], "]"}]}]], "Output",
 CellChangeTimes->{{3.73804931065893*^9, 3.738049330248946*^9}, 
   3.7380493934620247`*^9, 3.738049445925296*^9},
 CellLabel->
  "Out[207]=",ExpressionUUID->"259d36ff-150a-49e4-823f-586171bc705d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"indicesintensorialparthavingfreeindices", "=", " ", 
  RowBox[{"Flatten", "[", 
   RowBox[{"Extract", "[", 
    RowBox[{
     RowBox[{"dummy", " ", "tensorialparthavingfreeindices"}], ",", 
     RowBox[{"Drop", "[", 
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"dummy", " ", "tensorialparthavingfreeindices"}], ",", 
         "List"}], "]"}], ",", "None", ",", 
       RowBox[{"-", "1"}]}], "]"}]}], "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"indicesintensorialpartnothavingfreeindices", "=", " ", 
  RowBox[{"Flatten", "[", 
   RowBox[{"Extract", "[", 
    RowBox[{
     RowBox[{"dummy", " ", "tensorialpartnothavingfreeindices"}], ",", 
     RowBox[{"Drop", "[", 
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"dummy", " ", "tensorialpartnothavingfreeindices"}], ",", 
         "List"}], "]"}], ",", "None", ",", 
       RowBox[{"-", "1"}]}], "]"}]}], "]"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.738049333756609*^9, 3.738049342217593*^9}, {
  3.738049421036249*^9, 3.738049473770731*^9}, {3.738049545646494*^9, 
  3.7380495503626013`*^9}, {3.738049786008376*^9, 3.738049792747884*^9}},
 CellLabel->
  "In[213]:=",ExpressionUUID->"705a95c4-7c15-4976-b86b-5345e7c0af11"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "e", ",", "i", ",", "j", ",", "k", ",", "l", ",", "m", ",", "n", ",", "o", 
   ",", "p"}], "}"}]], "Output",
 CellChangeTimes->{3.738049342847529*^9, 3.738049396443438*^9, 
  3.738049474555739*^9, 3.738049550913113*^9, 3.73804979337125*^9},
 CellLabel->
  "Out[213]=",ExpressionUUID->"b2189b96-af19-4b9c-b3ba-8ba1186cf993"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"m", ",", "l", ",", "o"}], "}"}]], "Output",
 CellChangeTimes->{3.738049342847529*^9, 3.738049396443438*^9, 
  3.738049474555739*^9, 3.738049550913113*^9, 3.7380497933777122`*^9},
 CellLabel->
  "Out[214]=",ExpressionUUID->"a7b19003-e0a2-4d5c-9c4a-403c87e554f8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Intersection", "[", 
  RowBox[{
  "indicesintensorialparthavingfreeindices", ",", 
   "indicesintensorialpartnothavingfreeindices"}], "]"}]], "Input",
 CellChangeTimes->{{3.738049801151338*^9, 3.73804981767441*^9}},
 CellLabel->
  "In[215]:=",ExpressionUUID->"ae8a7299-36ed-49bb-a308-7c3a1bfa6a59"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"l", ",", "m", ",", "o"}], "}"}]], "Output",
 CellChangeTimes->{3.73804981932754*^9},
 CellLabel->
  "Out[215]=",ExpressionUUID->"be441aa9-df24-427d-9005-b3c3c70f9d7c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Position", "[", 
  RowBox[{"tensorialpartnothavingfreeindices", ",", "List"}], "]"}]], "Input",\

 CellChangeTimes->{{3.738049360281383*^9, 3.7380493607615147`*^9}},
 CellLabel->
  "In[202]:=",ExpressionUUID->"d722017f-f5c7-45e5-84a1-8df1b6954de8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "1", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7380493617325993`*^9},
 CellLabel->
  "Out[202]=",ExpressionUUID->"686f18c5-9c69-47c8-a828-8bba57aae785"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Flatten", "[", 
  RowBox[{"Extract", "[", 
   RowBox[{"tensorialpartnothavingfreeindices", ",", 
    RowBox[{"Drop", "[", 
     RowBox[{
      RowBox[{"Position", "[", 
       RowBox[{"tensorialpartnothavingfreeindices", ",", "List"}], "]"}], ",",
       "None", ",", 
      RowBox[{"-", "1"}]}], "]"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.7380495206869497`*^9, 3.738049540346693*^9}},
 CellLabel->
  "In[211]:=",ExpressionUUID->"b644e80d-f47f-4dae-b3c4-932275458d6e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"m", ",", "l", ",", "o"}], "}"}]], "Output",
 CellChangeTimes->{{3.738049523748733*^9, 3.738049541461381*^9}},
 CellLabel->
  "Out[211]=",ExpressionUUID->"7aa1d5c5-4826-473e-ac34-d031b22f8443"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fullytracefreeform1", "[", 
  RowBox[{"ex", "[", "17", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.7380424465090237`*^9, 3.738042455021504*^9}, {
   3.73804267009411*^9, 3.738042670639934*^9}, 3.7380436125731077`*^9, {
   3.7380436429565077`*^9, 3.738043658616288*^9}, 3.738043711814975*^9, {
   3.738044260012764*^9, 3.738044262761587*^9}, {3.738044300332955*^9, 
   3.738044301242031*^9}, {3.738044484218624*^9, 3.738044484537747*^9}, {
   3.7380445777105722`*^9, 3.73804460126166*^9}, {3.738047598818274*^9, 
   3.7380475993907537`*^9}},
 CellLabel->
  "In[177]:=",ExpressionUUID->"ecfb6295-33a5-4614-a3a5-1f3b787727cb"],

Cell[BoxData[
 RowBox[{"X", "[", 
  RowBox[{"{", "k", "}"}], "]"}]], "Output",
 CellChangeTimes->{
  3.738042455692326*^9, 3.738042563946035*^9, {3.738042611695735*^9, 
   3.738042639063652*^9}, 3.738042672027342*^9, 3.738042796738896*^9, 
   3.738043310527707*^9, 3.738043364649148*^9, 3.738043443433584*^9, 
   3.7380435574106627`*^9, 3.738043613280287*^9, {3.738043643377689*^9, 
   3.738043659086541*^9}, 3.7380437122028313`*^9, 3.738043744630134*^9, 
   3.738044115328987*^9, 3.738044192043243*^9, {3.738044248432678*^9, 
   3.738044263439434*^9}, {3.738044296125229*^9, 3.738044301962523*^9}, {
   3.738044378578524*^9, 3.738044424787376*^9}, {3.738044484978732*^9, 
   3.7380445349938793`*^9}, {3.7380445745516567`*^9, 3.738044601543827*^9}, 
   3.738047600309927*^9, 3.738047729337459*^9},
 CellLabel->
  "Out[177]=",ExpressionUUID->"f9602dfa-e6c1-45ff-9ad1-95a50eb971a8"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Return", "[", 
  RowBox[{
   RowBox[{"contractedtensor", "[", 
    RowBox[{"sym", "[", "tensorialpart", "]"}], "]"}], "\[Rule]", 
   RowBox[{"contractedtensor", "[", 
    RowBox[{"sym", "[", "tensorialpart", "]"}], "]"}]}], "]"}]], "Input",Expre\
ssionUUID->"d7fd27ba-7699-4743-94ae-100b748aa394"],

Cell[BoxData[
 RowBox[{"Return", "[", 
  RowBox[{"contractedtensor", "[", 
   RowBox[{
    RowBox[{"sym", "[", "tensorialpart", "]"}], "\[Rule]", 
    RowBox[{"contractedtensor", "[", 
     RowBox[{"sym", "[", "tensorialpart", "]"}], "]"}]}], "]"}], 
  "]"}]], "Input",ExpressionUUID->"7b619a46-26f0-420c-915e-0ddf988b0cde"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tensorattributes", "[", 
  RowBox[{"ex", "[", "11", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.738043755176107*^9, 3.738043760893673*^9}},
 CellLabel->"In[63]:=",ExpressionUUID->"04931500-f2f3-42c1-8ea7-587f561d8a7f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"constantfactor", "\[Rule]", "9"}], ",", 
   RowBox[{"tensorialpart", "\[Rule]", 
    SuperscriptBox[
     RowBox[{"A", "[", 
      RowBox[{"{", "i", "}"}], "]"}], "2"]}], ",", 
   RowBox[{"freeindices", "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{"tensorialparthavingfreeindices", "\[Rule]", "1"}], ",", 
   RowBox[{"tensornames$havingfreeindices", "\[Rule]", 
    RowBox[{"{", "}"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.738043761735368*^9},
 CellLabel->"Out[63]=",ExpressionUUID->"56342f2a-4864-401c-b2df-5db48d058543"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"contractedtensor", "[", 
  RowBox[{"sym", "[", 
   RowBox[{"A", "[", 
    RowBox[{"2", ",", 
     RowBox[{"{", 
      RowBox[{"l", ",", "l"}], "}"}]}], "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.7380427011224613`*^9, 3.73804271836806*^9}},
 CellLabel->
  "In[133]:=",ExpressionUUID->"67496acf-01d3-4456-a1c3-11b8c18aa428"],

Cell[BoxData[
 RowBox[{"A", "[", 
  RowBox[{"3", ",", 
   RowBox[{"{", "}"}]}], "]"}]], "Output",
 CellChangeTimes->{{3.7380427118250113`*^9, 3.7380427188620462`*^9}},
 CellLabel->
  "Out[133]=",ExpressionUUID->"f43c9664-a6dc-4914-87fc-f1f293f19778"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"list$alltensors", "=", 
  RowBox[{"fulltracefreeform2", "[", 
   RowBox[{"ex", "[", "5", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.737998011111824*^9, 3.7379980126223383`*^9}, {
   3.737998160162793*^9, 3.737998160809423*^9}, 3.737998253832961*^9, {
   3.7379983531594753`*^9, 3.737998389265581*^9}, 3.738040754192253*^9, {
   3.7380408005504837`*^9, 3.738040830399695*^9}, 3.7380410704491167`*^9, {
   3.738041625509112*^9, 3.7380416258442373`*^9}},
 CellLabel->
  "In[112]:=",ExpressionUUID->"a40dafae-6abb-4f54-a68b-5c07ee64305f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"A", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}]}], "]"}], ",", 
   RowBox[{"A", "[", 
    RowBox[{"1", ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "j"}], "}"}]}], "]"}], ",", 
   RowBox[{"A", "[", 
    RowBox[{"1", ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "k"}], "}"}]}], "]"}], ",", 
   RowBox[{"A", "[", 
    RowBox[{"1", ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "l"}], "}"}]}], "]"}], ",", 
   RowBox[{"A", "[", 
    RowBox[{"1", ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "k"}], "}"}]}], "]"}], ",", 
   RowBox[{"A", "[", 
    RowBox[{"1", ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "l"}], "}"}]}], "]"}], ",", 
   RowBox[{"A", "[", 
    RowBox[{"1", ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "l"}], "}"}]}], "]"}], ",", 
   RowBox[{"A", "[", 
    RowBox[{"2", ",", 
     RowBox[{"{", "}"}]}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7379983154490643`*^9, 3.737998365887315*^9}, 
   3.7379984328573313`*^9, 3.738040728496193*^9, 3.738040764058663*^9, {
   3.738040801246748*^9, 3.73804083100812*^9}, {3.738040861602072*^9, 
   3.738040871416421*^9}, 3.7380409639362392`*^9, {3.738041027894705*^9, 
   3.738041070702961*^9}, 3.738041140019517*^9, 3.738041172741474*^9, 
   3.738041398935005*^9, 3.738041449753469*^9, 3.738041514989451*^9, 
   3.738041554234634*^9, 3.7380416265320683`*^9},
 CellLabel->
  "Out[112]=",ExpressionUUID->"e36d0141-589e-4e6f-afb7-8596c5bcd7ba"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fullytracefreeform1", "[", 
  RowBox[{
  "list$alltensors", "\[LeftDoubleBracket]", "8", "\[RightDoubleBracket]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.7380423599492073`*^9, 3.738042388269105*^9}, 
   3.738059710892058*^9},
 CellLabel->
  "In[122]:=",ExpressionUUID->"cad29b6d-811e-4973-9321-2ff83593d124"],

Cell[BoxData[
 TemplateBox[{
  "Part","partw",
   "\"Part \\!\\(\\*RowBox[{\\\"1\\\"}]\\) of \\!\\(\\*RowBox[{\\\"{\\\", \
\\\"}\\\"}]\\) does not exist.\"",2,122,9,30045083346955987851,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.738042388577736*^9},
 CellLabel->
  "During evaluation of \
In[122]:=",ExpressionUUID->"627605f4-221b-4999-a05d-43c755de7d3f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"A", "[", 
    RowBox[{"2", ",", 
     RowBox[{"{", "}"}]}], "]"}], "\[Rule]", 
   RowBox[{"A", "[", 
    RowBox[{"2", ",", 
     RowBox[{"{", "}"}]}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.73804236077746*^9, 3.7380423885794277`*^9}},
 CellLabel->
  "Out[122]=",ExpressionUUID->"0bb7f061-61bb-40fe-9897-a58de7b6b42c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{
   "list$alltensors", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"ii", ",", "1", ",", 
     RowBox[{"Length", "[", "list$alltensors", "]"}]}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.738042340783166*^9, 3.738042350594819*^9}},
 CellLabel->
  "In[114]:=",ExpressionUUID->"fa5bbde1-d2ba-48b4-85c5-5eeb8acbe7df"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"A", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}]}], "]"}], ",", 
   RowBox[{"A", "[", 
    RowBox[{"1", ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "j"}], "}"}]}], "]"}], ",", 
   RowBox[{"A", "[", 
    RowBox[{"1", ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "k"}], "}"}]}], "]"}], ",", 
   RowBox[{"A", "[", 
    RowBox[{"1", ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "l"}], "}"}]}], "]"}], ",", 
   RowBox[{"A", "[", 
    RowBox[{"1", ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "k"}], "}"}]}], "]"}], ",", 
   RowBox[{"A", "[", 
    RowBox[{"1", ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "l"}], "}"}]}], "]"}], ",", 
   RowBox[{"A", "[", 
    RowBox[{"1", ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "l"}], "}"}]}], "]"}], ",", 
   RowBox[{"A", "[", 
    RowBox[{"2", ",", 
     RowBox[{"{", "}"}]}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.738042352609832*^9},
 CellLabel->
  "Out[114]=",ExpressionUUID->"86c8d60b-dd28-4893-9b75-4b2aa9ef47ce"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ex", "[", "5", "]"}]], "Input",
 CellLabel->
  "In[101]:=",ExpressionUUID->"a559644b-6c4e-4a37-9f73-c50ead469ed3"],

Cell[BoxData[
 RowBox[{"3.01`", " ", 
  RowBox[{"A", "[", 
   RowBox[{"{", 
    RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}], "]"}]}]], "Output",
 CellChangeTimes->{3.7380447564421177`*^9},
 CellLabel->
  "Out[101]=",ExpressionUUID->"e141842f-6e32-4c80-a43c-31591be285d5"]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.7380461069524393`*^9, 
  3.7380461163907347`*^9}},ExpressionUUID->"d7a00e4e-6744-4837-b005-\
62adba09b46d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ex0", "=", 
   RowBox[{
    RowBox[{"A", "[", 
     RowBox[{"{", "k", "}"}], "]"}], 
    RowBox[{"B", "[", 
     RowBox[{"{", "k", "}"}], "]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7380452897480783`*^9, 3.738045306432744*^9}, 
   3.738045455555757*^9},
 CellLabel->
  "In[119]:=",ExpressionUUID->"f93e266b-ebdb-48fd-94eb-bcc6ef3881be"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fullytracefreeform1", "[", "ex0", "]"}]], "Input",
 CellChangeTimes->{{3.738045464193426*^9, 3.7380454770898046`*^9}},
 CellLabel->
  "In[116]:=",ExpressionUUID->"72304c39-a6cb-47ed-afe2-2542e594add3"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"A", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
   RowBox[{"B", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", "p0", "}"}]}], "]"}]}], "\[Rule]", 
  RowBox[{
   RowBox[{"A", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
   RowBox[{"B", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", "p0", "}"}]}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.7380454780518303`*^9},
 CellLabel->
  "Out[116]=",ExpressionUUID->"9982f243-a1c9-43a0-82e8-2118c5e75e40"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tensorattributes", "[", "ex0", "]"}]], "Input",
 CellChangeTimes->{{3.738045309906949*^9, 3.738045319136756*^9}},
 CellLabel->
  "In[120]:=",ExpressionUUID->"6c620592-6ee4-44a4-bfee-da7c6acdf952"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"constantfactor", "\[Rule]", "1"}], ",", 
   RowBox[{"tensorialpart", "\[Rule]", 
    RowBox[{
     RowBox[{"A", "[", 
      RowBox[{"{", "k", "}"}], "]"}], " ", 
     RowBox[{"B", "[", 
      RowBox[{"{", "k", "}"}], "]"}]}]}], ",", 
   RowBox[{"freeindices", "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{"tensorialparthavingfreeindices", "\[Rule]", "1"}], ",", 
   RowBox[{"tensornames$havingfreeindices", "\[Rule]", 
    RowBox[{"{", "}"}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.738045320141831*^9, {3.73804570669531*^9, 3.738045714605076*^9}},
 CellLabel->
  "Out[120]=",ExpressionUUID->"b7d9948e-de23-40d6-a2f8-87e379788d68"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fulltracefreeform2", "[", 
  RowBox[{"ex", "[", "5", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.738044678874415*^9, 3.73804470025668*^9}, 
   3.7380447935483027`*^9, {3.738044966461769*^9, 3.738044969533823*^9}},
 CellLabel->
  "In[112]:=",ExpressionUUID->"4202f3af-42f5-4171-b46e-88bd27d6adc7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"A", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}]}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      FractionBox["1", 
       RowBox[{"4", "+", "d"}]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"A", "[", 
          RowBox[{"1", ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "l"}], "}"}]}], "]"}], " ", 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"A", "[", 
          RowBox[{"1", ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "l"}], "}"}]}], "]"}], " ", 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"A", "[", 
          RowBox[{"1", ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "k"}], "}"}]}], "]"}], " ", 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"i", ",", "l"}], "}"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"A", "[", 
          RowBox[{"1", ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "l"}], "}"}]}], "]"}], " ", 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"A", "[", 
          RowBox[{"1", ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "k"}], "}"}]}], "]"}], " ", 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"A", "[", 
          RowBox[{"1", ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "j"}], "}"}]}], "]"}], " ", 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"k", ",", "l"}], "}"}], "]"}]}]}], ")"}]}], "-", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"2", ",", 
          RowBox[{"{", "}"}]}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i", ",", "l"}], "}"}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"2", ",", 
          RowBox[{"{", "}"}]}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i", ",", "k"}], "}"}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"2", ",", 
          RowBox[{"{", "}"}]}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"k", ",", "l"}], "}"}], "]"}]}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"2", "+", "d"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"4", "+", "d"}], ")"}]}]], "+", 
     RowBox[{"\[CapitalUpsilon]", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}]}], "]"}]}]}], ",", 
   
   RowBox[{
    RowBox[{"A", "[", 
     RowBox[{"1", ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "j"}], "}"}]}], "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"A", "[", 
        RowBox[{"2", ",", 
         RowBox[{"{", "}"}]}], "]"}], " ", 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
      RowBox[{"d", " ", 
       RowBox[{"\[CapitalUpsilon]", "[", 
        RowBox[{"1", ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "j"}], "}"}]}], "]"}]}]}], "d"]}], ",", 
   RowBox[{
    RowBox[{"A", "[", 
     RowBox[{"1", ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "k"}], "}"}]}], "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"A", "[", 
        RowBox[{"2", ",", 
         RowBox[{"{", "}"}]}], "]"}], " ", 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
      RowBox[{"d", " ", 
       RowBox[{"\[CapitalUpsilon]", "[", 
        RowBox[{"1", ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "k"}], "}"}]}], "]"}]}]}], "d"]}], ",", 
   RowBox[{
    RowBox[{"A", "[", 
     RowBox[{"1", ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "l"}], "}"}]}], "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"A", "[", 
        RowBox[{"2", ",", 
         RowBox[{"{", "}"}]}], "]"}], " ", 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"i", ",", "l"}], "}"}], "]"}]}], "+", 
      RowBox[{"d", " ", 
       RowBox[{"\[CapitalUpsilon]", "[", 
        RowBox[{"1", ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "l"}], "}"}]}], "]"}]}]}], "d"]}], ",", 
   RowBox[{
    RowBox[{"A", "[", 
     RowBox[{"1", ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "k"}], "}"}]}], "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"A", "[", 
        RowBox[{"2", ",", 
         RowBox[{"{", "}"}]}], "]"}], " ", 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
      RowBox[{"d", " ", 
       RowBox[{"\[CapitalUpsilon]", "[", 
        RowBox[{"1", ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "k"}], "}"}]}], "]"}]}]}], "d"]}], ",", 
   RowBox[{
    RowBox[{"A", "[", 
     RowBox[{"1", ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "l"}], "}"}]}], "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"A", "[", 
        RowBox[{"2", ",", 
         RowBox[{"{", "}"}]}], "]"}], " ", 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
      RowBox[{"d", " ", 
       RowBox[{"\[CapitalUpsilon]", "[", 
        RowBox[{"1", ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "l"}], "}"}]}], "]"}]}]}], "d"]}], ",", 
   RowBox[{
    RowBox[{"A", "[", 
     RowBox[{"1", ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", "l"}], "}"}]}], "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"A", "[", 
        RowBox[{"2", ",", 
         RowBox[{"{", "}"}]}], "]"}], " ", 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"k", ",", "l"}], "}"}], "]"}]}], "+", 
      RowBox[{"d", " ", 
       RowBox[{"\[CapitalUpsilon]", "[", 
        RowBox[{"1", ",", 
         RowBox[{"{", 
          RowBox[{"k", ",", "l"}], "}"}]}], "]"}]}]}], "d"]}], ",", 
   RowBox[{
    RowBox[{"A", "[", 
     RowBox[{"2", ",", 
      RowBox[{"{", "}"}]}], "]"}], "\[Rule]", 
    RowBox[{"A", "[", 
     RowBox[{"2", ",", 
      RowBox[{"{", "}"}]}], "]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7380446832020397`*^9, 3.7380447007511473`*^9}, 
   3.7380447483117332`*^9, 3.738044794149332*^9, {3.7380449668609333`*^9, 
   3.7380449698423557`*^9}, 3.738045001926749*^9, 3.738045037063747*^9},
 CellLabel->
  "Out[112]=",ExpressionUUID->"5c7dacf3-1d96-4de2-8ab7-d7b7af55b49e"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{"Clear", "[", "fulltracefreeform2", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fulltracefreeform2", "[", "ex_", "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "output", ",", "constantfactor", ",", "tensorialpart", ",", 
      "freeindices", ",", "tensorialparthavingfreeindices", ",", 
      "tensorialpartnothavingfreeindices", ",", "tensornames", ",", 
      "tensornames$havingfreeindices", ",", "tensorname", ",", 
      RowBox[{"list", "=", 
       RowBox[{"{", "}"}]}], ",", "contractionreplacements", ",", 
      "deftracefree", ",", "originaltensor", ",", "tempvar", ",", "dummy", 
      ",", "list$alltensors", ",", "replacementlist"}], "}"}], ",", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"output", "=", 
      RowBox[{"tensorattributes", "[", "ex", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Head", "[", "output", "]"}], "\[Equal]", "String"}], ",", 
       RowBox[{"Return", "[", "output", "]"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"constantfactor", "=", 
      RowBox[{"constantfactor", "/.", "output"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"tensorialpart", "=", 
      RowBox[{"tensorialpart", "/.", "output"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"freeindices", "=", 
      RowBox[{"freeindices", "/.", "output"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"tensorialparthavingfreeindices", "=", 
      RowBox[{"tensorialparthavingfreeindices", "/.", "output"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"tensorialpartnothavingfreeindices", "=", 
      RowBox[{"tensorialpartnothavingfreeindices", "/.", "output"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"tensornames", "=", 
      RowBox[{"DeleteDuplicates", "[", 
       RowBox[{"tensornames$havingfreeindices", "/.", "output"}], "]"}]}], 
     ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Length", "[", "freeindices", "]"}], "<", "2"}], ",", 
       RowBox[{"Return", "[", 
        RowBox[{"constantfactor", " ", 
         RowBox[{"contractedtensor", "[", 
          RowBox[{"sym", "[", "tensorialpart", "]"}], "]"}]}], "]"}]}], "]"}],
      ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Length", "[", "tensornames", "]"}], ">", "1"}], ",", 
       RowBox[{"Return", "[", 
        RowBox[{
        "\"\<\!\(\*StyleBox[\"Free\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"indices\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, 0]]\)\>\"", "<>", 
         RowBox[{"ToString", "[", "freeindices", "]"}], "<>", 
         "\"\<\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"in\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"the\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"given\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"expression\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"belong\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\
\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"to\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"more\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"than\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"one\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"tensor\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\
\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"head\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\".\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"Thus\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\",\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"the\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"given\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"expression\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"is\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"not\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"in\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"symmetric\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"form\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\".\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"Consequently\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\",\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"this\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"function\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"is\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"not\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"capable\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"of\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"representing\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\"the\
\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, \
0, 0]]\)\!\(\*StyleBox[\"given\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"expression\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"in\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"terms\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"of\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"traceless\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"tensors\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"completely\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\";\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"sorry\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\".\",FontColor->RGBColor[1, 0, 0]]\)\>\""}], "]"}]}], 
      "]"}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"indicesintensorialparthavingfreeindices", "=", " ", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Extract", "[", 
        RowBox[{
         RowBox[{"dummy", " ", "tensorialparthavingfreeindices"}], ",", 
         RowBox[{"Drop", "[", 
          RowBox[{
           RowBox[{"Position", "[", 
            RowBox[{
             RowBox[{"dummy", " ", "tensorialparthavingfreeindices"}], ",", 
             "List"}], "]"}], ",", "None", ",", 
           RowBox[{"-", "1"}]}], "]"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"indicesintensorialpartnothavingfreeindices", "=", " ", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Extract", "[", 
        RowBox[{
         RowBox[{"dummy", " ", "tensorialpartnothavingfreeindices"}], ",", 
         RowBox[{"Drop", "[", 
          RowBox[{
           RowBox[{"Position", "[", 
            RowBox[{
             RowBox[{"dummy", " ", "tensorialpartnothavingfreeindices"}], ",",
              "List"}], "]"}], ",", "None", ",", 
           RowBox[{"-", "1"}]}], "]"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Intersection", "[", 
         RowBox[{
         "indicesintensorialparthavingfreeindices", ",", 
          "indicesintensorialpartnothavingfreeindices"}], "]"}], 
        "\[NotEqual]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"Return", "[", 
        RowBox[{
        "\"\<\!\(\*StyleBox[\"The\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"tensorial\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"parts\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"of\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"the\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"given\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"expression\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"having\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\
\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"free\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"indices\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\",\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\"i\",FontColor->RGBColor[1, \
0, 0]]\)\!\(\*StyleBox[\".\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"e\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\".\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, 0]]\)\>\"", "<>", 
         RowBox[{"ToString", "[", 
          StyleBox["tensorialparthavingfreeindices",
           FontColor->RGBColor[1, 0, 0]], "]"}], "<>", 
         "\"\<\!\(\*StyleBox[\",\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\"and\
\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, \
0, 0]]\)\!\(\*StyleBox[\"that\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\"not\
\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, \
0, 0]]\)\!\(\*StyleBox[\"having\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"free\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"indices\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\",\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\"i\",FontColor->RGBColor[1, \
0, 0]]\)\!\(\*StyleBox[\".\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"e\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\".\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, 0]]\)\>\"", "<>", 
         RowBox[{"ToString", "[", "tensorialpartnothavingfreeindices", "]"}], 
         "<>", "\"\<\!\(\*StyleBox[\",\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"have\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"some\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"common\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\
\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"indices\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\".\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"This\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"function\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"is\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"not\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"capable\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"of\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"representing\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\"the\
\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, \
0, 0]]\)\!\(\*StyleBox[\"given\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"tensor\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\
\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"in\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"terms\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"of\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"traceless\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"tensors\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\";\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"sorry\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\".\",FontColor->RGBColor[1, 0, 0]]\)\>\""}], "]"}]}], 
      "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Length", "[", "tensornames", "]"}], "\[Equal]", "0"}], ",", 
         RowBox[{"Return", "[", 
          RowBox[{"contractedtensor", "[", 
           RowBox[{"sym", "[", "ex", "]"}], "]"}], "]"}]}], "]"}], ";"}], 
      "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"tensorname", "=", 
      RowBox[{
      "tensornames", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}],
      ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"tensorialpart", "=", 
      RowBox[{"contractedtensor", "[", "tensorialpart", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"deftracefree", "=", 
      RowBox[{"tracelessPart", "[", "tensorialpart", "]"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      StyleBox[
       RowBox[{
       "To", " ", "extract", " ", "all", " ", "the", " ", "tensors", " ", 
        "from", " ", "deftracefree"}],
       FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
     RowBox[{"tempvar", "=", 
      RowBox[{"DeleteCases", "[", 
       RowBox[{
        RowBox[{"Apply", "[", 
         RowBox[{"List", ",", 
          RowBox[{"Expand", "[", 
           RowBox[{
            RowBox[{"dummy", "+", "deftracefree"}], "/.", 
            RowBox[{
             RowBox[{"\[Delta]", "[", "_", "]"}], "\[Rule]", "1"}]}], "]"}]}],
          "]"}], ",", "dummy"}], "]"}]}], ";", " ", 
     RowBox[{"(*", 
      StyleBox[
       RowBox[{
        RowBox[{
        "dummy", " ", "is", " ", "added", " ", "and", " ", "deleted", " ", 
         "to", " ", "get", " ", "correct", " ", "list", " ", "when", " ", 
         "there", " ", "is", " ", "only", " ", "a", " ", "single", " ", 
         "element", " ", "with", " ", "square"}], ",", " ", 
        RowBox[{"e", ".", "g", ".", " ", 
         SuperscriptBox[
          RowBox[{"A", "[", 
           RowBox[{"{", "p0", "}"}], "]"}], "2"]}]}],
       FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"list$alltensors", "=", 
      RowBox[{"DeleteDuplicates", "[", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"tensorialpart", "/.", 
          RowBox[{"tensorattributes", "[", 
           RowBox[{
           "tempvar", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}],
            "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"ii", ",", "1", ",", 
           RowBox[{"Length", "[", "tempvar", "]"}]}], "}"}]}], "]"}], "]"}]}],
      ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"pos", "=", 
        RowBox[{"Position", "[", 
         RowBox[{"deftracefree", ",", 
          RowBox[{
           RowBox[{"Head", "[", "ex", "]"}], "[", 
           RowBox[{"_", ",", "_"}], "]"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"list$alltensors", "=", 
        RowBox[{"DeleteDuplicates", "[", 
         RowBox[{"Extract", "[", 
          RowBox[{"deftracefree", ",", "pos"}], "]"}], "]"}]}], ";"}], "*)"}],
      "\[IndentingNewLine]", 
     RowBox[{"replacementlist", "=", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"fullytracefreeform1", "[", 
          RowBox[{
          "list$alltensors", "\[LeftDoubleBracket]", "ii", 
           "\[RightDoubleBracket]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"ii", ",", "1", ",", 
           RowBox[{"Length", "[", "list$alltensors", "]"}]}], "}"}]}], "]"}], 
       "]"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"Return", "[", "replacementlist", "]"}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Position", "[", 
         RowBox[{"list$alltensors", ",", "tensorname"}], "]"}], "!=", 
        RowBox[{"{", "}"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"list$alltensors", "=", 
         RowBox[{"list$alltensors", "/.", "replacementlist"}]}], ";"}]}], 
      "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"Return", "[", 
      RowBox[{
      "list$alltensors", "\[LeftDoubleBracket]", "1", 
       "\[RightDoubleBracket]"}], "]"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.737997499572261*^9, 3.7379975763011208`*^9}, {
   3.737997620651123*^9, 3.7379976263945436`*^9}, {3.737997721174739*^9, 
   3.737997734379236*^9}, {3.737997788191543*^9, 3.737997841682022*^9}, {
   3.737997890155767*^9, 3.7379979193054123`*^9}, {3.737997960897305*^9, 
   3.737997982094205*^9}, {3.7379980580694427`*^9, 3.737998082391124*^9}, {
   3.737998172086772*^9, 3.7379981849966288`*^9}, {3.737998225403391*^9, 
   3.73799823372342*^9}, {3.7380408477778587`*^9, 3.738040856288974*^9}, {
   3.738040923221547*^9, 3.7380409587704077`*^9}, {3.738041018824834*^9, 
   3.738041042865993*^9}, {3.738041128387639*^9, 3.7380411680186577`*^9}, 
   3.738041392761586*^9, {3.738041437924844*^9, 3.7380414450453157`*^9}, {
   3.738041499991287*^9, 3.7380415088608427`*^9}, {3.738041541734633*^9, 
   3.738041547977282*^9}, {3.7380416084716377`*^9, 3.738041617702633*^9}, 
   3.738044722788307*^9, {3.738044943054943*^9, 3.738044953202861*^9}, {
   3.738044987424705*^9, 3.738045028128829*^9}, {3.738056261529653*^9, 
   3.738056276199909*^9}, 3.738056334419272*^9, {3.738057119533383*^9, 
   3.738057128357931*^9}, {3.738057174127945*^9, 3.738057223423402*^9}, {
   3.7380572798732367`*^9, 3.7380572802057056`*^9}, {3.7380573309587812`*^9, 
   3.738057338621887*^9}, 3.738057369330119*^9, 3.7380574190606833`*^9, 
   3.7380574879697523`*^9, 3.738057952961323*^9, {3.7380580150781803`*^9, 
   3.738058063607257*^9}, {3.73805811744685*^9, 3.738058126963133*^9}, {
   3.738059189353321*^9, 3.738059265160791*^9}, {3.7380593553400927`*^9, 
   3.738059357457678*^9}, {3.7380594210661783`*^9, 3.738059426384089*^9}, 
   3.738059634722979*^9},ExpressionUUID->"26e85ff9-fc4f-47b1-a02b-\
aaa4f6bf5ba9"],

Cell[BoxData[
 RowBox[{"ex", "=", 
  RowBox[{"A", "[", "]"}]}]], "Input",
 CellChangeTimes->{{3.7380625178784037`*^9, 
  3.7380625221764812`*^9}},ExpressionUUID->"5046a3d9-12a2-4031-af52-\
be8d62c8aa40"],

Cell[BoxData[
 RowBox[{"tracefreeform1", "[", "]"}]], "Input",
 CellChangeTimes->{
  3.7380625157626*^9},ExpressionUUID->"0f7b7e90-2511-47eb-98fd-288a5996bfd4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tensorattributes", "[", 
  RowBox[{"ex", "[", "0", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.737991859138422*^9, 3.737991867904929*^9}, {
  3.737992919649432*^9, 
  3.737992920488654*^9}},ExpressionUUID->"8e3a461d-b85e-435f-9a05-\
2acbb2ca0390"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"constantfactor", "\[Rule]", "1"}], ",", 
   RowBox[{"tensorialpart", "\[Rule]", "1"}], ",", 
   RowBox[{"freeindices", "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{"tensorialparthavingfreeindices", "\[Rule]", "1"}], ",", 
   RowBox[{"tensornames$havingfreeindices", "\[Rule]", 
    RowBox[{"{", "}"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.73799186897639*^9, 3.737991893316012*^9}, 
   3.737992011949416*^9, {3.737992921277096*^9, 
   3.737992927390827*^9}},ExpressionUUID->"32f6575f-c880-4151-8761-\
5bdf9bf94885"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{"Clear", "[", "ex", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"tensorwithoutconstfactor", "[", "ex_", "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"position$tensors", ",", "dummy", ",", "ex1"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"ex1", "=", 
       RowBox[{"dummy", " ", "ex"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"position$tensors", "=", 
       RowBox[{"Partition", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Position", "[", 
           RowBox[{"ex1", ",", "List"}], "]"}], "\[LeftDoubleBracket]", 
          RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", "1"}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Apply", "[", 
       RowBox[{"Times", ",", 
        RowBox[{"Extract", "[", 
         RowBox[{"ex1", ",", "position$tensors"}], "]"}]}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"fulltracefreeform1", "[", "ex_", "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\[CapitalKoppa]", ",", "deftracefree", ",", "pos", ",", 
       "tensorialpart", ",", "constantpart", ",", 
       "list$factorsintensorialpart", ",", "list$nonrepeatedtensors", ",", 
       "headoftensors", ",", "tempname", ",", "\[CapitalUpsilon]", ",", 
       "output", ",", "ex1"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"tensorialpart", "=", 
       RowBox[{"tensorwithoutconstfactor", "[", "ex", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"constantpart", "=", 
       RowBox[{"ex", "/", "tensorialpart"}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"TrueQ", "[", 
         RowBox[{"tensorialpart", "\[Equal]", "1"}], "]"}], ",", 
        RowBox[{"output", "=", "tensorialpart"}], ",", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{"(*", 
         StyleBox[
          RowBox[{"Checking", " ", "for", " ", "repeated", " ", "indices"}],
          FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"list$factorsintensorialpart", "=", 
          RowBox[{"FactorList", "[", "tensorialpart", "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"(*", 
          RowBox[{
           RowBox[{"output", "=", "list$factorsintensorialpart"}], ";"}], 
          "*)"}], "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Max", "[", 
             RowBox[{"list$factorsintensorialpart", "\[LeftDoubleBracket]", 
              RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], "]"}], 
            ">", "2"}], ",", 
           RowBox[{"output", "=", 
            RowBox[{"Print", "[", "\"\<\!\(\*
StyleBox[\"Please\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"check\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"the\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"exponents\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"on\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"tensors\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"or\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"the\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"number\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"of\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"repeated\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"indices\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\".\",
FontColor->RGBColor[1, 0, 0]]\)\>\"", "]"}]}], ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"list$nonrepeatedtensors", "=", 
             RowBox[{"DeleteCases", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"Cases", "[", 
                 RowBox[{"list$factorsintensorialpart", ",", 
                  RowBox[{"{", 
                   RowBox[{"_", ",", "1"}], "}"}]}], "]"}], 
                "\[LeftDoubleBracket]", 
                RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
               "_Integer"}], "]"}]}], ";", "\[IndentingNewLine]", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"list$nonrepeatedtensors", "\[Equal]", 
               RowBox[{"{", "}"}]}], ",", 
              RowBox[{"output", "=", "tensorialpart"}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Length", "[", 
                   RowBox[{"DeleteDuplicates", "[", 
                    RowBox[{"Head", "/@", "list$nonrepeatedtensors"}], "]"}], 
                   "]"}], "!=", "1"}], ",", 
                 RowBox[{"output", "=", 
                  RowBox[{"Print", "[", "\"\<\!\(\*
StyleBox[\"Input\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"tensor\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"contains\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"multiple\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"heads\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\".\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"This\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"function\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"is\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"not\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"capable\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"of\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"producing\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"the\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"traceless\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"tensor\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"in\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"fully\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"traceless\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"form\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\".\",
FontColor->RGBColor[1, 0, 0]]\)\>\"", "]"}]}], ",", "\[IndentingNewLine]", 
                 RowBox[{
                  RowBox[{"headoftensors", "=", 
                   RowBox[{"Head", "[", 
                    RowBox[{
                    "list$nonrepeatedtensors", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], "]"}]}], ";", 
                  "\[IndentingNewLine]", 
                  RowBox[{"ex1", "=", 
                   RowBox[{"contractedtensor", "[", "tensorialpart", "]"}]}], 
                  ";", "\[IndentingNewLine]", 
                  RowBox[{"deftracefree", "=", 
                   RowBox[{"Deftracefreetensor", "[", "ex1", "]"}]}], ";", 
                  "\[IndentingNewLine]", 
                  RowBox[{"output", "=", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"Solve", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"ex1", "/.", 
                    RowBox[{
                    "headoftensors", "\[Rule]", "\[CapitalUpsilon]"}]}], 
                    ")"}], "\[Equal]", 
                    RowBox[{"(", 
                    RowBox[{"deftracefree", "/.", 
                    RowBox[{
                    RowBox[{"sym", "[", "ex1", "]"}], "\[Rule]", 
                    "tempname"}]}], ")"}]}], ",", "tempname"}], "]"}], 
                    "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "/.", 
                    RowBox[{"{", 
                    RowBox[{"tempname", "\[Rule]", 
                    RowBox[{"sym", "[", "ex1", "]"}]}], "}"}]}]}], ";"}]}], 
                "\[IndentingNewLine]", "]"}], ";"}]}], "\[IndentingNewLine]", 
             "]"}], ";"}]}], "\[IndentingNewLine]", "]"}], ";"}]}], 
       "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", "output"}]}],
     "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fulltracefreeform2", "[", "exp_", "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "tensorialpart", ",", "constantpart", ",", "\[CapitalUpsilon]", ",", 
      "deftracefree", ",", "pos", ",", "ex", ",", "list$alltensors", ",", 
      "replacementlist", ",", "temp", ",", "tempvar", ",", "output", ",", 
      "dummy"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"tensorialpart", "=", 
      RowBox[{"tensorwithoutconstfactor", "[", "exp", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"constantpart", "=", 
      RowBox[{"exp", "/", "tensorialpart"}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"ex", "=", 
      RowBox[{"contractedtensor", "[", "tensorialpart", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"deftracefree", "=", 
      RowBox[{"Deftracefreetensor", "[", "ex", "]"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      StyleBox[
       RowBox[{
       "To", " ", "extract", " ", "all", " ", "the", " ", "tensors", " ", 
        "from", " ", "deftracefree"}],
       FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
     RowBox[{"tempvar", "=", 
      RowBox[{"DeleteCases", "[", 
       RowBox[{
        RowBox[{"Apply", "[", 
         RowBox[{"List", ",", 
          RowBox[{"Expand", "[", 
           RowBox[{
            RowBox[{"dummy", "+", "deftracefree"}], "/.", 
            RowBox[{
             RowBox[{"\[Delta]", "[", "_", "]"}], "\[Rule]", "1"}]}], "]"}]}],
          "]"}], ",", "dummy"}], "]"}]}], ";", " ", 
     RowBox[{"(*", 
      StyleBox[
       RowBox[{
        RowBox[{
        "dummy", " ", "is", " ", "added", " ", "and", " ", "deleted", " ", 
         "to", " ", "get", " ", "correct", " ", "list", " ", "when", " ", 
         "there", " ", "is", " ", "only", " ", "a", " ", "single", " ", 
         "element", " ", "with", " ", "square"}], ",", " ", 
        RowBox[{"e", ".", "g", ".", " ", 
         SuperscriptBox[
          RowBox[{"A", "[", 
           RowBox[{"{", "p0", "}"}], "]"}], "2"]}]}],
       FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"list$alltensors", "=", 
      RowBox[{"DeleteDuplicates", "[", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"tensorwithoutconstfactor", "[", 
          RowBox[{
          "tempvar", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}], 
          "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"ii", ",", "1", ",", 
           RowBox[{"Length", "[", "tempvar", "]"}]}], "}"}]}], "]"}], "]"}]}],
      ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"pos", "=", 
        RowBox[{"Position", "[", 
         RowBox[{"deftracefree", ",", 
          RowBox[{
           RowBox[{"Head", "[", "ex", "]"}], "[", 
           RowBox[{"_", ",", "_"}], "]"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"list$alltensors", "=", 
        RowBox[{"DeleteDuplicates", "[", 
         RowBox[{"Extract", "[", 
          RowBox[{"deftracefree", ",", "pos"}], "]"}], "]"}]}], ";"}], "*)"}],
      "\[IndentingNewLine]", 
     RowBox[{"replacementlist", "=", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"fulltracefreeform1", "[", 
          RowBox[{
          "list$alltensors", "\[LeftDoubleBracket]", "ii", 
           "\[RightDoubleBracket]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"ii", ",", "1", ",", 
           RowBox[{"Length", "[", "list$alltensors", "]"}]}], "}"}]}], "]"}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"While", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Position", "[", 
           RowBox[{"list$alltensors", ",", 
            RowBox[{"Head", "[", "ex", "]"}]}], "]"}], "!=", 
          RowBox[{"{", "}"}]}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"list$alltensors", "=", 
           RowBox[{"list$alltensors", "/.", "replacementlist"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"output", "=", 
           RowBox[{
           "list$alltensors", "\[LeftDoubleBracket]", "1", 
            "\[RightDoubleBracket]"}]}], ";"}]}], "\[IndentingNewLine]", 
        "]"}], ";"}], "*)"}], "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"output", "=", "list$alltensors"}], "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"output", "=", "replacementlist"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.7376351301281033`*^9, 3.7376351836768923`*^9}, {
   3.737635223680814*^9, 3.737635250103099*^9}, {3.737635430212997*^9, 
   3.737635436583983*^9}, {3.7376354778368797`*^9, 3.737635534889591*^9}, {
   3.7376356193643417`*^9, 3.737635698696705*^9}, {3.7376357671880217`*^9, 
   3.737635795404121*^9}, {3.73763583969131*^9, 3.737635867484005*^9}, {
   3.73763592484307*^9, 3.737636037394813*^9}, {3.737636121507575*^9, 
   3.737636153377962*^9}, {3.737636242155931*^9, 3.7376362749542418`*^9}, {
   3.737648444275178*^9, 3.737648463562593*^9}, {3.737701981221196*^9, 
   3.737701982305867*^9}, {3.737704822597096*^9, 3.7377048479440193`*^9}, {
   3.737704953259519*^9, 3.7377050803280077`*^9}, {3.7377051278791733`*^9, 
   3.737705128052517*^9}, {3.7377051654547863`*^9, 3.7377052814139423`*^9}, {
   3.737705348553087*^9, 3.737705351222198*^9}, {3.7377054002172813`*^9, 
   3.737705458667964*^9}, {3.7377054915809393`*^9, 3.737705585164003*^9}, {
   3.737705641241748*^9, 3.73770568271202*^9}, {3.737714351324543*^9, 
   3.737714385162253*^9}, {3.737714505892989*^9, 3.7377145338935223`*^9}, {
   3.73771458437081*^9, 3.737714615164199*^9}, 3.737714715678947*^9, {
   3.7377161213684587`*^9, 3.737716158178026*^9}, {3.737716188257229*^9, 
   3.737716215347986*^9}, {3.737716287127186*^9, 3.737716314694858*^9}, 
   3.737716363247963*^9, {3.737717112435108*^9, 3.737717167026362*^9}, {
   3.737717223452857*^9, 3.737717307438117*^9}, {3.737717352575992*^9, 
   3.7377173683039627`*^9}, {3.7377174344810343`*^9, 3.73771750347314*^9}, {
   3.737717539840926*^9, 3.7377175506135063`*^9}, {3.737717595857389*^9, 
   3.737717614934037*^9}, {3.737717651777746*^9, 3.737717797490367*^9}, {
   3.737717979016446*^9, 3.73771798779532*^9}, 3.737718031864847*^9, 
   3.7377181007890778`*^9, {3.737718258789851*^9, 3.737718268154181*^9}, 
   3.73771829909881*^9, {3.737718390774489*^9, 3.737718455211616*^9}, {
   3.737718605962049*^9, 3.737718728969309*^9}, {3.737788467114242*^9, 
   3.7377884851826077`*^9}, {3.737788562525251*^9, 3.737788609949995*^9}, {
   3.737788643222136*^9, 3.7377886691032553`*^9}, {3.73778895958731*^9, 
   3.737789016370451*^9}, {3.73778926119322*^9, 3.737789421503646*^9}, {
   3.737789480225832*^9, 3.737789488778582*^9}, {3.737789942179677*^9, 
   3.737789997698759*^9}, {3.737790044531044*^9, 3.7377900509630003`*^9}, {
   3.737790108424822*^9, 3.737790146848071*^9}, 3.737790372055489*^9, {
   3.7377904142769747`*^9, 3.737790516566619*^9}, 3.7377906162627907`*^9, {
   3.737790683351367*^9, 3.737790684278528*^9}, {3.737801365497851*^9, 
   3.737801372031756*^9}, {3.737801822836331*^9, 3.737801862065168*^9}, {
   3.737802009635522*^9, 3.737802012722731*^9}, {3.737802075378358*^9, 
   3.737802078674938*^9}, {3.737802112690271*^9, 3.737802114369259*^9}, {
   3.7378079333493357`*^9, 3.7378079928293056`*^9}, {3.7378080624207*^9, 
   3.737808072131604*^9}, {3.737808326805347*^9, 3.737808340164381*^9}, {
   3.737808907064259*^9, 3.7378089956716347`*^9}, {3.7378090520282183`*^9, 
   3.737809053145439*^9}, {3.73780909858528*^9, 3.737809110056593*^9}, {
   3.737809149017517*^9, 3.737809177069333*^9}, {3.73780930137261*^9, 
   3.737809308288497*^9}, {3.7378738076477833`*^9, 3.737873829728613*^9}, {
   3.7378739032508373`*^9, 3.737873906209097*^9}},
 ExpressionUUID -> "c608147a-5677-4159-bc58-b09570455de9"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ex", "=", 
   RowBox[{
    FractionBox["1", "6"], 
    RowBox[{"A", "[", 
     RowBox[{"{", "i1", "}"}], "]"}], 
    RowBox[{"A", "[", 
     RowBox[{"{", "i2", "}"}], "]"}], 
    RowBox[{"A", "[", 
     RowBox[{"{", "i3", "}"}], "]"}], 
    RowBox[{"A", "[", 
     RowBox[{"{", "i4", "}"}], "]"}], 
    RowBox[{"A", "[", 
     RowBox[{"{", "p0", "}"}], "]"}], 
    RowBox[{"A", "[", 
     RowBox[{"{", "p0", "}"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"fulltracefreeform1", "[", "ex", "]"}]}], "Input",
 CellChangeTimes->{{3.737710345041642*^9, 3.7377103823864193`*^9}, {
   3.737710571863139*^9, 3.737710578534672*^9}, {3.737710879704207*^9, 
   3.737710880708373*^9}, {3.73771097400839*^9, 3.7377109779568872`*^9}, {
   3.737711324186307*^9, 3.7377113266312637`*^9}, 3.737713067462104*^9, {
   3.737716340281536*^9, 3.737716351900688*^9}, {3.7377173285094223`*^9, 
   3.737717332507275*^9}, 3.737717380640008*^9, {3.737717843489533*^9, 
   3.7377178449581747`*^9}, {3.737717884433646*^9, 3.737717893586959*^9}, 
   3.737717999060746*^9, 3.7377180640997972`*^9, {3.737718751525976*^9, 
   3.7377187517466507`*^9}, {3.7377197627300453`*^9, 3.737719762938322*^9}, {
   3.737719839869837*^9, 3.737719843497075*^9}},
 ExpressionUUID -> "d564e041-eb8e-405b-9cf7-85433d863f40"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"A", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", "i1", "}"}]}], "]"}], " ", 
    RowBox[{"A", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", "i2", "}"}]}], "]"}], " ", 
    RowBox[{"A", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", "i3", "}"}]}], "]"}], " ", 
    RowBox[{"A", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", "i4", "}"}]}], "]"}], " ", 
    SuperscriptBox[
     RowBox[{"A", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", "p0", "}"}]}], "]"}], "2"]}], "\[Rule]", 
   RowBox[{
    RowBox[{
     FractionBox["1", 
      RowBox[{"4", "+", "d"}]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "i3", "}"}]}], "]"}], " ", 
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "i4", "}"}]}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{"A", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"A", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p1", "}"}]}], "]"}], "2"], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i1", ",", "i2"}], "}"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "i2", "}"}]}], "]"}], " ", 
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "i4", "}"}]}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{"A", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"A", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p1", "}"}]}], "]"}], "2"], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i1", ",", "i3"}], "}"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "i2", "}"}]}], "]"}], " ", 
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "i3", "}"}]}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{"A", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"A", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p1", "}"}]}], "]"}], "2"], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i1", ",", "i4"}], "}"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "i1", "}"}]}], "]"}], " ", 
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "i4", "}"}]}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{"A", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"A", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p1", "}"}]}], "]"}], "2"], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i2", ",", "i3"}], "}"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "i1", "}"}]}], "]"}], " ", 
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "i3", "}"}]}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{"A", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"A", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p1", "}"}]}], "]"}], "2"], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i2", ",", "i4"}], "}"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "i1", "}"}]}], "]"}], " ", 
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "i2", "}"}]}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{"A", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"A", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p1", "}"}]}], "]"}], "2"], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i3", ",", "i4"}], "}"}], "]"}]}]}], ")"}]}], "-", 
    RowBox[{
     FractionBox["1", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"2", "+", "d"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"4", "+", "d"}], ")"}]}]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"A", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"A", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p1", "}"}]}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"A", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p2", "}"}]}], "]"}], "2"], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i1", ",", "i4"}], "}"}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i2", ",", "i3"}], "}"}], "]"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"A", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"A", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p1", "}"}]}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"A", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p2", "}"}]}], "]"}], "2"], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i1", ",", "i3"}], "}"}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i2", ",", "i4"}], "}"}], "]"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"A", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"A", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p1", "}"}]}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"A", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "p2", "}"}]}], "]"}], "2"], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i1", ",", "i2"}], "}"}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i3", ",", "i4"}], "}"}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"\[CapitalUpsilon]", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", "i1", "}"}]}], "]"}], " ", 
     RowBox[{"\[CapitalUpsilon]", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", "i2", "}"}]}], "]"}], " ", 
     RowBox[{"\[CapitalUpsilon]", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", "i3", "}"}]}], "]"}], " ", 
     RowBox[{"\[CapitalUpsilon]", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", "i4", "}"}]}], "]"}], " ", 
     SuperscriptBox[
      RowBox[{"\[CapitalUpsilon]", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "p0", "}"}]}], "]"}], "2"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7377197634419737`*^9, 3.7377198459529953`*^9, 
  3.737788381066267*^9},
 ExpressionUUID -> "8aae41f9-ee7f-4f07-891b-41334b43f3db"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"ex3", "=", 
   RowBox[{
    RowBox[{"A", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", "i1", "}"}]}], "]"}], " ", 
    RowBox[{"A", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", "i2", "}"}]}], "]"}], " ", 
    RowBox[{"A", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", "i3", "}"}]}], "]"}], " ", 
    RowBox[{"A", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", "i4", "}"}]}], "]"}], " ", 
    SuperscriptBox[
     RowBox[{"A", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", "k", "}"}]}], "]"}], "2"]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.737719792620124*^9, 
  3.737719807288773*^9}},ExpressionUUID->"eb0751d4-18be-4dce-870b-\
eab0f647798a"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ex1", "=", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1.3", "6"]}], 
    RowBox[{"A", "[", 
     RowBox[{"{", "i1", "}"}], "]"}], 
    RowBox[{"A", "[", 
     RowBox[{"{", "i2", "}"}], "]"}], 
    RowBox[{"A", "[", 
     RowBox[{"{", "i3", "}"}], "]"}], 
    RowBox[{"A", "[", 
     RowBox[{"{", "i4", "}"}], "]"}], 
    RowBox[{"A", "[", 
     RowBox[{"{", "k", "}"}], "]"}], 
    RowBox[{"A", "[", 
     RowBox[{"{", "k", "}"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"tensorwithoutconstfactor", "[", "ex1", "]"}]}], "Input",
 CellChangeTimes->{{3.737711312455102*^9, 3.737711315094975*^9}, {
   3.737711357616651*^9, 3.7377113590479317`*^9}, {3.737711412648621*^9, 
   3.737711416327847*^9}, {3.737711532394864*^9, 3.737711533176672*^9}, {
   3.7377115736112547`*^9, 3.737711582411833*^9}, 3.737711925245928*^9, 
   3.737712795153728*^9},
 ExpressionUUID -> "b95db0ca-b478-4c4a-b569-4d2ecd9a7384"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ex2", "=", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1.3", "6"]}], 
    RowBox[{"A", "[", 
     RowBox[{"{", 
      RowBox[{"i1", ",", "i2", ",", "i3", ",", "i4"}], "}"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"fulltracefreeform2", "[", "ex2", "]"}]}], "Input",ExpressionUUID->\
"921c2b16-8430-426c-86ab-03452251a6b7"],

Cell[BoxData[""], "Input",
 CellChangeTimes->{
  3.737636527021914*^9, 3.737636804323988*^9, {3.7376486472769413`*^9, 
   3.737648647458529*^9}, 3.7377018958101807`*^9, {3.737701957618832*^9, 
   3.737701985849409*^9}, 
   3.737705015958589*^9},ExpressionUUID->"bcf18a84-0644-48c1-94df-\
14091f131250"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ex", "=", 
   RowBox[{"A", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "j", ",", "k", ",", "l", ",", "m", ",", "n"}], 
      "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"fulltracefreeform2", "[", "ex", "]"}]}], "Input",
 CellChangeTimes->{{3.737705107058943*^9, 3.7377051103229723`*^9}, 
   3.737705370299179*^9, {3.7377065045427513`*^9, 3.737706520956099*^9}},
 ExpressionUUID -> "2f35e875-319f-43c4-bbe9-2784d90774c7"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ex", "=", 
   RowBox[{
    RowBox[{"A", "[", 
     RowBox[{"{", "i", "}"}], "]"}], 
    RowBox[{"A", "[", 
     RowBox[{"{", "j", "}"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"fulltracefreeform2", "[", "ex", "]"}]}], "Input",
 CellChangeTimes->{{3.7377066107838907`*^9, 3.737706634751791*^9}},
 ExpressionUUID -> "7d3bc55d-b20a-4536-94d8-fae7d5d0ae3a"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ex", "=", 
   RowBox[{"A", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"fulltracefreeform2", "[", "ex", "]"}]}], "Input",
 CellChangeTimes->{{3.737705107058943*^9, 3.7377051103229723`*^9}, 
   3.737705370299179*^9, {3.7377065045427513`*^9, 3.737706520956099*^9}, {
   3.737706672430091*^9, 3.737706740349347*^9}},
 ExpressionUUID -> "4bf915d3-a7f3-40e3-84a7-833c4b2ad035"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[CapitalUpsilon]", "[", 
   RowBox[{"0", ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}]}], "]"}], "-", 
  FractionBox[
   RowBox[{
    RowBox[{
     RowBox[{"\[Delta]", "[", 
      RowBox[{"{", 
       RowBox[{"i", ",", "l"}], "}"}], "]"}], " ", 
     RowBox[{"\[Delta]", "[", 
      RowBox[{"{", 
       RowBox[{"j", ",", "k"}], "}"}], "]"}], " ", 
     RowBox[{"\[CapitalUpsilon]", "[", 
      RowBox[{"2", ",", 
       RowBox[{"{", "}"}]}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"\[Delta]", "[", 
      RowBox[{"{", 
       RowBox[{"i", ",", "k"}], "}"}], "]"}], " ", 
     RowBox[{"\[Delta]", "[", 
      RowBox[{"{", 
       RowBox[{"j", ",", "l"}], "}"}], "]"}], " ", 
     RowBox[{"\[CapitalUpsilon]", "[", 
      RowBox[{"2", ",", 
       RowBox[{"{", "}"}]}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"\[Delta]", "[", 
      RowBox[{"{", 
       RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
     RowBox[{"\[Delta]", "[", 
      RowBox[{"{", 
       RowBox[{"k", ",", "l"}], "}"}], "]"}], " ", 
     RowBox[{"\[CapitalUpsilon]", "[", 
      RowBox[{"2", ",", 
       RowBox[{"{", "}"}]}], "]"}]}]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"2", "+", "d"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"4", "+", "d"}], ")"}]}]], "+", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"4", "+", "d"}]], 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"k", ",", "l"}], "}"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"d", " ", 
          RowBox[{"\[CapitalUpsilon]", "[", 
           RowBox[{"1", ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "j"}], "}"}]}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
          RowBox[{"\[CapitalUpsilon]", "[", 
           RowBox[{"2", ",", 
            RowBox[{"{", "}"}]}], "]"}]}]}], ")"}]}], "d"], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"j", ",", "l"}], "}"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"d", " ", 
          RowBox[{"\[CapitalUpsilon]", "[", 
           RowBox[{"1", ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "k"}], "}"}]}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i", ",", "k"}], "}"}], "]"}], " ", 
          RowBox[{"\[CapitalUpsilon]", "[", 
           RowBox[{"2", ",", 
            RowBox[{"{", "}"}]}], "]"}]}]}], ")"}]}], "d"], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"j", ",", "k"}], "}"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"d", " ", 
          RowBox[{"\[CapitalUpsilon]", "[", 
           RowBox[{"1", ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "l"}], "}"}]}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i", ",", "l"}], "}"}], "]"}], " ", 
          RowBox[{"\[CapitalUpsilon]", "[", 
           RowBox[{"2", ",", 
            RowBox[{"{", "}"}]}], "]"}]}]}], ")"}]}], "d"], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"i", ",", "l"}], "}"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"d", " ", 
          RowBox[{"\[CapitalUpsilon]", "[", 
           RowBox[{"1", ",", 
            RowBox[{"{", 
             RowBox[{"j", ",", "k"}], "}"}]}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"j", ",", "k"}], "}"}], "]"}], " ", 
          RowBox[{"\[CapitalUpsilon]", "[", 
           RowBox[{"2", ",", 
            RowBox[{"{", "}"}]}], "]"}]}]}], ")"}]}], "d"], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"i", ",", "k"}], "}"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"d", " ", 
          RowBox[{"\[CapitalUpsilon]", "[", 
           RowBox[{"1", ",", 
            RowBox[{"{", 
             RowBox[{"j", ",", "l"}], "}"}]}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"j", ",", "l"}], "}"}], "]"}], " ", 
          RowBox[{"\[CapitalUpsilon]", "[", 
           RowBox[{"2", ",", 
            RowBox[{"{", "}"}]}], "]"}]}]}], ")"}]}], "d"], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"d", " ", 
          RowBox[{"\[CapitalUpsilon]", "[", 
           RowBox[{"1", ",", 
            RowBox[{"{", 
             RowBox[{"k", ",", "l"}], "}"}]}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"k", ",", "l"}], "}"}], "]"}], " ", 
          RowBox[{"\[CapitalUpsilon]", "[", 
           RowBox[{"2", ",", 
            RowBox[{"{", "}"}]}], "]"}]}]}], ")"}]}], "d"]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.737706636031356*^9, {3.7377066732724857`*^9, 3.737706741282683*^9}},
 ExpressionUUID -> "d6744abf-f0f3-4c5d-b696-e63d068f4846"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ex", "=", 
   RowBox[{"A", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"list", "=", 
  RowBox[{"DeleteDuplicates", "[", 
   RowBox[{"fulltracefreeform1", "[", "ex", "]"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.737635301401998*^9, 3.73763534612525*^9}, {
  3.737635425565206*^9, 3.7376354272764807`*^9}, {3.737648570201874*^9, 
  3.7376485717847958`*^9}, {3.737701868242351*^9, 3.737701877039853*^9}, {
  3.737702112885203*^9, 3.737702113793088*^9}, {3.737704536306993*^9, 
  3.73770453660839*^9}},
 ExpressionUUID -> "c309c3bb-6845-4378-80ba-4cc2e6e1594e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"A", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}]}], "]"}], "\[Rule]", 
   
   RowBox[{
    RowBox[{
     FractionBox["1", 
      RowBox[{"4", "+", "d"}]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"1", ",", 
          RowBox[{"{", 
           RowBox[{"k", ",", "l"}], "}"}]}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"1", ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "l"}], "}"}]}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"1", ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "k"}], "}"}]}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i", ",", "l"}], "}"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"1", ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "l"}], "}"}]}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"1", ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "k"}], "}"}]}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"1", ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "j"}], "}"}]}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"k", ",", "l"}], "}"}], "]"}]}]}], ")"}]}], "-", 
    RowBox[{
     FractionBox["1", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"2", "+", "d"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"4", "+", "d"}], ")"}]}]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"2", ",", 
          RowBox[{"{", "}"}]}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i", ",", "l"}], "}"}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"2", ",", 
          RowBox[{"{", "}"}]}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i", ",", "k"}], "}"}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"2", ",", 
          RowBox[{"{", "}"}]}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"k", ",", "l"}], "}"}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{"\[CapitalUpsilon]", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}]}], "]"}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.737648530493862*^9, 3.737700956461165*^9, 3.737701836596919*^9, 
   3.737701877636578*^9, 3.737701996427618*^9, 3.737702114685747*^9, 
   3.737704077861875*^9, 3.737704253480693*^9, 3.737704539530136*^9, 
   3.737704818414753*^9, {3.7377049646492443`*^9, 3.737705000688669*^9}, 
   3.737705174037126*^9, 3.7377053108533583`*^9},
 ExpressionUUID -> "9b73eca2-5e33-44eb-8974-8b60e7dca764"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"replace", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"fulltracefreeform2", "[", 
     RowBox[{"list", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}], 
     "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"ii", ",", "1", ",", 
      RowBox[{"Length", "[", "list", "]"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.737648691677445*^9, 3.7376486919733458`*^9}, {
  3.737701935283826*^9, 3.737701937648623*^9}},
 ExpressionUUID -> "275153b5-8431-4664-aeb5-5b14fc1630e0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"A", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}]}], "]"}], 
     "\[Rule]", 
     RowBox[{
      RowBox[{
       FractionBox["1", 
        RowBox[{"4", "+", "d"}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"1", ",", 
            RowBox[{"{", 
             RowBox[{"k", ",", "l"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"1", ",", 
            RowBox[{"{", 
             RowBox[{"j", ",", "l"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"1", ",", 
            RowBox[{"{", 
             RowBox[{"j", ",", "k"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i", ",", "l"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"1", ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "l"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"1", ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "k"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"1", ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "j"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"k", ",", "l"}], "}"}], "]"}]}]}], ")"}]}], "-", 
      RowBox[{
       FractionBox["1", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"2", "+", "d"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"4", "+", "d"}], ")"}]}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"2", ",", 
            RowBox[{"{", "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i", ",", "l"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"2", ",", 
            RowBox[{"{", "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i", ",", "k"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"2", ",", 
            RowBox[{"{", "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"k", ",", "l"}], "}"}], "]"}]}]}], ")"}]}], "+", 
      RowBox[{"\[CapitalUpsilon]", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}]}], "]"}]}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"A", "[", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "l"}], "}"}]}], "]"}], "\[Rule]", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"2", ",", 
          RowBox[{"{", "}"}]}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"k", ",", "l"}], "}"}], "]"}]}], "+", 
       RowBox[{"d", " ", 
        RowBox[{"\[CapitalUpsilon]", "[", 
         RowBox[{"1", ",", 
          RowBox[{"{", 
           RowBox[{"k", ",", "l"}], "}"}]}], "]"}]}]}], "d"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"A", "[", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "l"}], "}"}]}], "]"}], "\[Rule]", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"2", ",", 
          RowBox[{"{", "}"}]}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
       RowBox[{"d", " ", 
        RowBox[{"\[CapitalUpsilon]", "[", 
         RowBox[{"1", ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "l"}], "}"}]}], "]"}]}]}], "d"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"A", "[", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "k"}], "}"}]}], "]"}], "\[Rule]", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"2", ",", 
          RowBox[{"{", "}"}]}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
       RowBox[{"d", " ", 
        RowBox[{"\[CapitalUpsilon]", "[", 
         RowBox[{"1", ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "k"}], "}"}]}], "]"}]}]}], "d"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"A", "[", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "l"}], "}"}]}], "]"}], "\[Rule]", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"2", ",", 
          RowBox[{"{", "}"}]}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i", ",", "l"}], "}"}], "]"}]}], "+", 
       RowBox[{"d", " ", 
        RowBox[{"\[CapitalUpsilon]", "[", 
         RowBox[{"1", ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "l"}], "}"}]}], "]"}]}]}], "d"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"A", "[", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "k"}], "}"}]}], "]"}], "\[Rule]", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"2", ",", 
          RowBox[{"{", "}"}]}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
       RowBox[{"d", " ", 
        RowBox[{"\[CapitalUpsilon]", "[", 
         RowBox[{"1", ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "k"}], "}"}]}], "]"}]}]}], "d"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"A", "[", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "j"}], "}"}]}], "]"}], "\[Rule]", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"2", ",", 
          RowBox[{"{", "}"}]}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
       RowBox[{"d", " ", 
        RowBox[{"\[CapitalUpsilon]", "[", 
         RowBox[{"1", ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "j"}], "}"}]}], "]"}]}]}], "d"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"A", "[", 
      RowBox[{"2", ",", 
       RowBox[{"{", "}"}]}], "]"}], "\[Rule]", 
     RowBox[{"\[CapitalUpsilon]", "[", 
      RowBox[{"2", ",", 
       RowBox[{"{", "}"}]}], "]"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.737648692453416*^9, {3.7377019192136374`*^9, 3.737701965017158*^9}, 
   3.737701999237967*^9, 3.737702117372778*^9, 3.737703249990734*^9, 
   3.737703399414258*^9, 3.737704081368203*^9, 3.7377042554032*^9, 
   3.7377045447996387`*^9},
 ExpressionUUID -> "2c804168-6bf2-4379-9fa4-0e9daf99c0d7"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"While", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Position", "[", 
     RowBox[{"list", ",", "A"}], "]"}], "!=", 
    RowBox[{"{", "}"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"list", "=", 
    RowBox[{"list", "/.", 
     RowBox[{"Flatten", "[", "replace", "]"}]}]}]}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 CellChangeTimes->{{3.737704187567336*^9, 3.737704242723935*^9}, {
  3.737704305489277*^9, 3.7377043058709183`*^9}},
 ExpressionUUID -> "3446384a-3cc4-4f12-ae3f-a68e8f9ed184"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Expand", "[", 
  RowBox[{"list", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.737704266112918*^9, 3.7377042666863127`*^9}, {
  3.737704386977721*^9, 3.737704404686985*^9}, {3.737704586035596*^9, 
  3.737704587774592*^9}},
 ExpressionUUID -> "37ca7356-e528-43f7-97d6-02a12afa7f27"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[CapitalUpsilon]", "[", 
   RowBox[{"0", ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}]}], "]"}], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"\[Delta]", "[", 
     RowBox[{"{", 
      RowBox[{"k", ",", "l"}], "}"}], "]"}], " ", 
    RowBox[{"\[CapitalUpsilon]", "[", 
     RowBox[{"1", ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "j"}], "}"}]}], "]"}]}], 
   RowBox[{"4", "+", "d"}]], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"\[Delta]", "[", 
     RowBox[{"{", 
      RowBox[{"j", ",", "l"}], "}"}], "]"}], " ", 
    RowBox[{"\[CapitalUpsilon]", "[", 
     RowBox[{"1", ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "k"}], "}"}]}], "]"}]}], 
   RowBox[{"4", "+", "d"}]], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"\[Delta]", "[", 
     RowBox[{"{", 
      RowBox[{"j", ",", "k"}], "}"}], "]"}], " ", 
    RowBox[{"\[CapitalUpsilon]", "[", 
     RowBox[{"1", ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "l"}], "}"}]}], "]"}]}], 
   RowBox[{"4", "+", "d"}]], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"\[Delta]", "[", 
     RowBox[{"{", 
      RowBox[{"i", ",", "l"}], "}"}], "]"}], " ", 
    RowBox[{"\[CapitalUpsilon]", "[", 
     RowBox[{"1", ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "k"}], "}"}]}], "]"}]}], 
   RowBox[{"4", "+", "d"}]], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"\[Delta]", "[", 
     RowBox[{"{", 
      RowBox[{"i", ",", "k"}], "}"}], "]"}], " ", 
    RowBox[{"\[CapitalUpsilon]", "[", 
     RowBox[{"1", ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "l"}], "}"}]}], "]"}]}], 
   RowBox[{"4", "+", "d"}]], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"\[Delta]", "[", 
     RowBox[{"{", 
      RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
    RowBox[{"\[CapitalUpsilon]", "[", 
     RowBox[{"1", ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", "l"}], "}"}]}], "]"}]}], 
   RowBox[{"4", "+", "d"}]], "+", 
  FractionBox[
   RowBox[{"2", " ", 
    RowBox[{"\[Delta]", "[", 
     RowBox[{"{", 
      RowBox[{"i", ",", "l"}], "}"}], "]"}], " ", 
    RowBox[{"\[Delta]", "[", 
     RowBox[{"{", 
      RowBox[{"j", ",", "k"}], "}"}], "]"}], " ", 
    RowBox[{"\[CapitalUpsilon]", "[", 
     RowBox[{"2", ",", 
      RowBox[{"{", "}"}]}], "]"}]}], 
   RowBox[{"d", " ", 
    RowBox[{"(", 
     RowBox[{"4", "+", "d"}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    RowBox[{"\[Delta]", "[", 
     RowBox[{"{", 
      RowBox[{"i", ",", "l"}], "}"}], "]"}], " ", 
    RowBox[{"\[Delta]", "[", 
     RowBox[{"{", 
      RowBox[{"j", ",", "k"}], "}"}], "]"}], " ", 
    RowBox[{"\[CapitalUpsilon]", "[", 
     RowBox[{"2", ",", 
      RowBox[{"{", "}"}]}], "]"}]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"2", "+", "d"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"4", "+", "d"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"2", " ", 
    RowBox[{"\[Delta]", "[", 
     RowBox[{"{", 
      RowBox[{"i", ",", "k"}], "}"}], "]"}], " ", 
    RowBox[{"\[Delta]", "[", 
     RowBox[{"{", 
      RowBox[{"j", ",", "l"}], "}"}], "]"}], " ", 
    RowBox[{"\[CapitalUpsilon]", "[", 
     RowBox[{"2", ",", 
      RowBox[{"{", "}"}]}], "]"}]}], 
   RowBox[{"d", " ", 
    RowBox[{"(", 
     RowBox[{"4", "+", "d"}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    RowBox[{"\[Delta]", "[", 
     RowBox[{"{", 
      RowBox[{"i", ",", "k"}], "}"}], "]"}], " ", 
    RowBox[{"\[Delta]", "[", 
     RowBox[{"{", 
      RowBox[{"j", ",", "l"}], "}"}], "]"}], " ", 
    RowBox[{"\[CapitalUpsilon]", "[", 
     RowBox[{"2", ",", 
      RowBox[{"{", "}"}]}], "]"}]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"2", "+", "d"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"4", "+", "d"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"2", " ", 
    RowBox[{"\[Delta]", "[", 
     RowBox[{"{", 
      RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
    RowBox[{"\[Delta]", "[", 
     RowBox[{"{", 
      RowBox[{"k", ",", "l"}], "}"}], "]"}], " ", 
    RowBox[{"\[CapitalUpsilon]", "[", 
     RowBox[{"2", ",", 
      RowBox[{"{", "}"}]}], "]"}]}], 
   RowBox[{"d", " ", 
    RowBox[{"(", 
     RowBox[{"4", "+", "d"}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    RowBox[{"\[Delta]", "[", 
     RowBox[{"{", 
      RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
    RowBox[{"\[Delta]", "[", 
     RowBox[{"{", 
      RowBox[{"k", ",", "l"}], "}"}], "]"}], " ", 
    RowBox[{"\[CapitalUpsilon]", "[", 
     RowBox[{"2", ",", 
      RowBox[{"{", "}"}]}], "]"}]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"2", "+", "d"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"4", "+", "d"}], ")"}]}]]}]], "Output",
 CellChangeTimes->{
  3.7377042676213913`*^9, 3.7377043112832212`*^9, {3.7377043905313168`*^9, 
   3.7377044053093443`*^9}, {3.7377045626147213`*^9, 3.737704588370751*^9}},
 ExpressionUUID -> "d80c7f62-64f5-482e-9d2e-827d8aed1eee"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"+", 
    FractionBox[
     RowBox[{"2", " ", 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"i", ",", "l"}], "}"}], "]"}], " ", 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"j", ",", "k"}], "}"}], "]"}], " ", 
      RowBox[{"\[CapitalUpsilon]", "[", 
       RowBox[{"2", ",", 
        RowBox[{"{", "}"}]}], "]"}]}], 
     RowBox[{"d", " ", 
      RowBox[{"(", 
       RowBox[{"4", "+", "d"}], ")"}]}]]}], "-", 
   FractionBox[
    RowBox[{
     RowBox[{"\[Delta]", "[", 
      RowBox[{"{", 
       RowBox[{"i", ",", "l"}], "}"}], "]"}], " ", 
     RowBox[{"\[Delta]", "[", 
      RowBox[{"{", 
       RowBox[{"j", ",", "k"}], "}"}], "]"}], " ", 
     RowBox[{"\[CapitalUpsilon]", "[", 
      RowBox[{"2", ",", 
       RowBox[{"{", "}"}]}], "]"}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2", "+", "d"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"4", "+", "d"}], ")"}]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", 
     RowBox[{"\[Delta]", "[", 
      RowBox[{"{", 
       RowBox[{"i", ",", "k"}], "}"}], "]"}], " ", 
     RowBox[{"\[Delta]", "[", 
      RowBox[{"{", 
       RowBox[{"j", ",", "l"}], "}"}], "]"}], " ", 
     RowBox[{"\[CapitalUpsilon]", "[", 
      RowBox[{"2", ",", 
       RowBox[{"{", "}"}]}], "]"}]}], 
    RowBox[{"d", " ", 
     RowBox[{"(", 
      RowBox[{"4", "+", "d"}], ")"}]}]], "-", 
   FractionBox[
    RowBox[{
     RowBox[{"\[Delta]", "[", 
      RowBox[{"{", 
       RowBox[{"i", ",", "k"}], "}"}], "]"}], " ", 
     RowBox[{"\[Delta]", "[", 
      RowBox[{"{", 
       RowBox[{"j", ",", "l"}], "}"}], "]"}], " ", 
     RowBox[{"\[CapitalUpsilon]", "[", 
      RowBox[{"2", ",", 
       RowBox[{"{", "}"}]}], "]"}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2", "+", "d"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"4", "+", "d"}], ")"}]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", 
     RowBox[{"\[Delta]", "[", 
      RowBox[{"{", 
       RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
     RowBox[{"\[Delta]", "[", 
      RowBox[{"{", 
       RowBox[{"k", ",", "l"}], "}"}], "]"}], " ", 
     RowBox[{"\[CapitalUpsilon]", "[", 
      RowBox[{"2", ",", 
       RowBox[{"{", "}"}]}], "]"}]}], 
    RowBox[{"d", " ", 
     RowBox[{"(", 
      RowBox[{"4", "+", "d"}], ")"}]}]], "-", 
   FractionBox[
    RowBox[{
     RowBox[{"\[Delta]", "[", 
      RowBox[{"{", 
       RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
     RowBox[{"\[Delta]", "[", 
      RowBox[{"{", 
       RowBox[{"k", ",", "l"}], "}"}], "]"}], " ", 
     RowBox[{"\[CapitalUpsilon]", "[", 
      RowBox[{"2", ",", 
       RowBox[{"{", "}"}]}], "]"}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2", "+", "d"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"4", "+", "d"}], ")"}]}]]}], "]"}]], "Input",
 CellChangeTimes->{{3.737704651252367*^9, 3.737704654186243*^9}},
 ExpressionUUID -> "ec5b2d8e-cb7a-496c-8c83-d677de3e0409"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"i", ",", "l"}], "}"}], "]"}], " ", 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"i", ",", "k"}], "}"}], "]"}], " ", 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"k", ",", "l"}], "}"}], "]"}]}]}], ")"}], " ", 
   RowBox[{"\[CapitalUpsilon]", "[", 
    RowBox[{"2", ",", 
     RowBox[{"{", "}"}]}], "]"}]}], 
  RowBox[{"d", " ", 
   RowBox[{"(", 
    RowBox[{"2", "+", "d"}], ")"}]}]]], "Output",
 CellChangeTimes->{3.737704654605022*^9},
 ExpressionUUID -> "f78e35be-20ad-48b8-a8b1-5d15aa0c56f3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"list", "=", 
  RowBox[{"list", "/.", 
   RowBox[{"Flatten", "[", "replace", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.7377038991029882`*^9, 3.737703924459619*^9}, {
  3.7377039800631533`*^9, 3.737703981373259*^9}, {3.737704033885766*^9, 
  3.737704035885021*^9}},
 ExpressionUUID -> "4f3a606b-d815-4cd7-92ea-e5faba2e05bc"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"\[CapitalUpsilon]", "[", 
     RowBox[{"2", ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}]}], "]"}], "-", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"i", ",", "l"}], "}"}], "]"}], " ", 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"j", ",", "k"}], "}"}], "]"}], " ", 
       RowBox[{"\[CapitalUpsilon]", "[", 
        RowBox[{"4", ",", 
         RowBox[{"{", "}"}]}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"i", ",", "k"}], "}"}], "]"}], " ", 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"j", ",", "l"}], "}"}], "]"}], " ", 
       RowBox[{"\[CapitalUpsilon]", "[", 
        RowBox[{"4", ",", 
         RowBox[{"{", "}"}]}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"k", ",", "l"}], "}"}], "]"}], " ", 
       RowBox[{"\[CapitalUpsilon]", "[", 
        RowBox[{"4", ",", 
         RowBox[{"{", "}"}]}], "]"}]}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2", "+", "d"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"4", "+", "d"}], ")"}]}]], "+", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"4", "+", "d"}]], 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"k", ",", "l"}], "}"}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"d", " ", 
            RowBox[{"\[CapitalUpsilon]", "[", 
             RowBox[{"3", ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "j"}], "}"}]}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
            RowBox[{"\[CapitalUpsilon]", "[", 
             RowBox[{"4", ",", 
              RowBox[{"{", "}"}]}], "]"}]}]}], ")"}]}], "d"], "+", 
       FractionBox[
        RowBox[{
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"j", ",", "l"}], "}"}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"d", " ", 
            RowBox[{"\[CapitalUpsilon]", "[", 
             RowBox[{"3", ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "k"}], "}"}]}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "k"}], "}"}], "]"}], " ", 
            RowBox[{"\[CapitalUpsilon]", "[", 
             RowBox[{"4", ",", 
              RowBox[{"{", "}"}]}], "]"}]}]}], ")"}]}], "d"], "+", 
       FractionBox[
        RowBox[{
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"j", ",", "k"}], "}"}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"d", " ", 
            RowBox[{"\[CapitalUpsilon]", "[", 
             RowBox[{"3", ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "l"}], "}"}]}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "l"}], "}"}], "]"}], " ", 
            RowBox[{"\[CapitalUpsilon]", "[", 
             RowBox[{"4", ",", 
              RowBox[{"{", "}"}]}], "]"}]}]}], ")"}]}], "d"], "+", 
       FractionBox[
        RowBox[{
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"i", ",", "l"}], "}"}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"d", " ", 
            RowBox[{"\[CapitalUpsilon]", "[", 
             RowBox[{"3", ",", 
              RowBox[{"{", 
               RowBox[{"j", ",", "k"}], "}"}]}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"j", ",", "k"}], "}"}], "]"}], " ", 
            RowBox[{"\[CapitalUpsilon]", "[", 
             RowBox[{"4", ",", 
              RowBox[{"{", "}"}]}], "]"}]}]}], ")"}]}], "d"], "+", 
       FractionBox[
        RowBox[{
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"i", ",", "k"}], "}"}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"d", " ", 
            RowBox[{"\[CapitalUpsilon]", "[", 
             RowBox[{"3", ",", 
              RowBox[{"{", 
               RowBox[{"j", ",", "l"}], "}"}]}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"j", ",", "l"}], "}"}], "]"}], " ", 
            RowBox[{"\[CapitalUpsilon]", "[", 
             RowBox[{"4", ",", 
              RowBox[{"{", "}"}]}], "]"}]}]}], ")"}]}], "d"], "+", 
       FractionBox[
        RowBox[{
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"d", " ", 
            RowBox[{"\[CapitalUpsilon]", "[", 
             RowBox[{"3", ",", 
              RowBox[{"{", 
               RowBox[{"k", ",", "l"}], "}"}]}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"k", ",", "l"}], "}"}], "]"}], " ", 
            RowBox[{"\[CapitalUpsilon]", "[", 
             RowBox[{"4", ",", 
              RowBox[{"{", "}"}]}], "]"}]}]}], ")"}]}], "d"]}], ")"}]}]}], 
   ",", 
   FractionBox[
    RowBox[{
     RowBox[{"d", " ", 
      RowBox[{"\[CapitalUpsilon]", "[", 
       RowBox[{"3", ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "l"}], "}"}]}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"k", ",", "l"}], "}"}], "]"}], " ", 
      RowBox[{"\[CapitalUpsilon]", "[", 
       RowBox[{"4", ",", 
        RowBox[{"{", "}"}]}], "]"}]}]}], "d"], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"d", " ", 
      RowBox[{"\[CapitalUpsilon]", "[", 
       RowBox[{"3", ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "l"}], "}"}]}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"j", ",", "l"}], "}"}], "]"}], " ", 
      RowBox[{"\[CapitalUpsilon]", "[", 
       RowBox[{"4", ",", 
        RowBox[{"{", "}"}]}], "]"}]}]}], "d"], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"d", " ", 
      RowBox[{"\[CapitalUpsilon]", "[", 
       RowBox[{"3", ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "k"}], "}"}]}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"j", ",", "k"}], "}"}], "]"}], " ", 
      RowBox[{"\[CapitalUpsilon]", "[", 
       RowBox[{"4", ",", 
        RowBox[{"{", "}"}]}], "]"}]}]}], "d"], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"d", " ", 
      RowBox[{"\[CapitalUpsilon]", "[", 
       RowBox[{"3", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "l"}], "}"}]}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"i", ",", "l"}], "}"}], "]"}], " ", 
      RowBox[{"\[CapitalUpsilon]", "[", 
       RowBox[{"4", ",", 
        RowBox[{"{", "}"}]}], "]"}]}]}], "d"], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"d", " ", 
      RowBox[{"\[CapitalUpsilon]", "[", 
       RowBox[{"3", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "k"}], "}"}]}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"i", ",", "k"}], "}"}], "]"}], " ", 
      RowBox[{"\[CapitalUpsilon]", "[", 
       RowBox[{"4", ",", 
        RowBox[{"{", "}"}]}], "]"}]}]}], "d"], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"d", " ", 
      RowBox[{"\[CapitalUpsilon]", "[", 
       RowBox[{"3", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "j"}], "}"}]}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
      RowBox[{"\[CapitalUpsilon]", "[", 
       RowBox[{"4", ",", 
        RowBox[{"{", "}"}]}], "]"}]}]}], "d"], ",", 
   RowBox[{"\[CapitalUpsilon]", "[", 
    RowBox[{"4", ",", 
     RowBox[{"{", "}"}]}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.73770390310942*^9, 3.737703924961629*^9}, {
  3.737704046336134*^9, 3.737704064309177*^9}},
 ExpressionUUID -> "ee0562a3-db22-4420-936f-0ee080f5b89a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "replace", "]"}]], "Input",
 ExpressionUUID -> "3da1b8c8-3a54-4ab2-8e7a-1f68d3b564b8"],

Cell[BoxData["8"], "Output",
 CellChangeTimes->{3.7377031881898603`*^9},
 ExpressionUUID -> "316b7d2c-1494-451d-b8f8-299e0acd5bcf"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Join", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Drop", "[", 
     RowBox[{"replace", ",", 
      RowBox[{"-", "1"}]}], "]"}], "/.", 
    RowBox[{
    "replace", "\[LeftDoubleBracket]", "8", "\[RightDoubleBracket]"}]}], ",", 
   
   RowBox[{
   "replace", "\[LeftDoubleBracket]", "8", "\[RightDoubleBracket]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.7377034184734097`*^9, 3.7377034211133347`*^9}},
 ExpressionUUID -> "97f0acd8-ac69-44ba-a46a-2ed95c92ecf3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"A", "[", 
      RowBox[{"2", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}]}], "]"}], 
     "\[Rule]", 
     RowBox[{
      RowBox[{
       FractionBox["1", 
        RowBox[{"4", "+", "d"}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"3", ",", 
            RowBox[{"{", 
             RowBox[{"k", ",", "l"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"3", ",", 
            RowBox[{"{", 
             RowBox[{"j", ",", "l"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"3", ",", 
            RowBox[{"{", 
             RowBox[{"j", ",", "k"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i", ",", "l"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"3", ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "l"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"3", ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "k"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"3", ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "j"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"k", ",", "l"}], "}"}], "]"}]}]}], ")"}]}], "+", 
      RowBox[{"\[CapitalUpsilon]", "[", 
       RowBox[{"2", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}]}], "]"}], "-", 
      RowBox[{
       FractionBox["1", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"2", "+", "d"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"4", "+", "d"}], ")"}]}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i", ",", "l"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"j", ",", "k"}], "}"}], "]"}], " ", 
          RowBox[{"\[CapitalUpsilon]", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", "}"}]}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i", ",", "k"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"j", ",", "l"}], "}"}], "]"}], " ", 
          RowBox[{"\[CapitalUpsilon]", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", "}"}]}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"k", ",", "l"}], "}"}], "]"}], " ", 
          RowBox[{"\[CapitalUpsilon]", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", "}"}]}], "]"}]}]}], ")"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"A", "[", 
      RowBox[{"3", ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "l"}], "}"}]}], "]"}], "\[Rule]", 
     FractionBox[
      RowBox[{
       RowBox[{"d", " ", 
        RowBox[{"\[CapitalUpsilon]", "[", 
         RowBox[{"3", ",", 
          RowBox[{"{", 
           RowBox[{"k", ",", "l"}], "}"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"k", ",", "l"}], "}"}], "]"}], " ", 
        RowBox[{"\[CapitalUpsilon]", "[", 
         RowBox[{"4", ",", 
          RowBox[{"{", "}"}]}], "]"}]}]}], "d"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"A", "[", 
      RowBox[{"3", ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "l"}], "}"}]}], "]"}], "\[Rule]", 
     FractionBox[
      RowBox[{
       RowBox[{"d", " ", 
        RowBox[{"\[CapitalUpsilon]", "[", 
         RowBox[{"3", ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "l"}], "}"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"j", ",", "l"}], "}"}], "]"}], " ", 
        RowBox[{"\[CapitalUpsilon]", "[", 
         RowBox[{"4", ",", 
          RowBox[{"{", "}"}]}], "]"}]}]}], "d"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"A", "[", 
      RowBox[{"3", ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "k"}], "}"}]}], "]"}], "\[Rule]", 
     FractionBox[
      RowBox[{
       RowBox[{"d", " ", 
        RowBox[{"\[CapitalUpsilon]", "[", 
         RowBox[{"3", ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "k"}], "}"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"j", ",", "k"}], "}"}], "]"}], " ", 
        RowBox[{"\[CapitalUpsilon]", "[", 
         RowBox[{"4", ",", 
          RowBox[{"{", "}"}]}], "]"}]}]}], "d"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"A", "[", 
      RowBox[{"3", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "l"}], "}"}]}], "]"}], "\[Rule]", 
     FractionBox[
      RowBox[{
       RowBox[{"d", " ", 
        RowBox[{"\[CapitalUpsilon]", "[", 
         RowBox[{"3", ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "l"}], "}"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i", ",", "l"}], "}"}], "]"}], " ", 
        RowBox[{"\[CapitalUpsilon]", "[", 
         RowBox[{"4", ",", 
          RowBox[{"{", "}"}]}], "]"}]}]}], "d"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"A", "[", 
      RowBox[{"3", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "k"}], "}"}]}], "]"}], "\[Rule]", 
     FractionBox[
      RowBox[{
       RowBox[{"d", " ", 
        RowBox[{"\[CapitalUpsilon]", "[", 
         RowBox[{"3", ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "k"}], "}"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i", ",", "k"}], "}"}], "]"}], " ", 
        RowBox[{"\[CapitalUpsilon]", "[", 
         RowBox[{"4", ",", 
          RowBox[{"{", "}"}]}], "]"}]}]}], "d"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"A", "[", 
      RowBox[{"3", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "j"}], "}"}]}], "]"}], "\[Rule]", 
     FractionBox[
      RowBox[{
       RowBox[{"d", " ", 
        RowBox[{"\[CapitalUpsilon]", "[", 
         RowBox[{"3", ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "j"}], "}"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
        RowBox[{"\[CapitalUpsilon]", "[", 
         RowBox[{"4", ",", 
          RowBox[{"{", "}"}]}], "]"}]}]}], "d"]}], "}"}], ",", 
   RowBox[{
    RowBox[{"A", "[", 
     RowBox[{"4", ",", 
      RowBox[{"{", "}"}]}], "]"}], "\[Rule]", 
    RowBox[{"\[CapitalUpsilon]", "[", 
     RowBox[{"4", ",", 
      RowBox[{"{", "}"}]}], "]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7377034221307373`*^9},
 ExpressionUUID -> "2f007c56-d69a-4fc4-afc9-211c29005465"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"lis", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x", "\[Rule]", "a"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", "\[Rule]", "b"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", "\[Rule]", "c"}], "}"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.737703781165859*^9, 3.737703813980069*^9}},
 ExpressionUUID -> "7fbaa3d8-832a-414c-96f7-cc2de1d44836"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"x", "\[Rule]", "a"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", "\[Rule]", "b"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "c"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7377038146681232`*^9},
 ExpressionUUID -> "c586c48d-3f57-4a38-8481-3b551fd0d007"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"lis", "\[LeftDoubleBracket]", 
  RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}]], "Input",
 CellChangeTimes->{{3.737703818141741*^9, 3.737703835888219*^9}},
 ExpressionUUID -> "fb8b4996-bef1-44ea-baf3-02e20e39081b"],

Cell[BoxData[
 TemplateBox[{
  "Part","partw",
   "\"Part \\!\\(\\*RowBox[{\\\"2\\\"}]\\) of \\!\\(\\*RowBox[{\\\"{\\\", \
RowBox[{\\\"x\\\", \\\"\[Rule]\\\", \\\"a\\\"}], \\\"}\\\"}]\\) does not \
exist.\"",2,88,8,30042855680959468762,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.737703836366543*^9},ExpressionUUID->"3ceaf14c-5938-4027-8096-\
f76396e2cf06"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x", "\[Rule]", "a"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", "\[Rule]", "b"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", "\[Rule]", "c"}], "}"}]}], "}"}], "\[LeftDoubleBracket]", 
  RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}]], "Output",
 CellChangeTimes->{{3.737703826543557*^9, 3.737703836368291*^9}},
 ExpressionUUID -> "86a8decf-a1ce-470c-892e-f4274cb46f2b"]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.737703286778945*^9, 3.737703297912506*^9}, 
   3.737703394808992*^9},ExpressionUUID->"d2f862d9-795e-4931-b044-\
31352b5b4935"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"replace1", "=", 
  RowBox[{"replace", "/.", 
   RowBox[{
   "replace", "\[LeftDoubleBracket]", "8", 
    "\[RightDoubleBracket]"}]}]}]], "Input",
 CellChangeTimes->{3.7377032011120377`*^9},
 ExpressionUUID -> "8c1d760b-6896-4c18-a5ec-5291bb139566"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"A", "[", 
      RowBox[{"2", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}]}], "]"}], 
     "\[Rule]", 
     RowBox[{
      RowBox[{
       FractionBox["1", 
        RowBox[{"4", "+", "d"}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"3", ",", 
            RowBox[{"{", 
             RowBox[{"k", ",", "l"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"3", ",", 
            RowBox[{"{", 
             RowBox[{"j", ",", "l"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"3", ",", 
            RowBox[{"{", 
             RowBox[{"j", ",", "k"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i", ",", "l"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"3", ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "l"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"3", ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "k"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"3", ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "j"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"k", ",", "l"}], "}"}], "]"}]}]}], ")"}]}], "+", 
      RowBox[{"\[CapitalUpsilon]", "[", 
       RowBox[{"2", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}]}], "]"}], "-", 
      RowBox[{
       FractionBox["1", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"2", "+", "d"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"4", "+", "d"}], ")"}]}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i", ",", "l"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"j", ",", "k"}], "}"}], "]"}], " ", 
          RowBox[{"\[CapitalUpsilon]", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", "}"}]}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i", ",", "k"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"j", ",", "l"}], "}"}], "]"}], " ", 
          RowBox[{"\[CapitalUpsilon]", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", "}"}]}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"k", ",", "l"}], "}"}], "]"}], " ", 
          RowBox[{"\[CapitalUpsilon]", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", "}"}]}], "]"}]}]}], ")"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"A", "[", 
      RowBox[{"3", ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "l"}], "}"}]}], "]"}], "\[Rule]", 
     FractionBox[
      RowBox[{
       RowBox[{"d", " ", 
        RowBox[{"\[CapitalUpsilon]", "[", 
         RowBox[{"3", ",", 
          RowBox[{"{", 
           RowBox[{"k", ",", "l"}], "}"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"k", ",", "l"}], "}"}], "]"}], " ", 
        RowBox[{"\[CapitalUpsilon]", "[", 
         RowBox[{"4", ",", 
          RowBox[{"{", "}"}]}], "]"}]}]}], "d"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"A", "[", 
      RowBox[{"3", ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "l"}], "}"}]}], "]"}], "\[Rule]", 
     FractionBox[
      RowBox[{
       RowBox[{"d", " ", 
        RowBox[{"\[CapitalUpsilon]", "[", 
         RowBox[{"3", ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "l"}], "}"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"j", ",", "l"}], "}"}], "]"}], " ", 
        RowBox[{"\[CapitalUpsilon]", "[", 
         RowBox[{"4", ",", 
          RowBox[{"{", "}"}]}], "]"}]}]}], "d"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"A", "[", 
      RowBox[{"3", ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "k"}], "}"}]}], "]"}], "\[Rule]", 
     FractionBox[
      RowBox[{
       RowBox[{"d", " ", 
        RowBox[{"\[CapitalUpsilon]", "[", 
         RowBox[{"3", ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "k"}], "}"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"j", ",", "k"}], "}"}], "]"}], " ", 
        RowBox[{"\[CapitalUpsilon]", "[", 
         RowBox[{"4", ",", 
          RowBox[{"{", "}"}]}], "]"}]}]}], "d"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"A", "[", 
      RowBox[{"3", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "l"}], "}"}]}], "]"}], "\[Rule]", 
     FractionBox[
      RowBox[{
       RowBox[{"d", " ", 
        RowBox[{"\[CapitalUpsilon]", "[", 
         RowBox[{"3", ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "l"}], "}"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i", ",", "l"}], "}"}], "]"}], " ", 
        RowBox[{"\[CapitalUpsilon]", "[", 
         RowBox[{"4", ",", 
          RowBox[{"{", "}"}]}], "]"}]}]}], "d"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"A", "[", 
      RowBox[{"3", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "k"}], "}"}]}], "]"}], "\[Rule]", 
     FractionBox[
      RowBox[{
       RowBox[{"d", " ", 
        RowBox[{"\[CapitalUpsilon]", "[", 
         RowBox[{"3", ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "k"}], "}"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i", ",", "k"}], "}"}], "]"}], " ", 
        RowBox[{"\[CapitalUpsilon]", "[", 
         RowBox[{"4", ",", 
          RowBox[{"{", "}"}]}], "]"}]}]}], "d"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"A", "[", 
      RowBox[{"3", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "j"}], "}"}]}], "]"}], "\[Rule]", 
     FractionBox[
      RowBox[{
       RowBox[{"d", " ", 
        RowBox[{"\[CapitalUpsilon]", "[", 
         RowBox[{"3", ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "j"}], "}"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
        RowBox[{"\[CapitalUpsilon]", "[", 
         RowBox[{"4", ",", 
          RowBox[{"{", "}"}]}], "]"}]}]}], "d"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[CapitalUpsilon]", "[", 
      RowBox[{"4", ",", 
       RowBox[{"{", "}"}]}], "]"}], "\[Rule]", 
     RowBox[{"\[CapitalUpsilon]", "[", 
      RowBox[{"4", ",", 
       RowBox[{"{", "}"}]}], "]"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7377032020565987`*^9, 3.73770325435119*^9},
 ExpressionUUID -> "5f9407d6-9c9c-4d27-b8b0-ced359858cb1"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"replace", "\[LeftDoubleBracket]"}]], "Input",
 CellChangeTimes->{{3.7377032371619883`*^9, 
  3.7377032397569532`*^9}},ExpressionUUID->"ad3aa275-6e11-4ee2-8cbf-\
0b16d6289891"],

Cell[BoxData[
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"replace1", "=", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Drop", "[", 
         RowBox[{"replace", ",", 
          RowBox[{"-", "1"}]}], "]"}], "/.", 
        RowBox[{
        "replace", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}]}], 
       ",", 
       RowBox[{
       "replace", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}]}], 
      "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"replace", "=", "replace1"}], ";"}], "\[IndentingNewLine]", ",", 
   RowBox[{"{", 
    RowBox[{"ii", ",", 
     RowBox[{
      RowBox[{"Length", "[", "replace", "]"}], "-", "1"}]}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.7377030297213573`*^9, 3.7377030631754313`*^9}, {
   3.7377031025995703`*^9, 3.737703147031828*^9}, 3.737703193486367*^9, {
   3.737703313946683*^9, 3.737703356713345*^9}},
 ExpressionUUID -> "fd31a408-42cd-49e6-b387-cb9f1712169b"],

Cell[CellGroupData[{

Cell[BoxData["replace"], "Input",
 CellChangeTimes->{{3.737703149849949*^9, 3.737703150810017*^9}},
 ExpressionUUID -> "8cf67601-45e8-4437-a4d7-be53aabd56ad"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        FractionBox["1", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"2", "+", "d"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"4", "+", "d"}], ")"}]}]], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"A", "[", 
            RowBox[{"4", ",", 
             RowBox[{"{", "}"}]}], "]"}], " ", 
           RowBox[{"\[Delta]", "[", 
            RowBox[{"{", 
             RowBox[{"i", ",", "l"}], "}"}], "]"}], " ", 
           RowBox[{"\[Delta]", "[", 
            RowBox[{"{", 
             RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"A", "[", 
            RowBox[{"4", ",", 
             RowBox[{"{", "}"}]}], "]"}], " ", 
           RowBox[{"\[Delta]", "[", 
            RowBox[{"{", 
             RowBox[{"i", ",", "k"}], "}"}], "]"}], " ", 
           RowBox[{"\[Delta]", "[", 
            RowBox[{"{", 
             RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"A", "[", 
            RowBox[{"4", ",", 
             RowBox[{"{", "}"}]}], "]"}], " ", 
           RowBox[{"\[Delta]", "[", 
            RowBox[{"{", 
             RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
           RowBox[{"\[Delta]", "[", 
            RowBox[{"{", 
             RowBox[{"k", ",", "l"}], "}"}], "]"}]}]}], ")"}]}]}], "+", 
      RowBox[{"\[CapitalUpsilon]", "[", 
       RowBox[{"2", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}]}], "]"}], "+", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"4", "+", "d"}]], 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{"\[Delta]", "[", 
            RowBox[{"{", 
             RowBox[{"k", ",", "l"}], "}"}], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"A", "[", 
               RowBox[{"4", ",", 
                RowBox[{"{", "}"}]}], "]"}], " ", 
              RowBox[{"\[Delta]", "[", 
               RowBox[{"{", 
                RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
             RowBox[{"d", " ", 
              RowBox[{"\[CapitalUpsilon]", "[", 
               RowBox[{"3", ",", 
                RowBox[{"{", 
                 RowBox[{"i", ",", "j"}], "}"}]}], "]"}]}]}], ")"}]}], "d"], 
         "+", 
         FractionBox[
          RowBox[{
           RowBox[{"\[Delta]", "[", 
            RowBox[{"{", 
             RowBox[{"j", ",", "l"}], "}"}], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"A", "[", 
               RowBox[{"4", ",", 
                RowBox[{"{", "}"}]}], "]"}], " ", 
              RowBox[{"\[Delta]", "[", 
               RowBox[{"{", 
                RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
             RowBox[{"d", " ", 
              RowBox[{"\[CapitalUpsilon]", "[", 
               RowBox[{"3", ",", 
                RowBox[{"{", 
                 RowBox[{"i", ",", "k"}], "}"}]}], "]"}]}]}], ")"}]}], "d"], 
         "+", 
         FractionBox[
          RowBox[{
           RowBox[{"\[Delta]", "[", 
            RowBox[{"{", 
             RowBox[{"j", ",", "k"}], "}"}], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"A", "[", 
               RowBox[{"4", ",", 
                RowBox[{"{", "}"}]}], "]"}], " ", 
              RowBox[{"\[Delta]", "[", 
               RowBox[{"{", 
                RowBox[{"i", ",", "l"}], "}"}], "]"}]}], "+", 
             RowBox[{"d", " ", 
              RowBox[{"\[CapitalUpsilon]", "[", 
               RowBox[{"3", ",", 
                RowBox[{"{", 
                 RowBox[{"i", ",", "l"}], "}"}]}], "]"}]}]}], ")"}]}], "d"], 
         "+", 
         FractionBox[
          RowBox[{
           RowBox[{"\[Delta]", "[", 
            RowBox[{"{", 
             RowBox[{"i", ",", "l"}], "}"}], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"A", "[", 
               RowBox[{"4", ",", 
                RowBox[{"{", "}"}]}], "]"}], " ", 
              RowBox[{"\[Delta]", "[", 
               RowBox[{"{", 
                RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
             RowBox[{"d", " ", 
              RowBox[{"\[CapitalUpsilon]", "[", 
               RowBox[{"3", ",", 
                RowBox[{"{", 
                 RowBox[{"j", ",", "k"}], "}"}]}], "]"}]}]}], ")"}]}], "d"], 
         "+", 
         FractionBox[
          RowBox[{
           RowBox[{"\[Delta]", "[", 
            RowBox[{"{", 
             RowBox[{"i", ",", "k"}], "}"}], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"A", "[", 
               RowBox[{"4", ",", 
                RowBox[{"{", "}"}]}], "]"}], " ", 
              RowBox[{"\[Delta]", "[", 
               RowBox[{"{", 
                RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
             RowBox[{"d", " ", 
              RowBox[{"\[CapitalUpsilon]", "[", 
               RowBox[{"3", ",", 
                RowBox[{"{", 
                 RowBox[{"j", ",", "l"}], "}"}]}], "]"}]}]}], ")"}]}], "d"], 
         "+", 
         FractionBox[
          RowBox[{
           RowBox[{"\[Delta]", "[", 
            RowBox[{"{", 
             RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"A", "[", 
               RowBox[{"4", ",", 
                RowBox[{"{", "}"}]}], "]"}], " ", 
              RowBox[{"\[Delta]", "[", 
               RowBox[{"{", 
                RowBox[{"k", ",", "l"}], "}"}], "]"}]}], "+", 
             RowBox[{"d", " ", 
              RowBox[{"\[CapitalUpsilon]", "[", 
               RowBox[{"3", ",", 
                RowBox[{"{", 
                 RowBox[{"k", ",", "l"}], "}"}]}], "]"}]}]}], ")"}]}], "d"]}],
         ")"}]}]}], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        FractionBox["1", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"2", "+", "d"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"4", "+", "d"}], ")"}]}]], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"A", "[", 
            RowBox[{"4", ",", 
             RowBox[{"{", "}"}]}], "]"}], " ", 
           RowBox[{"\[Delta]", "[", 
            RowBox[{"{", 
             RowBox[{"i", ",", "l"}], "}"}], "]"}], " ", 
           RowBox[{"\[Delta]", "[", 
            RowBox[{"{", 
             RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"A", "[", 
            RowBox[{"4", ",", 
             RowBox[{"{", "}"}]}], "]"}], " ", 
           RowBox[{"\[Delta]", "[", 
            RowBox[{"{", 
             RowBox[{"i", ",", "k"}], "}"}], "]"}], " ", 
           RowBox[{"\[Delta]", "[", 
            RowBox[{"{", 
             RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"A", "[", 
            RowBox[{"4", ",", 
             RowBox[{"{", "}"}]}], "]"}], " ", 
           RowBox[{"\[Delta]", "[", 
            RowBox[{"{", 
             RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
           RowBox[{"\[Delta]", "[", 
            RowBox[{"{", 
             RowBox[{"k", ",", "l"}], "}"}], "]"}]}]}], ")"}]}]}], "+", 
      RowBox[{"\[CapitalUpsilon]", "[", 
       RowBox[{"2", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}]}], "]"}], "+", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"4", "+", "d"}]], 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{"\[Delta]", "[", 
            RowBox[{"{", 
             RowBox[{"k", ",", "l"}], "}"}], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"A", "[", 
               RowBox[{"4", ",", 
                RowBox[{"{", "}"}]}], "]"}], " ", 
              RowBox[{"\[Delta]", "[", 
               RowBox[{"{", 
                RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
             RowBox[{"d", " ", 
              RowBox[{"\[CapitalUpsilon]", "[", 
               RowBox[{"3", ",", 
                RowBox[{"{", 
                 RowBox[{"i", ",", "j"}], "}"}]}], "]"}]}]}], ")"}]}], "d"], 
         "+", 
         FractionBox[
          RowBox[{
           RowBox[{"\[Delta]", "[", 
            RowBox[{"{", 
             RowBox[{"j", ",", "l"}], "}"}], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"A", "[", 
               RowBox[{"4", ",", 
                RowBox[{"{", "}"}]}], "]"}], " ", 
              RowBox[{"\[Delta]", "[", 
               RowBox[{"{", 
                RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
             RowBox[{"d", " ", 
              RowBox[{"\[CapitalUpsilon]", "[", 
               RowBox[{"3", ",", 
                RowBox[{"{", 
                 RowBox[{"i", ",", "k"}], "}"}]}], "]"}]}]}], ")"}]}], "d"], 
         "+", 
         FractionBox[
          RowBox[{
           RowBox[{"\[Delta]", "[", 
            RowBox[{"{", 
             RowBox[{"j", ",", "k"}], "}"}], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"A", "[", 
               RowBox[{"4", ",", 
                RowBox[{"{", "}"}]}], "]"}], " ", 
              RowBox[{"\[Delta]", "[", 
               RowBox[{"{", 
                RowBox[{"i", ",", "l"}], "}"}], "]"}]}], "+", 
             RowBox[{"d", " ", 
              RowBox[{"\[CapitalUpsilon]", "[", 
               RowBox[{"3", ",", 
                RowBox[{"{", 
                 RowBox[{"i", ",", "l"}], "}"}]}], "]"}]}]}], ")"}]}], "d"], 
         "+", 
         FractionBox[
          RowBox[{
           RowBox[{"\[Delta]", "[", 
            RowBox[{"{", 
             RowBox[{"i", ",", "l"}], "}"}], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"A", "[", 
               RowBox[{"4", ",", 
                RowBox[{"{", "}"}]}], "]"}], " ", 
              RowBox[{"\[Delta]", "[", 
               RowBox[{"{", 
                RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
             RowBox[{"d", " ", 
              RowBox[{"\[CapitalUpsilon]", "[", 
               RowBox[{"3", ",", 
                RowBox[{"{", 
                 RowBox[{"j", ",", "k"}], "}"}]}], "]"}]}]}], ")"}]}], "d"], 
         "+", 
         FractionBox[
          RowBox[{
           RowBox[{"\[Delta]", "[", 
            RowBox[{"{", 
             RowBox[{"i", ",", "k"}], "}"}], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"A", "[", 
               RowBox[{"4", ",", 
                RowBox[{"{", "}"}]}], "]"}], " ", 
              RowBox[{"\[Delta]", "[", 
               RowBox[{"{", 
                RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
             RowBox[{"d", " ", 
              RowBox[{"\[CapitalUpsilon]", "[", 
               RowBox[{"3", ",", 
                RowBox[{"{", 
                 RowBox[{"j", ",", "l"}], "}"}]}], "]"}]}]}], ")"}]}], "d"], 
         "+", 
         FractionBox[
          RowBox[{
           RowBox[{"\[Delta]", "[", 
            RowBox[{"{", 
             RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"A", "[", 
               RowBox[{"4", ",", 
                RowBox[{"{", "}"}]}], "]"}], " ", 
              RowBox[{"\[Delta]", "[", 
               RowBox[{"{", 
                RowBox[{"k", ",", "l"}], "}"}], "]"}]}], "+", 
             RowBox[{"d", " ", 
              RowBox[{"\[CapitalUpsilon]", "[", 
               RowBox[{"3", ",", 
                RowBox[{"{", 
                 RowBox[{"k", ",", "l"}], "}"}]}], "]"}]}]}], ")"}]}], "d"]}],
         ")"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"4", ",", 
          RowBox[{"{", "}"}]}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"k", ",", "l"}], "}"}], "]"}]}], "+", 
       RowBox[{"d", " ", 
        RowBox[{"\[CapitalUpsilon]", "[", 
         RowBox[{"3", ",", 
          RowBox[{"{", 
           RowBox[{"k", ",", "l"}], "}"}]}], "]"}]}]}], "d"], "\[Rule]", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"4", ",", 
          RowBox[{"{", "}"}]}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"k", ",", "l"}], "}"}], "]"}]}], "+", 
       RowBox[{"d", " ", 
        RowBox[{"\[CapitalUpsilon]", "[", 
         RowBox[{"3", ",", 
          RowBox[{"{", 
           RowBox[{"k", ",", "l"}], "}"}]}], "]"}]}]}], "d"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"4", ",", 
          RowBox[{"{", "}"}]}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
       RowBox[{"d", " ", 
        RowBox[{"\[CapitalUpsilon]", "[", 
         RowBox[{"3", ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "l"}], "}"}]}], "]"}]}]}], "d"], "\[Rule]", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"4", ",", 
          RowBox[{"{", "}"}]}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
       RowBox[{"d", " ", 
        RowBox[{"\[CapitalUpsilon]", "[", 
         RowBox[{"3", ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "l"}], "}"}]}], "]"}]}]}], "d"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"4", ",", 
          RowBox[{"{", "}"}]}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
       RowBox[{"d", " ", 
        RowBox[{"\[CapitalUpsilon]", "[", 
         RowBox[{"3", ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "k"}], "}"}]}], "]"}]}]}], "d"], "\[Rule]", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"4", ",", 
          RowBox[{"{", "}"}]}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
       RowBox[{"d", " ", 
        RowBox[{"\[CapitalUpsilon]", "[", 
         RowBox[{"3", ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "k"}], "}"}]}], "]"}]}]}], "d"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"4", ",", 
          RowBox[{"{", "}"}]}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i", ",", "l"}], "}"}], "]"}]}], "+", 
       RowBox[{"d", " ", 
        RowBox[{"\[CapitalUpsilon]", "[", 
         RowBox[{"3", ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "l"}], "}"}]}], "]"}]}]}], "d"], "\[Rule]", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"4", ",", 
          RowBox[{"{", "}"}]}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i", ",", "l"}], "}"}], "]"}]}], "+", 
       RowBox[{"d", " ", 
        RowBox[{"\[CapitalUpsilon]", "[", 
         RowBox[{"3", ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "l"}], "}"}]}], "]"}]}]}], "d"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"4", ",", 
          RowBox[{"{", "}"}]}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
       RowBox[{"d", " ", 
        RowBox[{"\[CapitalUpsilon]", "[", 
         RowBox[{"3", ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "k"}], "}"}]}], "]"}]}]}], "d"], "\[Rule]", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"4", ",", 
          RowBox[{"{", "}"}]}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
       RowBox[{"d", " ", 
        RowBox[{"\[CapitalUpsilon]", "[", 
         RowBox[{"3", ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "k"}], "}"}]}], "]"}]}]}], "d"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"4", ",", 
          RowBox[{"{", "}"}]}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
       RowBox[{"d", " ", 
        RowBox[{"\[CapitalUpsilon]", "[", 
         RowBox[{"3", ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "j"}], "}"}]}], "]"}]}]}], "d"], "\[Rule]", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"4", ",", 
          RowBox[{"{", "}"}]}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
       RowBox[{"d", " ", 
        RowBox[{"\[CapitalUpsilon]", "[", 
         RowBox[{"3", ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "j"}], "}"}]}], "]"}]}]}], "d"]}], "}"}], ",", 
   RowBox[{
    RowBox[{"A", "[", 
     RowBox[{"3", ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "j"}], "}"}]}], "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"A", "[", 
        RowBox[{"4", ",", 
         RowBox[{"{", "}"}]}], "]"}], " ", 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
      RowBox[{"d", " ", 
       RowBox[{"\[CapitalUpsilon]", "[", 
        RowBox[{"3", ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "j"}], "}"}]}], "]"}]}]}], "d"]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.737703151329401*^9, 3.737703362236322*^9},
 ExpressionUUID -> "de10e261-5ad9-4b14-8042-ab21093a3929"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"list1", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"list1", "=", 
    RowBox[{"Join", "[", 
     RowBox[{"list1", ",", 
      RowBox[{
       RowBox[{"replace", "\[LeftDoubleBracket]", 
        RowBox[{"ii", "-", "1"}], "\[RightDoubleBracket]"}], "/.", 
       RowBox[{
       "replace", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}]}]}],
      "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"ii", ",", 
     RowBox[{"Length", "[", "replace", "]"}], ",", "2", ",", 
     RowBox[{"-", "1"}]}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.737702206387632*^9, 3.737702209633729*^9}, {
   3.737702475347612*^9, 3.737702601796722*^9}, 3.737702657689239*^9},
 ExpressionUUID -> "20072c68-6ead-43f7-aab3-b73298cb9a99"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"A", "[", 
      RowBox[{"3", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "j"}], "}"}]}], "]"}], "\[Rule]", 
     FractionBox[
      RowBox[{
       RowBox[{"d", " ", 
        RowBox[{"\[CapitalUpsilon]", "[", 
         RowBox[{"3", ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "j"}], "}"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
        RowBox[{"\[CapitalUpsilon]", "[", 
         RowBox[{"4", ",", 
          RowBox[{"{", "}"}]}], "]"}]}]}], "d"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"A", "[", 
       RowBox[{"3", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "j"}], "}"}]}], "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{"d", " ", 
         RowBox[{"\[CapitalUpsilon]", "[", 
          RowBox[{"3", ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "j"}], "}"}]}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
         RowBox[{"\[CapitalUpsilon]", "[", 
          RowBox[{"4", ",", 
           RowBox[{"{", "}"}]}], "]"}]}]}], "d"]}], ",", 
     RowBox[{
      RowBox[{"A", "[", 
       RowBox[{"3", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "k"}], "}"}]}], "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"A", "[", 
          RowBox[{"4", ",", 
           RowBox[{"{", "}"}]}], "]"}], " ", 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
        RowBox[{"d", " ", 
         RowBox[{"\[CapitalUpsilon]", "[", 
          RowBox[{"3", ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "k"}], "}"}]}], "]"}]}]}], "d"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"A", "[", 
       RowBox[{"3", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "j"}], "}"}]}], "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{"d", " ", 
         RowBox[{"\[CapitalUpsilon]", "[", 
          RowBox[{"3", ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "j"}], "}"}]}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
         RowBox[{"\[CapitalUpsilon]", "[", 
          RowBox[{"4", ",", 
           RowBox[{"{", "}"}]}], "]"}]}]}], "d"]}], ",", 
     RowBox[{
      RowBox[{"A", "[", 
       RowBox[{"3", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "k"}], "}"}]}], "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"A", "[", 
          RowBox[{"4", ",", 
           RowBox[{"{", "}"}]}], "]"}], " ", 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
        RowBox[{"d", " ", 
         RowBox[{"\[CapitalUpsilon]", "[", 
          RowBox[{"3", ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "k"}], "}"}]}], "]"}]}]}], "d"]}], ",", 
     RowBox[{
      RowBox[{"A", "[", 
       RowBox[{"3", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "l"}], "}"}]}], "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"A", "[", 
          RowBox[{"4", ",", 
           RowBox[{"{", "}"}]}], "]"}], " ", 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"i", ",", "l"}], "}"}], "]"}]}], "+", 
        RowBox[{"d", " ", 
         RowBox[{"\[CapitalUpsilon]", "[", 
          RowBox[{"3", ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "l"}], "}"}]}], "]"}]}]}], "d"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"A", "[", 
       RowBox[{"3", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "j"}], "}"}]}], "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{"d", " ", 
         RowBox[{"\[CapitalUpsilon]", "[", 
          RowBox[{"3", ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "j"}], "}"}]}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
         RowBox[{"\[CapitalUpsilon]", "[", 
          RowBox[{"4", ",", 
           RowBox[{"{", "}"}]}], "]"}]}]}], "d"]}], ",", 
     RowBox[{
      RowBox[{"A", "[", 
       RowBox[{"3", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "k"}], "}"}]}], "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"A", "[", 
          RowBox[{"4", ",", 
           RowBox[{"{", "}"}]}], "]"}], " ", 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
        RowBox[{"d", " ", 
         RowBox[{"\[CapitalUpsilon]", "[", 
          RowBox[{"3", ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "k"}], "}"}]}], "]"}]}]}], "d"]}], ",", 
     RowBox[{
      RowBox[{"A", "[", 
       RowBox[{"3", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "l"}], "}"}]}], "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"A", "[", 
          RowBox[{"4", ",", 
           RowBox[{"{", "}"}]}], "]"}], " ", 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"i", ",", "l"}], "}"}], "]"}]}], "+", 
        RowBox[{"d", " ", 
         RowBox[{"\[CapitalUpsilon]", "[", 
          RowBox[{"3", ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "l"}], "}"}]}], "]"}]}]}], "d"]}], ",", 
     RowBox[{
      RowBox[{"A", "[", 
       RowBox[{"3", ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "k"}], "}"}]}], "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"A", "[", 
          RowBox[{"4", ",", 
           RowBox[{"{", "}"}]}], "]"}], " ", 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
        RowBox[{"d", " ", 
         RowBox[{"\[CapitalUpsilon]", "[", 
          RowBox[{"3", ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "k"}], "}"}]}], "]"}]}]}], "d"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"A", "[", 
       RowBox[{"3", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "j"}], "}"}]}], "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{"d", " ", 
         RowBox[{"\[CapitalUpsilon]", "[", 
          RowBox[{"3", ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "j"}], "}"}]}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
         RowBox[{"\[CapitalUpsilon]", "[", 
          RowBox[{"4", ",", 
           RowBox[{"{", "}"}]}], "]"}]}]}], "d"]}], ",", 
     RowBox[{
      RowBox[{"A", "[", 
       RowBox[{"3", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "k"}], "}"}]}], "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"A", "[", 
          RowBox[{"4", ",", 
           RowBox[{"{", "}"}]}], "]"}], " ", 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
        RowBox[{"d", " ", 
         RowBox[{"\[CapitalUpsilon]", "[", 
          RowBox[{"3", ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "k"}], "}"}]}], "]"}]}]}], "d"]}], ",", 
     RowBox[{
      RowBox[{"A", "[", 
       RowBox[{"3", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "l"}], "}"}]}], "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"A", "[", 
          RowBox[{"4", ",", 
           RowBox[{"{", "}"}]}], "]"}], " ", 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"i", ",", "l"}], "}"}], "]"}]}], "+", 
        RowBox[{"d", " ", 
         RowBox[{"\[CapitalUpsilon]", "[", 
          RowBox[{"3", ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "l"}], "}"}]}], "]"}]}]}], "d"]}], ",", 
     RowBox[{
      RowBox[{"A", "[", 
       RowBox[{"3", ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "k"}], "}"}]}], "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"A", "[", 
          RowBox[{"4", ",", 
           RowBox[{"{", "}"}]}], "]"}], " ", 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
        RowBox[{"d", " ", 
         RowBox[{"\[CapitalUpsilon]", "[", 
          RowBox[{"3", ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "k"}], "}"}]}], "]"}]}]}], "d"]}], ",", 
     RowBox[{
      RowBox[{"A", "[", 
       RowBox[{"3", ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "l"}], "}"}]}], "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"A", "[", 
          RowBox[{"4", ",", 
           RowBox[{"{", "}"}]}], "]"}], " ", 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
        RowBox[{"d", " ", 
         RowBox[{"\[CapitalUpsilon]", "[", 
          RowBox[{"3", ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "l"}], "}"}]}], "]"}]}]}], "d"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"A", "[", 
       RowBox[{"3", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "j"}], "}"}]}], "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{"d", " ", 
         RowBox[{"\[CapitalUpsilon]", "[", 
          RowBox[{"3", ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "j"}], "}"}]}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
         RowBox[{"\[CapitalUpsilon]", "[", 
          RowBox[{"4", ",", 
           RowBox[{"{", "}"}]}], "]"}]}]}], "d"]}], ",", 
     RowBox[{
      RowBox[{"A", "[", 
       RowBox[{"3", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "k"}], "}"}]}], "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"A", "[", 
          RowBox[{"4", ",", 
           RowBox[{"{", "}"}]}], "]"}], " ", 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
        RowBox[{"d", " ", 
         RowBox[{"\[CapitalUpsilon]", "[", 
          RowBox[{"3", ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "k"}], "}"}]}], "]"}]}]}], "d"]}], ",", 
     RowBox[{
      RowBox[{"A", "[", 
       RowBox[{"3", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "l"}], "}"}]}], "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"A", "[", 
          RowBox[{"4", ",", 
           RowBox[{"{", "}"}]}], "]"}], " ", 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"i", ",", "l"}], "}"}], "]"}]}], "+", 
        RowBox[{"d", " ", 
         RowBox[{"\[CapitalUpsilon]", "[", 
          RowBox[{"3", ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "l"}], "}"}]}], "]"}]}]}], "d"]}], ",", 
     RowBox[{
      RowBox[{"A", "[", 
       RowBox[{"3", ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "k"}], "}"}]}], "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"A", "[", 
          RowBox[{"4", ",", 
           RowBox[{"{", "}"}]}], "]"}], " ", 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
        RowBox[{"d", " ", 
         RowBox[{"\[CapitalUpsilon]", "[", 
          RowBox[{"3", ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "k"}], "}"}]}], "]"}]}]}], "d"]}], ",", 
     RowBox[{
      RowBox[{"A", "[", 
       RowBox[{"3", ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "l"}], "}"}]}], "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"A", "[", 
          RowBox[{"4", ",", 
           RowBox[{"{", "}"}]}], "]"}], " ", 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
        RowBox[{"d", " ", 
         RowBox[{"\[CapitalUpsilon]", "[", 
          RowBox[{"3", ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "l"}], "}"}]}], "]"}]}]}], "d"]}], ",", 
     RowBox[{
      RowBox[{"A", "[", 
       RowBox[{"3", ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "l"}], "}"}]}], "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"A", "[", 
          RowBox[{"4", ",", 
           RowBox[{"{", "}"}]}], "]"}], " ", 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"k", ",", "l"}], "}"}], "]"}]}], "+", 
        RowBox[{"d", " ", 
         RowBox[{"\[CapitalUpsilon]", "[", 
          RowBox[{"3", ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "l"}], "}"}]}], "]"}]}]}], "d"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"A", "[", 
       RowBox[{"3", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "j"}], "}"}]}], "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{"d", " ", 
         RowBox[{"\[CapitalUpsilon]", "[", 
          RowBox[{"3", ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "j"}], "}"}]}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
         RowBox[{"\[CapitalUpsilon]", "[", 
          RowBox[{"4", ",", 
           RowBox[{"{", "}"}]}], "]"}]}]}], "d"]}], ",", 
     RowBox[{
      RowBox[{"A", "[", 
       RowBox[{"3", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "k"}], "}"}]}], "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"A", "[", 
          RowBox[{"4", ",", 
           RowBox[{"{", "}"}]}], "]"}], " ", 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
        RowBox[{"d", " ", 
         RowBox[{"\[CapitalUpsilon]", "[", 
          RowBox[{"3", ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "k"}], "}"}]}], "]"}]}]}], "d"]}], ",", 
     RowBox[{
      RowBox[{"A", "[", 
       RowBox[{"3", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "l"}], "}"}]}], "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"A", "[", 
          RowBox[{"4", ",", 
           RowBox[{"{", "}"}]}], "]"}], " ", 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"i", ",", "l"}], "}"}], "]"}]}], "+", 
        RowBox[{"d", " ", 
         RowBox[{"\[CapitalUpsilon]", "[", 
          RowBox[{"3", ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "l"}], "}"}]}], "]"}]}]}], "d"]}], ",", 
     RowBox[{
      RowBox[{"A", "[", 
       RowBox[{"3", ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "k"}], "}"}]}], "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"A", "[", 
          RowBox[{"4", ",", 
           RowBox[{"{", "}"}]}], "]"}], " ", 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
        RowBox[{"d", " ", 
         RowBox[{"\[CapitalUpsilon]", "[", 
          RowBox[{"3", ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "k"}], "}"}]}], "]"}]}]}], "d"]}], ",", 
     RowBox[{
      RowBox[{"A", "[", 
       RowBox[{"3", ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "l"}], "}"}]}], "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"A", "[", 
          RowBox[{"4", ",", 
           RowBox[{"{", "}"}]}], "]"}], " ", 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
        RowBox[{"d", " ", 
         RowBox[{"\[CapitalUpsilon]", "[", 
          RowBox[{"3", ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "l"}], "}"}]}], "]"}]}]}], "d"]}], ",", 
     RowBox[{
      RowBox[{"A", "[", 
       RowBox[{"3", ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "l"}], "}"}]}], "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"A", "[", 
          RowBox[{"4", ",", 
           RowBox[{"{", "}"}]}], "]"}], " ", 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"k", ",", "l"}], "}"}], "]"}]}], "+", 
        RowBox[{"d", " ", 
         RowBox[{"\[CapitalUpsilon]", "[", 
          RowBox[{"3", ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "l"}], "}"}]}], "]"}]}]}], "d"]}], ",", 
     RowBox[{
      RowBox[{"A", "[", 
       RowBox[{"2", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}]}], "]"}], 
      "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{
         FractionBox["1", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"2", "+", "d"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"4", "+", "d"}], ")"}]}]], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"4", ",", 
              RowBox[{"{", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "l"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"4", ",", 
              RowBox[{"{", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "k"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"4", ",", 
              RowBox[{"{", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"k", ",", "l"}], "}"}], "]"}]}]}], ")"}]}]}], "+", 
       RowBox[{"\[CapitalUpsilon]", "[", 
        RowBox[{"2", ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}]}], "]"}], "+", 
       RowBox[{
        FractionBox["1", 
         RowBox[{"4", "+", "d"}]], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"A", "[", 
            RowBox[{"3", ",", 
             RowBox[{"{", 
              RowBox[{"j", ",", "l"}], "}"}]}], "]"}], " ", 
           RowBox[{"\[Delta]", "[", 
            RowBox[{"{", 
             RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"A", "[", 
            RowBox[{"3", ",", 
             RowBox[{"{", 
              RowBox[{"j", ",", "k"}], "}"}]}], "]"}], " ", 
           RowBox[{"\[Delta]", "[", 
            RowBox[{"{", 
             RowBox[{"i", ",", "l"}], "}"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"A", "[", 
            RowBox[{"3", ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "l"}], "}"}]}], "]"}], " ", 
           RowBox[{"\[Delta]", "[", 
            RowBox[{"{", 
             RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"A", "[", 
            RowBox[{"3", ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "k"}], "}"}]}], "]"}], " ", 
           RowBox[{"\[Delta]", "[", 
            RowBox[{"{", 
             RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"A", "[", 
            RowBox[{"3", ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "j"}], "}"}]}], "]"}], " ", 
           RowBox[{"\[Delta]", "[", 
            RowBox[{"{", 
             RowBox[{"k", ",", "l"}], "}"}], "]"}]}], "+", 
          FractionBox[
           RowBox[{
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"A", "[", 
                RowBox[{"4", ",", 
                 RowBox[{"{", "}"}]}], "]"}], " ", 
               RowBox[{"\[Delta]", "[", 
                RowBox[{"{", 
                 RowBox[{"k", ",", "l"}], "}"}], "]"}]}], "+", 
              RowBox[{"d", " ", 
               RowBox[{"\[CapitalUpsilon]", "[", 
                RowBox[{"3", ",", 
                 RowBox[{"{", 
                  RowBox[{"k", ",", "l"}], "}"}]}], "]"}]}]}], ")"}]}], 
           "d"]}], ")"}]}]}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.737702603433178*^9, 3.73770266078452*^9},
 ExpressionUUID -> "d52e18f6-0b4c-4dda-9400-1ad315b3e225"]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.737702763095316*^9, 3.737702798581723*^9}, 
   3.737702842457349*^9},ExpressionUUID->"81344afc-bfa4-433c-932c-\
e9e77910566d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"list", "=", 
   RowBox[{"DeleteDuplicates", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"A", "[", 
       RowBox[{"2", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}]}], "]"}], ",", 
      RowBox[{"A", "[", 
       RowBox[{"3", ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "l"}], "}"}]}], "]"}], ",", 
      RowBox[{"A", "[", 
       RowBox[{"3", ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "l"}], "}"}]}], "]"}], ",", 
      RowBox[{"A", "[", 
       RowBox[{"3", ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "k"}], "}"}]}], "]"}], ",", 
      RowBox[{"A", "[", 
       RowBox[{"3", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "l"}], "}"}]}], "]"}], ",", 
      RowBox[{"A", "[", 
       RowBox[{"3", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "k"}], "}"}]}], "]"}], ",", 
      RowBox[{"A", "[", 
       RowBox[{"3", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "j"}], "}"}]}], "]"}], ",", 
      RowBox[{"A", "[", 
       RowBox[{"4", ",", 
        RowBox[{"{", "}"}]}], "]"}], ",", 
      RowBox[{"A", "[", 
       RowBox[{"4", ",", 
        RowBox[{"{", "}"}]}], "]"}], ",", 
      RowBox[{"A", "[", 
       RowBox[{"4", ",", 
        RowBox[{"{", "}"}]}], "]"}]}], "}"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.737636698726471*^9, 3.737636704636147*^9}, {
  3.7376368800447206`*^9, 
  3.737636887019619*^9}},ExpressionUUID->"0fd8b6e3-9280-4246-9859-\
fa841685746b"],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.737647312426758*^9, 3.737647317687842*^9}, 
   3.7376478014657383`*^9},ExpressionUUID->"7ca13c9d-56f3-4d99-bfb9-\
a282079292c9"],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.737647319902947*^9, 
  3.737647453547471*^9}},ExpressionUUID->"c0457d1f-a650-4e33-9b17-\
7848e4b74825"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"replace", "=", 
  RowBox[{"Flatten", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"fulltracefreeform1", "[", 
      RowBox[{"list", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}],
       "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"ii", ",", "1", ",", 
       RowBox[{"Length", "[", "list", "]"}]}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.7376367282507343`*^9, 3.737636773612999*^9}, {
  3.737636964850881*^9, 3.737636969961434*^9}, {3.737637011405007*^9, 
  3.7376370152418756`*^9}},ExpressionUUID->"d985ab19-4bb0-484a-9f53-\
379c54c99809"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"A", "[", 
     RowBox[{"2", ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}]}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      FractionBox["1", 
       RowBox[{"4", "+", "d"}]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"A", "[", 
          RowBox[{"3", ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "l"}], "}"}]}], "]"}], " ", 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"A", "[", 
          RowBox[{"3", ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "l"}], "}"}]}], "]"}], " ", 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"A", "[", 
          RowBox[{"3", ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "k"}], "}"}]}], "]"}], " ", 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"i", ",", "l"}], "}"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"A", "[", 
          RowBox[{"3", ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "l"}], "}"}]}], "]"}], " ", 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"A", "[", 
          RowBox[{"3", ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "k"}], "}"}]}], "]"}], " ", 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"A", "[", 
          RowBox[{"3", ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "j"}], "}"}]}], "]"}], " ", 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"k", ",", "l"}], "}"}], "]"}]}]}], ")"}]}], "-", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"4", ",", 
          RowBox[{"{", "}"}]}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i", ",", "l"}], "}"}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"4", ",", 
          RowBox[{"{", "}"}]}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i", ",", "k"}], "}"}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"4", ",", 
          RowBox[{"{", "}"}]}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"k", ",", "l"}], "}"}], "]"}]}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"2", "+", "d"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"4", "+", "d"}], ")"}]}]], "+", 
     RowBox[{"\[CapitalKoppa]", "[", 
      RowBox[{"2", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}]}], "]"}]}]}], ",", 
   
   RowBox[{
    RowBox[{"A", "[", 
     RowBox[{"3", ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", "l"}], "}"}]}], "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"A", "[", 
        RowBox[{"4", ",", 
         RowBox[{"{", "}"}]}], "]"}], " ", 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"k", ",", "l"}], "}"}], "]"}]}], "+", 
      RowBox[{"d", " ", 
       RowBox[{"\[CapitalKoppa]", "[", 
        RowBox[{"3", ",", 
         RowBox[{"{", 
          RowBox[{"k", ",", "l"}], "}"}]}], "]"}]}]}], "d"]}], ",", 
   RowBox[{
    RowBox[{"A", "[", 
     RowBox[{"3", ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "l"}], "}"}]}], "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"A", "[", 
        RowBox[{"4", ",", 
         RowBox[{"{", "}"}]}], "]"}], " ", 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
      RowBox[{"d", " ", 
       RowBox[{"\[CapitalKoppa]", "[", 
        RowBox[{"3", ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "l"}], "}"}]}], "]"}]}]}], "d"]}], ",", 
   RowBox[{
    RowBox[{"A", "[", 
     RowBox[{"3", ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "k"}], "}"}]}], "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"A", "[", 
        RowBox[{"4", ",", 
         RowBox[{"{", "}"}]}], "]"}], " ", 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
      RowBox[{"d", " ", 
       RowBox[{"\[CapitalKoppa]", "[", 
        RowBox[{"3", ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "k"}], "}"}]}], "]"}]}]}], "d"]}], ",", 
   RowBox[{
    RowBox[{"A", "[", 
     RowBox[{"3", ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "l"}], "}"}]}], "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"A", "[", 
        RowBox[{"4", ",", 
         RowBox[{"{", "}"}]}], "]"}], " ", 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"i", ",", "l"}], "}"}], "]"}]}], "+", 
      RowBox[{"d", " ", 
       RowBox[{"\[CapitalKoppa]", "[", 
        RowBox[{"3", ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "l"}], "}"}]}], "]"}]}]}], "d"]}], ",", 
   RowBox[{
    RowBox[{"A", "[", 
     RowBox[{"3", ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "k"}], "}"}]}], "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"A", "[", 
        RowBox[{"4", ",", 
         RowBox[{"{", "}"}]}], "]"}], " ", 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
      RowBox[{"d", " ", 
       RowBox[{"\[CapitalKoppa]", "[", 
        RowBox[{"3", ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "k"}], "}"}]}], "]"}]}]}], "d"]}], ",", 
   RowBox[{
    RowBox[{"A", "[", 
     RowBox[{"3", ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "j"}], "}"}]}], "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"A", "[", 
        RowBox[{"4", ",", 
         RowBox[{"{", "}"}]}], "]"}], " ", 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
      RowBox[{"d", " ", 
       RowBox[{"\[CapitalKoppa]", "[", 
        RowBox[{"3", ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "j"}], "}"}]}], "]"}]}]}], "d"]}], ",", 
   RowBox[{
    RowBox[{"A", "[", 
     RowBox[{"4", ",", 
      RowBox[{"{", "}"}]}], "]"}], "\[Rule]", 
    RowBox[{"\[CapitalKoppa]", "[", 
     RowBox[{"4", ",", 
      RowBox[{"{", "}"}]}], "]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.737636754835557*^9, 3.737636809400035*^9}, 
   3.737636892888083*^9, 3.7376369706741743`*^9, 3.737637017598575*^9, 
   3.737637884645583*^9, 3.73764745953861*^9, 
   3.737647573925932*^9},ExpressionUUID->"cf6bf317-6b88-4896-95fd-\
7bcf71474560"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"replace", "/.", 
  RowBox[{
  "replace", "\[LeftDoubleBracket]", "8", 
   "\[RightDoubleBracket]"}]}]], "Input",
 CellChangeTimes->{
  3.737648125983581*^9},ExpressionUUID->"f44c75fd-1022-474d-8d8b-\
0644975d9ab1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"A", "[", 
     RowBox[{"2", ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}]}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      FractionBox["1", 
       RowBox[{"4", "+", "d"}]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"A", "[", 
          RowBox[{"3", ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "l"}], "}"}]}], "]"}], " ", 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"A", "[", 
          RowBox[{"3", ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "l"}], "}"}]}], "]"}], " ", 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"A", "[", 
          RowBox[{"3", ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "k"}], "}"}]}], "]"}], " ", 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"i", ",", "l"}], "}"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"A", "[", 
          RowBox[{"3", ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "l"}], "}"}]}], "]"}], " ", 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"A", "[", 
          RowBox[{"3", ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "k"}], "}"}]}], "]"}], " ", 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"A", "[", 
          RowBox[{"3", ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "j"}], "}"}]}], "]"}], " ", 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"k", ",", "l"}], "}"}], "]"}]}]}], ")"}]}], "+", 
     RowBox[{"\[CapitalKoppa]", "[", 
      RowBox[{"2", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}]}], "]"}], "-", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i", ",", "l"}], "}"}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"j", ",", "k"}], "}"}], "]"}], " ", 
        RowBox[{"\[CapitalKoppa]", "[", 
         RowBox[{"4", ",", 
          RowBox[{"{", "}"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i", ",", "k"}], "}"}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"j", ",", "l"}], "}"}], "]"}], " ", 
        RowBox[{"\[CapitalKoppa]", "[", 
         RowBox[{"4", ",", 
          RowBox[{"{", "}"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"k", ",", "l"}], "}"}], "]"}], " ", 
        RowBox[{"\[CapitalKoppa]", "[", 
         RowBox[{"4", ",", 
          RowBox[{"{", "}"}]}], "]"}]}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"2", "+", "d"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"4", "+", "d"}], ")"}]}]]}]}], ",", 
   RowBox[{
    RowBox[{"A", "[", 
     RowBox[{"3", ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", "l"}], "}"}]}], "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"d", " ", 
       RowBox[{"\[CapitalKoppa]", "[", 
        RowBox[{"3", ",", 
         RowBox[{"{", 
          RowBox[{"k", ",", "l"}], "}"}]}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"k", ",", "l"}], "}"}], "]"}], " ", 
       RowBox[{"\[CapitalKoppa]", "[", 
        RowBox[{"4", ",", 
         RowBox[{"{", "}"}]}], "]"}]}]}], "d"]}], ",", 
   RowBox[{
    RowBox[{"A", "[", 
     RowBox[{"3", ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "l"}], "}"}]}], "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"d", " ", 
       RowBox[{"\[CapitalKoppa]", "[", 
        RowBox[{"3", ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "l"}], "}"}]}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"j", ",", "l"}], "}"}], "]"}], " ", 
       RowBox[{"\[CapitalKoppa]", "[", 
        RowBox[{"4", ",", 
         RowBox[{"{", "}"}]}], "]"}]}]}], "d"]}], ",", 
   RowBox[{
    RowBox[{"A", "[", 
     RowBox[{"3", ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "k"}], "}"}]}], "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"d", " ", 
       RowBox[{"\[CapitalKoppa]", "[", 
        RowBox[{"3", ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "k"}], "}"}]}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"j", ",", "k"}], "}"}], "]"}], " ", 
       RowBox[{"\[CapitalKoppa]", "[", 
        RowBox[{"4", ",", 
         RowBox[{"{", "}"}]}], "]"}]}]}], "d"]}], ",", 
   RowBox[{
    RowBox[{"A", "[", 
     RowBox[{"3", ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "l"}], "}"}]}], "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"d", " ", 
       RowBox[{"\[CapitalKoppa]", "[", 
        RowBox[{"3", ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "l"}], "}"}]}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"i", ",", "l"}], "}"}], "]"}], " ", 
       RowBox[{"\[CapitalKoppa]", "[", 
        RowBox[{"4", ",", 
         RowBox[{"{", "}"}]}], "]"}]}]}], "d"]}], ",", 
   RowBox[{
    RowBox[{"A", "[", 
     RowBox[{"3", ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "k"}], "}"}]}], "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"d", " ", 
       RowBox[{"\[CapitalKoppa]", "[", 
        RowBox[{"3", ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "k"}], "}"}]}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"i", ",", "k"}], "}"}], "]"}], " ", 
       RowBox[{"\[CapitalKoppa]", "[", 
        RowBox[{"4", ",", 
         RowBox[{"{", "}"}]}], "]"}]}]}], "d"]}], ",", 
   RowBox[{
    RowBox[{"A", "[", 
     RowBox[{"3", ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "j"}], "}"}]}], "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"d", " ", 
       RowBox[{"\[CapitalKoppa]", "[", 
        RowBox[{"3", ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "j"}], "}"}]}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
       RowBox[{"\[CapitalKoppa]", "[", 
        RowBox[{"4", ",", 
         RowBox[{"{", "}"}]}], "]"}]}]}], "d"]}], ",", 
   RowBox[{
    RowBox[{"\[CapitalKoppa]", "[", 
     RowBox[{"4", ",", 
      RowBox[{"{", "}"}]}], "]"}], "\[Rule]", 
    RowBox[{"\[CapitalKoppa]", "[", 
     RowBox[{"4", ",", 
      RowBox[{"{", "}"}]}], "]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7376481266395187`*^9},ExpressionUUID->"7e06cb1b-c321-44db-9f20-\
e343f2bd3435"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"replace", "/.", 
    RowBox[{
    "replace", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"ii", ",", 
     RowBox[{"Length", "[", "replace", "]"}], ",", "2", ",", 
     RowBox[{"-", "1"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.737648025266987*^9, 
  3.73764809439205*^9}},ExpressionUUID->"228096d0-c8e1-40b7-8a6a-\
df5b89d403c1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "replace", "]"}]], "Input",ExpressionUUID->"31c8ef15-078b-4a90-ae52-4631db8c443d"],

Cell[BoxData["8"], "Output",
 CellChangeTimes->{
  3.7376476325491734`*^9},ExpressionUUID->"acf9e065-49ef-4531-9726-\
78db8f5716b1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"replace", "\[LeftDoubleBracket]", "7", "\[RightDoubleBracket]"}], "/.", 
  RowBox[{
  "replace", "\[LeftDoubleBracket]", "8", 
   "\[RightDoubleBracket]"}]}]], "Input",
 CellChangeTimes->{{3.737647636635695*^9, 3.737647639152891*^9}, {
  3.737647701396674*^9, 
  3.7376477183860903`*^9}},ExpressionUUID->"b4a78d71-507c-415d-a24e-\
915e33aa0f10"],

Cell[BoxData[
 RowBox[{
  RowBox[{"A", "[", 
   RowBox[{"3", ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "j"}], "}"}]}], "]"}], "\[Rule]", 
  FractionBox[
   RowBox[{
    RowBox[{"d", " ", 
     RowBox[{"\[CapitalKoppa]", "[", 
      RowBox[{"3", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "j"}], "}"}]}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"\[Delta]", "[", 
      RowBox[{"{", 
       RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
     RowBox[{"\[CapitalKoppa]", "[", 
      RowBox[{"4", ",", 
       RowBox[{"{", "}"}]}], "]"}]}]}], "d"]}]], "Output",
 CellChangeTimes->{
  3.737647640035225*^9, {3.7376477062003317`*^9, 
   3.7376477194146767`*^9}},ExpressionUUID->"25272d93-feb6-4e08-bfa3-\
5f0ff318317b"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"list1", "=", 
   RowBox[{"{", "}"}]}], ";", 
  RowBox[{"list2", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"list1", "=", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Join", "[", 
        RowBox[{"list1", ",", 
         RowBox[{"{", 
          RowBox[{"replace", "/.", 
           RowBox[{
           "replace", "\[LeftDoubleBracket]", "ii", 
            "\[RightDoubleBracket]"}]}], "}"}]}], "]"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"ii", ",", 
       RowBox[{"Length", "[", "replace", "]"}], ",", "2", ",", 
       RowBox[{"-", "1"}]}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.737647468554749*^9, 3.73764752565539*^9}, {
   3.737647598767683*^9, 3.737647605086855*^9}, {3.737647664111124*^9, 
   3.737647691802044*^9}, {3.737647739021426*^9, 3.737647805482885*^9}, {
   3.73764784023801*^9, 3.737647845292388*^9}, 
   3.737647880179022*^9},ExpressionUUID->"346ba154-a5c1-4379-8a3e-\
c83cd94f21c9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Apply", "[", 
  RowBox[{"ReplaceAll", ",", "replace"}], "]"}]], "Input",
 CellChangeTimes->{{3.737637629027459*^9, 
  3.737637668990912*^9}},ExpressionUUID->"c0b4d559-f2d3-4511-9158-\
79b208f1cafe"],

Cell[BoxData[
 TemplateBox[{
  "ReplaceAll","argt",
   "\"\\!\\(\\*RowBox[{\\\"ReplaceAll\\\"}]\\) called with \
\\!\\(\\*RowBox[{\\\"8\\\"}]\\) arguments; \\!\\(\\*RowBox[{\\\"1\\\"}]\\) or \
\\!\\(\\*RowBox[{\\\"2\\\"}]\\) arguments are expected.\"",2,122,13,
   33568332740436794465,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.737637639575626*^9, 
  3.737637669853455*^9},ExpressionUUID->"58d94f0c-49ea-4d04-ba20-\
cba503ae94e0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"replace", "\[LeftDoubleBracket]", 
     RowBox[{"ii", "-", "1"}], "\[RightDoubleBracket]"}], "/.", 
    RowBox[{
    "replace", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"ii", ",", 
     RowBox[{"Length", "[", "replace", "]"}], ",", "2", ",", 
     RowBox[{"-", "1"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.737637024176365*^9, 3.7376371131149282`*^9}, {
  3.737637211501334*^9, 
  3.737637275894635*^9}},ExpressionUUID->"752f3e9d-ff89-4819-b5d4-\
6ada8cc66b7b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"A", "[", 
     RowBox[{"3", ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "j"}], "}"}]}], "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"d", " ", 
       RowBox[{"\[CapitalKoppa]", "[", 
        RowBox[{"3", ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "j"}], "}"}]}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
       RowBox[{"\[CapitalKoppa]", "[", 
        RowBox[{"4", ",", 
         RowBox[{"{", "}"}]}], "]"}]}]}], "d"]}], ",", 
   RowBox[{
    RowBox[{"A", "[", 
     RowBox[{"3", ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "k"}], "}"}]}], "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"A", "[", 
        RowBox[{"4", ",", 
         RowBox[{"{", "}"}]}], "]"}], " ", 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
      RowBox[{"d", " ", 
       RowBox[{"\[CapitalKoppa]", "[", 
        RowBox[{"3", ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "k"}], "}"}]}], "]"}]}]}], "d"]}], ",", 
   RowBox[{
    RowBox[{"A", "[", 
     RowBox[{"3", ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "l"}], "}"}]}], "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"A", "[", 
        RowBox[{"4", ",", 
         RowBox[{"{", "}"}]}], "]"}], " ", 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"i", ",", "l"}], "}"}], "]"}]}], "+", 
      RowBox[{"d", " ", 
       RowBox[{"\[CapitalKoppa]", "[", 
        RowBox[{"3", ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "l"}], "}"}]}], "]"}]}]}], "d"]}], ",", 
   RowBox[{
    RowBox[{"A", "[", 
     RowBox[{"3", ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "k"}], "}"}]}], "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"A", "[", 
        RowBox[{"4", ",", 
         RowBox[{"{", "}"}]}], "]"}], " ", 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
      RowBox[{"d", " ", 
       RowBox[{"\[CapitalKoppa]", "[", 
        RowBox[{"3", ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "k"}], "}"}]}], "]"}]}]}], "d"]}], ",", 
   RowBox[{
    RowBox[{"A", "[", 
     RowBox[{"3", ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "l"}], "}"}]}], "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"A", "[", 
        RowBox[{"4", ",", 
         RowBox[{"{", "}"}]}], "]"}], " ", 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
      RowBox[{"d", " ", 
       RowBox[{"\[CapitalKoppa]", "[", 
        RowBox[{"3", ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "l"}], "}"}]}], "]"}]}]}], "d"]}], ",", 
   RowBox[{
    RowBox[{"A", "[", 
     RowBox[{"3", ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", "l"}], "}"}]}], "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"A", "[", 
        RowBox[{"4", ",", 
         RowBox[{"{", "}"}]}], "]"}], " ", 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"k", ",", "l"}], "}"}], "]"}]}], "+", 
      RowBox[{"d", " ", 
       RowBox[{"\[CapitalKoppa]", "[", 
        RowBox[{"3", ",", 
         RowBox[{"{", 
          RowBox[{"k", ",", "l"}], "}"}]}], "]"}]}]}], "d"]}], ",", 
   RowBox[{
    RowBox[{"A", "[", 
     RowBox[{"2", ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}]}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"A", "[", 
          RowBox[{"4", ",", 
           RowBox[{"{", "}"}]}], "]"}], " ", 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"i", ",", "l"}], "}"}], "]"}], " ", 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"A", "[", 
          RowBox[{"4", ",", 
           RowBox[{"{", "}"}]}], "]"}], " ", 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"i", ",", "k"}], "}"}], "]"}], " ", 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"A", "[", 
          RowBox[{"4", ",", 
           RowBox[{"{", "}"}]}], "]"}], " ", 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"k", ",", "l"}], "}"}], "]"}]}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"2", "+", "d"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"4", "+", "d"}], ")"}]}]]}], "+", 
     RowBox[{"\[CapitalKoppa]", "[", 
      RowBox[{"2", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}]}], "]"}], "+", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"4", "+", "d"}]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"A", "[", 
          RowBox[{"3", ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "l"}], "}"}]}], "]"}], " ", 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"A", "[", 
          RowBox[{"3", ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "k"}], "}"}]}], "]"}], " ", 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"i", ",", "l"}], "}"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"A", "[", 
          RowBox[{"3", ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "l"}], "}"}]}], "]"}], " ", 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"A", "[", 
          RowBox[{"3", ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "k"}], "}"}]}], "]"}], " ", 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"A", "[", 
          RowBox[{"3", ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "j"}], "}"}]}], "]"}], " ", 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"k", ",", "l"}], "}"}], "]"}]}], "+", 
        FractionBox[
         RowBox[{
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"4", ",", 
               RowBox[{"{", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"k", ",", "l"}], "}"}], "]"}]}], "+", 
            RowBox[{"d", " ", 
             RowBox[{"\[CapitalKoppa]", "[", 
              RowBox[{"3", ",", 
               RowBox[{"{", 
                RowBox[{"k", ",", "l"}], "}"}]}], "]"}]}]}], ")"}]}], "d"]}], 
       ")"}]}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7376371145547037`*^9, {3.737637255129918*^9, 
   3.737637277351898*^9}},ExpressionUUID->"35785cb6-2ae9-4622-884b-\
bbc7ef62df4a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Deftracefreetensor", "[", "ex", "]"}], "\[LeftDoubleBracket]", 
  RowBox[{"2", ",", "3", ",", "1", ",", "1"}], 
  "\[RightDoubleBracket]"}]], "Input",
 CellChangeTimes->{{3.737636061055756*^9, 3.737636102778657*^9}, {
  3.737636168153542*^9, 
  3.7376362056921663`*^9}},ExpressionUUID->"3d9c2deb-a98f-40a1-95e8-\
3ced7fa16166"],

Cell[BoxData[
 RowBox[{"A", "[", 
  RowBox[{"3", ",", 
   RowBox[{"{", 
    RowBox[{"k", ",", "l"}], "}"}]}], "]"}]], "Output",
 CellChangeTimes->{{3.737636068325892*^9, 3.737636103520895*^9}, {
  3.737636169712254*^9, 
  3.737636206395184*^9}},ExpressionUUID->"2b344329-d9b2-4bd3-9b3e-\
d2fc0c2f37a9"]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{
  3.7376353216253767`*^9},ExpressionUUID->"1d09e1ca-c60a-490a-a328-\
b13a5d20ddb3"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Deftracefreetensor1", "[", "ex_", "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "output", ",", "pos", ",", "counttensorindex", ",", "indicesoccurence", 
       ",", "list$factorswithpowers", ",", "factors", ",", "theirpowers", ",",
        "list$tensors", ",", "position$tensors", ",", "power$tensors", ",", 
       "allsingleindices", ",", "num$freeindices", ",", 
       "contractionreplacements", ",", "listdeltas", ",", 
       "tensor\[Delta]combinations", ",", "generalform", ",", "cvalues", ",", 
       
       RowBox[{"list", "=", 
        RowBox[{"{", "}"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"product", "=", "1"}], ",", "c", ",", "d"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"list$factorswithpowers", "=", 
       RowBox[{"FactorList", "[", "ex", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"factors", "=", 
       RowBox[{"list$factorswithpowers", "\[LeftDoubleBracket]", 
        RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"theirpowers", "=", 
       RowBox[{"list$factorswithpowers", "\[LeftDoubleBracket]", 
        RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", 
       StyleBox[
        RowBox[{
        "condition", " ", "for", " ", "powers", " ", "in", " ", "tensors"}],
        FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
      RowBox[{"list$tensors", "=", 
       RowBox[{"Extract", "[", 
        RowBox[{"factors", ",", 
         RowBox[{"Drop", "[", 
          RowBox[{
           RowBox[{"Complement", "[", 
            RowBox[{
             RowBox[{"Position", "[", 
              RowBox[{"factors", ",", "List"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"{", "0", "}"}], "}"}]}], "]"}], ",", "None", ",", 
           RowBox[{"-", "1"}]}], "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"position$tensors", "=", 
       RowBox[{"Drop", "[", 
        RowBox[{
         RowBox[{"Drop", "[", 
          RowBox[{
           RowBox[{"Complement", "[", 
            RowBox[{
             RowBox[{"Position", "[", 
              RowBox[{"factors", ",", "List"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"{", "0", "}"}], "}"}]}], "]"}], ",", "None", ",", 
           RowBox[{"-", "1"}]}], "]"}], ",", "None", ",", 
         RowBox[{"-", "1"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"power$tensors", "=", 
       RowBox[{"Extract", "[", 
        RowBox[{"theirpowers", ",", "position$tensors"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Max", "[", "power$tensors", "]"}], ">", "2"}], ",", 
        RowBox[{"output", "=", 
         RowBox[{"Print", "[", "\"\<\!\(\*
StyleBox[\"Please\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"check\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"the\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"exponents\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"on\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"tensors\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\".\",
FontColor->RGBColor[1, 0, 0]]\)\>\"", "]"}]}], ",", 
        RowBox[{
         RowBox[{"indicesoccurence", "=", 
          RowBox[{"Tally", "[", 
           RowBox[{"Flatten", "[", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"ConstantArray", "[", 
               RowBox[{
                RowBox[{
                "list$tensors", "\[LeftDoubleBracket]", "ii", 
                 "\[RightDoubleBracket]"}], ",", 
                RowBox[{
                "power$tensors", "\[LeftDoubleBracket]", "ii", 
                 "\[RightDoubleBracket]"}]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"ii", ",", 
                RowBox[{"1", 
                 RowBox[{"Length", "[", "list$tensors", "]"}]}]}], "}"}]}], 
             "]"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Max", "[", 
             RowBox[{"indicesoccurence", "\[LeftDoubleBracket]", 
              RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], "]"}], 
            ">", "2"}], ",", "\[IndentingNewLine]", 
           RowBox[{"output", "=", 
            RowBox[{"Print", "[", "\"\<\!\(\*
StyleBox[\"Please\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"check\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"the\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"repeated\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"indices\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\".\",
FontColor->RGBColor[1, 0, 0]]\)\>\"", "]"}]}], ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
             RowBox[{"allsingleindices", "=", 
              RowBox[{"Sort", "[", 
               RowBox[{
                RowBox[{"Extract", "[", 
                 RowBox[{"indicesoccurence", ",", 
                  RowBox[{"Drop", "[", 
                   RowBox[{
                    RowBox[{"Position", "[", 
                    RowBox[{"indicesoccurence", ",", "1"}], "]"}], ",", 
                    "None", ",", 
                    RowBox[{"-", "1"}]}], "]"}]}], "]"}], 
                "\[LeftDoubleBracket]", 
                RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], "]"}]}],
              ";", "\[IndentingNewLine]", 
             RowBox[{"num$freeindices", "=", 
              RowBox[{"Length", "[", "allsingleindices", "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"contractionreplacements", "=", 
              RowBox[{"Table", "[", 
               RowBox[{
                RowBox[{"list", "=", 
                 RowBox[{"Join", "[", 
                  RowBox[{"list", ",", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"allsingleindices", "\[LeftDoubleBracket]", 
                    RowBox[{"2", "ii"}], "\[RightDoubleBracket]"}], "\[Rule]", 
                    RowBox[{"allsingleindices", "\[LeftDoubleBracket]", 
                    RowBox[{
                    RowBox[{"2", "ii"}], "-", "1"}], 
                    "\[RightDoubleBracket]"}]}], "}"}]}], "]"}]}], ",", 
                RowBox[{"{", 
                 RowBox[{"ii", ",", 
                  RowBox[{
                   RowBox[{"Length", "[", "allsingleindices", "]"}], "/", 
                   "2"}], ",", "1", ",", 
                  RowBox[{"-", "1"}]}], "}"}]}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"listdeltas", "=", 
              RowBox[{"Table", "[", 
               RowBox[{
                RowBox[{"product", "=", 
                 RowBox[{"product", "*", 
                  RowBox[{"\[Delta]", "[", 
                   RowBox[{"Sort", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"allsingleindices", "\[LeftDoubleBracket]", 
                    RowBox[{"2", "ii"}], "\[RightDoubleBracket]"}], ",", 
                    RowBox[{"allsingleindices", "\[LeftDoubleBracket]", 
                    RowBox[{
                    RowBox[{"2", "ii"}], "-", "1"}], "\[RightDoubleBracket]"}]
                    }], "}"}], "]"}], "]"}]}]}], ",", 
                RowBox[{"{", 
                 RowBox[{"ii", ",", 
                  RowBox[{
                   RowBox[{"Length", "[", "allsingleindices", "]"}], "/", 
                   "2"}], ",", "1", ",", 
                  RowBox[{"-", "1"}]}], "}"}]}], "]"}]}], ";", 
             "\[IndentingNewLine]", "\[IndentingNewLine]", 
             RowBox[{"(*", 
              StyleBox[
               RowBox[{
               "list", " ", "of", " ", "tensors", " ", "formed", " ", "with", 
                " ", "free", " ", "indices", " ", "and", " ", "deltas"}],
               FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
             RowBox[{"tensor\[Delta]combinations", "=", 
              RowBox[{"Table", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"contractedtensor", "[", 
                   RowBox[{"Einstein", "[", 
                    RowBox[{"Expand", "[", 
                    RowBox[{
                    RowBox[{"sym", "[", "ex", "]"}], "/.", 
                    RowBox[{
                    "contractionreplacements", "\[LeftDoubleBracket]", "ii", 
                    "\[RightDoubleBracket]"}]}], "]"}], "]"}], "]"}], ")"}], 
                 RowBox[{
                 "listdeltas", "\[LeftDoubleBracket]", "ii", 
                  "\[RightDoubleBracket]"}]}], ",", 
                RowBox[{"{", 
                 RowBox[{"ii", ",", "1", ",", 
                  RowBox[{"Length", "[", "listdeltas", "]"}]}], "}"}]}], 
               "]"}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
            RowBox[{"(*", 
             RowBox[{"Join", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"contractedtensor", "[", 
                 RowBox[{"sym", "[", 
                  RowBox[{"Einstein", "[", 
                   RowBox[{"Expand", "[", "ex", "]"}], "]"}], "]"}], "]"}], 
                "}"}], ",", 
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"contractedtensor", "[", 
                    RowBox[{"Einstein", "[", 
                    RowBox[{"Expand", "[", 
                    RowBox[{
                    RowBox[{"sym", "[", "ex", "]"}], "/.", 
                    RowBox[{
                    "contractionreplacements", "\[LeftDoubleBracket]", "ii", 
                    "\[RightDoubleBracket]"}]}], "]"}], "]"}], "]"}], ")"}], 
                  RowBox[{
                  "listdeltas", "\[LeftDoubleBracket]", "ii", 
                   "\[RightDoubleBracket]"}]}], ",", 
                 RowBox[{"{", 
                  RowBox[{"ii", ",", "1", ",", 
                   RowBox[{"Length", "[", "listdeltas", "]"}]}], "}"}]}], 
                "]"}]}], "]"}], "*)"}], ";", "\[IndentingNewLine]", 
            "\[IndentingNewLine]", 
            RowBox[{"generalform", "=", 
             RowBox[{
              RowBox[{
               RowBox[{"contractedtensor", "[", 
                RowBox[{"sym", "[", 
                 RowBox[{"Einstein", "[", 
                  RowBox[{"Expand", "[", "ex", "]"}], "]"}], "]"}], "]"}], 
               "+", 
               RowBox[{"Apply", "[", 
                RowBox[{"Plus", ",", 
                 RowBox[{
                  RowBox[{"Table", "[", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"c", "[", 
                    RowBox[{"num$freeindices", ",", "ii"}], "]"}], 
                    RowBox[{"symwithoutfactor", "[", 
                    RowBox[{
                    "tensor\[Delta]combinations", "\[LeftDoubleBracket]", 
                    "ii", "\[RightDoubleBracket]"}], "]"}]}], ",", 
                    RowBox[{"{", 
                    RowBox[{"ii", ",", "1", ",", 
                    RowBox[{
                    "Length", "[", "tensor\[Delta]combinations", "]"}]}], 
                    "}"}]}], "]"}], "/.", 
                  RowBox[{
                   RowBox[{"c", "[", 
                    RowBox[{"num$freeindices", ",", "0"}], "]"}], "\[Rule]", 
                   "1"}]}]}], "]"}]}], "/.", 
              RowBox[{"Table", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"c", "[", 
                  RowBox[{"num$freeindices", ",", "k"}], "]"}], "\[Rule]", 
                 FractionBox[
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{"-", "1"}], ")"}], "k"], 
                  RowBox[{
                   UnderoverscriptBox["\[Product]", 
                    RowBox[{"j", "=", "0"}], 
                    RowBox[{"k", "-", "1"}]], 
                   RowBox[{"(", 
                    RowBox[{"d", "+", 
                    RowBox[{"2", "num$freeindices"}], "-", "4", "-", 
                    RowBox[{"2", "j"}]}], ")"}]}]]}], ",", 
                RowBox[{"{", 
                 RowBox[{"k", ",", "1", ",", 
                  FractionBox["num$freeindices", "2"]}], "}"}]}], "]"}]}]}], 
            ";", " ", 
            RowBox[{"(*", 
             StyleBox[
              RowBox[{
              "These", " ", "coefficients", " ", "can", " ", "be", " ", 
               "computed", " ", "separately", " ", "using", " ", "the", " ", 
               "function", " ", 
               RowBox[{"coeff$symtracefreetensor", "."}]}],
              FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
            "\[IndentingNewLine]", 
            RowBox[{"output", "=", "generalform"}], ";"}]}], 
          "\[IndentingNewLine]", "]"}], ";"}]}], "\[IndentingNewLine]", "]"}],
       ";", "\[IndentingNewLine]", "output"}]}], "\[IndentingNewLine]", 
    "]"}]}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Deftracefreetensor", "[", "ex_", "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"output", ",", "ex1"}], "}"}], ",", 
    RowBox[{
     RowBox[{"ex1", "=", 
      RowBox[{"Expand", "[", "ex", "]"}]}], ";", 
     RowBox[{"output", "=", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Head", "[", "ex1", "]"}], "===", " ", "Plus"}], ",", 
        RowBox[{"Apply", "[", 
         RowBox[{"Plus", ",", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"Deftracefreetensor1", "[", 
             RowBox[{
             "ex1", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}], 
             "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"ii", ",", "1", ",", 
              RowBox[{"Length", "[", "ex1", "]"}]}], "}"}]}], "]"}]}], "]"}], 
        ",", 
        RowBox[{"Deftracefreetensor1", "[", "ex1", "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", "output"}]}], "\[IndentingNewLine]", 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.737963078219451*^9, 3.7379630791278152`*^9}},
 ExpressionUUID -> "b4495409-e992-44d2-867e-9939e9c35b59"]
}, Closed]]
}, Open  ]]
},
WindowSize->{959, 613},
WindowMargins->{{35, Automatic}, {0, Automatic}},
Magnification:>1.25 Inherited,
FrontEndVersion->"11.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (September \
21, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 223, 4, 80, "Section"],
Cell[CellGroupData[{
Cell[828, 30, 166, 3, 54, "Subsection"],
Cell[997, 35, 26968, 683, 6510356, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[28002, 723, 171, 2, 43, "Subsection"],
Cell[28176, 727, 729, 20, 181622, "Input"],
Cell[CellGroupData[{
Cell[28930, 751, 838, 21, 148497, "Input"],
Cell[29771, 774, 1152, 31, 132310, "Output"]
}, Open  ]],
Cell[30938, 808, 6831, 174, 1328790, "Input"],
Cell[CellGroupData[{
Cell[37794, 986, 300, 6, 159593, "Input"],
Cell[38097, 994, 206, 4, 93126, "Output"],
Cell[38306, 1000, 1250, 39, 145452, "Output"]
}, Open  ]],
Cell[39571, 1042, 9925, 232, 1940633, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[49533, 1279, 275, 5, 74, "Subsection"],
Cell[CellGroupData[{
Cell[49833, 1288, 275, 8, 682162, "Input"],
Cell[50111, 1298, 482, 13, 818916, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[50630, 1316, 652, 21, 1270577, "Input"],
Cell[51285, 1339, 873, 26, 1328790, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[52195, 1370, 2216, 71, 3219166, "Input"],
Cell[54414, 1443, 221, 4, 776662, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[54672, 1452, 5050, 152, 7517931, "Input"],
Cell[59725, 1606, 298, 5, 776662, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[60084, 1618, 250, 6, 125, "Section"],
Cell[60337, 1626, 731, 21, 1506356, "Input"],
Cell[CellGroupData[{
Cell[61093, 1651, 840, 22, 1107600, "Input"],
Cell[61936, 1675, 1154, 32, 986810, "Output"]
}, Open  ]],
Cell[63105, 1710, 6881, 175, 10860445, "Input"],
Cell[69989, 1887, 10035, 233, 18276103, "Input"],
Cell[80027, 2122, 989, 25, 1197496, "Input"],
Cell[CellGroupData[{
Cell[81041, 2151, 746, 15, 692660, "Input"],
Cell[81790, 2168, 12686, 410, 13872335, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[94513, 2583, 2016, 51, 2191812, "Input"],
Cell[96532, 2636, 837, 12, 692660, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[97406, 2653, 1102, 30, 1786382, "Input"],
Cell[98511, 2685, 486, 13, 958165, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[99046, 2704, 229, 4, 80, "Title"],
Cell[CellGroupData[{
Cell[99300, 2712, 186, 3, 43, "Subsubsection"],
Cell[99489, 2717, 18496, 431, 3204971, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[118022, 3153, 315, 5, 34, "Subsubsection"],
Cell[118340, 3160, 17085, 387, 139831, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[135462, 3552, 159, 3, 34, "Subsubsection"],
Cell[CellGroupData[{
Cell[135646, 3559, 5291, 154, 538772, "Input"],
Cell[CellGroupData[{
Cell[140962, 3717, 1053, 15, 44727, "Print"],
Cell[142018, 3734, 915, 13, 44727, "Print"]
}, Open  ]],
Cell[142948, 3750, 3488, 107, 302035, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[146473, 3862, 5591, 158, 703856, "Input"],
Cell[CellGroupData[{
Cell[152089, 4024, 1143, 16, 44727, "Print"],
Cell[153235, 4042, 1005, 14, 44727, "Print"]
}, Open  ]],
Cell[154255, 4059, 60017, 1642, 481458, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[214309, 5706, 274, 5, 59570, "Input"],
Cell[214586, 5713, 15255, 469, 922822, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[229878, 6187, 494, 12, 59570, "Input"],
Cell[230375, 6201, 246, 5, 59570, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[230658, 6211, 412, 8, 59570, "Input"],
Cell[231073, 6221, 609, 18, 59570, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[231719, 6244, 1008, 26, 103000, "Input"],
Cell[232730, 6272, 2339, 75, 143543, "Output"]
}, Open  ]],
Cell[235084, 6350, 500, 15, 59570, "Input"],
Cell[235587, 6367, 386, 8, 59570, "Input"],
Cell[235976, 6377, 1838, 60, 348341, "Input"],
Cell[237817, 6439, 3823, 117, 575872, "Input"],
Cell[241643, 6558, 827, 23, 184922, "Input"],
Cell[242473, 6583, 92, 1, 59570, "Input"],
Cell[242568, 6586, 296, 8, 59570, "Input"],
Cell[242867, 6596, 198, 4, 59570, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[243102, 6605, 392, 5, 62, "Section"],
Cell[243497, 6612, 6794, 221, 577, "Input"],
Cell[250294, 6835, 1075, 28, 120, "Input"],
Cell[CellGroupData[{
Cell[251394, 6867, 93, 1, 54, "Subsection"],
Cell[CellGroupData[{
Cell[251512, 6872, 3366, 84, 405, "Input"],
Cell[254881, 6958, 1031, 26, 72, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[255949, 6989, 3282, 93, 473, "Input"],
Cell[259234, 7084, 714, 22, 73, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[259985, 7111, 5258, 150, 638, "Input"],
Cell[265246, 7263, 1148, 35, 73, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[266431, 7303, 5582, 153, 662, "Input"],
Cell[272016, 7458, 456, 12, 73, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[272521, 7476, 144, 2, 43, "Subsection"],
Cell[CellGroupData[{
Cell[272690, 7482, 3368, 84, 430, "Input"],
Cell[276061, 7568, 1055, 26, 58, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[277153, 7599, 4342, 120, 473, "Input"],
Cell[281498, 7721, 1588, 46, 133, "Output"]
}, Open  ]],
Cell[283101, 7770, 167, 4, 48, "Input"],
Cell[CellGroupData[{
Cell[283293, 7778, 3031, 88, 245, "Input"],
Cell[286327, 7868, 1286, 43, 122, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[287650, 7916, 5257, 149, 751, "Input"],
Cell[292910, 8067, 1172, 35, 73, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[294119, 8107, 5581, 152, 865, "Input"],
Cell[299703, 8261, 480, 12, 73, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[300232, 8279, 185, 3, 43, "Subsection"],
Cell[300420, 8284, 208, 5, 39, "Input"],
Cell[CellGroupData[{
Cell[300653, 8293, 2144, 60, 223, "Input"],
Cell[302800, 8355, 205, 4, 39, "Output"]
}, Open  ]],
Cell[303020, 8362, 964, 30, 88, "Input"],
Cell[CellGroupData[{
Cell[304009, 8396, 687, 20, 75, "Input"],
Cell[304699, 8418, 291, 8, 40, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[305027, 8431, 709, 21, 75, "Input"],
Cell[305739, 8454, 314, 8, 40, "Output"]
}, Open  ]],
Cell[306068, 8465, 2978, 81, 200, "Input"],
Cell[309049, 8548, 1036, 30, 88, "Input"],
Cell[CellGroupData[{
Cell[310110, 8582, 842, 22, 75, "Input"],
Cell[310955, 8606, 421, 11, 40, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[311413, 8622, 743, 21, 75, "Input"],
Cell[312159, 8645, 163, 4, 39, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[312359, 8654, 708, 20, 75, "Input"],
Cell[313070, 8676, 290, 8, 40, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[313397, 8689, 165, 3, 43, "Subsubsection"],
Cell[CellGroupData[{
Cell[313587, 8696, 4623, 141, 390, "Input"],
Cell[318213, 8839, 277, 4, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[318527, 8848, 4384, 129, 463, "Input"],
Cell[322914, 8979, 504, 13, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[323455, 8997, 1975, 63, 230, "Input"],
Cell[325433, 9062, 437, 11, 48, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[325919, 9079, 214, 4, 34, "Subsubsection"],
Cell[326136, 9085, 3235, 97, 243, "Input"],
Cell[CellGroupData[{
Cell[329396, 9186, 10122, 273, 859, "Input"],
Cell[339521, 9461, 306, 8, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[339864, 9474, 5522, 151, 611, "Input"],
Cell[345389, 9627, 518, 13, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[345944, 9645, 3708, 112, 450, "Input"],
Cell[349655, 9759, 385, 10, 48, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[350089, 9775, 264, 4, 34, "Subsubsection"],
Cell[350356, 9781, 4469, 132, 302, "Input"],
Cell[CellGroupData[{
Cell[354850, 9917, 10086, 272, 859, "Input"],
Cell[364939, 10191, 307, 8, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[365283, 10204, 5574, 152, 611, "Input"],
Cell[370860, 10358, 516, 13, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[371413, 10376, 5551, 163, 540, "Input"],
Cell[376967, 10541, 794, 24, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[377798, 10570, 4280, 124, 403, "Input"],
Cell[382081, 10696, 634, 17, 53, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[382788, 10721, 196, 3, 80, "Section"],
Cell[382987, 10726, 323, 8, 93, "Input"],
Cell[CellGroupData[{
Cell[383335, 10738, 341, 9, 147, "Input"],
Cell[383679, 10749, 513, 16, 250, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[384229, 10770, 333, 9, 147, "Input"],
Cell[384565, 10781, 659, 21, 250, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[385261, 10807, 743, 17, 171, "Input"],
Cell[386007, 10826, 509, 15, 171, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[386553, 10846, 468, 13, 171, "Input"],
Cell[387024, 10861, 391, 12, 171, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[387452, 10878, 470, 13, 171, "Input"],
Cell[387925, 10893, 391, 12, 200, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[388353, 10910, 1367, 41, 372, "Input"],
Cell[389723, 10953, 574, 17, 345, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[390334, 10975, 819, 25, 326, "Input"],
Cell[391156, 11002, 267, 7, 327, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[391460, 11014, 933, 28, 326, "Input"],
Cell[392396, 11044, 710, 22, 327, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[393143, 11071, 1574, 48, 741, "Input"],
Cell[394720, 11121, 884, 25, 206, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[395641, 11151, 3891, 121, 1297, "Input"],
Cell[399535, 11274, 175, 2, 206, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[399747, 11281, 2688, 78, 1243, "Input"],
Cell[402438, 11361, 464, 13, 503, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[402951, 11380, 168, 3, 62, "Section"],
Cell[403122, 11385, 886, 24, 308, "Input"],
Cell[404011, 11411, 4254, 91, 946, "Input"],
Cell[408268, 11504, 5791, 125, 1583, "Input"],
Cell[414062, 11631, 628, 19, 182, "Input"],
Cell[414693, 11652, 303, 9, 182, "Input"],
Cell[414999, 11663, 229, 4, 182, "Input"],
Cell[415231, 11669, 623, 19, 182, "Input"],
Cell[415857, 11690, 573, 17, 326, "Input"],
Cell[416433, 11709, 1259, 29, 741, "Input"],
Cell[417695, 11740, 13962, 348, 6546, "Input"],
Cell[CellGroupData[{
Cell[431682, 12092, 195, 4, 863, "Input"],
Cell[431880, 12098, 487, 12, 1656, "Output"]
}, Open  ]],
Cell[432382, 12113, 182, 4, 863, "Input"],
Cell[432567, 12119, 716, 20, 863, "Input"],
Cell[CellGroupData[{
Cell[433308, 12143, 595, 18, 863, "Input"],
Cell[433906, 12163, 466, 15, 977, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[434409, 12183, 470, 8, 863, "Input"],
Cell[434882, 12193, 7655, 223, 8966, "Output"]
}, Open  ]],
Cell[442552, 12419, 962, 32, 2213, "Input"],
Cell[CellGroupData[{
Cell[443539, 12455, 226, 5, 863, "Input"],
Cell[443768, 12462, 646, 20, 977, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[444451, 12487, 580, 16, 2171, "Input"],
Cell[445034, 12505, 1317, 41, 2583, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[446388, 12551, 1676, 48, 3481, "Input"],
Cell[448067, 12601, 7732, 220, 10552, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[455836, 12826, 226, 4, 863, "Input"],
Cell[456065, 12832, 3610, 109, 5460, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[459712, 12946, 229, 4, 863, "Input"],
Cell[459944, 12952, 2297, 71, 3793, "Output"]
}, Open  ]],
Cell[462256, 13026, 6741, 219, 16601, "Input"],
Cell[CellGroupData[{
Cell[469022, 13249, 599, 10, 863, "Input"],
Cell[469624, 13261, 1368, 35, 3163, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[471029, 13301, 232, 5, 863, "Input"],
Cell[471264, 13308, 359, 11, 977, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[471660, 13324, 211, 5, 863, "Input"],
Cell[471874, 13331, 224, 6, 977, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[472135, 13342, 284, 5, 863, "Input"],
Cell[472422, 13349, 129, 2, 977, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[472588, 13356, 617, 15, 863, "Input"],
Cell[473208, 13373, 5897, 175, 6825, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[479142, 13553, 183, 3, 1341, "Input"],
Cell[479328, 13558, 152, 2, 1341, "Output"]
}, Open  ]],
Cell[479495, 13563, 451, 11, 1341, "Input"],
Cell[CellGroupData[{
Cell[479971, 13578, 554, 15, 1341, "Input"],
Cell[480528, 13595, 8738, 225, 6702, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[489303, 13825, 403, 7, 1341, "Input"],
Cell[489709, 13834, 627, 15, 1390, "Output"]
}, Open  ]],
Cell[490351, 13852, 3767, 66, 2862, "Input"],
Cell[494121, 13920, 3740, 66, 2213, "Input"],
Cell[CellGroupData[{
Cell[497886, 13990, 785, 20, 1533, "Input"],
Cell[498674, 14012, 434, 11, 977, "Output"],
Cell[499111, 14025, 377, 10, 977, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[499525, 14040, 1281, 29, 4197, "Input"],
Cell[500809, 14071, 365, 8, 977, "Output"],
Cell[501177, 14081, 301, 6, 977, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[501515, 14092, 322, 7, 1533, "Input"],
Cell[501840, 14101, 207, 5, 977, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[502084, 14111, 272, 6, 863, "Input"],
Cell[502359, 14119, 318, 9, 977, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[502714, 14133, 504, 12, 1533, "Input"],
Cell[503221, 14147, 232, 5, 977, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[503490, 14157, 649, 11, 863, "Input"],
Cell[504142, 14170, 880, 15, 977, "Output"]
}, Open  ]],
Cell[505037, 14188, 321, 7, 863, "Input"],
Cell[505361, 14197, 324, 7, 863, "Input"],
Cell[CellGroupData[{
Cell[505710, 14208, 244, 4, 863, "Input"],
Cell[505957, 14214, 590, 14, 4435, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[506584, 14233, 356, 9, 2096, "Input"],
Cell[506943, 14244, 250, 6, 2387, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[507230, 14255, 563, 10, 2096, "Input"],
Cell[507796, 14267, 1537, 42, 1656, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[509370, 14314, 336, 8, 863, "Input"],
Cell[509709, 14324, 384, 9, 608, "Message"],
Cell[510096, 14335, 379, 11, 977, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[510512, 14351, 434, 12, 863, "Input"],
Cell[510949, 14365, 1102, 36, 1656, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[512088, 14406, 138, 3, 863, "Input"],
Cell[512229, 14411, 278, 7, 977, "Output"]
}, Open  ]],
Cell[512522, 14421, 156, 3, 863, "Input"],
Cell[512681, 14426, 377, 11, 863, "Input"],
Cell[CellGroupData[{
Cell[513083, 14441, 225, 4, 863, "Input"],
Cell[513311, 14447, 553, 18, 977, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[513901, 14470, 220, 4, 863, "Input"],
Cell[514124, 14476, 699, 18, 1656, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[514860, 14499, 322, 6, 863, "Input"],
Cell[515185, 14507, 7342, 229, 12596, "Output"]
}, Open  ]],
Cell[522542, 14739, 20648, 406, 51216, "Input"],
Cell[543193, 15147, 203, 5, 863, "Input"],
Cell[543399, 15154, 160, 3, 863, "Input"],
Cell[CellGroupData[{
Cell[543584, 15161, 273, 6, 863, "Input"],
Cell[543860, 15169, 583, 13, 1656, "Output"]
}, Open  ]],
Cell[544458, 15185, 17682, 425, 48570, "Input"],
Cell[CellGroupData[{
Cell[562165, 15614, 1322, 28, 2171, "Input"],
Cell[563490, 15644, 7411, 219, 9618, "Output"]
}, Open  ]],
Cell[570916, 15866, 697, 22, 863, "Input"],
Cell[571616, 15890, 954, 24, 2171, "Input"],
Cell[572573, 15916, 377, 11, 2171, "Input"],
Cell[572953, 15929, 302, 6, 863, "Input"],
Cell[573258, 15937, 498, 11, 1533, "Input"],
Cell[573759, 15950, 401, 10, 1533, "Input"],
Cell[CellGroupData[{
Cell[574185, 15964, 524, 12, 1533, "Input"],
Cell[574712, 15978, 5473, 165, 10383, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[580222, 16148, 712, 16, 1533, "Input"],
Cell[580937, 16166, 3756, 112, 5460, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[584730, 16283, 516, 12, 863, "Input"],
Cell[585249, 16297, 7882, 241, 14385, "Output"]
}, Open  ]],
Cell[593146, 16541, 516, 13, 2213, "Input"],
Cell[CellGroupData[{
Cell[593687, 16558, 357, 7, 863, "Input"],
Cell[594047, 16567, 4854, 159, 7162, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[598938, 16731, 2979, 95, 4320, "Input"],
Cell[601920, 16828, 1048, 33, 1656, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[603005, 16866, 347, 7, 863, "Input"],
Cell[603355, 16875, 8591, 254, 18270, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[611983, 17134, 124, 2, 863, "Input"],
Cell[612110, 17138, 131, 2, 977, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[612278, 17145, 486, 14, 863, "Input"],
Cell[612767, 17161, 7775, 235, 14385, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[620579, 17401, 404, 11, 863, "Input"],
Cell[620986, 17414, 351, 10, 977, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[621374, 17429, 243, 4, 863, "Input"],
Cell[621620, 17435, 388, 9, 608, "Message"],
Cell[622011, 17446, 470, 12, 977, "Output"]
}, Open  ]],
Cell[622496, 17461, 175, 3, 863, "Input"],
Cell[CellGroupData[{
Cell[622696, 17468, 272, 7, 863, "Input"],
Cell[622971, 17477, 7843, 236, 14385, "Output"]
}, Open  ]],
Cell[630829, 17716, 199, 4, 863, "Input"],
Cell[631031, 17722, 978, 26, 2213, "Input"],
Cell[CellGroupData[{
Cell[632034, 17752, 158, 2, 863, "Input"],
Cell[632195, 17756, 18507, 546, 35860, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[650739, 18307, 824, 21, 1533, "Input"],
Cell[651566, 18330, 21305, 646, 41181, "Output"]
}, Open  ]],
Cell[672886, 18979, 175, 3, 863, "Input"],
Cell[673064, 18984, 1527, 46, 1533, "Input"],
Cell[674594, 19032, 177, 3, 863, "Input"],
Cell[674774, 19037, 152, 3, 863, "Input"],
Cell[CellGroupData[{
Cell[674951, 19044, 611, 15, 863, "Input"],
Cell[675565, 19061, 7309, 229, 12596, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[682911, 19295, 238, 7, 863, "Input"],
Cell[683152, 19304, 7281, 226, 12596, "Output"]
}, Open  ]],
Cell[690448, 19533, 451, 12, 863, "Input"],
Cell[CellGroupData[{
Cell[690924, 19549, 120, 1, 863, "Input"],
Cell[691047, 19552, 132, 3, 977, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[691216, 19560, 380, 9, 863, "Input"],
Cell[691599, 19571, 727, 23, 1588, "Output"]
}, Open  ]],
Cell[692341, 19597, 977, 25, 2213, "Input"],
Cell[CellGroupData[{
Cell[693343, 19626, 222, 5, 863, "Input"],
Cell[693568, 19633, 460, 10, 608, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[694065, 19648, 599, 15, 863, "Input"],
Cell[694667, 19665, 7473, 233, 13577, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[702177, 19903, 362, 8, 863, "Input"],
Cell[702542, 19913, 302, 8, 977, "Output"]
}, Open  ]],
Cell[702859, 19924, 130, 3, 863, "Input"],
Cell[702992, 19929, 14846, 352, 45071, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)

