(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.4' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    930866,      22961]
NotebookOptionsPosition[    906544,      22580]
NotebookOutlinePosition[    906898,      22596]
CellTagsIndexPosition[    906855,      22593]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Setting up required functions for computing production terms", "Section",
 CellChangeTimes->{{3.678793324410656*^9, 
  3.678793347451144*^9}},ExpressionUUID->"c913b4d3-eb50-4a2e-8a11-\
0620dac11554"],

Cell["\<\
We start with some functions to be used in the collision integral.\
\>", "Text",
 CellChangeTimes->{{3.5379862279857197`*^9, 3.53798625940003*^9}},
 FontColor->RGBColor[1, 0, 0],
 Background->RGBColor[
  1, 0.85, 0.85],ExpressionUUID->"f37fff76-5627-411b-9307-9424dff87b7e"],

Cell[CellGroupData[{

Cell["Einstein Convention", "Subsection",
 CellChangeTimes->{{3.73727221835075*^9, 
  3.737272227214916*^9}},ExpressionUUID->"c359f6e3-11d6-4de6-a1f9-\
fb7e47140308"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "ii", ",", "jj", ",", "ex", ",", "ex0", ",", "ex1", ",", "ex2", ",", 
    "idx1", ",", "idx2", ",", "rule", ",", "\[Delta]", ",", "pos", ",", "idx",
     ",", " ", "double", ",", "sidx", ",", "dummy", ",", "xx", ",", 
    "\[Delta]$", ",", "\[Delta]", ",", "d"}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"StandardizeIdx", "[", 
    RowBox[{"ex_", ",", "flag_"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "ex0", ",", "ex1", ",", "pos", ",", "idx", ",", "double", ",", "dummy", 
       ",", 
       RowBox[{"sidx", "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "s0", ",", "s1", ",", "s2", ",", "s3", ",", "s4", ",", "s5", ",", 
            "s6", ",", "s7", ",", "s8", ",", "s9"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
           "p0", ",", "p1", ",", "p2", ",", "p3", ",", "p4", ",", "p5", ",", 
            "p6", ",", "p7", ",", "p8", ",", "p9"}], "}"}]}], "}"}]}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"ex0", "=", 
       RowBox[{"dummy", " ", "ex"}]}], ";", "    ", 
      RowBox[{"(*", 
       StyleBox[
        RowBox[{
        "makes", " ", "sure", " ", "expression", " ", "is", " ", "a", " ", 
         "product"}],
        FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"pos", "=", 
       RowBox[{"Drop", "[", 
        RowBox[{
         RowBox[{"Position", "[", 
          RowBox[{"ex0", ",", "List"}], "]"}], ",", "None", ",", 
         RowBox[{"-", "1"}]}], "]"}]}], ";", "     ", 
      RowBox[{"(*", 
       StyleBox[
        RowBox[{
        "pos", " ", "identifies", " ", "all", " ", "lists", " ", "of", " ", 
         "indices", " ", "in", " ", "the", " ", "expression"}],
        FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"idx", "=", 
       RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Do", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"idx", "=", 
          RowBox[{"Join", "[", 
           RowBox[{"idx", ",", 
            RowBox[{"Extract", "[", 
             RowBox[{"ex0", ",", 
              RowBox[{
              "pos", "\[LeftDoubleBracket]", "ii", 
               "\[RightDoubleBracket]"}]}], "]"}]}], "]"}]}], ";", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Length", "[", 
             RowBox[{
             "pos", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}], 
             "]"}], "\[Equal]", "3"}], ",", 
           RowBox[{"idx", "=", 
            RowBox[{"Join", "[", 
             RowBox[{"idx", ",", 
              RowBox[{"Extract", "[", 
               RowBox[{"ex0", ",", 
                RowBox[{
                "pos", "\[LeftDoubleBracket]", "ii", 
                 "\[RightDoubleBracket]"}]}], "]"}]}], "]"}]}]}], "]"}]}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"ii", ",", "1", ",", 
          RowBox[{"Length", "[", "pos", "]"}]}], "}"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", 
       StyleBox[
        RowBox[{
        "idx", " ", "contains", " ", "all", " ", "the", " ", "indices", " ", 
         "in", " ", "the", " ", "expression"}],
        FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"ex1", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
         "ex0", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}], ",", 
         
         RowBox[{"{", 
          RowBox[{"ii", ",", "1", ",", 
           RowBox[{"Length", "[", "ex0", "]"}]}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"double", "=", 
       RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Do", "[", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Count", "[", 
             RowBox[{"idx", ",", 
              RowBox[{
              "idx", "\[LeftDoubleBracket]", "ii", 
               "\[RightDoubleBracket]"}]}], "]"}], "\[Equal]", "2"}], "&&", 
           RowBox[{"!", 
            RowBox[{"MemberQ", "[", 
             RowBox[{"double", ",", 
              RowBox[{
              "idx", "\[LeftDoubleBracket]", "ii", 
               "\[RightDoubleBracket]"}]}], "]"}]}]}], ",", 
          RowBox[{"double", "=", 
           RowBox[{"Join", "[", 
            RowBox[{"double", ",", 
             RowBox[{"{", 
              RowBox[{
              "idx", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}], 
              "}"}]}], "]"}]}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"ii", ",", "1", ",", 
          RowBox[{"Length", "[", "idx", "]"}]}], "}"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", 
       StyleBox[
        RowBox[{
        "double", " ", "contains", " ", "all", " ", "the", " ", "double", " ",
          "indices"}],
        FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
      RowBox[{"Do", "[", 
       RowBox[{
        RowBox[{"ex1", "=", 
         RowBox[{"ReplacePart", "[", 
          RowBox[{"ex1", ",", 
           RowBox[{
            RowBox[{"Position", "[", 
             RowBox[{"ex1", ",", 
              RowBox[{
              "double", "\[LeftDoubleBracket]", "ii", 
               "\[RightDoubleBracket]"}]}], "]"}], "\[Rule]", 
            RowBox[{"sidx", "\[LeftDoubleBracket]", 
             RowBox[{"flag", ",", "ii"}], "\[RightDoubleBracket]"}]}]}], 
          "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"ii", ",", "1", ",", 
          RowBox[{"Length", "[", "double", "]"}]}], "}"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Do", "[", 
       RowBox[{
        RowBox[{"ex1", "=", 
         RowBox[{"ReplacePart", "[", 
          RowBox[{"ex1", ",", 
           RowBox[{
            RowBox[{
            "pos", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}], 
            "\[Rule]", 
            RowBox[{"Sort", "[", 
             RowBox[{"Extract", "[", 
              RowBox[{"ex1", ",", 
               RowBox[{
               "pos", "\[LeftDoubleBracket]", "ii", 
                "\[RightDoubleBracket]"}]}], "]"}], "]"}]}]}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"ii", ",", "1", ",", 
          RowBox[{"Length", "[", "pos", "]"}]}], "}"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Apply", "[", 
        RowBox[{"Times", ",", "ex1"}], "]"}], "/.", 
       RowBox[{"{", 
        RowBox[{"dummy", "\[Rule]", "1"}], "}"}]}]}]}], "\[IndentingNewLine]",
     "]"}]}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Einstein1", "[", "ex_", "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "ex0", ",", "ex1", ",", "ex2", ",", "idx1", ",", "idx2", ",", "rule", 
       ",", "dummy"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"ex", "\[Equal]", "0"}], ",", 
        RowBox[{"Return", "[", "ex", "]"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"ex0", "=", 
       RowBox[{"dummy", " ", "ex"}]}], ";", "  ", 
      RowBox[{"(*", 
       StyleBox[
        RowBox[{
        "makes", " ", "sure", " ", "expression", " ", "is", " ", "a", " ", 
         "product"}],
        FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"ex0", "=", 
       RowBox[{"Flatten", "[", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Head", "[", 
               RowBox[{
               "ex0", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}],
                "]"}], "===", "Power"}], "&&", 
             RowBox[{
              RowBox[{"Length", "[", 
               RowBox[{"Position", "[", 
                RowBox[{
                 RowBox[{
                 "ex0", "\[LeftDoubleBracket]", "ii", 
                  "\[RightDoubleBracket]"}], ",", "List"}], "]"}], "]"}], ">",
               "0"}]}], ",", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"ex0", "\[LeftDoubleBracket]", 
               RowBox[{"ii", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
              RowBox[{"{", 
               RowBox[{"jj", ",", "1", ",", 
                RowBox[{"ex0", "\[LeftDoubleBracket]", 
                 RowBox[{"ii", ",", "2"}], "\[RightDoubleBracket]"}]}], 
               "}"}]}], "]"}], ",", 
            RowBox[{
            "ex0", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}]}], 
           "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"ii", ",", "1", ",", 
            RowBox[{"Length", "[", "ex0", "]"}]}], "}"}]}], "]"}], "]"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"(*", 
       StyleBox[
        RowBox[{
        "makes", " ", "sure", " ", "expression", " ", "is", " ", "a", " ", 
         "product"}],
        FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"ex1", "=", 
       RowBox[{"Extract", "[", 
        RowBox[{"ex0", ",", 
         RowBox[{"Position", "[", 
          RowBox[{"ex0", ",", 
           RowBox[{"\[Delta]", "[", "_", "]"}]}], "]"}]}], "]"}]}], ";", 
      "   ", 
      RowBox[{"(*", 
       StyleBox[
        RowBox[{
        "list", " ", "all", " ", "\[Delta]", " ", "expressions", " ", "and", 
         " ", "corresponding", " ", "indices"}],
        FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
      RowBox[{"idx1", "=", 
       RowBox[{"Extract", "[", 
        RowBox[{"ex1", ",", 
         RowBox[{"Drop", "[", 
          RowBox[{
           RowBox[{"Drop", "[", 
            RowBox[{
             RowBox[{"Position", "[", 
              RowBox[{"ex1", ",", "List"}], "]"}], ",", "None", ",", 
             RowBox[{"-", "1"}]}], "]"}], ",", "1"}], "]"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"ex2", "=", 
       RowBox[{"Delete", "[", 
        RowBox[{"ex0", ",", 
         RowBox[{"Position", "[", 
          RowBox[{"ex0", ",", 
           RowBox[{"\[Delta]", "[", "_", "]"}]}], "]"}]}], "]"}]}], ";", 
      "    ", 
      RowBox[{"(*", 
       StyleBox[
        RowBox[{
        "list", " ", "expressions", " ", "without", " ", "\[Delta]", " ", 
         "and", " ", "corresponding", " ", "indices"}],
        FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
      RowBox[{"idx2", "=", 
       RowBox[{"Flatten", "[", 
        RowBox[{"Extract", "[", 
         RowBox[{"ex2", ",", 
          RowBox[{"Drop", "[", 
           RowBox[{
            RowBox[{"Drop", "[", 
             RowBox[{
              RowBox[{"Position", "[", 
               RowBox[{"ex2", ",", "List"}], "]"}], ",", "None", ",", 
              RowBox[{"-", "1"}]}], "]"}], ",", "1"}], "]"}]}], "]"}], 
        "]"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"Do", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"rule", "=", 
          RowBox[{"{", "}"}]}], ";", "     ", 
         RowBox[{"(*", 
          StyleBox[
           RowBox[{
           "extract", " ", "of", " ", "index", " ", "replacement", " ", 
            "rule"}],
           FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Count", "[", 
             RowBox[{
              RowBox[{"Join", "[", 
               RowBox[{"idx2", ",", 
                RowBox[{"Flatten", "[", 
                 RowBox[{"Delete", "[", 
                  RowBox[{"idx1", ",", 
                   RowBox[{"{", "ii", "}"}]}], "]"}], "]"}]}], "]"}], ",", 
              RowBox[{"idx1", "\[LeftDoubleBracket]", 
               RowBox[{"ii", ",", "1"}], "\[RightDoubleBracket]"}]}], "]"}], 
            "\[Equal]", "1"}], ",", 
           RowBox[{
            RowBox[{"rule", "=", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"idx1", "\[LeftDoubleBracket]", 
                RowBox[{"ii", ",", "1"}], "\[RightDoubleBracket]"}], "->", 
               RowBox[{"idx1", "\[LeftDoubleBracket]", 
                RowBox[{"ii", ",", "2"}], "\[RightDoubleBracket]"}]}], 
              "}"}]}], ";"}], "\[IndentingNewLine]", ",", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Count", "[", 
               RowBox[{
                RowBox[{"Join", "[", 
                 RowBox[{"idx2", ",", 
                  RowBox[{"Flatten", "[", 
                   RowBox[{"Delete", "[", 
                    RowBox[{"idx1", ",", 
                    RowBox[{"{", "ii", "}"}]}], "]"}], "]"}]}], "]"}], ",", 
                RowBox[{"idx1", "\[LeftDoubleBracket]", 
                 RowBox[{"ii", ",", "2"}], "\[RightDoubleBracket]"}]}], "]"}],
               "\[Equal]", "1"}], ",", 
             RowBox[{
              RowBox[{"rule", "=", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"idx1", "\[LeftDoubleBracket]", 
                  RowBox[{"ii", ",", "2"}], "\[RightDoubleBracket]"}], "->", 
                 RowBox[{"idx1", "\[LeftDoubleBracket]", 
                  RowBox[{"ii", ",", "1"}], "\[RightDoubleBracket]"}]}], 
                "}"}]}], ";"}]}], "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
         "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Length", "[", "rule", "]"}], "\[Equal]", "1"}], ",", 
           "     ", 
           RowBox[{"(*", 
            StyleBox[
             RowBox[{"apply", " ", "index", " ", "replacement", " ", "rule"}],
             
             FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"ex1", "=", 
             RowBox[{
              RowBox[{"ReplacePart", "[", 
               RowBox[{"ex1", ",", 
                RowBox[{
                 RowBox[{"{", "ii", "}"}], "\[Rule]", "1"}]}], "]"}], "/.", 
              "rule"}]}], ";", "\[IndentingNewLine]", 
            RowBox[{"ex2", "=", 
             RowBox[{"ex2", "/.", "rule"}]}], ";", "\[IndentingNewLine]", 
            RowBox[{"idx1", "=", 
             RowBox[{
              RowBox[{"ReplacePart", "[", 
               RowBox[{"idx1", ",", 
                RowBox[{
                 RowBox[{"{", "ii", "}"}], "\[Rule]", 
                 RowBox[{"{", 
                  RowBox[{"0", ",", 
                   RowBox[{"-", "1"}]}], "}"}]}]}], "]"}], "/.", "rule"}]}], 
            ";", "\[IndentingNewLine]", 
            RowBox[{"idx2", "=", 
             RowBox[{"idx2", "/.", "rule"}]}], ";"}]}], "\[IndentingNewLine]",
           "]"}], ";"}], "\[IndentingNewLine]", ",", 
        RowBox[{"{", 
         RowBox[{"ii", ",", "1", ",", 
          RowBox[{"Length", "[", "idx1", "]"}]}], "}"}]}], "]"}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"Do", "[", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Length", "[", 
            RowBox[{
            "idx1", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}], 
            "]"}], ">", "0"}], ",", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"idx1", "\[LeftDoubleBracket]", 
              RowBox[{"ii", ",", "1"}], "\[RightDoubleBracket]"}], "\[Equal]", 
             RowBox[{"idx1", "\[LeftDoubleBracket]", 
              RowBox[{"ii", ",", "2"}], "\[RightDoubleBracket]"}]}], ",", 
            RowBox[{"ex1", "=", 
             RowBox[{"ReplacePart", "[", 
              RowBox[{"ex1", ",", 
               RowBox[{
                RowBox[{"{", "ii", "}"}], "\[Rule]", "d"}]}], "]"}]}]}], 
           "]"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"ii", ",", "1", ",", 
          RowBox[{"Length", "[", "idx1", "]"}]}], "}"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       StyleBox[
        RowBox[{
         RowBox[{
         "d", " ", "is", " ", "dimesnion", " ", "of", " ", "the", " ", 
          "problem"}], ",", " ", 
         RowBox[{"i", ".", "e", "."}], ",", " ", 
         RowBox[{
          SubscriptBox[
           StyleBox["\[Delta]",
            FontColor->RGBColor[1, 0, 0]], "ii"], "=", "d"}]}],
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[" ",
        FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"StandardizeIdx", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Apply", "[", 
          RowBox[{"Times", ",", 
           RowBox[{"Join", "[", 
            RowBox[{"ex1", ",", "ex2"}], "]"}]}], "]"}], "/.", 
         RowBox[{"{", 
          RowBox[{"dummy", "\[Rule]", "1"}], "}"}]}], ",", "1"}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Einstein", "[", "ex_", "]"}], ":=", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Head", "[", "ex", "]"}], "===", " ", "Plus"}], ",", 
     RowBox[{"Apply", "[", 
      RowBox[{"Plus", ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Einstein1", "[", 
          RowBox[{
          "ex", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}], 
          "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"ii", ",", "1", ",", 
           RowBox[{"Length", "[", "ex", "]"}]}], "}"}]}], "]"}]}], "]"}], ",", 
     RowBox[{"Einstein1", "[", "ex", "]"}]}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Delta]$", "[", 
    RowBox[{"ii_", ",", "jj_"}], "]"}], "=", 
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"ii", ",", "jj"}], "}"}], "]"}]}], ";"}], "\[IndentingNewLine]", 

 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"DeltaTensor", "[", "idx_", "]"}], ":=", 
    RowBox[{"Block", "[", 
     RowBox[{
      RowBox[{"{", "xx", "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"OddQ", "[", 
          RowBox[{"Length", "[", "idx", "]"}], "]"}], ",", 
         RowBox[{"Return", "[", "0", "]"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"xx", "=", 
        RowBox[{"Permutations", "[", "idx", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Expand", "[", 
        RowBox[{
         FractionBox["1", 
          RowBox[{
           RowBox[{"Length", "[", "idx", "]"}], "!"}]], 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{"Product", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"KroneckerDelta", "[", 
               RowBox[{
                RowBox[{"xx", "\[LeftDoubleBracket]", 
                 RowBox[{"ii", ",", "jj"}], "\[RightDoubleBracket]"}], ",", 
                RowBox[{"xx", "\[LeftDoubleBracket]", 
                 RowBox[{"ii", ",", 
                  RowBox[{"jj", "+", "1"}]}], "\[RightDoubleBracket]"}]}], 
               "]"}], "/.", 
              RowBox[{"{", 
               RowBox[{"KroneckerDelta", "\[Rule]", "\[Delta]$"}], "}"}]}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"jj", ",", "1", ",", 
               RowBox[{"Length", "[", "idx", "]"}], ",", "2"}], "}"}]}], 
            "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"ii", ",", "1", ",", 
             RowBox[{
              RowBox[{"Length", "[", "idx", "]"}], "!"}]}], "}"}]}], "]"}]}], 
        "]"}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"sym1", "[", "ex_", "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"ex0", "=", "ex"}], ",", "pos", ",", "idx", ",", "perm", ",", 
       "double", ",", "tmp"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"pos", "=", 
       RowBox[{"Drop", "[", 
        RowBox[{
         RowBox[{"Position", "[", 
          RowBox[{"ex0", ",", "List"}], "]"}], ",", "None", ",", 
         RowBox[{"-", "1"}]}], "]"}]}], ";", "  ", "\[IndentingNewLine]", 
      RowBox[{"idx", "=", 
       RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Do", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"idx", "=", 
          RowBox[{"Join", "[", 
           RowBox[{"idx", ",", 
            RowBox[{"Extract", "[", 
             RowBox[{"ex0", ",", 
              RowBox[{
              "pos", "\[LeftDoubleBracket]", "ii", 
               "\[RightDoubleBracket]"}]}], "]"}]}], "]"}]}], ";", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Length", "[", 
             RowBox[{
             "pos", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}], 
             "]"}], "\[Equal]", "3"}], ",", 
           RowBox[{"idx", "=", 
            RowBox[{"Join", "[", 
             RowBox[{"idx", ",", 
              RowBox[{"Extract", "[", 
               RowBox[{"ex0", ",", 
                RowBox[{
                "pos", "\[LeftDoubleBracket]", "ii", 
                 "\[RightDoubleBracket]"}]}], "]"}]}], "]"}]}]}], "]"}]}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"ii", ",", "1", ",", 
          RowBox[{"Length", "[", "pos", "]"}]}], "}"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"double", "=", 
       RowBox[{
        RowBox[{"Select", "[", 
         RowBox[{
          RowBox[{"Tally", "[", "idx", "]"}], ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
             "#", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], ">",
              "1"}], ")"}], "&"}]}], "]"}], "\[LeftDoubleBracket]", 
        RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Do", "[", 
       RowBox[{
        RowBox[{"idx", "=", 
         RowBox[{"Delete", "[", 
          RowBox[{"idx", ",", 
           RowBox[{"Position", "[", 
            RowBox[{"idx", ",", 
             RowBox[{
             "double", "\[LeftDoubleBracket]", "kk", 
              "\[RightDoubleBracket]"}]}], "]"}]}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"kk", ",", "1", ",", 
          RowBox[{"Length", "[", "double", "]"}]}], "}"}]}], "]"}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"perm", "=", 
       RowBox[{"Permutations", "[", "idx", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"tmp", "=", 
       RowBox[{"ex0", "/.", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Thread", "[", 
           RowBox[{"idx", "\[Rule]", 
            RowBox[{
            "perm", "\[LeftDoubleBracket]", "kk", "\[RightDoubleBracket]"}]}],
            "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"kk", ",", "1", ",", 
            RowBox[{
             RowBox[{"Length", "[", "idx", "]"}], "!"}]}], "}"}]}], "]"}]}]}],
       ";", "\[IndentingNewLine]", 
      RowBox[{"tmp", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"StandardizeIdx", "[", 
          RowBox[{
           RowBox[{
           "tmp", "\[LeftDoubleBracket]", "kk", "\[RightDoubleBracket]"}], 
           ",", "2"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"kk", ",", "1", ",", 
           RowBox[{"Length", "[", "tmp", "]"}]}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Apply", "[", 
       RowBox[{"Plus", ",", 
        RowBox[{
         FractionBox["1", 
          RowBox[{"Length", "[", "perm", "]"}]], "tmp"}]}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sym", "[", "ex_", "]"}], ":=", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Head", "[", "ex", "]"}], "===", " ", "Plus"}], ",", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"sym1", "[", 
         RowBox[{
         "ex", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}], "]"}],
         ",", 
        RowBox[{"{", 
         RowBox[{"ii", ",", "1", ",", 
          RowBox[{"Length", "[", "ex", "]"}]}], "}"}]}], "]"}]}], "]"}], ",", 
    
    RowBox[{"sym1", "[", "ex", "]"}]}], 
   "]"}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.535821055158787*^9, 3.535821066078806*^9}, {
   3.535821166901783*^9, 3.5358212958048096`*^9}, {3.5358214123838143`*^9, 
   3.5358214147862186`*^9}, {3.5358215618008766`*^9, 3.535821604123751*^9}, {
   3.535821698332317*^9, 3.5358217011715217`*^9}, {3.5358217447579985`*^9, 
   3.5358217566140194`*^9}, {3.535822680152241*^9, 3.535822696126669*^9}, {
   3.5358228323617086`*^9, 3.5358228417061253`*^9}, {3.5358231551106753`*^9, 
   3.535823169774701*^9}, {3.5358232120663757`*^9, 3.535823265168869*^9}, {
   3.5358233044185376`*^9, 3.53582333451099*^9}, {3.535823374915062*^9, 
   3.5358235131157045`*^9}, {3.5358235856090317`*^9, 3.5358236244219*^9}, {
   3.535823671143982*^9, 3.5358236829064026`*^9}, {3.5358237600797377`*^9, 
   3.535823791919394*^9}, {3.535823830810262*^9, 3.535823834351468*^9}, {
   3.535823891807369*^9, 3.5358239053637934`*^9}, {3.5358239420706577`*^9, 
   3.5358239633490953`*^9}, 3.535863647709474*^9, 3.535867745488166*^9, {
   3.535870455408924*^9, 3.535870473645012*^9}, {3.536173856347906*^9, 
   3.536173963457694*^9}, {3.536174014454184*^9, 3.536174027729807*^9}, {
   3.5361746053218217`*^9, 3.5361746149314384`*^9}, {3.5361749406132107`*^9, 
   3.5361749546688356`*^9}, {3.537099203659336*^9, 3.537099204123344*^9}, {
   3.537099273283682*^9, 3.5370992965788307`*^9}, 3.5371001026471033`*^9, {
   3.5371002063851147`*^9, 3.537100208309923*^9}, {3.537100238826915*^9, 
   3.5371004036702833`*^9}, {3.537100455360618*^9, 3.537100530540921*^9}, {
   3.537100577355506*^9, 3.53710059160116*^9}, {3.537109198461097*^9, 
   3.537109236618764*^9}, {3.537111875319599*^9, 3.537111966766959*^9}, {
   3.544510085142268*^9, 3.544510086491521*^9}, {3.544511135130258*^9, 
   3.544511149122176*^9}, {3.544511265775567*^9, 3.5445112663694477`*^9}, {
   3.544511306595739*^9, 3.544511450576692*^9}, {3.54451148203868*^9, 
   3.544511513829035*^9}, {3.544511554825622*^9, 3.544511571921101*^9}, {
   3.544589325870937*^9, 3.5445893449341707`*^9}, {3.545669873420969*^9, 
   3.5456699152446423`*^9}, {3.73678534119002*^9, 3.736785499923944*^9}, {
   3.736785561742168*^9, 3.7367855622511272`*^9}, {3.736785791969393*^9, 
   3.736785808825666*^9}, {3.7371070607483997`*^9, 
   3.737107084991353*^9}},ExpressionUUID->"9e5f712b-701c-4722-93c8-\
41377a5e393f"]
}, Closed]],

Cell[CellGroupData[{

Cell["Function for finding attributes of a tensor", "Subsection",
 CellChangeTimes->{{3.737445347185349*^9, 3.7374453615045757`*^9}, {
  3.737960845965096*^9, 
  3.73796085292483*^9}},ExpressionUUID->"42a72e10-3e0d-4b42-898a-\
691f5071bb61"],

Cell["\<\
The function takes a tensorial expression as input and returns the constant \
factor, its tensorial part, free indices,its tensorial part which contains \
free indices and names of tensors having free indices, in a list form.\
\>", "Text",
 CellChangeTimes->{{3.7379608756466103`*^9, 3.7379609165889893`*^9}, {
  3.737960953181436*^9, 3.737961016241243*^9}, {3.737961124382243*^9, 
  3.7379612278238907`*^9}},
 FontColor->RGBColor[1, 0, 0],
 Background->RGBColor[
  0.87, 0.94, 1],ExpressionUUID->"14c1703f-7dd3-47bf-8162-6609c3ea8e71"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tensorattributes", "[", "ex_", "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "position$tensors", ",", "dummy", ",", "ex1", ",", "tensorialpart$", ",",
       "constantfactor$", ",", "tensorialpart", ",", "constantfactor", ",", 
      "list$factorsintensorialpart", ",", "list$nonrepeatedtensors", ",", 
      "list$indices", ",", "indicesoccurence", ",", "list$freeindices", ",", 
      "freeindices", ",", "tensornames$havingfreeindices", ",", 
      "list$repeatedindices", ",", "pos$tensorshavingfreeindices", ",", 
      "list$tensorshavingfreeindices", ",", "tensorialparthavingfreeindices$",
       ",", "tensorialparthavingfreeindices", ",", 
      "tensorialpartNOThavingfreeindices", ",", 
      "tensorialpartnothavingfreeindices$"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ex1", "=", 
      RowBox[{"dummy", " ", "ex"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"position$tensors", "=", 
      RowBox[{"Partition", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Position", "[", 
          RowBox[{"ex1", ",", "List"}], "]"}], "\[LeftDoubleBracket]", 
         RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", "1"}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"tensorialpart$", "=", 
      RowBox[{"Apply", "[", 
       RowBox[{"Times", ",", 
        RowBox[{"Extract", "[", 
         RowBox[{"ex1", ",", "position$tensors"}], "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"constantfactor$", "=", 
      RowBox[{"ex", "/", "tensorialpart$"}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"TrueQ", "[", 
        RowBox[{"tensorialpart$", "\[Equal]", "1"}], "]"}], ",", 
       RowBox[{"Return", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
          "constantfactor", "\[Rule]", "\[IndentingNewLine]", 
           "constantfactor$"}], ",", 
          RowBox[{"tensorialpart", "\[Rule]", "tensorialpart$"}], ",", 
          RowBox[{"freeindices", "\[Rule]", 
           RowBox[{"{", "}"}]}], ",", 
          RowBox[{"tensorialparthavingfreeindices", "\[Rule]", "1"}], ",", 
          RowBox[{"tensorialpartNOThavingfreeindices", "\[Rule]", "1"}], ",", 
          
          RowBox[{"tensornames$havingfreeindices", "\[Rule]", 
           RowBox[{"{", "}"}]}]}], "}"}], "]"}]}], "]"}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"list$factorsintensorialpart", "=", 
      RowBox[{"DeleteCases", "[", 
       RowBox[{
        RowBox[{"FactorList", "[", "tensorialpart$", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"list$indices", "=", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"ConstantArray", "[", 
          RowBox[{
           RowBox[{"Extract", "[", 
            RowBox[{
             RowBox[{"list$factorsintensorialpart", "\[LeftDoubleBracket]", 
              RowBox[{"ii", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
             RowBox[{"Drop", "[", 
              RowBox[{
               RowBox[{"Position", "[", 
                RowBox[{
                 RowBox[{
                 "list$factorsintensorialpart", "\[LeftDoubleBracket]", 
                  RowBox[{"ii", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
                 "List"}], "]"}], ",", "None", ",", 
               RowBox[{"-", "1"}]}], "]"}]}], "]"}], ",", 
           RowBox[{"list$factorsintensorialpart", "\[LeftDoubleBracket]", 
            RowBox[{"ii", ",", "2"}], "\[RightDoubleBracket]"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"ii", ",", "1", ",", 
           RowBox[{"Length", "[", "list$factorsintensorialpart", "]"}]}], 
          "}"}]}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"(*", 
       StyleBox[
        RowBox[{
        "This", " ", "does", " ", "not", " ", "give", " ", "correct", " ", 
         "free", " ", "indices", " ", "for", " ", "tensors", " ", "of", " ", 
         "the", " ", "form", " ", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "i", "}"}]}], "]"}], "."}]}],
        FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"list$indices", "=", 
        RowBox[{"Flatten", "[", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"ConstantArray", "[", 
            RowBox[{
             RowBox[{"list$factorsintensorialpart", "\[LeftDoubleBracket]", 
              RowBox[{"ii", ",", "1", ",", "1"}], "\[RightDoubleBracket]"}], 
             ",", 
             RowBox[{"list$factorsintensorialpart", "\[LeftDoubleBracket]", 
              RowBox[{"ii", ",", "2"}], "\[RightDoubleBracket]"}]}], "]"}], 
           ",", 
           RowBox[{"{", 
            RowBox[{"ii", ",", 
             RowBox[{"1", 
              RowBox[{"Length", "[", "list$factorsintensorialpart", "]"}]}]}],
             "}"}]}], "]"}], "]"}]}], ";"}], "*)"}], "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Length", "[", "list$indices", "]"}], "\[Equal]", "1"}], ",", 
       
       RowBox[{"Return", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
          "constantfactor", "\[Rule]", "\[IndentingNewLine]", 
           "constantfactor$"}], ",", 
          RowBox[{"tensorialpart", "\[Rule]", "tensorialpart$"}], ",", 
          RowBox[{"freeindices", "\[Rule]", "list$indices"}], ",", 
          RowBox[{
          "tensorialparthavingfreeindices", "\[Rule]", "tensorialpart$"}], 
          ",", 
          RowBox[{"tensorialpartNOThavingfreeindices", "\[Rule]", "1"}], ",", 
          
          RowBox[{"tensornames$havingfreeindices", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"Head", "[", "tensorialpart$", "]"}], "}"}]}]}], "}"}], 
        "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"indicesoccurence", "=", 
      RowBox[{"Tally", "[", "list$indices", "]"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Max", "[", 
         RowBox[{"indicesoccurence", "\[LeftDoubleBracket]", 
          RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], "]"}], ">", 
        "2"}], ",", 
       RowBox[{
       "Return", "[", 
        "\"\<\!\(\*StyleBox[\"Please\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"check\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\"the\
\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, \
0, 0]]\)\!\(\*StyleBox[\"exponents\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"on\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"tensors\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"or\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"the\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"number\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\
\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"of\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"repeated\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"indices\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\".\",FontColor->RGBColor[1, 0, 0]]\)\>\"", "]"}]}], 
      "]"}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"list$freeindices", "=", 
      RowBox[{
       RowBox[{"Cases", "[", 
        RowBox[{"indicesoccurence", ",", 
         RowBox[{"{", 
          RowBox[{"_", ",", "1"}], "}"}]}], "]"}], "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"list$repeatedindices", "=", 
      RowBox[{
       RowBox[{"Cases", "[", 
        RowBox[{"indicesoccurence", ",", 
         RowBox[{"{", 
          RowBox[{"_", ",", "2"}], "}"}]}], "]"}], "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"list$freeindices", "\[Equal]", "list$indices"}], ",", 
         RowBox[{"Return", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
            "constantfactor", "\[Rule]", "\[IndentingNewLine]", 
             "constantfactor$"}], ",", 
            RowBox[{"tensorialpart", "\[Rule]", "tensorialpart$"}], ",", 
            RowBox[{"freeindices", "\[Rule]", "list$freeindices"}]}], "}"}], 
          "]"}]}], "]"}], ";"}], "*)"}], "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"list$nonrepeatedtensors", "=", 
      RowBox[{"DeleteCases", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Cases", "[", 
          RowBox[{"list$factorsintensorialpart", ",", 
           RowBox[{"{", 
            RowBox[{"_", ",", "1"}], "}"}]}], "]"}], "\[LeftDoubleBracket]", 
         RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
        "_Integer"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"Return", "[", "list$nonrepeatedtensors", "]"}], ";"}], "*)"}],
      "\[IndentingNewLine]", 
     RowBox[{"pos$tensorshavingfreeindices", "=", 
      RowBox[{"DeleteDuplicates", "[", 
       RowBox[{
        RowBox[{"Position", "[", 
         RowBox[{"tensorialpart$", ",", 
          RowBox[{"Alternatives", "@@", "list$freeindices"}]}], "]"}], 
        "\[LeftDoubleBracket]", 
        RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Length", "[", "pos$tensorshavingfreeindices", "]"}], 
         "\[Equal]", "1"}], "&&", 
        RowBox[{
         RowBox[{"Length", "[", "list$nonrepeatedtensors", "]"}], "\[Equal]", 
         "1"}]}], ",", 
       RowBox[{
       "list$tensorshavingfreeindices", "=", "list$nonrepeatedtensors"}], ",",
        "\[IndentingNewLine]", 
       RowBox[{"list$tensorshavingfreeindices", "=", 
        RowBox[{"Extract", "[", 
         RowBox[{"tensorialpart$", ",", 
          RowBox[{"Partition", "[", 
           RowBox[{"pos$tensorshavingfreeindices", ",", "1"}], "]"}]}], 
         "]"}]}]}], "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"tensorialparthavingfreeindices$", "=", 
      RowBox[{"Apply", "[", 
       RowBox[{"Times", ",", "list$tensorshavingfreeindices"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"tensorialpartnothavingfreeindices$", "=", 
      RowBox[{"tensorialpart$", "/", "tensorialparthavingfreeindices$"}]}], 
     ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"Return", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
        "constantfactor", "\[Rule]", "\[IndentingNewLine]", 
         "constantfactor$"}], ",", 
        RowBox[{"tensorialpart", "\[Rule]", "tensorialpart$"}], ",", 
        RowBox[{"freeindices", "\[Rule]", "list$freeindices"}], ",", 
        RowBox[{
        "tensorialparthavingfreeindices", "\[Rule]", 
         "tensorialparthavingfreeindices$"}], ",", 
        RowBox[{
        "tensorialpartNOThavingfreeindices", "\[Rule]", 
         "tensorialpartnothavingfreeindices$"}], ",", 
        RowBox[{"tensornames$havingfreeindices", "\[Rule]", 
         RowBox[{"Head", "/@", "list$tensorshavingfreeindices"}]}]}], "}"}], 
      "]"}]}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", "tensorialparthavingfreeindices", "*)"}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.737873444149817*^9, 3.737873505398519*^9}, {
   3.737873912042206*^9, 3.737873914429421*^9}, {3.737874006041627*^9, 
   3.737874104527811*^9}, {3.737874599854004*^9, 3.73787464710261*^9}, {
   3.737874704558936*^9, 3.7378747401602793`*^9}, {3.7378747836344833`*^9, 
   3.7378748087394648`*^9}, {3.737874890151431*^9, 3.7378749462064466`*^9}, 
   3.73787497676064*^9, 3.7378760003815823`*^9, {3.737877470176045*^9, 
   3.73787754233914*^9}, {3.737877590145666*^9, 3.737877630063467*^9}, {
   3.737877796657827*^9, 3.737877837648694*^9}, {3.73788813967266*^9, 
   3.737888161982396*^9}, {3.7378883404116077`*^9, 3.7378883570170794`*^9}, {
   3.737888531401895*^9, 3.737888550970998*^9}, {3.737888583851099*^9, 
   3.737888658266695*^9}, 3.7378887184747553`*^9, {3.7378887846300573`*^9, 
   3.7378888227693872`*^9}, {3.7378888856151114`*^9, 3.737888905181182*^9}, {
   3.7378889359238853`*^9, 3.737889015437792*^9}, {3.737889835556378*^9, 
   3.737889912927951*^9}, {3.737890001574188*^9, 3.737890004834824*^9}, {
   3.7378900771406517`*^9, 3.7378901043708143`*^9}, {3.737890135763968*^9, 
   3.737890196726946*^9}, {3.7378903812621717`*^9, 3.737890385109735*^9}, {
   3.737890757113912*^9, 3.737890804603331*^9}, {3.737891208571246*^9, 
   3.7378912099614267`*^9}, {3.7378912509699373`*^9, 3.737891363404022*^9}, {
   3.7378914052447*^9, 3.737891405451157*^9}, {3.7378914548020487`*^9, 
   3.737891630211689*^9}, {3.7378919163373537`*^9, 3.7378919949988203`*^9}, 
   3.7378920298147078`*^9, 3.737892216360777*^9, {3.737892342963614*^9, 
   3.737892414729166*^9}, {3.737892483028646*^9, 3.737892494607236*^9}, 
   3.7378926037612953`*^9, {3.737892638688724*^9, 3.737892648435903*^9}, 
   3.7378931256232224`*^9, {3.737893464392359*^9, 3.737893510293949*^9}, {
   3.737893552522386*^9, 3.7378936189674807`*^9}, {3.737893716764442*^9, 
   3.7378937219288673`*^9}, 3.737893825503366*^9, {3.737894736990343*^9, 
   3.737894748046142*^9}, {3.737894965699312*^9, 3.737894967555573*^9}, {
   3.737895002961411*^9, 3.737895018209095*^9}, {3.737895081670211*^9, 
   3.737895087375628*^9}, 3.7378952634456797`*^9, {3.73795800542448*^9, 
   3.7379580107841873`*^9}, {3.737960112572125*^9, 3.737960129307458*^9}, {
   3.737960483372562*^9, 3.737960525381826*^9}, {3.738046029583342*^9, 
   3.738046097815036*^9}, {3.738046200890985*^9, 3.738046206604821*^9}, {
   3.738046286227366*^9, 3.7380463033028717`*^9}, 3.738046432023266*^9, {
   3.738046718578298*^9, 3.738046778720519*^9}, {3.738324437714979*^9, 
   3.738324480229918*^9}, 3.7383247498173723`*^9, {3.7383251066299543`*^9, 
   3.738325119317021*^9}, {3.7383251797755127`*^9, 3.738325208647303*^9}, {
   3.738342237165594*^9, 3.738342250247217*^9}, {3.738363525640148*^9, 
   3.7383635562326202`*^9}, {3.738363675645494*^9, 3.738363688933701*^9}, {
   3.738363837857588*^9, 3.738363847903467*^9}, {3.738364260395423*^9, 
   3.73836433118528*^9}},ExpressionUUID->"8d38371f-a55f-4e35-b9a1-\
7aaedd37663d"]
}, Closed]],

Cell[CellGroupData[{

Cell["Function for contracting a tensor", "Subsection",
 CellChangeTimes->{{3.737445347185349*^9, 
  3.7374453615045757`*^9}},ExpressionUUID->"5201fe82-7184-4ca0-a918-\
115d1c1dc2e3"],

Cell[BoxData[{
 RowBox[{"Clear", "[", 
  RowBox[{
  "contractedtensorsingle", ",", "contractedtensormultiple", ",", 
   "contractedtensor"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"contractedtensorsingle", "[", "ex_", "]"}], ":=", 
    RowBox[{"Block", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "pos", ",", "allindices", ",", "repeatedindices", ",", "freeindices", 
        ",", "tensorname", ",", "contractedpart", ",", "idx", ",", 
        "counteachindex", ",", "checkindices", ",", 
        "number$contarctedindices", ",", "uncontarctedindices", ",", 
        "output"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Position", "[", 
           RowBox[{"ex", ",", "List"}], "]"}], "\[Equal]", 
          RowBox[{"{", "}"}]}], ",", 
         RowBox[{"output", "=", "ex"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"pos", "=", 
           RowBox[{"Drop", "[", 
            RowBox[{
             RowBox[{"Position", "[", 
              RowBox[{"ex", ",", "List"}], "]"}], ",", "None", ",", 
             RowBox[{"-", "1"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"allindices", "=", 
           RowBox[{"Tally", "[", 
            RowBox[{"Flatten", "[", 
             RowBox[{"Extract", "[", 
              RowBox[{"ex", ",", "pos"}], "]"}], "]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Max", "[", 
              RowBox[{"allindices", "\[LeftDoubleBracket]", 
               RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], "]"}], 
             ">", "2"}], ",", "\[IndentingNewLine]", 
            RowBox[{"output", "=", 
             RowBox[{
             "Print", "[", 
              "\"\<\!\(\*StyleBox[\"Please\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"check\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\"the\
\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, \
0, 0]]\)\!\(\*StyleBox[\"repeated\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"indices\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\".\",FontColor->RGBColor[1, 0, 0]]\)\>\"", "]"}]}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"tensorname", "=", 
              RowBox[{"Head", "[", "ex", "]"}]}], ";", "\[IndentingNewLine]", 
             
             RowBox[{"contractedpart", "=", 
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"Cases", "[", 
                  RowBox[{"ex", ",", "_Integer"}], "]"}], "\[Equal]", 
                 RowBox[{"{", "}"}]}], ",", "0", ",", 
                RowBox[{"First", "[", 
                 RowBox[{"Cases", "[", 
                  RowBox[{"ex", ",", "_Integer"}], "]"}], "]"}]}], "]"}]}], 
             ";", "\[IndentingNewLine]", 
             RowBox[{"freeindices", "=", 
              RowBox[{"Flatten", "[", 
               RowBox[{"Drop", "[", 
                RowBox[{
                 RowBox[{"Select", "[", 
                  RowBox[{"allindices", ",", 
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    "#", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}], "\[Equal]", "1"}], "&"}]}], 
                  "]"}], ",", "None", ",", 
                 RowBox[{"-", "1"}]}], "]"}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"repeatedindices", "=", 
              RowBox[{"Flatten", "[", 
               RowBox[{"Drop", "[", 
                RowBox[{
                 RowBox[{"Select", "[", 
                  RowBox[{"allindices", ",", 
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    "#", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}], "\[Equal]", "2"}], "&"}]}], 
                  "]"}], ",", "None", ",", 
                 RowBox[{"-", "1"}]}], "]"}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"output", "=", 
              RowBox[{"tensorname", "[", 
               RowBox[{
                RowBox[{"contractedpart", "+", 
                 RowBox[{"Length", "[", "repeatedindices", "]"}]}], ",", 
                RowBox[{"Sort", "[", "freeindices", "]"}]}], "]"}]}], ";"}]}],
            "\[IndentingNewLine]", "]"}], ";"}]}], "\[IndentingNewLine]", 
        "]"}], ";", "\[IndentingNewLine]", "output"}]}], 
     "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"contractedtensormultiple", "[", "ex_", "]"}], ":=", 
    RowBox[{"Block", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "output", ",", "pos", ",", "counttensorindex", ",", "indicesoccurence",
         ",", "list$factorswithpowers", ",", "factors", ",", "theirpowers", 
        ",", "list$tensors", ",", "position$tensors", ",", "power$tensors"}], 
       "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"list$factorswithpowers", "=", 
        RowBox[{"FactorList", "[", "ex", "]"}]}], ";", "\[IndentingNewLine]", 
       
       RowBox[{"factors", "=", 
        RowBox[{"list$factorswithpowers", "\[LeftDoubleBracket]", 
         RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"theirpowers", "=", 
        RowBox[{"list$factorswithpowers", "\[LeftDoubleBracket]", 
         RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", 
        StyleBox[
         RowBox[{
         "condition", " ", "for", " ", "powers", " ", "in", " ", "tensors"}],
         FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
       RowBox[{"list$tensors", "=", 
        RowBox[{"Extract", "[", 
         RowBox[{"factors", ",", 
          RowBox[{"Drop", "[", 
           RowBox[{
            RowBox[{"Complement", "[", 
             RowBox[{
              RowBox[{"Position", "[", 
               RowBox[{"factors", ",", "List"}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"{", "0", "}"}], "}"}]}], "]"}], ",", "None", ",", 
            RowBox[{"-", "1"}]}], "]"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"position$tensors", "=", 
        RowBox[{"Drop", "[", 
         RowBox[{
          RowBox[{"Drop", "[", 
           RowBox[{
            RowBox[{"Complement", "[", 
             RowBox[{
              RowBox[{"Position", "[", 
               RowBox[{"factors", ",", "List"}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"{", "0", "}"}], "}"}]}], "]"}], ",", "None", ",", 
            RowBox[{"-", "1"}]}], "]"}], ",", "None", ",", 
          RowBox[{"-", "1"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"power$tensors", "=", 
        RowBox[{"Extract", "[", 
         RowBox[{"theirpowers", ",", "position$tensors"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Max", "[", "power$tensors", "]"}], ">", "2"}], ",", 
         RowBox[{"output", "=", 
          RowBox[{
          "Print", "[", 
           "\"\<\!\(\*StyleBox[\"Please\",FontColor->RGBColor[1, 0, 0]]\)\!\(\
\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"check\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\"the\
\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, \
0, 0]]\)\!\(\*StyleBox[\"exponents\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"on\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"tensors\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\".\",FontColor->RGBColor[1, 0, 0]]\)\>\"", "]"}]}], ",", 
         
         RowBox[{
          RowBox[{"indicesoccurence", "=", 
           RowBox[{"Tally", "[", 
            RowBox[{"Flatten", "[", 
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"ConstantArray", "[", 
                RowBox[{
                 RowBox[{
                 "list$tensors", "\[LeftDoubleBracket]", "ii", 
                  "\[RightDoubleBracket]"}], ",", 
                 RowBox[{
                 "power$tensors", "\[LeftDoubleBracket]", "ii", 
                  "\[RightDoubleBracket]"}]}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"ii", ",", 
                 RowBox[{"1", 
                  RowBox[{"Length", "[", "list$tensors", "]"}]}]}], "}"}]}], 
              "]"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Max", "[", 
              RowBox[{"indicesoccurence", "\[LeftDoubleBracket]", 
               RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], "]"}], 
             ">", "2"}], ",", "\[IndentingNewLine]", 
            RowBox[{"output", "=", 
             RowBox[{
             "Print", "[", 
              "\"\<\!\(\*StyleBox[\"Please\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"check\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\"the\
\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, \
0, 0]]\)\!\(\*StyleBox[\"repeated\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"indices\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\".\",FontColor->RGBColor[1, 0, 0]]\)\>\"", "]"}]}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"output", "=", 
              RowBox[{"Apply", "[", 
               RowBox[{"Times", ",", 
                RowBox[{"Table", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"contractedtensorsingle", "[", 
                    RowBox[{
                    "factors", "\[LeftDoubleBracket]", "ii", 
                    "\[RightDoubleBracket]"}], "]"}], "^", 
                   RowBox[{
                   "theirpowers", "\[LeftDoubleBracket]", "ii", 
                    "\[RightDoubleBracket]"}]}], ",", 
                  RowBox[{"{", 
                   RowBox[{"ii", ",", "1", ",", 
                    RowBox[{"Length", "[", "factors", "]"}]}], "}"}]}], 
                 "]"}]}], "]"}]}], ";"}]}], "\[IndentingNewLine]", "]"}], 
          ";"}]}], "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Position", "[", 
             RowBox[{"ex", ",", "List"}], "]"}], "\[Equal]", 
            RowBox[{"{", "}"}]}], ",", 
           RowBox[{"output", "=", "ex"}], ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"pos", "=", 
             RowBox[{"Drop", "[", 
              RowBox[{
               RowBox[{"Position", "[", 
                RowBox[{"ex", ",", "List"}], "]"}], ",", "None", ",", 
               RowBox[{"-", "1"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
            RowBox[{"counteachindex", "=", 
             RowBox[{"Tally", "[", 
              RowBox[{"Flatten", "[", 
               RowBox[{"Extract", "[", 
                RowBox[{"ex", ",", "pos"}], "]"}], "]"}], "]"}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"Max", "[", 
                RowBox[{"counteachindex", "\[LeftDoubleBracket]", 
                 RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], "]"}], 
               ">", "2"}], ",", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"output", "=", 
                RowBox[{
                "Print", "[", 
                 "\"\<\!\(\*StyleBox[\"Please\",FontColor->RGBColor[1, 0, 0]]\
\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"check\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\"the\
\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, \
0, 0]]\)\!\(\*StyleBox[\"repeated\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"indices\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\".\",FontColor->RGBColor[1, 0, 0]]\)\>\"", "]"}]}], 
               ";"}], ",", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"output", "=", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Head", "[", "ex", "]"}], "===", " ", "Times"}], 
                  ",", 
                  RowBox[{"Apply", "[", 
                   RowBox[{"Times", ",", 
                    RowBox[{"Table", "[", 
                    RowBox[{
                    RowBox[{"contractedtensorsingle", "[", 
                    RowBox[{
                    "ex", "\[LeftDoubleBracket]", "ii", 
                    "\[RightDoubleBracket]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"ii", ",", "1", ",", 
                    RowBox[{"Length", "[", "ex", "]"}]}], "}"}]}], "]"}]}], 
                   "]"}], ",", 
                  RowBox[{"contractedtensorsingle", "[", "ex", "]"}]}], 
                 "]"}]}], ";"}]}], "\[IndentingNewLine]", "]"}], ";"}]}], 
          "\[IndentingNewLine]", "]"}], ";"}], "*)"}], "\[IndentingNewLine]", 
       "output"}]}], "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"contractedtensor", "[", "ex_", "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"output", ",", "ex1"}], "}"}], ",", 
    RowBox[{
     RowBox[{"ex1", "=", 
      RowBox[{"Expand", "[", "ex", "]"}]}], ";", 
     RowBox[{"output", "=", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Head", "[", "ex1", "]"}], "===", " ", "Plus"}], ",", 
        RowBox[{"Apply", "[", 
         RowBox[{"Plus", ",", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"contractedtensormultiple", "[", 
             RowBox[{
             "ex1", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}], 
             "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"ii", ",", "1", ",", 
              RowBox[{"Length", "[", "ex1", "]"}]}], "}"}]}], "]"}]}], "]"}], 
        ",", 
        RowBox[{"contractedtensormultiple", "[", "ex1", "]"}]}], "]"}]}], ";",
      "\[IndentingNewLine]", "output"}]}], "\[IndentingNewLine]", 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.7373067847420597`*^9, 3.737306845687756*^9}, {
   3.73730693932476*^9, 3.737306943925753*^9}, {3.737307732434574*^9, 
   3.737307737330307*^9}, {3.737307812314247*^9, 3.73730789265221*^9}, {
   3.737308362765875*^9, 3.73730846144346*^9}, {3.7373084971934233`*^9, 
   3.737308537261639*^9}, {3.737308621386368*^9, 3.73730862177708*^9}, {
   3.737308671706202*^9, 3.737308740258708*^9}, {3.737308833149935*^9, 
   3.737308834196536*^9}, {3.737309696179824*^9, 3.737309702610691*^9}, {
   3.737309736527088*^9, 3.737309926656425*^9}, {3.737353307311985*^9, 
   3.7373533640767527`*^9}, {3.737353955972994*^9, 3.7373539922151213`*^9}, {
   3.73735473452045*^9, 3.737354798086873*^9}, {3.737354923688064*^9, 
   3.737355070094801*^9}, {3.737355246205312*^9, 3.7373552748912582`*^9}, {
   3.737355354828206*^9, 3.7373554173572807`*^9}, {3.737355941807774*^9, 
   3.737355986416884*^9}, 3.737356048212471*^9, {3.7373561190115433`*^9, 
   3.737356157188695*^9}, {3.737356327988091*^9, 3.7373563383213253`*^9}, {
   3.737356374952667*^9, 3.7373564208589497`*^9}, {3.7373566772694063`*^9, 
   3.737356678594577*^9}, {3.7373568135089207`*^9, 3.737356820285232*^9}, {
   3.737357035512478*^9, 3.737357035908517*^9}, {3.737357134695261*^9, 
   3.7373573364072037`*^9}, {3.737357407254107*^9, 3.737357415200259*^9}, {
   3.737357461303514*^9, 3.737357508606369*^9}, {3.737357555067363*^9, 
   3.737357610494637*^9}, {3.737357657501978*^9, 3.737357740774876*^9}, {
   3.737357776394527*^9, 3.737357787593939*^9}, {3.737357881852453*^9, 
   3.737358002270784*^9}, {3.7373580522198887`*^9, 3.73735807573799*^9}, {
   3.737358444834366*^9, 3.7373584965252943`*^9}, {3.737358558029749*^9, 
   3.737358597404949*^9}, 3.737358658847885*^9, {3.737358790397118*^9, 
   3.737358859499847*^9}, {3.737358899807248*^9, 3.737358934588709*^9}, {
   3.737359024941484*^9, 3.737359123613124*^9}, {3.737359248208066*^9, 
   3.737359249271846*^9}, {3.737359281088624*^9, 3.7373593080863037`*^9}, {
   3.737359375700179*^9, 3.73735938043435*^9}, {3.737359546726116*^9, 
   3.737359569812318*^9}, {3.737359691793664*^9, 3.737359716863969*^9}, {
   3.737359913750153*^9, 3.737359927126952*^9}, {3.737359991557061*^9, 
   3.737360057066595*^9}, {3.7373600949633923`*^9, 3.7373601340505753`*^9}, 
   3.73736064249551*^9, {3.7373607434184093`*^9, 3.737360748439577*^9}, 
   3.737360787658482*^9, {3.737361249587199*^9, 3.737361291010128*^9}, {
   3.737361336691976*^9, 3.737361386573201*^9}, {3.737361439871396*^9, 
   3.73736147998297*^9}, {3.7373615567885027`*^9, 3.737361560109888*^9}, {
   3.737361598228786*^9, 3.737361607866694*^9}, 3.737361648274693*^9, {
   3.73736181830634*^9, 3.737361823550358*^9}, 3.737370716785842*^9, {
   3.7373707482698393`*^9, 3.73737093013669*^9}, {3.737372355877223*^9, 
   3.7373725007915287`*^9}, {3.737372558472457*^9, 3.737372566806579*^9}, {
   3.737372611512191*^9, 3.73737269092037*^9}, {3.737373420054227*^9, 
   3.737373475643779*^9}, {3.737373866687354*^9, 3.7373739635183477`*^9}, 
   3.7373740077002153`*^9, {3.737374079714848*^9, 3.737374094911789*^9}, {
   3.73737420723624*^9, 3.737374270613062*^9}, {3.737374311463786*^9, 
   3.737374314001593*^9}, {3.737374346993307*^9, 3.737374462337899*^9}, {
   3.7373745007389297`*^9, 3.7373745545618963`*^9}, {3.737374586386669*^9, 
   3.737374597330714*^9}, {3.737374671605042*^9, 3.7373747942753477`*^9}, {
   3.737374883209215*^9, 3.737374885331951*^9}, {3.737613527789194*^9, 
   3.737613527868012*^9}},ExpressionUUID->"8cfd4115-3756-49d3-b22b-\
f6795dfa02b4"]
}, Closed]],

Cell[CellGroupData[{

Cell["Function for defining a traceless part of a tensor", "Subsection",
 CellChangeTimes->{{3.73744529910393*^9, 3.737445317616681*^9}, {
  3.737445371377437*^9, 3.7374453844968567`*^9}, {3.7375211271986647`*^9, 
  3.7375211382437963`*^9}, {3.737700375799358*^9, 
  3.737700376518396*^9}},ExpressionUUID->"da6ec88e-e2b6-4d2f-a1c8-\
311700687c73"],

Cell[TextData[{
 "These functions symmetrize a tensor but removes the constant factor from \
it. For example: it takes ",
 Cell[BoxData[
  FormBox["7", TraditionalForm]],ExpressionUUID->
  "0143784e-39c6-432e-83f9-0fb273d08a7a"],
 "A[{i}]B[{j}] and returns ",
 Cell[BoxData[
  FormBox["7", TraditionalForm]],ExpressionUUID->
  "66820839-e974-4dae-916b-081afc899ed8"],
 "(A[{i}]B[{j}]+B[{j}]A[{i}]) without a factor of 1/2."
}], "Text",
 CellChangeTimes->{{3.7379631276442547`*^9, 3.7379631505567627`*^9}, {
  3.737963185539649*^9, 3.7379632377736*^9}, {3.737963268285248*^9, 
  3.737963336254232*^9}, {3.737963465467987*^9, 3.737963478300344*^9}, {
  3.737964203376766*^9, 3.737964232610635*^9}},
 FontColor->RGBColor[1, 0, 0],
 Background->RGBColor[
  0.87, 0.94, 1],ExpressionUUID->"e3492fb4-7ebc-4a68-98a0-63cc2a47a577"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"symwithoutfactorsingle", "[", "ex_", "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "ex1", ",", "dummy", ",", "output", ",", "pos", ",", "tensorialpart", 
       ",", "constantfactor"}], "}"}], ",", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"output", "=", 
       RowBox[{"tensorattributes", "[", "ex", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Head", "[", "output", "]"}], "\[Equal]", "String"}], ",", 
        RowBox[{"Return", "[", "output", "]"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"constantfactor", "=", 
       RowBox[{"constantfactor", "/.", "output"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"tensorialpart", "=", 
       RowBox[{"tensorialpart", "/.", "output"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"Return", "[", 
       RowBox[{"constantfactor", " ", 
        RowBox[{
         RowBox[{"FactorTermsList", "[", 
          RowBox[{"sym", "[", "tensorialpart", "]"}], "]"}], 
         "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"symwithoutfactor", "[", "ex_", "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", "ex1", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ex1", "=", 
      RowBox[{"Expand", "[", "ex", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Head", "[", "ex1", "]"}], "===", " ", "Plus"}], ",", 
       RowBox[{"Apply", "[", 
        RowBox[{"Plus", ",", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"symwithoutfactorsingle", "[", 
            RowBox[{
            "ex1", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}], 
            "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"ii", ",", "1", ",", 
             RowBox[{"Length", "[", "ex1", "]"}]}], "}"}]}], "]"}]}], "]"}], 
       ",", 
       RowBox[{"symwithoutfactorsingle", "[", "ex1", "]"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]}], "Input",
 CellChangeTimes->{{3.7373898075617027`*^9, 3.737389848088016*^9}, {
   3.737390747017433*^9, 3.737390783410701*^9}, {3.7373909218924437`*^9, 
   3.7373909571964684`*^9}, {3.737391581147747*^9, 3.737391863768633*^9}, {
   3.737391940270989*^9, 3.7373919487255783`*^9}, 3.7373921694970827`*^9, {
   3.7373924108898697`*^9, 3.7373924215206842`*^9}, {3.7373924716415358`*^9, 
   3.73739247895188*^9}, {3.73739263105202*^9, 3.7373926560021133`*^9}, {
   3.737392716046008*^9, 3.737392718037957*^9}, {3.737392759120242*^9, 
   3.7373928386483*^9}, {3.737392875537838*^9, 3.737392933496498*^9}, {
   3.737393127464574*^9, 3.737393134950301*^9}, {3.737393199951563*^9, 
   3.737393315070085*^9}, {3.7373933473438663`*^9, 3.73739341946835*^9}, {
   3.737393600269292*^9, 3.7373936463543787`*^9}, {3.737393690473794*^9, 
   3.737393691936407*^9}, {3.7373938601732063`*^9, 3.737393891885086*^9}, {
   3.737394062848123*^9, 3.737394068797803*^9}, {3.7373941052084846`*^9, 
   3.737394111150548*^9}, {3.737394173895423*^9, 3.7373942003353167`*^9}, 
   3.7373943238490143`*^9, 3.737394386971182*^9, {3.737394428833026*^9, 
   3.737394436544656*^9}, 3.737394493685444*^9, {3.737394558801825*^9, 
   3.737394562712968*^9}, {3.737394870948062*^9, 3.7373949362599382`*^9}, {
   3.737394997166273*^9, 3.737395001070047*^9}, {3.7374446250081587`*^9, 
   3.737444645011342*^9}, {3.737445021510281*^9, 3.7374450229220457`*^9}, {
   3.737445069430604*^9, 3.73744510833783*^9}, {3.7374597715314207`*^9, 
   3.7374597985171537`*^9}, {3.7375212041170464`*^9, 
   3.7375212096939707`*^9}, {3.73760163422828*^9, 3.737601667124991*^9}, {
   3.737601738048499*^9, 3.737601768513637*^9}, {3.737601993862471*^9, 
   3.737602101518778*^9}, 3.7376021364059143`*^9, {3.737602254300578*^9, 
   3.737602259313821*^9}, {3.737602310776073*^9, 3.737602322312333*^9}, {
   3.737602417530241*^9, 3.737602420583943*^9}, {3.737602556226366*^9, 
   3.737602570678252*^9}, {3.7376026722945642`*^9, 3.7376026783736258`*^9}, {
   3.7376027820423517`*^9, 3.737602782577059*^9}, {3.737603564160473*^9, 
   3.737603601062541*^9}, {3.7376040574816313`*^9, 3.737604068809782*^9}, {
   3.7376042506842327`*^9, 3.7376043053467083`*^9}, {3.737606536528862*^9, 
   3.7376065375032*^9}, 3.73760661373555*^9, 3.737606660198266*^9, 
   3.737606762691753*^9, {3.737606841225388*^9, 3.7376068527985353`*^9}, {
   3.7376069471109743`*^9, 3.737606953596558*^9}, 3.737607016498376*^9, {
   3.737607083408895*^9, 3.737607097522291*^9}, 3.737607138572296*^9, {
   3.737607216286727*^9, 3.73760722457978*^9}, {3.7376072607056847`*^9, 
   3.737607266575758*^9}, {3.737607312206007*^9, 3.737607318365533*^9}, {
   3.737607480191413*^9, 3.7376074821265993`*^9}, {3.737608867857106*^9, 
   3.73760886986661*^9}, {3.737608917271209*^9, 3.737608935713193*^9}, {
   3.737608987143733*^9, 3.737608998929427*^9}, {3.7376091024532824`*^9, 
   3.737609109178396*^9}, {3.737609238416655*^9, 3.737609247456108*^9}, {
   3.737609307420145*^9, 3.737609404590152*^9}, {3.737609618564479*^9, 
   3.737609627492959*^9}, {3.737609815783477*^9, 3.7376098325051613`*^9}, {
   3.737609863058433*^9, 3.737609888787179*^9}, {3.7376100078142033`*^9, 
   3.737610043855587*^9}, {3.7376101102093487`*^9, 3.737610119497998*^9}, {
   3.737610187688632*^9, 3.737610192089609*^9}, 3.737612699551239*^9, {
   3.737613527034273*^9, 3.7376135270638866`*^9}, {3.737962424925535*^9, 
   3.737962441847745*^9}, {3.7379624757103577`*^9, 3.73796250063512*^9}, {
   3.7379625443336554`*^9, 3.737962623313693*^9}, {3.737962665420251*^9, 
   3.737962669635779*^9}, 3.737962702417184*^9, {3.7379627408120117`*^9, 
   3.737962765372888*^9}, {3.737962902821693*^9, 3.7379629084287567`*^9}, {
   3.7379630627710657`*^9, 3.7379630731519012`*^9}, {3.737963529398134*^9, 
   3.73796355078129*^9}, {3.737963822048452*^9, 3.737963823070652*^9}, {
   3.737963932479363*^9, 3.737963932703187*^9}, {3.737995112187852*^9, 
   3.737995114593062*^9}},ExpressionUUID->"f4ddad0b-5304-417d-9e9f-\
85a31941015d"],

Cell[TextData[{
 "These functions give the traceless part of a tensor. For example: it takes \
A[{i}]B[{j}] as input and returns the traceless part of it: ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"A", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "i", "}"}]}], "]"}], " ", 
       RowBox[{"B", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "j", "}"}]}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"A", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "j", "}"}]}], "]"}], " ", 
       RowBox[{"B", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "i", "}"}]}], "]"}]}]}], ")"}]}], "-", 
   RowBox[{
    FractionBox["1", "d"], 
    RowBox[{"\[Delta]", "[", 
     RowBox[{"{", 
      RowBox[{"i", ",", "j"}], "}"}], "]"}], 
    RowBox[{"A", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
    RowBox[{"B", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", "p0", "}"}]}], "]"}]}]}]], "Output",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  CellChangeTimes->{{3.737964256546504*^9, 3.7379642670355253`*^9}},
  ExpressionUUID->"5defa1b4-bd36-42e6-95b6-faf38b2b1e0f"],
 "."
}], "Text",
 CellChangeTimes->{{3.7379631276442547`*^9, 3.7379631505567627`*^9}, {
  3.737963185539649*^9, 3.7379632377736*^9}, {3.737963268285248*^9, 
  3.737963336254232*^9}, {3.737963465467987*^9, 3.737963478300344*^9}, {
  3.7379640248802557`*^9, 3.7379640940325747`*^9}, {3.737964290642398*^9, 
  3.7379643595375433`*^9}, {3.737993850608988*^9, 3.7379938907109537`*^9}},
 FontColor->RGBColor[1, 0, 0],
 Background->RGBColor[
  0.87, 0.94, 1],ExpressionUUID->"d4f48cb6-463a-4442-ac76-af4dc34c4364"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"tracelessPart1", "[", "ex_", "]"}], ":=", 
    RowBox[{"Block", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "constantfactor", ",", "tensorialpart", ",", "freeindices", ",", 
        "num$freeindices", ",", "contractionreplacements", ",", "listdeltas", 
        ",", "tensor\[Delta]combinations", ",", "\[Delta]", ",", 
        "generalform", ",", "output", ",", "c", ",", "d", ",", 
        RowBox[{"list", "=", 
         RowBox[{"{", "}"}]}], ",", 
        RowBox[{"product", "=", "1"}]}], "}"}], ",", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"output", "=", 
        RowBox[{"tensorattributes", "[", "ex", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Head", "[", "output", "]"}], "\[Equal]", "String"}], ",", 
         RowBox[{"Return", "[", "output", "]"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"constantfactor", "=", 
        RowBox[{"constantfactor", "/.", "output"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"tensorialpart", "=", 
        RowBox[{"tensorialpart", "/.", "output"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"freeindices", "=", 
        RowBox[{"freeindices", "/.", "output"}]}], ";", "\[IndentingNewLine]",
        "\[IndentingNewLine]", 
       RowBox[{"num$freeindices", "=", 
        RowBox[{"Length", "[", "freeindices", "]"}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"contractionreplacements", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"list", "=", 
           RowBox[{"Join", "[", 
            RowBox[{"list", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"freeindices", "\[LeftDoubleBracket]", 
                RowBox[{"2", "ii"}], "\[RightDoubleBracket]"}], "\[Rule]", 
               RowBox[{"freeindices", "\[LeftDoubleBracket]", 
                RowBox[{
                 RowBox[{"2", "ii"}], "-", "1"}], "\[RightDoubleBracket]"}]}],
               "}"}]}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"ii", ",", 
            RowBox[{
             RowBox[{"Length", "[", "freeindices", "]"}], "/", "2"}], ",", 
            "1", ",", 
            RowBox[{"-", "1"}]}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"listdeltas", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"product", "=", 
           RowBox[{"product", "*", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"Sort", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"freeindices", "\[LeftDoubleBracket]", 
                 RowBox[{"2", "ii"}], "\[RightDoubleBracket]"}], ",", 
                RowBox[{"freeindices", "\[LeftDoubleBracket]", 
                 RowBox[{
                  RowBox[{"2", "ii"}], "-", "1"}], 
                 "\[RightDoubleBracket]"}]}], "}"}], "]"}], "]"}]}]}], ",", 
          RowBox[{"{", 
           RowBox[{"ii", ",", 
            RowBox[{
             RowBox[{"Length", "[", "freeindices", "]"}], "/", "2"}], ",", 
            "1", ",", 
            RowBox[{"-", "1"}]}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        StyleBox[
         RowBox[{
         "list", " ", "of", " ", "tensors", " ", "formed", " ", "with", " ", 
          "free", " ", "indices", " ", "and", " ", "deltas"}],
         FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
       RowBox[{"tensor\[Delta]combinations", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"contractedtensor", "[", 
             RowBox[{"Einstein", "[", 
              RowBox[{"Expand", "[", 
               RowBox[{
                RowBox[{"sym", "[", "tensorialpart", "]"}], "/.", 
                RowBox[{
                "contractionreplacements", "\[LeftDoubleBracket]", "ii", 
                 "\[RightDoubleBracket]"}]}], "]"}], "]"}], "]"}], ")"}], 
           RowBox[{
           "listdeltas", "\[LeftDoubleBracket]", "ii", 
            "\[RightDoubleBracket]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"ii", ",", "1", ",", 
            RowBox[{"Length", "[", "listdeltas", "]"}]}], "}"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"generalform", "=", 
        RowBox[{
         RowBox[{
          RowBox[{"contractedtensor", "[", 
           RowBox[{"sym", "[", 
            RowBox[{"Einstein", "[", 
             RowBox[{"Expand", "[", "tensorialpart", "]"}], "]"}], "]"}], 
           "]"}], "+", 
          RowBox[{"Apply", "[", 
           RowBox[{"Plus", ",", 
            RowBox[{
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"c", "[", 
                 RowBox[{"num$freeindices", ",", "ii"}], "]"}], 
                RowBox[{"symwithoutfactor", "[", 
                 RowBox[{
                 "tensor\[Delta]combinations", "\[LeftDoubleBracket]", "ii", 
                  "\[RightDoubleBracket]"}], "]"}]}], ",", 
               RowBox[{"{", 
                RowBox[{"ii", ",", "1", ",", 
                 RowBox[{"Length", "[", "tensor\[Delta]combinations", "]"}]}],
                 "}"}]}], "]"}], "/.", 
             RowBox[{
              RowBox[{"c", "[", 
               RowBox[{"num$freeindices", ",", "0"}], "]"}], "\[Rule]", 
              "1"}]}]}], "]"}]}], "/.", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"c", "[", 
             RowBox[{"num$freeindices", ",", "k"}], "]"}], "\[Rule]", 
            FractionBox[
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], "k"], 
             RowBox[{
              UnderoverscriptBox["\[Product]", 
               RowBox[{"j", "=", "0"}], 
               RowBox[{"k", "-", "1"}]], 
              RowBox[{"(", 
               RowBox[{"d", "+", 
                RowBox[{"2", "num$freeindices"}], "-", "4", "-", 
                RowBox[{"2", "j"}]}], ")"}]}]]}], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "1", ",", 
             FractionBox["num$freeindices", "2"]}], "}"}]}], "]"}]}]}], ";", 
       " ", 
       RowBox[{"(*", 
        StyleBox[
         RowBox[{
          RowBox[{
          "These", " ", "coefficients", " ", "can", " ", "be", " ", 
           "computed", " ", "separately", " ", "using", " ", "the", " ", 
           "function", " ", "coeff$symtracefreetensor"}], ";", " ", 
          RowBox[{
          "see", " ", "the", " ", "function", " ", "in", " ", "Appendix", " ",
            "at", " ", "the", " ", "end", " ", "of", " ", "this", " ", 
           RowBox[{"file", "."}]}]}],
         FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"Return", "[", 
        RowBox[{"constantfactor", " ", "generalform"}], "]"}]}]}], 
     "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tracelessPart", "[", "ex_", "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"output", ",", "ex1"}], "}"}], ",", 
    RowBox[{
     RowBox[{"ex1", "=", 
      RowBox[{"Expand", "[", "ex", "]"}]}], ";", 
     RowBox[{"output", "=", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Head", "[", "ex1", "]"}], "===", " ", "Plus"}], ",", 
        RowBox[{"Apply", "[", 
         RowBox[{"Plus", ",", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"tracelessPart1", "[", 
             RowBox[{
             "ex1", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}], 
             "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"ii", ",", "1", ",", 
              RowBox[{"Length", "[", "ex1", "]"}]}], "}"}]}], "]"}]}], "]"}], 
        ",", 
        RowBox[{"tracelessPart1", "[", "ex1", "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Return", "[", "output", "]"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.737963078219451*^9, 3.7379630791278152`*^9}, {
  3.737992038942061*^9, 3.737992062408701*^9}, {3.737992325979456*^9, 
  3.737992354705715*^9}, {3.7379923874358053`*^9, 3.7379924081736193`*^9}, {
  3.737992472744418*^9, 3.737992548856498*^9}, {3.737992616923456*^9, 
  3.737992751385076*^9}, {3.737992802823071*^9, 3.737992838834827*^9}, {
  3.73799351135367*^9, 3.737993706996868*^9}, {3.737993766942254*^9, 
  3.737993768084895*^9}, {3.737993903462543*^9, 3.737993978247134*^9}, {
  3.737994234671432*^9, 3.737994264550948*^9}, {3.737995140831094*^9, 
  3.737995145244542*^9}},ExpressionUUID->"b4495409-e992-44d2-867e-\
9939e9c35b59"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Function for representing a symmetric tensor in terms of traceless tensors\
\>", "Subsection",
 CellChangeTimes->{{3.73744529910393*^9, 3.737445317616681*^9}, {
  3.737445371377437*^9, 3.7374453844968567`*^9}, {3.7375211271986647`*^9, 
  3.7375211382437963`*^9}, {3.737700375799358*^9, 3.737700376518396*^9}, {
  3.737994065793682*^9, 3.737994100979127*^9}, {3.738058565037451*^9, 
  3.738058569341807*^9}},ExpressionUUID->"da6ec88e-e2b6-4d2f-a1c8-\
311700687c73"],

Cell[TextData[{
 "In the following, ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Upsilon]", "[", 
    RowBox[{"n", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["i", "1"], 
         SubscriptBox["i", "2"]}], "..."}], 
       SubscriptBox["i", "n"]}], "}"}]}], "]"}], TraditionalForm]],
  ExpressionUUID->"3e954359-b589-4a67-9920-4890f71a8303"],
 "=",
 Cell[BoxData[
  FormBox[
   RowBox[{"Y", "[", 
    RowBox[{
     RowBox[{"2", "n"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["i", "1"], 
         SubscriptBox["i", "2"]}], "..."}], 
       SubscriptBox["i", "n"]}], "}"}]}], "]"}], TraditionalForm]],
  ExpressionUUID->"4fdbb55e-ed72-4ee6-8cb5-07acb4802db0"],
 ", where \[Upsilon] is the Henning\[CloseCurlyQuote]s notation for traceless \
tensor while ",
 Cell[BoxData[
  FormBox["Y", TraditionalForm]],ExpressionUUID->
  "859d478f-167b-4af1-8547-fa8dd804f934"],
 " are Ikenberry polynomials used in Garz\[OAcute] and Santos 2007 J. Phys. \
A: Math. Theor. 40 14927."
}], "Text",
 CellChangeTimes->{{3.7383948757726603`*^9, 3.7383951458540382`*^9}, {
  3.7383952080125837`*^9, 3.738395212061092*^9}},
 FontColor->RGBColor[1, 0, 0],
 Background->RGBColor[
  0.87, 0.94, 1],ExpressionUUID->"8f4c2be6-537c-42b5-a89c-f5fe3b74d127"],

Cell[TextData[{
 "This function takes a tensor (e.g., A[{i,j,k,l}] or ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["A", "2"], 
    RowBox[{"A", "[", 
     RowBox[{"{", "i", "}"}], "]"}], 
    RowBox[{"A", "[", 
     RowBox[{"{", "j", "}"}], "]"}], 
    RowBox[{"A", "[", 
     RowBox[{"{", "k", "}"}], "]"}], 
    RowBox[{"A", "[", 
     RowBox[{"{", "l", "}"}], "]"}]}], TraditionalForm]],ExpressionUUID->
  "f121c98a-e787-4d8e-a5b2-eafe79ea6d42"],
 " or A[{i}]A[{j}]A[{k}]A[{l}]A[{m}]A[{m}]) and represents it in the \
contracted form with only one head (e.g., A[0,{i,j,k,l}] or ",
 Cell[BoxData[
  FormBox[
   RowBox[{"A", "[", 
    RowBox[{"1", ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}]}], "]"}], 
   TraditionalForm]],ExpressionUUID->"00bbb620-b933-46d4-9ebe-31d4cd8ab162"],
 " or A[1,{i,j,k,l}], respectively for the above examples)."
}], "Text",
 CellChangeTimes->{{3.7380585808613586`*^9, 3.738058713486417*^9}, {
  3.738318066763255*^9, 3.7383182502686*^9}},
 FontColor->RGBColor[1, 0, 0],
 Background->RGBColor[
  0.87, 0.94, 1],ExpressionUUID->"e41506d7-0671-46b5-9d0a-dd9a55eef1ad"],

Cell[BoxData[
 RowBox[{
  RowBox[{"changetensorform", "[", "ex_", "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "attributes", ",", "constantfactor", ",", "tensorialpart", ",", 
      "freeindices", ",", "tensorialparthavingfreeindices", ",", 
      "tensorialpartNOThavingfreeindices", ",", "tensornames", ",", 
      "tensorname", ",", "newtensor", ",", "initialtensor", ",", "initialpow",
       ",", "templist", ",", "pow", ",", "powinconstantfactor", ",", 
      "originaltensor", ",", "newform", ",", "newtensorname", ",", 
      "newtensorialpart", ",", "newtensorialpartNOThavingfreeindices", ",", 
      "newconstantfactor"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"attributes", "=", 
      RowBox[{"tensorattributes", "[", "ex", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Head", "[", "attributes", "]"}], "\[Equal]", "String"}], ",", 
       RowBox[{"Return", "[", "attributes", "]"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"constantfactor", "=", 
      RowBox[{"constantfactor", "/.", "attributes"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"tensorialpart", "=", 
      RowBox[{"tensorialpart", "/.", "attributes"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"freeindices", "=", 
      RowBox[{"freeindices", "/.", "attributes"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"tensorialparthavingfreeindices", "=", 
      RowBox[{"tensorialparthavingfreeindices", "/.", "attributes"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"tensorialpartNOThavingfreeindices", "=", 
      RowBox[{"tensorialpartNOThavingfreeindices", "/.", "attributes"}]}], 
     ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"Return", "[", "tensorialpartNOThavingfreeindices", "]"}], 
       ";"}], "*)"}], "\[IndentingNewLine]", 
     RowBox[{"tensornames", "=", 
      RowBox[{"Head", "/@", 
       RowBox[{
        RowBox[{"Drop", "[", 
         RowBox[{
          RowBox[{"FactorList", "[", "tensorialpart", "]"}], ",", "1"}], 
         "]"}], "\[LeftDoubleBracket]", 
        RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}]}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Length", "[", "tensornames", "]"}], "\[Equal]", "1"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"tensorname", "=", 
         RowBox[{
         "tensornames", "\[LeftDoubleBracket]", "1", 
          "\[RightDoubleBracket]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"newtensor", "=", 
         RowBox[{"contractedtensor", "[", "tensorialpart", "]"}]}]}], ",", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"tensorname", "=", 
         RowBox[{
          RowBox[{"DeleteDuplicates", "[", 
           RowBox[{"Head", "/@", 
            RowBox[{
             RowBox[{"Drop", "[", 
              RowBox[{
               RowBox[{"FactorList", "[", "tensorialpart", "]"}], ",", "1"}], 
              "]"}], "\[LeftDoubleBracket]", 
             RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}]}], "]"}], 
          "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"initialtensor", "=", 
         RowBox[{"contractedtensor", "[", 
          RowBox[{"tensorname", "[", "freeindices", "]"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"initialpow", "=", 
         RowBox[{
          RowBox[{"Cases", "[", 
           RowBox[{"initialtensor", ",", "_Integer"}], "]"}], 
          "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"(*", 
         StyleBox[
          RowBox[{
          "For", " ", "tensors", " ", "of", " ", "the", " ", "form", " ", 
           RowBox[{"V", "[", 
            RowBox[{"{", "i", "}"}], "]"}], 
           RowBox[{"V", "[", 
            RowBox[{"{", "j", "}"}], "]"}], 
           RowBox[{"V", "[", 
            RowBox[{"{", "m", "}"}], "]"}], 
           RowBox[{"V", "[", 
            RowBox[{"{", "m", "}"}], "]"}]}],
          FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
        RowBox[{"templist", "=", 
         RowBox[{"Cases", "[", 
          RowBox[{"tensorialpartNOThavingfreeindices", ",", 
           SuperscriptBox[
            RowBox[{"tensorname", "[", "_", "]"}], "2"]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"pow", "=", 
         RowBox[{"initialpow", "+", 
          RowBox[{"Length", "[", "templist", "]"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{"newtensor", "=", 
           RowBox[{"contractedtensor", "[", 
            RowBox[{"tensorname", "[", 
             RowBox[{"pow", ",", "freeindices"}], "]"}], "]"}]}], ";"}], 
         "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"(*", 
         StyleBox[
          RowBox[{
          "For", " ", "tensors", " ", "of", " ", "the", " ", "form", " ", 
           SuperscriptBox["V", "4"], 
           RowBox[{"V", "[", 
            RowBox[{"{", "i", "}"}], "]"}], 
           RowBox[{"V", "[", 
            RowBox[{"{", "j", "}"}], "]"}]}],
          FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
        RowBox[{"powinconstantfactor", "=", 
         RowBox[{"Exponent", "[", 
          RowBox[{"constantfactor", ",", "tensorname"}], "]"}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"EvenQ", "[", "powinconstantfactor", "]"}], ",", 
          RowBox[{
           RowBox[{"constantfactor", "=", 
            RowBox[{"constantfactor", "/", 
             SuperscriptBox["tensorname", "powinconstantfactor"]}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"pow", "+=", 
            FractionBox["powinconstantfactor", "2"]}], ";"}], 
          "\[IndentingNewLine]", 
          RowBox[{"(*", 
           RowBox[{"newtensor", "=", 
            RowBox[{"contractedtensor", "[", 
             RowBox[{"tensorname", "[", 
              RowBox[{"pow", ",", "freeindices"}], "]"}], "]"}]}], "*)"}], 
          ",", 
          RowBox[{
           RowBox[{"constantfactor", "=", 
            RowBox[{"constantfactor", "/", 
             SuperscriptBox["tensorname", 
              RowBox[{"powinconstantfactor", "-", "1"}]]}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"pow", "+=", 
            FractionBox[
             RowBox[{"powinconstantfactor", "-", "1"}], "2"]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"(*", 
            RowBox[{
             RowBox[{"newtensor", "=", 
              RowBox[{"(*", "constantfactor", "*)"}], " ", 
              RowBox[{"contractedtensor", "[", 
               RowBox[{"tensorname", "[", 
                RowBox[{"pow", ",", "freeindices"}], "]"}], "]"}]}], ";"}], 
            "*)"}], "\[IndentingNewLine]", 
           RowBox[{
           "Print", "[", 
            "\"\<\!\(\*StyleBox[\"Warning\",FontColor->RGBColor[1, 0, 0]]\)\!\
\(\*StyleBox[\":\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"Power\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"of\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"tensor\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\
\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"magnitude\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\"was\
\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, \
0, 0]]\)\!\(\*StyleBox[\"odd\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\
\".\",FontColor->RGBColor[1, 0, 0]]\)\>\"", "]"}], ";"}]}], 
         "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"newtensor", "=", 
         RowBox[{"contractedtensor", "[", 
          RowBox[{"tensorname", "[", 
           RowBox[{"pow", ",", "freeindices"}], "]"}], "]"}]}], ";"}]}], 
      "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"Return", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"originaltensor", "\[Rule]", "ex"}], ",", 
        RowBox[{"newform", "\[Rule]", 
         RowBox[{
         "constantfactor", " ", "newtensor", " ", 
          "tensorialpartNOThavingfreeindices"}]}], ",", 
        RowBox[{"newtensorname", "\[Rule]", "tensorname"}], ",", 
        RowBox[{"newtensorialpart", "\[Rule]", "newtensor"}], ",", 
        RowBox[{
        "newtensorialpartNOThavingfreeindices", "\[Rule]", 
         "tensorialpartNOThavingfreeindices"}], ",", 
        RowBox[{"newconstantfactor", "\[Rule]", "constantfactor"}]}], "}"}], 
      "]"}]}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.738317496311796*^9, 3.7383175019121017`*^9}, {
   3.738317580440467*^9, 3.7383176701257772`*^9}, {3.73831771134057*^9, 
   3.738317754894517*^9}, {3.7383178149576397`*^9, 3.738317853022511*^9}, {
   3.738317909663526*^9, 3.7383179577781057`*^9}, {3.738318467058538*^9, 
   3.7383184913342533`*^9}, 3.7383187381935463`*^9, {3.738364405709947*^9, 
   3.738364491429195*^9}, {3.7383920488873158`*^9, 3.7383920581178417`*^9}, 
   3.738392747066654*^9, {3.738393092138783*^9, 3.738393092781755*^9}, {
   3.738393173663793*^9, 3.738393186153934*^9}, {3.738393220575008*^9, 
   3.738393256157117*^9}},ExpressionUUID->"855fe1f3-b537-4644-9444-\
95ede9f12ef3"],

Cell["\<\
This function takes only a fully symmetric tensor (e.g., A[{i,j,k,l}] or \
A[{i}]A[{j}]A[{k}]A[{l}]) and represents it in terms of its own traceless \
part.\
\>", "Text",
 CellChangeTimes->{{3.7380585808613586`*^9, 3.738058713486417*^9}, {
  3.738060201414957*^9, 3.7380602033662148`*^9}, {3.738318354764119*^9, 
  3.738318389197043*^9}},
 FontColor->RGBColor[1, 0, 0],
 Background->RGBColor[
  0.87, 0.94, 1],ExpressionUUID->"05a5a839-82ac-4c71-a5cd-1f27387b0b1d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"replacementsfortracefreerepresentation", "[", "ex_", "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "attributes", ",", "freeindices", ",", "transformed", ",", "newtensor", 
      ",", "newtensorialpart", ",", "constantfactor", ",", 
      "newconstantfactor", ",", "tensorname", ",", "newtensorname", ",", 
      "\[Upsilon]", ",", 
      RowBox[{"list", "=", 
       RowBox[{"{", "}"}]}], ",", "contractionreplacements", ",", 
      "deftracefree", ",", "originaltensor", ",", "partialtracelessform"}], 
     "}"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"attributes", "=", 
      RowBox[{"tensorattributes", "[", "ex", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Head", "[", "attributes", "]"}], "\[Equal]", "String"}], ",", 
       RowBox[{"Return", "[", "attributes", "]"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"freeindices", "=", 
      RowBox[{"freeindices", "/.", "attributes"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"transformed", "=", 
      RowBox[{"changetensorform", "[", "ex", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"newtensor", "=", 
      RowBox[{"newtensorialpart", "/.", "transformed"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"constantfactor", "=", 
      RowBox[{"newconstantfactor", "/.", "transformed"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"tensorname", "=", 
      RowBox[{"newtensorname", "/.", "transformed"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"Return", "[", "tensorname", "]"}], ";"}], "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Length", "[", "freeindices", "]"}], "<", "2"}], ",", 
       RowBox[{"Return", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"contractedtensor", "[", 
           RowBox[{"sym", "[", "newtensor", "]"}], "]"}], "\[Rule]", 
          RowBox[{"contractedtensor", "[", 
           RowBox[{"sym", "[", "newtensor", "]"}], 
           RowBox[{"(*", 
            RowBox[{"/.", 
             RowBox[{"tensorname", "\[Rule]", "\[Upsilon]"}]}], "*)"}], 
           "]"}]}], "}"}], "]"}]}], "\[IndentingNewLine]", "]"}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Length", "[", "freeindices", "]"}], "\[GreaterEqual]", "2"}],
        ",", 
       RowBox[{
        RowBox[{"contractionreplacements", "=", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"list", "=", 
            RowBox[{"Join", "[", 
             RowBox[{"list", ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"freeindices", "\[LeftDoubleBracket]", 
                 RowBox[{"2", "ii"}], "\[RightDoubleBracket]"}], "\[Rule]", 
                RowBox[{"freeindices", "\[LeftDoubleBracket]", 
                 RowBox[{
                  RowBox[{"2", "ii"}], "-", "1"}], 
                 "\[RightDoubleBracket]"}]}], "}"}]}], "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"ii", ",", 
             RowBox[{
              RowBox[{"Length", "[", "freeindices", "]"}], "/", "2"}], ",", 
             "1", ",", 
             RowBox[{"-", "1"}]}], "}"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"deftracefree", "=", 
         RowBox[{"tracelessPart", "[", "newtensor", "]"}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"(*", 
         RowBox[{
         "\[Upsilon]", " ", "denotes", " ", "traceless", " ", "tensor"}], 
         "*)"}], "\[IndentingNewLine]", 
        RowBox[{"partialtracelessform", "=", 
         RowBox[{
          RowBox[{
           RowBox[{"Solve", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"contractedtensor", "[", 
                 RowBox[{"sym", "[", "newtensor", "]"}], "]"}], "/.", 
                RowBox[{"{", 
                 RowBox[{"tensorname", "\[Rule]", "\[Upsilon]"}], "}"}]}], 
               ")"}], "\[Equal]", 
              RowBox[{"(", 
               RowBox[{"deftracefree", "/.", 
                RowBox[{
                 RowBox[{"contractedtensor", "[", 
                  RowBox[{"sym", "[", "newtensor", "]"}], "]"}], "\[Rule]", 
                 "originaltensor"}]}], ")"}]}], ",", "originaltensor"}], 
            "]"}], "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "/.", 
          RowBox[{"originaltensor", "\[Rule]", 
           RowBox[{"contractedtensor", "[", 
            RowBox[{"sym", "[", "newtensor", "]"}], "]"}]}]}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"Return", "[", "partialtracelessform", "]"}]}]}], 
      "\[IndentingNewLine]", "]"}], ";"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.738169674966022*^9, 3.738169719977676*^9}, {
   3.738303414991144*^9, 3.738303489601696*^9}, {3.73830352213078*^9, 
   3.7383035323065157`*^9}, {3.7383035670137863`*^9, 3.738303569508087*^9}, {
   3.7383036561159163`*^9, 3.7383036655107117`*^9}, 3.738303698011992*^9, 
   3.738303762252146*^9, 3.7383037973617353`*^9, {3.7383042096216297`*^9, 
   3.738304210145247*^9}, {3.738304274753131*^9, 3.7383043411865463`*^9}, {
   3.738306398767455*^9, 3.73830640423976*^9}, {3.7383064596966343`*^9, 
   3.73830651787278*^9}, {3.73830655364834*^9, 3.738306630018008*^9}, {
   3.738306660627219*^9, 3.738306690945657*^9}, {3.738306786594962*^9, 
   3.7383069636206903`*^9}, {3.738307108247685*^9, 3.738307163621603*^9}, {
   3.738307225878889*^9, 3.738307230251398*^9}, {3.738307273077756*^9, 
   3.73830727421498*^9}, {3.7383073120571938`*^9, 3.738307401565968*^9}, {
   3.7383074640904818`*^9, 3.738307465203055*^9}, {3.738307603115221*^9, 
   3.738307629991817*^9}, {3.738307683772244*^9, 3.738307724322152*^9}, {
   3.7383077552937593`*^9, 3.73830779509689*^9}, 3.738307893012343*^9, {
   3.738307987435824*^9, 3.738308050657168*^9}, {3.738308135855809*^9, 
   3.7383081529247217`*^9}, {3.738308326974309*^9, 3.738308370908351*^9}, {
   3.738308659728334*^9, 3.7383086899664907`*^9}, {3.73830872291486*^9, 
   3.7383087245922537`*^9}, {3.738308769366*^9, 3.7383088239355383`*^9}, {
   3.738308929857296*^9, 3.738308947989085*^9}, {3.738309092531556*^9, 
   3.7383091401449947`*^9}, {3.738309170149745*^9, 3.7383091758335333`*^9}, {
   3.7383092294288588`*^9, 3.738309278194317*^9}, {3.738309460499105*^9, 
   3.738309580387659*^9}, {3.738309620787589*^9, 3.7383097856943903`*^9}, {
   3.73830981812036*^9, 3.738309825157572*^9}, {3.7383099035439*^9, 
   3.7383099661111917`*^9}, {3.738310003109765*^9, 3.738310053094165*^9}, {
   3.738310108109519*^9, 3.738310181799576*^9}, {3.738313357095167*^9, 
   3.73831336608712*^9}, {3.7383134549516983`*^9, 3.73831350706397*^9}, {
   3.73831368591829*^9, 3.7383137633432703`*^9}, {3.738314131357395*^9, 
   3.738314143892229*^9}, {3.738314235243478*^9, 3.738314273259096*^9}, {
   3.738314315277017*^9, 3.738314331840507*^9}, {3.73831438570935*^9, 
   3.7383143905246*^9}, {3.738314478466794*^9, 3.738314505853961*^9}, {
   3.738314589232922*^9, 3.73831460270415*^9}, {3.7383147193600903`*^9, 
   3.738314749663074*^9}, {3.738314793424336*^9, 3.738314803443451*^9}, {
   3.738314844256749*^9, 3.738314844833063*^9}, {3.73831488024548*^9, 
   3.7383148861778383`*^9}, {3.738315704847309*^9, 3.738315727957183*^9}, {
   3.738315803113317*^9, 3.7383158061322193`*^9}, {3.738315840997525*^9, 
   3.738315853686187*^9}, 3.738318408950699*^9, {3.738318968789546*^9, 
   3.738319157477851*^9}, {3.738319192278493*^9, 3.738319235876857*^9}, {
   3.738319271236581*^9, 3.738319286084893*^9}, {3.738319341417778*^9, 
   3.738319485779086*^9}, {3.73831952482262*^9, 3.73831958871008*^9}, {
   3.738319630773674*^9, 3.73831963624688*^9}, {3.738319847689291*^9, 
   3.738319875549082*^9}, 3.738319922941267*^9, {3.738319956027327*^9, 
   3.7383200006494226`*^9}, 3.738320938562419*^9, {3.7383907596964006`*^9, 
   3.738390814319385*^9}},ExpressionUUID->"3bf9b250-d52c-46a6-b354-\
f8ea7de5ec8d"],

Cell["\<\
This function takes a fully symmetric tensor (e.g., A[{i,j,k,l}] or \
A[{i}]A[{j}]A[{k}]A[{l}]) and represents it completely in terms of traceless \
tensors.\
\>", "Text",
 CellChangeTimes->{{3.7380585808613586`*^9, 3.738058713486417*^9}},
 FontColor->RGBColor[1, 0, 0],
 Background->RGBColor[
  0.87, 0.94, 1],ExpressionUUID->"b3d9d75b-2b98-45c9-8ce0-ddfd5876e1c3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tracefreerepresentation", "[", "ex_", "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "attributes", ",", "constantfactor", ",", "tensorialpart", ",", 
      "freeindices", ",", "tensorialparthavingfreeindices", ",", 
      "tensorialpartNOThavingfreeindices", ",", 
      "tensorialpartNOThavingfreeindices$", ",", 
      "newtensorialpartNOThavingfreeindices", ",", "tensornames", ",", 
      "transformed", ",", "transformedtensor", ",", "newtensorialpart", ",", 
      "newconstantfactor", ",", "newtensorname", ",", "newtensor", ",", 
      "tensornames$havingfreeindices", ",", "tensorname", ",", 
      RowBox[{"list", "=", 
       RowBox[{"{", "}"}]}], ",", "contractionreplacements", ",", 
      "deftracefree", ",", "originaltensor", ",", "tempvar", ",", "dummy", 
      ",", "list$alltensors", ",", "replacementlist", ",", "toreplace", ",", 
      "\[CapitalSampi]"}], "}"}], ",", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"attributes", "=", 
      RowBox[{"tensorattributes", "[", "ex", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Head", "[", "attributes", "]"}], "\[Equal]", "String"}], ",", 
       RowBox[{"Return", "[", "attributes", "]"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"constantfactor", "=", 
      RowBox[{"constantfactor", "/.", "attributes"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"tensorialpart", "=", 
      RowBox[{"tensorialpart", "/.", "attributes"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"freeindices", "=", 
      RowBox[{"freeindices", "/.", "attributes"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"tensorialparthavingfreeindices", "=", 
      RowBox[{"tensorialparthavingfreeindices", "/.", "attributes"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"tensorialpartNOThavingfreeindices", "=", 
      RowBox[{"tensorialpartNOThavingfreeindices", "/.", "attributes"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"tensornames", "=", 
      RowBox[{"DeleteDuplicates", "[", 
       RowBox[{"tensornames$havingfreeindices", "/.", "attributes"}], "]"}]}],
      ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Length", "[", "freeindices", "]"}], "<", "2"}], ",", 
       RowBox[{"Return", "[", 
        RowBox[{"constantfactor", " ", 
         RowBox[{"contractedtensor", "[", 
          RowBox[{"sym", "[", "tensorialpart", "]"}], "]"}]}], "]"}]}], "]"}],
      ";", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"Return", "[", "tensorialparthavingfreeindices", "]"}], ";"}], 
      "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Length", "[", "tensornames", "]"}], ">", "1"}], ",", 
       RowBox[{"Return", "[", 
        RowBox[{
        "\"\<\!\(\*StyleBox[\"Free\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"indices\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, 0]]\)\>\"", "<>", 
         RowBox[{"ToString", "[", "freeindices", "]"}], "<>", 
         "\"\<\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"in\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"the\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"given\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"expression\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"belong\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\
\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"to\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"more\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"than\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"one\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"tensor\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\
\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"head\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\".\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"Thus\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\",\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"the\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"given\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"expression\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"is\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"not\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"in\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"symmetric\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"form\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\".\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"Consequently\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\",\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"this\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"function\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"is\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"not\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"capable\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"of\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"representing\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\"the\
\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, \
0, 0]]\)\!\(\*StyleBox[\"given\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"expression\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"in\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"terms\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"of\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"traceless\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"tensors\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"completely\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\";\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"sorry\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\".\",FontColor->RGBColor[1, 0, 0]]\)\>\""}], "]"}]}], 
      "]"}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Length", "[", "tensorialparthavingfreeindices", "]"}], 
           "\[NotEqual]", "1"}], "&&", 
          RowBox[{
           RowBox[{"Length", "[", "tensorialparthavingfreeindices", "]"}], 
           "\[NotEqual]", 
           RowBox[{"Length", "[", "freeindices", "]"}]}]}], ",", 
         RowBox[{
         "Return", "[", 
          "\"\<\!\(\*StyleBox[\"The\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"given\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"expression\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"is\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"not\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"in\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"symmetric\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"form\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\".\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"Consequently\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\",\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"this\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"function\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"is\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"not\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"capable\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"of\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"representing\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\"the\
\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, \
0, 0]]\)\!\(\*StyleBox[\"given\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"expression\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"in\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"terms\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"of\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"traceless\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"tensors\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\" \",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"completely\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\";\",FontColor->RGBColor[1, 0, 0]]\)\!\(\*StyleBox[\" \
\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\"sorry\",FontColor->RGBColor[1, 0, \
0]]\)\!\(\*StyleBox[\".\",FontColor->RGBColor[1, 0, 0]]\)\>\"", "]"}]}], 
        "]"}], ";"}], "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"transformed", "=", 
      RowBox[{"changetensorform", "[", "ex", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"transformedtensor", "=", 
      RowBox[{"newtensorialpart", "/.", "transformed"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"constantfactor", "=", 
      RowBox[{"newconstantfactor", "/.", "transformed"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"tensorname", "=", 
      RowBox[{"newtensorname", "/.", "transformed"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"tensorialpartNOThavingfreeindices$", "=", 
      RowBox[{"newtensorialpartNOThavingfreeindices", "/.", "transformed"}]}],
      ";", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"tensorname", "=", 
        RowBox[{
        "tensornames", "\[LeftDoubleBracket]", "1", 
         "\[RightDoubleBracket]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"tensorialpart", "=", 
        RowBox[{"contractedtensor", "[", "tensorialpart", "]"}]}], ";"}], 
      "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"deftracefree", "=", 
      RowBox[{"tracelessPart", "[", "transformedtensor", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"Return", "[", "deftracefree", "]"}], ";"}], "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      StyleBox[
       RowBox[{
       "To", " ", "extract", " ", "all", " ", "the", " ", "tensors", " ", 
        "from", " ", "deftracefree"}],
       FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
     RowBox[{"tempvar", "=", 
      RowBox[{"DeleteCases", "[", 
       RowBox[{
        RowBox[{"Apply", "[", 
         RowBox[{"List", ",", 
          RowBox[{"Expand", "[", 
           RowBox[{
            RowBox[{"dummy", "+", "deftracefree"}], "/.", 
            RowBox[{
             RowBox[{"\[Delta]", "[", "_", "]"}], "\[Rule]", "1"}]}], "]"}]}],
          "]"}], ",", "dummy"}], "]"}]}], ";", " ", 
     RowBox[{"(*", 
      StyleBox[
       RowBox[{
        RowBox[{
        "dummy", " ", "is", " ", "added", " ", "and", " ", "deleted", " ", 
         "to", " ", "get", " ", "correct", " ", "list", " ", "when", " ", 
         "there", " ", "is", " ", "only", " ", "a", " ", "single", " ", 
         "element", " ", "with", " ", "square"}], ",", " ", 
        RowBox[{"e", ".", "g", ".", " ", 
         SuperscriptBox[
          RowBox[{"A", "[", 
           RowBox[{"{", "p0", "}"}], "]"}], "2"]}]}],
       FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"Return", "[", "tempvar", "]"}], ";"}], "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"list$alltensors", "=", 
      RowBox[{"DeleteDuplicates", "[", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"tensorialpart", "/.", 
          RowBox[{"tensorattributes", "[", 
           RowBox[{
           "tempvar", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}],
            "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"ii", ",", "1", ",", 
           RowBox[{"Length", "[", "tempvar", "]"}]}], "}"}]}], "]"}], "]"}]}],
      ";", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"Return", "[", "list$alltensors", "]"}], ";"}], "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"replacementlist", "=", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"replacementsfortracefreerepresentation", "[", 
          RowBox[{
          "list$alltensors", "\[LeftDoubleBracket]", "ii", 
           "\[RightDoubleBracket]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"ii", ",", "1", ",", 
           RowBox[{"Length", "[", "list$alltensors", "]"}]}], "}"}]}], "]"}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"Return", "[", "replacementlist", "]"}], ";"}], "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"toreplace", "=", 
      RowBox[{
      "list$alltensors", "\[LeftDoubleBracket]", "1", 
       "\[RightDoubleBracket]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"Return", "[", "toreplace", "]"}], ";"}], "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"\[CapitalSampi]", "=", "1"}], ",", 
       RowBox[{"\[CapitalSampi]", "\[LessEqual]", 
        RowBox[{"Length", "[", "replacementlist", "]"}]}], ",", 
       RowBox[{"\[CapitalSampi]", "++"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"toreplace", "=", 
         RowBox[{"toreplace", "/.", "replacementlist"}]}], ";"}]}], 
      "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"Return", "[", 
      RowBox[{
      "constantfactor", " ", "tensorialpartNOThavingfreeindices$", " ", 
       "toreplace"}], "]"}]}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.7380588169312572`*^9, 3.738058861423634*^9}, 
   3.73805892464764*^9, {3.7380596675183*^9, 3.73805968912715*^9}, {
   3.738059780492338*^9, 3.738059937612496*^9}, {3.738060057628709*^9, 
   3.73806011537691*^9}, {3.73806069251446*^9, 3.738060753667498*^9}, {
   3.738060840788409*^9, 3.738060847011858*^9}, {3.7380609090152903`*^9, 
   3.7380609108484373`*^9}, 3.738063656225876*^9, {3.738063717107703*^9, 
   3.738063738321307*^9}, {3.73806381280086*^9, 3.738063835680039*^9}, {
   3.73806393371532*^9, 3.738063937938118*^9}, {3.738064824776578*^9, 
   3.73806483034472*^9}, {3.738067704677537*^9, 3.738067716420665*^9}, {
   3.738067835496395*^9, 3.738067843239238*^9}, {3.738067894904694*^9, 
   3.738067899913848*^9}, {3.738068684777719*^9, 3.7380687859823008`*^9}, 
   3.73831397841294*^9, 3.738314946430634*^9, 3.738315259509736*^9, {
   3.738315926263205*^9, 3.738316034908394*^9}, {3.738316071982128*^9, 
   3.73831607376747*^9}, {3.73831610403377*^9, 3.738316112022951*^9}, {
   3.7383161939947023`*^9, 3.73831619668583*^9}, 3.7383162766003027`*^9, 
   3.73831633703306*^9, {3.738316388595091*^9, 3.738316416731206*^9}, {
   3.738316527978245*^9, 3.7383165803642817`*^9}, 3.738316755506865*^9, 
   3.73832030744419*^9, {3.738320445054994*^9, 3.738320487378869*^9}, {
   3.7383205290746117`*^9, 3.73832053073484*^9}, {3.738320566986361*^9, 
   3.738320610356975*^9}, {3.738320655263525*^9, 3.7383206898119793`*^9}, {
   3.7383207400006847`*^9, 3.738320833940485*^9}, {3.738320867735057*^9, 
   3.738320881682865*^9}, 3.738320965955205*^9, 3.738320999942438*^9, {
   3.738321032196884*^9, 3.738321059237789*^9}, {3.738321249667513*^9, 
   3.738321369331695*^9}, {3.738321491868328*^9, 3.738321493275383*^9}, {
   3.738321528245819*^9, 3.738321572132359*^9}, {3.738321618340273*^9, 
   3.738321661797677*^9}, {3.738321708794799*^9, 3.7383217349711933`*^9}, {
   3.738321970872705*^9, 3.738321977527932*^9}, {3.7383914315934753`*^9, 
   3.738391450231625*^9}, {3.738393508621937*^9, 3.738393630871583*^9}, {
   3.738393672020645*^9, 3.7383936727213793`*^9}, 3.738394602259956*^9, 
   3.738401826072948*^9},ExpressionUUID->"9f53ba55-ef85-4390-a6d6-\
1048eafecfb9"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"tracefreerepresentation", "[", "ex_", "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", "ex1", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"ex1", "=", 
       RowBox[{"Expand", "[", "ex", "]"}]}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Head", "[", "ex1", "]"}], "===", " ", "Plus"}], ",", 
        RowBox[{"Return", "[", 
         RowBox[{"Apply", "[", 
          RowBox[{"Plus", ",", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"tracefreerepresentationsingle", "[", 
              RowBox[{
              "ex1", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}], 
              "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"ii", ",", "1", ",", 
               RowBox[{"Length", "[", "ex1", "]"}]}], "}"}]}], "]"}]}], "]"}],
          "]"}], ",", 
        RowBox[{"Return", "[", 
         RowBox[{"tracefreerepresentationsingle", "[", "ex1", "]"}], "]"}]}], 
       "]"}]}]}], "\[IndentingNewLine]", "]"}]}], "*)"}]], "Input",
 CellChangeTimes->{{3.738391441762882*^9, 3.7383915403977327`*^9}, 
   3.738401833964082*^9},ExpressionUUID->"b974b5b7-b159-4ad8-bf16-\
5346eee9717b"]
}, Closed]],

Cell[CellGroupData[{

Cell["Function for Integration", "Subsection",
 CellChangeTimes->{{3.7372721891507196`*^9, 
  3.7372722074867897`*^9}},ExpressionUUID->"3374725b-b06c-475d-b0c1-\
9a6837154205"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Unprotect", "[", "C", "]"}], ";"}], "\n", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "\[Sigma]", ",", "q", ",", "delta", ",", "\[Delta]", ",", "C", ",", "C1", 
   ",", "ff1", ",", "\[Alpha]", ",", "a", ",", "ex", ",", "pos", ",", "pow", 
   ",", "idx", ",", "idx2", ",", "d", ",", "res", ",", "t", ",", "B"}], 
  "]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"range", "[", 
    RowBox[{"i_", ",", "j_"}], "]"}], "=", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"j", "<", "i"}], "||", 
      RowBox[{"j", "\[LessEqual]", "0"}], "||", 
      RowBox[{"i", "<", "0"}]}], ",", 
     RowBox[{"{", "}"}], ",", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"i", "\[Equal]", "0"}], ",", 
       RowBox[{"Range", "[", 
        RowBox[{"1", ",", "j"}], "]"}], ",", 
       RowBox[{"Range", "[", 
        RowBox[{"i", ",", "j"}], "]"}]}], "]"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.5379862703261337`*^9, 3.537986381515239*^9}, {
   3.537986454573757*^9, 3.537986550840365*^9}, {3.537986596435871*^9, 
   3.537986615115354*^9}, {3.5379868223130217`*^9, 3.53798683122495*^9}, {
   3.5379911775695887`*^9, 3.537991199042038*^9}, 3.5426226299496326`*^9, {
   3.7372720473458223`*^9, 3.737272048463789*^9}, {3.737272144880224*^9, 
   3.737272145264268*^9}},ExpressionUUID->"6d8efbb6-c2a9-4d76-bcf9-\
001298357aba"],

Cell[TextData[{
 "The following function \
\[OpenCurlyDoubleQuote]IntDir\[CloseCurlyDoubleQuote] gives the integral over \
the directions (in spherical coordinate system) of vector \[OpenCurlyQuote]",
 "a",
 "\[CloseCurlyQuote] in the expression \[OpenCurlyQuote]ex\[CloseCurlyQuote]. \
It also adjusts the remaining powers of \[OpenCurlyQuote]a\[CloseCurlyQuote]. \
For example, it simplifies the integral ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{
     StyleBox["\[Integral]", "Text"], 
     RowBox[{
      SubscriptBox[
       StyleBox["a", "Text"], "i"], 
      SubscriptBox["a", "j"], 
      SubscriptBox["a", "k"], 
      SubscriptBox["a", "l"], 
      RowBox[{"f", "(", "a", ")"}], 
      StyleBox[
       RowBox[{"\[DifferentialD]", 
        StyleBox["a",
         FontWeight->"Bold"]}], "Text"]}]}],
    Background->RGBColor[1, 0.85, 0.85]], TraditionalForm]],ExpressionUUID->
  "bfc42e56-6ad8-47b6-aaab-8390585ec5de"],
 " to ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{
     StyleBox[
      FractionBox[
       RowBox[{"4", "\[Pi]"}], "15"], "Text"], 
     RowBox[{
      StyleBox["(", "Text"], 
      RowBox[{
       RowBox[{
        SubscriptBox[
         StyleBox["\[Delta]", "Text"], 
         StyleBox["ij",
          FontSlant->"Italic"]], 
        SubscriptBox["\[Delta]", 
         StyleBox["kl",
          FontSlant->"Italic"]]}], "+", 
       RowBox[{
        SubscriptBox[
         StyleBox["\[Delta]", "Text"], 
         StyleBox["ik",
          FontSlant->"Italic"]], 
        SubscriptBox["\[Delta]", 
         StyleBox["jl",
          FontSlant->"Italic"]]}], "+", 
       RowBox[{
        SubscriptBox[
         StyleBox["\[Delta]", "Text"], 
         StyleBox["il",
          FontSlant->"Italic"]], 
        SubscriptBox["\[Delta]", 
         StyleBox["jk",
          FontSlant->"Italic"]]}]}], ")"}], 
     StyleBox[
      RowBox[{
       SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], 
       RowBox[{
        SuperscriptBox["a", "6"], 
        RowBox[{"f", "(", "a", ")"}], 
        RowBox[{"\[DifferentialD]", "a"}]}]}], "Text"]}],
    Background->RGBColor[1, 0.85, 0.85]], TraditionalForm]],ExpressionUUID->
  "5c1eeafa-25ff-4943-bc90-aa766c38cbe9"],
 "."
}], "Text",
 CellChangeTimes->{{3.5379862279857197`*^9, 3.53798625940003*^9}, {
   3.537987171952818*^9, 3.537987175062252*^9}, {3.537987219174953*^9, 
   3.5379872797921658`*^9}, {3.53798732997698*^9, 3.5379873410970583`*^9}, {
   3.537987373617735*^9, 3.537987387338408*^9}, {3.5379875176922293`*^9, 
   3.537987579564767*^9}, {3.537992254725892*^9, 3.537992260502223*^9}, {
   3.537992301740964*^9, 3.537992518988699*^9}, {3.537992583852743*^9, 
   3.5379926457265797`*^9}, {3.5379926968877068`*^9, 
   3.5379927842248583`*^9}, {3.537992814528508*^9, 3.537992871943898*^9}, {
   3.537992934825746*^9, 3.537993004554228*^9}, 3.537993089187582*^9, {
   3.540738494982298*^9, 3.540738506669654*^9}},
 FontColor->RGBColor[1, 0, 0],
 Background->RGBColor[
  1, 0.85, 0.85],ExpressionUUID->"c157655a-070a-4829-bd83-dffb19e4ec35"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   StyleBox[
    RowBox[{"For", " ", "Maxwell", " ", "molecules"}],
    FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"intoverCC1", "[", "ex_", "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "exCpart", ",", "exCsqpart", ",", "exC1part", ",", "exC1sqpart", ",", 
       "remainingpart", ",", "idxPowC", ",", "idxPowC1", ",", "indicesC", ",",
        "indicesC1", ",", "dummy"}], "}"}], ",", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      StyleBox[
       RowBox[{"Extracts", " ", "C", " ", "C1", " ", 
        SuperscriptBox["C", "2"], 
        SuperscriptBox["C1", "2"], " ", "and", " ", "constant", " ", "factor",
         " ", "in", " ", "an", " ", "expression"}],
       FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"exCpart", "=", 
       RowBox[{"Apply", "[", 
        RowBox[{"Times", ",", 
         RowBox[{"Extract", "[", 
          RowBox[{"ex", ",", 
           RowBox[{"Position", "[", 
            RowBox[{"ex", ",", 
             RowBox[{"C", "[", "_", "]"}], ",", "1"}], "]"}]}], "]"}]}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"exCsqpart", "=", 
       RowBox[{"Apply", "[", 
        RowBox[{"Times", ",", 
         RowBox[{"Extract", "[", 
          RowBox[{"ex", ",", 
           RowBox[{"Position", "[", 
            RowBox[{"ex", ",", 
             SuperscriptBox[
              RowBox[{"C", "[", "_", "]"}], "_"], ",", "1"}], "]"}]}], 
          "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"exC1part", "=", 
       RowBox[{"Apply", "[", 
        RowBox[{"Times", ",", 
         RowBox[{"Extract", "[", 
          RowBox[{"ex", ",", 
           RowBox[{"Position", "[", 
            RowBox[{"ex", ",", 
             RowBox[{"C1", "[", "_", "]"}], ",", "1"}], "]"}]}], "]"}]}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"exC1sqpart", "=", 
       RowBox[{"Apply", "[", 
        RowBox[{"Times", ",", 
         RowBox[{"Extract", "[", 
          RowBox[{"ex", ",", 
           RowBox[{"Position", "[", 
            RowBox[{"ex", ",", 
             SuperscriptBox[
              RowBox[{"C1", "[", "_", "]"}], "_"], ",", "1"}], "]"}]}], 
          "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"remainingpart", "=", 
       RowBox[{"ex", "/", 
        RowBox[{"(", 
         RowBox[{
         "exCpart", " ", "exCsqpart", " ", "exC1part", " ", "exC1sqpart"}], 
         ")"}]}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", 
       StyleBox[
        RowBox[{
         RowBox[{
         "Gives", " ", "the", " ", "order", " ", "of", " ", "moments"}], ",", 
         " ", 
         RowBox[{"e", ".", "g", "."}], ",", " ", 
         RowBox[{
          StyleBox["for",
           FontColor->RGBColor[1, 0, 0]], 
          StyleBox[" ",
           FontColor->RGBColor[1, 0, 0]], 
          StyleBox["a",
           FontColor->RGBColor[1, 0, 0]], 
          StyleBox[" ",
           FontColor->RGBColor[1, 0, 0]], 
          StyleBox["moment",
           FontColor->RGBColor[1, 0, 0]], 
          StyleBox[" ",
           FontColor->RGBColor[1, 0, 0]], 
          SubsuperscriptBox["\[Rho]", "ijk", "2"]}], ",", " ", 
         RowBox[{
          RowBox[{"it", " ", "returns", " ", "2", " ", "and", " ", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"i", ",", "j", ",", "k"}], "}"}], ".", " ", "Without"}], 
           " ", "multiplication", " ", "with", " ", "a", " ", "dummy", " ", 
           "variable", " ", "position", " ", "is", " ", "not", " ", 
           "identified", " ", "correctly"}], ";", " ", 
          RowBox[{
          "it", " ", "does", " ", "not", " ", "matter", " ", "to", " ", 
           "multiply", " ", "with", " ", "a", " ", "constant", " ", "for", 
           " ", "identifying", " ", "the", " ", 
           RowBox[{"position", "."}]}]}]}],
        FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"idxPowC", "=", 
       RowBox[{"Length", "[", 
        RowBox[{"Position", "[", 
         RowBox[{
          RowBox[{"dummy", " ", "exCsqpart"}], ",", 
          SuperscriptBox[
           RowBox[{"C", "[", "_", "]"}], "_"], ",", "1"}], "]"}], "]"}]}], 
      ";", " ", "\[IndentingNewLine]", 
      RowBox[{"idxPowC1", "=", 
       RowBox[{"Length", "[", 
        RowBox[{"Position", "[", 
         RowBox[{
          RowBox[{"dummy", " ", "exC1sqpart"}], ",", 
          SuperscriptBox[
           RowBox[{"C1", "[", "_", "]"}], "_"], ",", "1"}], "]"}], "]"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"indicesC", "=", 
       RowBox[{"Flatten", "[", 
        RowBox[{"Extract", "[", 
         RowBox[{"exCpart", ",", 
          RowBox[{"Drop", "[", 
           RowBox[{
            RowBox[{"Position", "[", 
             RowBox[{"exCpart", ",", "List"}], "]"}], ",", "None", ",", 
            RowBox[{"-", "1"}]}], "]"}]}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"indicesC1", "=", 
       RowBox[{"Flatten", "[", 
        RowBox[{"Extract", "[", 
         RowBox[{"exC1part", ",", 
          RowBox[{"Drop", "[", 
           RowBox[{
            RowBox[{"Position", "[", 
             RowBox[{"exC1part", ",", "List"}], "]"}], ",", "None", ",", 
            RowBox[{"-", "1"}]}], "]"}]}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", 
       StyleBox[
        RowBox[{
         RowBox[{"Struchtrup", "'"}], "s", " ", "Notation"}],
        FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"remainingpart", " ", 
        FractionBox[
         RowBox[{"\[Rho]", "[", 
          RowBox[{"idxPowC", ",", "indicesC"}], "]"}], "m"], 
        FractionBox[
         RowBox[{"\[Rho]", "[", 
          RowBox[{"idxPowC1", ",", "indicesC1"}], "]"}], "m"]}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"\[Rho]", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "}"}]}], "]"}], "\[Rule]", 
          RowBox[{"(", 
           RowBox[{"\[Rho]", "/.", 
            RowBox[{"\[Rho]", "\[Rule]", 
             RowBox[{"m", " ", "n"}]}]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"\[Rho]", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "_", "}"}]}], "]"}], "\[Rule]", "0"}]}], " ", 
        RowBox[{"(*", 
         RowBox[{
         "single", " ", "peculiar", " ", "velocity", " ", "integral"}], 
         "*)"}], "}"}]}]}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{"(*", 
      StyleBox[
       RowBox[{
        RowBox[{"Garzo", " ", "&"}], " ", 
        RowBox[{"Santoss", "'"}], " ", "Notation"}],
       FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"remainingpart", " ", 
       RowBox[{"M", "[", 
        RowBox[{
         RowBox[{"2", "idxPowC"}], ",", "indicesC"}], "]"}], 
       RowBox[{"M", "[", 
        RowBox[{
         RowBox[{"2", "idxPowC1"}], ",", "indicesC1"}], "]"}]}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"M", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "}"}]}], "]"}], "\[Rule]", "n"}], ",", 
        RowBox[{
         RowBox[{"M", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "_", "}"}]}], "]"}], "\[Rule]", "0"}]}], " ", 
       RowBox[{"(*", 
        RowBox[{"single", " ", "peculiar", " ", "velocity", " ", "integral"}],
         "*)"}], "}"}]}], "\[IndentingNewLine]", "*)"}], 
    "\[IndentingNewLine]", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.737196072345612*^9, 3.737196534567275*^9}, {
  3.7371966554794893`*^9, 3.737196787447968*^9}, {3.7371972388451443`*^9, 
  3.737197245914921*^9}, {3.737197285674193*^9, 3.7371974247162333`*^9}, {
  3.737197482782597*^9, 3.737197492219401*^9}, {3.7371977368327303`*^9, 
  3.73719774905171*^9}, {3.737197802366289*^9, 3.737197822296185*^9}, {
  3.737199715814702*^9, 3.7371997597885733`*^9}, {3.7372001199974957`*^9, 
  3.737200121400572*^9}, {3.737200248027317*^9, 3.737200248956999*^9}, {
  3.737264437434057*^9, 3.737264635306066*^9}, {3.7372646661074257`*^9, 
  3.7372646819774323`*^9}, {3.7372875983116093`*^9, 3.7372876185696707`*^9}, {
  3.7372878386030083`*^9, 
  3.7372878500330544`*^9}},ExpressionUUID->"13ad32d0-22a0-4b02-bae9-\
214686979d02"]
}, Closed]],

Cell[CellGroupData[{

Cell["Replacements", "Subsection",
 CellChangeTimes->{{3.737272285055086*^9, 
  3.737272289679254*^9}},ExpressionUUID->"a03cc323-5c73-4e62-b060-\
5d1590e61145"],

Cell[BoxData[
 RowBox[{
  RowBox[{"replace\[Alpha]", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Alpha]", "[", 
       RowBox[{"0", ",", "1"}], "]"}], "\[Rule]", 
      RowBox[{"B", "[", "1", "]"}]}], ",", 
     RowBox[{
      RowBox[{"\[Alpha]", "[", 
       RowBox[{"0", ",", "2"}], "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{"-", 
         RowBox[{"B", "[", "1", "]"}]}], "+", 
        RowBox[{"d", " ", 
         RowBox[{"B", "[", "2", "]"}]}]}], 
       RowBox[{
        RowBox[{"-", "1"}], "+", "d"}]]}], ",", 
     RowBox[{
      RowBox[{"\[Alpha]", "[", 
       RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{"B", "[", "1", "]"}], "-", 
        RowBox[{"B", "[", "2", "]"}]}], 
       RowBox[{
        RowBox[{"-", "1"}], "+", "d"}]]}], ",", 
     RowBox[{
      RowBox[{"\[Alpha]", "[", 
       RowBox[{"0", ",", "3"}], "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "3"}], " ", 
         RowBox[{"B", "[", "2", "]"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"2", "+", "d"}], ")"}], " ", 
         RowBox[{"B", "[", "3", "]"}]}]}], 
       RowBox[{
        RowBox[{"-", "1"}], "+", "d"}]]}], ",", 
     RowBox[{
      RowBox[{"\[Alpha]", "[", 
       RowBox[{"1", ",", "3"}], "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{"3", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"B", "[", "2", "]"}], "-", 
          RowBox[{"B", "[", "3", "]"}]}], ")"}]}], 
       RowBox[{
        RowBox[{"-", "1"}], "+", "d"}]]}], ",", 
     RowBox[{
      RowBox[{"\[Alpha]", "[", 
       RowBox[{"0", ",", "4"}], "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{"3", " ", 
         RowBox[{"B", "[", "2", "]"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"2", "+", "d"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "6"}], " ", 
            RowBox[{"B", "[", "3", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"4", "+", "d"}], ")"}], " ", 
            RowBox[{"B", "[", "4", "]"}]}]}], ")"}]}]}], 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox["d", "2"]}]]}], ",", 
     RowBox[{
      RowBox[{"\[Alpha]", "[", 
       RowBox[{"2", ",", "4"}], "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{"3", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"B", "[", "2", "]"}], "-", 
          RowBox[{"2", " ", 
           RowBox[{"B", "[", "3", "]"}]}], "+", 
          RowBox[{"B", "[", "4", "]"}]}], ")"}]}], 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox["d", "2"]}]]}], ",", 
     RowBox[{
      RowBox[{"\[Alpha]", "[", 
       RowBox[{"1", ",", "4"}], "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "6"}], " ", 
         RowBox[{"B", "[", "2", "]"}]}], "+", 
        RowBox[{"6", " ", 
         RowBox[{"(", 
          RowBox[{"3", "+", "d"}], ")"}], " ", 
         RowBox[{"B", "[", "3", "]"}]}], "-", 
        RowBox[{"6", " ", 
         RowBox[{"(", 
          RowBox[{"2", "+", "d"}], ")"}], " ", 
         RowBox[{"B", "[", "4", "]"}]}]}], 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox["d", "2"]}]]}], ",", 
     RowBox[{
      RowBox[{"\[Alpha]", "[", 
       RowBox[{"0", ",", "5"}], "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{"15", " ", 
         RowBox[{"B", "[", "3", "]"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"4", "+", "d"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "10"}], " ", 
            RowBox[{"B", "[", "4", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"6", "+", "d"}], ")"}], " ", 
            RowBox[{"B", "[", "5", "]"}]}]}], ")"}]}]}], 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox["d", "2"]}]]}], ",", 
     RowBox[{
      RowBox[{"\[Alpha]", "[", 
       RowBox[{"2", ",", "5"}], "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{"15", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"B", "[", "3", "]"}], "-", 
          RowBox[{"2", " ", 
           RowBox[{"B", "[", "4", "]"}]}], "+", 
          RowBox[{"B", "[", "5", "]"}]}], ")"}]}], 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox["d", "2"]}]]}], ",", 
     RowBox[{
      RowBox[{"\[Alpha]", "[", 
       RowBox[{"1", ",", "5"}], "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{"10", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "3"}], " ", 
           RowBox[{"B", "[", "3", "]"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"7", "+", "d"}], ")"}], " ", 
           RowBox[{"B", "[", "4", "]"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"4", "+", "d"}], ")"}], " ", 
           RowBox[{"B", "[", "5", "]"}]}]}], ")"}]}], 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox["d", "2"]}]]}], ",", 
     RowBox[{
      RowBox[{"\[Alpha]", "[", 
       RowBox[{"0", ",", "6"}], "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "15"}], " ", 
         RowBox[{"B", "[", "3", "]"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"4", "+", "d"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"45", " ", 
            RowBox[{"B", "[", "4", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"6", "+", "d"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "15"}], " ", 
               RowBox[{"B", "[", "5", "]"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"8", "+", "d"}], ")"}], " ", 
               RowBox[{"B", "[", "6", "]"}]}]}], ")"}]}]}], ")"}]}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "d"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "d"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"3", "+", "d"}], ")"}]}]]}], ",", 
     RowBox[{
      RowBox[{"\[Alpha]", "[", 
       RowBox[{"3", ",", "6"}], "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{"15", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"B", "[", "3", "]"}], "-", 
          RowBox[{"3", " ", 
           RowBox[{"B", "[", "4", "]"}]}], "+", 
          RowBox[{"3", " ", 
           RowBox[{"B", "[", "5", "]"}]}], "-", 
          RowBox[{"B", "[", "6", "]"}]}], ")"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "d"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "d"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"3", "+", "d"}], ")"}]}]]}], ",", 
     RowBox[{
      RowBox[{"\[Alpha]", "[", 
       RowBox[{"2", ",", "6"}], "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{"45", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"B", "[", "3", "]"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"6", "+", "d"}], ")"}], " ", 
           RowBox[{"B", "[", "4", "]"}]}], "-", 
          RowBox[{"9", " ", 
           RowBox[{"B", "[", "5", "]"}]}], "-", 
          RowBox[{"2", " ", "d", " ", 
           RowBox[{"B", "[", "5", "]"}]}], "+", 
          RowBox[{"4", " ", 
           RowBox[{"B", "[", "6", "]"}]}], "+", 
          RowBox[{"d", " ", 
           RowBox[{"B", "[", "6", "]"}]}]}], ")"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "d"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "d"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"3", "+", "d"}], ")"}]}]]}], ",", 
     RowBox[{
      RowBox[{"\[Alpha]", "[", 
       RowBox[{"1", ",", "6"}], "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{"15", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           RowBox[{"B", "[", "3", "]"}]}], "-", 
          RowBox[{"3", " ", 
           RowBox[{"(", 
            RowBox[{"9", "+", 
             RowBox[{"2", " ", "d"}]}], ")"}], " ", 
           RowBox[{"B", "[", "4", "]"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"4", "+", "d"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"12", "+", "d"}], ")"}], " ", 
              RowBox[{"B", "[", "5", "]"}]}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"6", "+", "d"}], ")"}], " ", 
              RowBox[{"B", "[", "6", "]"}]}]}], ")"}]}]}], ")"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "d"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "d"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"3", "+", "d"}], ")"}]}]]}], ",", 
     RowBox[{
      RowBox[{"\[Alpha]", "[", 
       RowBox[{"0", ",", "7"}], "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "105"}], " ", 
         RowBox[{"B", "[", "4", "]"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"6", "+", "d"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"105", " ", 
            RowBox[{"B", "[", "5", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"8", "+", "d"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "21"}], " ", 
               RowBox[{"B", "[", "6", "]"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"10", "+", "d"}], ")"}], " ", 
               RowBox[{"B", "[", "7", "]"}]}]}], ")"}]}]}], ")"}]}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "d"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "d"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"3", "+", "d"}], ")"}]}]]}], ",", 
     RowBox[{
      RowBox[{"\[Alpha]", "[", 
       RowBox[{"3", ",", "7"}], "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{"105", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"B", "[", "4", "]"}], "-", 
          RowBox[{"3", " ", 
           RowBox[{"B", "[", "5", "]"}]}], "+", 
          RowBox[{"3", " ", 
           RowBox[{"B", "[", "6", "]"}]}], "-", 
          RowBox[{"B", "[", "7", "]"}]}], ")"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "d"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "d"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"3", "+", "d"}], ")"}]}]]}], ",", 
     RowBox[{
      RowBox[{"\[Alpha]", "[", 
       RowBox[{"2", ",", "7"}], "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{"105", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "3"}], " ", 
           RowBox[{"B", "[", "4", "]"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"12", "+", "d"}], ")"}], " ", 
           RowBox[{"B", "[", "5", "]"}]}], "-", 
          RowBox[{"15", " ", 
           RowBox[{"B", "[", "6", "]"}]}], "-", 
          RowBox[{"2", " ", "d", " ", 
           RowBox[{"B", "[", "6", "]"}]}], "+", 
          RowBox[{"6", " ", 
           RowBox[{"B", "[", "7", "]"}]}], "+", 
          RowBox[{"d", " ", 
           RowBox[{"B", "[", "7", "]"}]}]}], ")"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "d"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "d"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"3", "+", "d"}], ")"}]}]]}], ",", 
     RowBox[{
      RowBox[{"\[Alpha]", "[", 
       RowBox[{"1", ",", "7"}], "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{"21", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"15", " ", 
           RowBox[{"B", "[", "4", "]"}]}], "-", 
          RowBox[{"5", " ", 
           RowBox[{"(", 
            RowBox[{"15", "+", 
             RowBox[{"2", " ", "d"}]}], ")"}], " ", 
           RowBox[{"B", "[", "5", "]"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"6", "+", "d"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"18", "+", "d"}], ")"}], " ", 
              RowBox[{"B", "[", "6", "]"}]}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"8", "+", "d"}], ")"}], " ", 
              RowBox[{"B", "[", "7", "]"}]}]}], ")"}]}]}], ")"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "d"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "d"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"3", "+", "d"}], ")"}]}]]}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.737272116995772*^9, 
  3.7372721345316343`*^9}},ExpressionUUID->"5f29daee-3e6d-445f-b1f4-\
8ee981698add"],

Cell[BoxData[
 RowBox[{
  RowBox[{"gammareplacements", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Gamma", "[", 
       RowBox[{"10", "+", 
        FractionBox["d", "2"]}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"9", "+", 
         FractionBox["d", "2"]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"8", "+", 
         FractionBox["d", "2"]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"7", "+", 
         FractionBox["d", "2"]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"6", "+", 
         FractionBox["d", "2"]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"5", "+", 
         FractionBox["d", "2"]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"4", "+", 
         FractionBox["d", "2"]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"3", "+", 
         FractionBox["d", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"2", "+", 
         FractionBox["d", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         FractionBox["d", "2"]}], ")"}], 
       FractionBox["d", "2"], 
       RowBox[{"Gamma", "[", 
        FractionBox["d", "2"], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"Gamma", "[", 
       RowBox[{"9", "+", 
        FractionBox["d", "2"]}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"8", "+", 
         FractionBox["d", "2"]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"7", "+", 
         FractionBox["d", "2"]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"6", "+", 
         FractionBox["d", "2"]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"5", "+", 
         FractionBox["d", "2"]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"4", "+", 
         FractionBox["d", "2"]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"3", "+", 
         FractionBox["d", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"2", "+", 
         FractionBox["d", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         FractionBox["d", "2"]}], ")"}], 
       FractionBox["d", "2"], 
       RowBox[{"Gamma", "[", 
        FractionBox["d", "2"], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"Gamma", "[", 
       RowBox[{"8", "+", 
        FractionBox["d", "2"]}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"7", "+", 
         FractionBox["d", "2"]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"6", "+", 
         FractionBox["d", "2"]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"5", "+", 
         FractionBox["d", "2"]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"4", "+", 
         FractionBox["d", "2"]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"3", "+", 
         FractionBox["d", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"2", "+", 
         FractionBox["d", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         FractionBox["d", "2"]}], ")"}], 
       FractionBox["d", "2"], 
       RowBox[{"Gamma", "[", 
        FractionBox["d", "2"], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"Gamma", "[", 
       RowBox[{"7", "+", 
        FractionBox["d", "2"]}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"6", "+", 
         FractionBox["d", "2"]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"5", "+", 
         FractionBox["d", "2"]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"4", "+", 
         FractionBox["d", "2"]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"3", "+", 
         FractionBox["d", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"2", "+", 
         FractionBox["d", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         FractionBox["d", "2"]}], ")"}], 
       FractionBox["d", "2"], 
       RowBox[{"Gamma", "[", 
        FractionBox["d", "2"], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"Gamma", "[", 
       RowBox[{"6", "+", 
        FractionBox["d", "2"]}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"5", "+", 
         FractionBox["d", "2"]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"4", "+", 
         FractionBox["d", "2"]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"3", "+", 
         FractionBox["d", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"2", "+", 
         FractionBox["d", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         FractionBox["d", "2"]}], ")"}], 
       FractionBox["d", "2"], 
       RowBox[{"Gamma", "[", 
        FractionBox["d", "2"], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"Gamma", "[", 
       RowBox[{"5", "+", 
        FractionBox["d", "2"]}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"4", "+", 
         FractionBox["d", "2"]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"3", "+", 
         FractionBox["d", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"2", "+", 
         FractionBox["d", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         FractionBox["d", "2"]}], ")"}], 
       FractionBox["d", "2"], 
       RowBox[{"Gamma", "[", 
        FractionBox["d", "2"], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"Gamma", "[", 
       RowBox[{"4", "+", 
        FractionBox["d", "2"]}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"3", "+", 
         FractionBox["d", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"2", "+", 
         FractionBox["d", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         FractionBox["d", "2"]}], ")"}], 
       FractionBox["d", "2"], 
       RowBox[{"Gamma", "[", 
        FractionBox["d", "2"], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"Gamma", "[", 
       RowBox[{"3", "+", 
        FractionBox["d", "2"]}], "]"}], "\[Rule]", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"2", "+", 
         FractionBox["d", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         FractionBox["d", "2"]}], ")"}], 
       FractionBox["d", "2"], 
       RowBox[{"Gamma", "[", 
        FractionBox["d", "2"], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"Gamma", "[", 
       RowBox[{"2", "+", 
        FractionBox["d", "2"]}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         FractionBox["d", "2"]}], ")"}], 
       FractionBox["d", "2"], 
       RowBox[{"Gamma", "[", 
        FractionBox["d", "2"], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"Gamma", "[", 
       RowBox[{"1", "+", 
        FractionBox["d", "2"]}], "]"}], "\[Rule]", 
      RowBox[{
       FractionBox["d", "2"], 
       RowBox[{"Gamma", "[", 
        FractionBox["d", "2"], "]"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Gamma", "[", 
       FractionBox[
        RowBox[{"d", "+", "20"}], "2"], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "18"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "16"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "14"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "12"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "10"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "8"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "6"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "4"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "2"}], "2"], ")"}], 
       FractionBox["d", "2"], 
       RowBox[{"Gamma", "[", 
        FractionBox["d", "2"], "]"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Gamma", "[", 
       FractionBox[
        RowBox[{"d", "+", "19"}], "2"], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "17"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "15"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "13"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "11"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "9"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "7"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "5"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "3"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "1"}], "2"], ")"}], 
       RowBox[{"Gamma", "[", 
        FractionBox[
         RowBox[{"d", "+", "1"}], "2"], "]"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Gamma", "[", 
       FractionBox[
        RowBox[{"d", "+", "18"}], "2"], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "16"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "14"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "12"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "10"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "8"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "6"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "4"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "2"}], "2"], ")"}], 
       FractionBox["d", "2"], 
       RowBox[{"Gamma", "[", 
        FractionBox["d", "2"], "]"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Gamma", "[", 
       FractionBox[
        RowBox[{"d", "+", "17"}], "2"], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "15"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "13"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "11"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "9"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "7"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "5"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "3"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "1"}], "2"], ")"}], 
       RowBox[{"Gamma", "[", 
        FractionBox[
         RowBox[{"d", "+", "1"}], "2"], "]"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Gamma", "[", 
       FractionBox[
        RowBox[{"d", "+", "16"}], "2"], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "14"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "12"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "10"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "8"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "6"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "4"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "2"}], "2"], ")"}], 
       FractionBox["d", "2"], 
       RowBox[{"Gamma", "[", 
        FractionBox["d", "2"], "]"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Gamma", "[", 
       FractionBox[
        RowBox[{"d", "+", "15"}], "2"], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "13"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "11"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "9"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "7"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "5"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "3"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "1"}], "2"], ")"}], 
       RowBox[{"Gamma", "[", 
        FractionBox[
         RowBox[{"d", "+", "1"}], "2"], "]"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Gamma", "[", 
       FractionBox[
        RowBox[{"d", "+", "14"}], "2"], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "12"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "10"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "8"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "6"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "4"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "2"}], "2"], ")"}], 
       FractionBox["d", "2"], 
       RowBox[{"Gamma", "[", 
        FractionBox["d", "2"], "]"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Gamma", "[", 
       FractionBox[
        RowBox[{"d", "+", "13"}], "2"], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "11"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "9"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "7"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "5"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "3"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "1"}], "2"], ")"}], 
       RowBox[{"Gamma", "[", 
        FractionBox[
         RowBox[{"d", "+", "1"}], "2"], "]"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Gamma", "[", 
       FractionBox[
        RowBox[{"d", "+", "12"}], "2"], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "10"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "8"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "6"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "4"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "2"}], "2"], ")"}], 
       FractionBox["d", "2"], 
       RowBox[{"Gamma", "[", 
        FractionBox["d", "2"], "]"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Gamma", "[", 
       FractionBox[
        RowBox[{"d", "+", "11"}], "2"], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "9"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "7"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "5"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "3"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "1"}], "2"], ")"}], 
       RowBox[{"Gamma", "[", 
        FractionBox[
         RowBox[{"d", "+", "1"}], "2"], "]"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Gamma", "[", 
       FractionBox[
        RowBox[{"d", "+", "10"}], "2"], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "8"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "6"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "4"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "2"}], "2"], ")"}], 
       FractionBox["d", "2"], 
       RowBox[{"Gamma", "[", 
        FractionBox["d", "2"], "]"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Gamma", "[", 
       FractionBox[
        RowBox[{"d", "+", "9"}], "2"], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "7"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "5"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "3"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "1"}], "2"], ")"}], 
       RowBox[{"Gamma", "[", 
        FractionBox[
         RowBox[{"d", "+", "1"}], "2"], "]"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Gamma", "[", 
       FractionBox[
        RowBox[{"d", "+", "8"}], "2"], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "6"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "4"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "2"}], "2"], ")"}], 
       FractionBox["d", "2"], 
       RowBox[{"Gamma", "[", 
        FractionBox["d", "2"], "]"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Gamma", "[", 
       FractionBox[
        RowBox[{"d", "+", "7"}], "2"], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "5"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "3"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "1"}], "2"], ")"}], 
       RowBox[{"Gamma", "[", 
        FractionBox[
         RowBox[{"d", "+", "1"}], "2"], "]"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Gamma", "[", 
       FractionBox[
        RowBox[{"d", "+", "6"}], "2"], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "4"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "2"}], "2"], ")"}], 
       FractionBox["d", "2"], 
       RowBox[{"Gamma", "[", 
        FractionBox["d", "2"], "]"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Gamma", "[", 
       FractionBox[
        RowBox[{"d", "+", "5"}], "2"], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "3"}], "2"], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "1"}], "2"], ")"}], 
       RowBox[{"Gamma", "[", 
        FractionBox[
         RowBox[{"d", "+", "1"}], "2"], "]"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Gamma", "[", 
       FractionBox[
        RowBox[{"d", "+", "4"}], "2"], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        FractionBox[
         RowBox[{"d", "+", "2"}], "2"], ")"}], 
       FractionBox["d", "2"], 
       RowBox[{"Gamma", "[", 
        FractionBox["d", "2"], "]"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Gamma", "[", 
       FractionBox[
        RowBox[{"d", "+", "3"}], "2"], "]"}], "\[Rule]", 
      RowBox[{
       FractionBox[
        RowBox[{"d", "+", "1"}], "2"], 
       RowBox[{"Gamma", "[", 
        FractionBox[
         RowBox[{"d", "+", "1"}], "2"], "]"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Gamma", "[", 
       FractionBox[
        RowBox[{"d", "+", "2"}], "2"], "]"}], "\[Rule]", 
      RowBox[{
       FractionBox["d", "2"], 
       RowBox[{"Gamma", "[", 
        FractionBox["d", "2"], "]"}]}]}]}], "\[IndentingNewLine]", "}"}]}], 
  ";"}]], "Input",ExpressionUUID->"2d004020-a302-4581-b08d-b7aa7b73c7e2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   StyleBox[
    RowBox[{"\[Rho]", " ", "and", " ", "\[Upsilon]", " ", "are", " ", 
     RowBox[{"Henning", "'"}], "s", " ", "notation", " ", "for", " ", "a", 
     " ", "general", " ", "tensor", " ", "and", " ", "its", " ", "traceless", 
     " ", "part", " ", 
     RowBox[{"respectively", "."}]}],
    FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"replace\[Rho]u", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Rho]", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "}"}]}], "]"}], "\[Rule]", "\[Rho]"}], ",", 
      RowBox[{
       RowBox[{"\[Rho]", "[", 
        RowBox[{"1", ",", 
         RowBox[{"{", "}"}]}], "]"}], "\[Rule]", 
       RowBox[{"d", " ", "\[Rho]", " ", "\[Theta]"}]}], ",", 
      RowBox[{
       RowBox[{"\[Upsilon]", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"i1_", ",", "j1_"}], "}"}]}], "]"}], "\[Rule]", 
       RowBox[{"\[Sigma]", "[", 
        RowBox[{"{", 
         RowBox[{"i1", ",", "j1"}], "}"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"\[Rho]", "[", 
        RowBox[{"1", ",", 
         RowBox[{"{", "i1_", "}"}]}], "]"}], "\[Rule]", 
       RowBox[{"2", 
        RowBox[{"q", "[", 
         RowBox[{"{", "i1", "}"}], "]"}]}]}], ",", 
      RowBox[{
       RowBox[{"\[Rho]", "[", 
        RowBox[{"2", ",", 
         RowBox[{"{", "i1_", "}"}]}], "]"}], "\[Rule]", 
       RowBox[{"ui2", "[", 
        RowBox[{"{", "i1", "}"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"\[Upsilon]", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"i1_", ",", "j1_", ",", "k1_"}], "}"}]}], "]"}], "\[Rule]", 
       
       RowBox[{"m", "[", 
        RowBox[{"{", 
         RowBox[{"i1", ",", "j1", ",", "k1"}], "}"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"\[Upsilon]", "[", 
        RowBox[{"1", ",", 
         RowBox[{"{", 
          RowBox[{"i1_", ",", "j1_"}], "}"}]}], "]"}], "\[Rule]", 
       RowBox[{"u1", "[", 
        RowBox[{"{", 
         RowBox[{"i1", ",", "j1"}], "}"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"\[Rho]", "[", 
        RowBox[{"2", ",", 
         RowBox[{"{", "}"}]}], "]"}], "\[Rule]", "u2"}], ",", 
      RowBox[{
       RowBox[{"\[Upsilon]", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"i1_", ",", "j1_", ",", "k1_", ",", "l1_"}], "}"}]}], "]"}],
        "\[Rule]", 
       RowBox[{"u", "[", 
        RowBox[{"{", 
         RowBox[{"i1", ",", "j1", ",", "k1", ",", "l1"}], "}"}], "]"}]}]}], 
     "}"}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.7386579109131193`*^9, 3.738658315944512*^9}, {
  3.738658376475819*^9, 3.738658376810169*^9}, {3.7386586433909483`*^9, 
  3.7386586447889977`*^9}, {3.738658872095509*^9, 3.738658891222191*^9}, {
  3.738659104513404*^9, 3.738659105608144*^9}, {3.738663826634973*^9, 
  3.738663886859695*^9}, {3.7386641239997597`*^9, 3.7386641241899347`*^9}, {
  3.743097961161461*^9, 
  3.743098009485293*^9}},ExpressionUUID->"25511b59-c447-4bf3-99a3-\
fa894bcaf9d4"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Examples (",
 StyleBox["do not run",
  FontColor->RGBColor[1, 0, 0]],
 ", unless necessary)"
}], "Section",
 CellChangeTimes->{{3.7375996208556957`*^9, 3.737599624766223*^9}, {
  3.7376002235045*^9, 
  3.7376002397496233`*^9}},ExpressionUUID->"5d386878-2449-4b70-a81e-\
bd8d5eed01cb"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"ex1", "=", 
    RowBox[{"Expand", "[", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"g", "[", 
        RowBox[{"{", "s0", "}"}], "]"}], "2"], 
      RowBox[{"g", "[", 
       RowBox[{"{", "i2", "}"}], "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
   RowBox[{"ex2", "=", 
    RowBox[{"Expand", "[", 
     RowBox[{
      RowBox[{"g", "[", 
       RowBox[{"{", "i", "}"}], "]"}], 
      RowBox[{"g", "[", 
       RowBox[{"{", "j", "}"}], "]"}], 
      RowBox[{"g", "[", 
       RowBox[{"{", "k", "}"}], "]"}]}], "]"}]}], ";", 
   RowBox[{"ex3", "=", 
    RowBox[{"Expand", "[", 
     RowBox[{
      RowBox[{"g", "[", 
       RowBox[{"{", "i", "}"}], "]"}], 
      RowBox[{"C", "[", 
       RowBox[{"{", "j", "}"}], "]"}], 
      RowBox[{"C", "[", 
       RowBox[{"{", "k", "}"}], "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
   
   RowBox[{"ex4", "=", 
    RowBox[{"Expand", "[", 
     RowBox[{
      RowBox[{"g", "[", 
       RowBox[{"{", "i", "}"}], "]"}], 
      RowBox[{"g", "[", 
       RowBox[{"{", "j", "}"}], "]"}], 
      RowBox[{"C", "[", 
       RowBox[{"{", "k", "}"}], "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
   
   RowBox[{"ex5", "=", 
    RowBox[{"Expand", "[", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"g", "[", 
        RowBox[{"{", "s0", "}"}], "]"}], "2"], 
      RowBox[{"C", "[", 
       RowBox[{"{", "i", "}"}], "]"}]}], "]"}]}], ";"}], "*)"}]], "Input",
 CellChangeTimes->{{3.737200551707522*^9, 3.737200619708148*^9}, 
   3.737200866552517*^9},ExpressionUUID->"2b248666-9701-4718-a3cd-\
8c1d5626b7f9"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Einstein", "[", 
        RowBox[{"intoverCC1", "[", 
         RowBox[{
         "ex1", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}], 
         "]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"ii", ",", "1", ",", 
         RowBox[{"Length", "[", "ex1", "]"}]}], "}"}]}], "]"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Einstein", "[", 
        RowBox[{"intoverCC1", "[", 
         RowBox[{
         "ex2", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}], 
         "]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"ii", ",", "1", ",", 
         RowBox[{"Length", "[", "ex2", "]"}]}], "}"}]}], "]"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Einstein", "[", 
        RowBox[{"intoverCC1", "[", 
         RowBox[{
         "ex3", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}], 
         "]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"ii", ",", "1", ",", 
         RowBox[{"Length", "[", "ex3", "]"}]}], "}"}]}], "]"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Einstein", "[", 
        RowBox[{"intoverCC1", "[", 
         RowBox[{
         "ex4", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}], 
         "]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"ii", ",", "1", ",", 
         RowBox[{"Length", "[", "ex4", "]"}]}], "}"}]}], "]"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Einstein", "[", 
        RowBox[{"intoverCC1", "[", 
         RowBox[{
         "ex5", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}], 
         "]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"ii", ",", "1", ",", 
         RowBox[{"Length", "[", "ex5", "]"}]}], "}"}]}], "]"}]}], "]"}]}], 
  "*)"}]], "Input",
 CellChangeTimes->{{3.73720050359057*^9, 3.737200510635146*^9}, {
   3.7372006260954733`*^9, 3.737200644904581*^9}, 
   3.7372008724121313`*^9},ExpressionUUID->"28ab776a-6f93-4576-94f2-\
7a06a73aa063"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   StyleBox[
    RowBox[{"Examples", " ", "on", " ", "contracting", " ", "tensors"}],
    FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"ex", "[", "0", "]"}], "=", 
     RowBox[{
      FractionBox["1", "6"], 
      RowBox[{"A", "[", 
       RowBox[{"{", 
        RowBox[{"i1", ",", "i1"}], "}"}], "]"}], 
      RowBox[{"B", "[", 
       RowBox[{"{", 
        RowBox[{"i2", ",", "i3"}], "}"}], "]"}], 
      RowBox[{"B", "[", 
       RowBox[{"{", 
        RowBox[{"i2", ",", "i3"}], "}"}], "]"}], 
      SuperscriptBox["x", "2"], 
      SuperscriptBox[
       RowBox[{"k", "[", "2", "]"}], "3"]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ex", "[", "1", "]"}], "=", 
     RowBox[{
      FractionBox["1", "6"], 
      RowBox[{"A", "[", 
       RowBox[{"{", 
        RowBox[{"i1", ",", "i1"}], "}"}], "]"}], 
      RowBox[{"B", "[", 
       RowBox[{"{", 
        RowBox[{"i2", ",", "i3"}], "}"}], "]"}], 
      RowBox[{"B", "[", 
       RowBox[{"{", 
        RowBox[{"i2", ",", "i3"}], "}"}], "]"}], 
      RowBox[{"B", "[", 
       RowBox[{"{", 
        RowBox[{"i2", ",", "i3"}], "}"}], "]"}], 
      SuperscriptBox["x", "2"], 
      SuperscriptBox[
       RowBox[{"k", "[", "2", "]"}], "3"]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ex", "[", "2", "]"}], "=", 
     RowBox[{
      FractionBox["1", "6"], 
      RowBox[{"A", "[", 
       RowBox[{"{", 
        RowBox[{"i1", ",", "i1"}], "}"}], "]"}], 
      RowBox[{"A", "[", 
       RowBox[{"{", 
        RowBox[{"i1", ",", "i1"}], "}"}], "]"}], 
      RowBox[{"B", "[", 
       RowBox[{"{", 
        RowBox[{"i2", ",", "i3"}], "}"}], "]"}], 
      RowBox[{"B", "[", 
       RowBox[{"{", 
        RowBox[{"i2", ",", "i3"}], "}"}], "]"}], 
      SuperscriptBox["x", "2"], 
      SuperscriptBox[
       RowBox[{"k", "[", "2", "]"}], "3"]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ex", "[", "3", "]"}], "=", 
     RowBox[{
      RowBox[{"7", 
       RowBox[{"A", "[", 
        RowBox[{"{", "i", "}"}], "]"}], 
       RowBox[{"A", "[", 
        RowBox[{"{", "i", "}"}], "]"}], 
       RowBox[{"B", "[", 
        RowBox[{"{", "j", "}"}], "]"}], 
       RowBox[{"B", "[", 
        RowBox[{"{", "k", "}"}], "]"}]}], "+", 
      RowBox[{"8", 
       SuperscriptBox["x", "2"], 
       RowBox[{"A", "[", 
        RowBox[{"{", 
         RowBox[{"i1", ",", "i1"}], "}"}], "]"}], 
       RowBox[{"B", "[", 
        RowBox[{"{", 
         RowBox[{"i2", ",", "i3"}], "}"}], "]"}], 
       RowBox[{"B", "[", 
        RowBox[{"{", 
         RowBox[{"i2", ",", "i3"}], "}"}], "]"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ex", "[", "4", "]"}], "=", 
     RowBox[{"8", 
      RowBox[{"A", "[", 
       RowBox[{"{", 
        RowBox[{"i1", ",", "i1"}], "}"}], "]"}], 
      RowBox[{"B", "[", 
       RowBox[{"{", 
        RowBox[{"i2", ",", "i3"}], "}"}], "]"}], 
      RowBox[{"B", "[", 
       RowBox[{"{", 
        RowBox[{"i4", ",", "i3"}], "}"}], "]"}], 
      RowBox[{"A", "[", 
       RowBox[{"{", "i5", "}"}], "]"}], 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"i6", ",", "i7", ",", "i0"}], "}"}], "]"}], 
      SuperscriptBox["x", "2"], 
      SuperscriptBox[
       RowBox[{"k", "[", "2", "]"}], "3"], 
      RowBox[{"A", "[", 
       RowBox[{"{", "i8", "}"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ex", "[", "5", "]"}], "=", 
     RowBox[{
      RowBox[{"A", "[", 
       RowBox[{"{", "i", "}"}], "]"}], 
      RowBox[{"B", "[", 
       RowBox[{"{", "j", "}"}], "]"}], 
      RowBox[{"F", "[", 
       RowBox[{"{", "k", "}"}], "]"}], 
      RowBox[{"Y", "[", 
       RowBox[{"{", "l", "}"}], "]"}], 
      RowBox[{"Y", "[", 
       RowBox[{"{", "m", "}"}], "]"}], 
      RowBox[{"Y", "[", 
       RowBox[{"{", "m", "}"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ex", "[", "6", "]"}], "=", 
     RowBox[{"A", "[", 
      RowBox[{"4", ",", 
       RowBox[{"{", 
        RowBox[{"i1", ",", "i2", ",", "i3", ",", "i4", ",", "i5", ",", "i5"}],
         "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"contractedtensor", "[", 
       RowBox[{"ex", "[", "ii", "]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"ii", ",", "0", ",", "6"}], "}"}]}], "]"}], "//", 
    "TableForm"}]}]}]], "Input",
 CellChangeTimes->{{3.7373691525626*^9, 3.73736916620849*^9}, {
   3.73736945251611*^9, 3.7373694553461123`*^9}, {3.73736959640558*^9, 
   3.73736959899459*^9}, {3.737369695526411*^9, 3.7373696987394*^9}, {
   3.737374132238474*^9, 3.7373741424026623`*^9}, {3.737374816994177*^9, 
   3.737374817973929*^9}, {3.7373886493364487`*^9, 3.737388725634396*^9}, {
   3.7373888277202387`*^9, 3.7373888592901163`*^9}, {3.737389051308626*^9, 
   3.7373890800048113`*^9}, {3.7373895218844643`*^9, 3.737389528926162*^9}, {
   3.73744540373221*^9, 3.73744541230724*^9}, {3.7374455788029203`*^9, 
   3.737445610263279*^9}, {3.737445762902358*^9, 3.7374457713484097`*^9}, 
   3.7376135270768623`*^9},ExpressionUUID->"102c02cd-8e72-4d70-9c42-\
2d74f803ace6"],

Cell[CellGroupData[{

Cell[BoxData["\<\"\\!\\(\\*\\nStyleBox[\\\"Please\\\",\\nFontColor->RGBColor[\
1, 0, 0]]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"check\\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"the\\\",\\nFontColor->RGBColor[1, 0, 0]]\\)\\!\
\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"exponents\\\",\\nFontColor->RGBColor[1, 0, 0]]\
\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"on\\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"tensors\\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\".\\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\"\>"], "Print",
 CellChangeTimes->{
  3.737603084979351*^9},ExpressionUUID->"406c2f03-ac20-4653-ad46-\
257d611f18f4"],

Cell[BoxData["\<\"\\!\\(\\*\\nStyleBox[\\\"Please\\\",\\nFontColor->RGBColor[\
1, 0, 0]]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"check\\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"the\\\",\\nFontColor->RGBColor[1, 0, 0]]\\)\\!\
\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"repeated\\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"indices\\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\".\\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\"\>"], "Print",
 CellChangeTimes->{
  3.7376030849900227`*^9},ExpressionUUID->"8db6c7cf-fc32-4617-8263-\
47494519687a"]
}, Open  ]],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      RowBox[{
       FractionBox["1", "6"], " ", 
       SuperscriptBox["x", "2"], " ", 
       RowBox[{"A", "[", 
        RowBox[{"1", ",", 
         RowBox[{"{", "}"}]}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{"B", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", 
           RowBox[{"i2", ",", "i3"}], "}"}]}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"k", "[", "2", "]"}], "3"]}]},
     {"Null"},
     {"Null"},
     {
      RowBox[{
       RowBox[{"7", " ", 
        SuperscriptBox[
         RowBox[{"A", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "i", "}"}]}], "]"}], "2"], " ", 
        RowBox[{"B", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "j", "}"}]}], "]"}], " ", 
        RowBox[{"B", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "k", "}"}]}], "]"}]}], "+", 
       RowBox[{"8", " ", 
        SuperscriptBox["x", "2"], " ", 
        RowBox[{"A", "[", 
         RowBox[{"1", ",", 
          RowBox[{"{", "}"}]}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{"B", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i3"}], "}"}]}], "]"}], "2"]}]}]},
     {
      RowBox[{"8", " ", 
       SuperscriptBox["x", "2"], " ", 
       RowBox[{"A", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "i5", "}"}]}], "]"}], " ", 
       RowBox[{"A", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "i8", "}"}]}], "]"}], " ", 
       RowBox[{"A", "[", 
        RowBox[{"1", ",", 
         RowBox[{"{", "}"}]}], "]"}], " ", 
       RowBox[{"B", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"i2", ",", "i3"}], "}"}]}], "]"}], " ", 
       RowBox[{"B", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"i3", ",", "i4"}], "}"}]}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{"k", "[", "2", "]"}], "3"], " ", 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"i0", ",", "i6", ",", "i7"}], "}"}]}], "]"}]}]},
     {
      RowBox[{
       RowBox[{"A", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "i", "}"}]}], "]"}], " ", 
       RowBox[{"B", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "j", "}"}]}], "]"}], " ", 
       RowBox[{"F", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "k", "}"}]}], "]"}], " ", 
       RowBox[{"Y", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "l", "}"}]}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{"Y", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "m", "}"}]}], "]"}], "2"]}]},
     {
      RowBox[{"A", "[", 
       RowBox[{"5", ",", 
        RowBox[{"{", 
         RowBox[{"i1", ",", "i2", ",", "i3", ",", "i4"}], "}"}]}], "]"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.5599999999999999]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   Column],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.73760308500578*^9},ExpressionUUID->"049bcb44-7701-4046-923a-ac9a45988d1f"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   StyleBox[
    RowBox[{"Examples", " ", "of", " ", "tensor", " ", "attributes"}],
    FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Clear", "[", "ex", "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ex", "[", "0", "]"}], "=", "1"}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
     RowBox[{"ex", "[", "1", "]"}], "=", 
     RowBox[{"k", "[", "2", "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ex", "[", "2", "]"}], "=", 
     RowBox[{"A", "[", 
      RowBox[{"{", "i", "}"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ex", "[", "3", "]"}], "=", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["17", "9"]}], 
      RowBox[{"A", "[", 
       RowBox[{"{", "i", "}"}], "]"}], 
      RowBox[{"B", "[", 
       RowBox[{"{", "j", "}"}], "]"}], 
      RowBox[{"X", "[", 
       RowBox[{"{", "k", "}"}], "]"}], 
      RowBox[{"Y", "[", 
       RowBox[{"{", "k", "}"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ex", "[", "4", "]"}], "=", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["7.83", "6"]}], 
      RowBox[{"A", "[", 
       RowBox[{"{", "i", "}"}], "]"}], 
      RowBox[{"B", "[", 
       RowBox[{"{", "j", "}"}], "]"}], 
      RowBox[{"X", "[", 
       RowBox[{"{", "k", "}"}], "]"}], 
      RowBox[{"X", "[", 
       RowBox[{"{", "k", "}"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ex", "[", "5", "]"}], "=", 
     RowBox[{"3.01", " ", 
      RowBox[{"A", "[", 
       RowBox[{"{", 
        RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ex", "[", "6", "]"}], "=", 
     RowBox[{"3", " ", 
      RowBox[{"A", "[", 
       RowBox[{"{", 
        RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}], "]"}], 
      RowBox[{"B", "[", 
       RowBox[{"{", "k", "}"}], "]"}], 
      RowBox[{"Y", "[", 
       RowBox[{"{", "k", "}"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ex", "[", "7", "]"}], "=", 
     RowBox[{"7", 
      RowBox[{"A", "[", 
       RowBox[{"{", "i", "}"}], "]"}], 
      RowBox[{"B", "[", 
       RowBox[{"{", "j", "}"}], "]"}], 
      RowBox[{"X", "[", 
       RowBox[{"{", "k", "}"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ex", "[", "8", "]"}], "=", 
     RowBox[{
      FractionBox["2", "3"], 
      RowBox[{"A", "[", 
       RowBox[{"{", "i", "}"}], "]"}], 
      RowBox[{"B", "[", 
       RowBox[{"{", "j", "}"}], "]"}], 
      SuperscriptBox[
       RowBox[{"X", "[", 
        RowBox[{"{", "k", "}"}], "]"}], "3"]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ex", "[", "9", "]"}], "=", 
     RowBox[{"3", " ", 
      RowBox[{"A", "[", 
       RowBox[{"{", 
        RowBox[{"i", ",", "j"}], "}"}], "]"}], 
      RowBox[{"B", "[", 
       RowBox[{"{", 
        RowBox[{"k", ",", "l"}], "}"}], "]"}], 
      RowBox[{"Y", "[", 
       RowBox[{"{", "k", "}"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ex", "[", "10", "]"}], "=", 
     RowBox[{"4", 
      RowBox[{"j", "[", 
       RowBox[{"2", ",", "1"}], "]"}], 
      RowBox[{"\[Alpha]", "[", "3", "]"}], 
      RowBox[{"A", "[", 
       RowBox[{"{", 
        RowBox[{
        "e", ",", "i", ",", "j", ",", "k", ",", "l", ",", "m", ",", "n", ",", 
         "o", ",", "p"}], "}"}], "]"}], 
      RowBox[{"B", "[", 
       RowBox[{"{", 
        RowBox[{"m", ",", "l"}], "}"}], "]"}], 
      RowBox[{"Y", "[", 
       RowBox[{"{", "o", "}"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ex", "[", "11", "]"}], "=", 
     RowBox[{"9", 
      SuperscriptBox[
       RowBox[{"A", "[", 
        RowBox[{"{", "i", "}"}], "]"}], "2"]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ex", "[", "12", "]"}], "=", 
     RowBox[{"59", 
      RowBox[{"A", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "i", "}"}]}], "]"}], 
      RowBox[{"B", "[", 
       RowBox[{"1", ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "k"}], "}"}]}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ex", "[", "13", "]"}], "=", 
     RowBox[{
      RowBox[{"-", "4"}], 
      SuperscriptBox[
       RowBox[{"A", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "i", "}"}]}], "]"}], "2"], 
      SuperscriptBox[
       RowBox[{"B", "[", 
        RowBox[{"1", ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "k"}], "}"}]}], "]"}], "2"]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ex", "[", "14", "]"}], "=", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["4", "7"]}], 
      SuperscriptBox[
       RowBox[{"A", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "i", "}"}]}], "]"}], "3"], 
      SuperscriptBox[
       RowBox[{"B", "[", 
        RowBox[{"1", ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "k"}], "}"}]}], "]"}], "2"]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ex", "[", "15", "]"}], "=", 
     RowBox[{
      FractionBox["1", "6"], 
      RowBox[{"A", "[", 
       RowBox[{"{", 
        RowBox[{"i1", ",", "i1"}], "}"}], "]"}], 
      RowBox[{"B", "[", 
       RowBox[{"{", 
        RowBox[{"i2", ",", "i3"}], "}"}], "]"}], 
      RowBox[{"B", "[", 
       RowBox[{"{", 
        RowBox[{"i2", ",", "i3"}], "}"}], "]"}], 
      SuperscriptBox["x", "2"], 
      SuperscriptBox[
       RowBox[{"k", "[", "2", "]"}], "3"]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ex", "[", "16", "]"}], "=", 
     RowBox[{
      FractionBox["1", "6"], 
      RowBox[{"A", "[", 
       RowBox[{"{", 
        RowBox[{"i1", ",", "i1"}], "}"}], "]"}], 
      RowBox[{"B", "[", 
       RowBox[{"{", 
        RowBox[{"i2", ",", "i3"}], "}"}], "]"}], 
      RowBox[{"B", "[", 
       RowBox[{"{", 
        RowBox[{"i2", ",", "i3"}], "}"}], "]"}], 
      RowBox[{"B", "[", 
       RowBox[{"{", 
        RowBox[{"i2", ",", "i3"}], "}"}], "]"}], 
      SuperscriptBox["x", "2"], 
      SuperscriptBox[
       RowBox[{"k", "[", "2", "]"}], "3"]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ex", "[", "17", "]"}], "=", 
     RowBox[{
      FractionBox["1", "6"], 
      RowBox[{"A", "[", 
       RowBox[{"{", 
        RowBox[{"i1", ",", "i1"}], "}"}], "]"}], 
      RowBox[{"A", "[", 
       RowBox[{"{", 
        RowBox[{"i1", ",", "i1"}], "}"}], "]"}], 
      RowBox[{"B", "[", 
       RowBox[{"{", 
        RowBox[{"i2", ",", "i3"}], "}"}], "]"}], 
      RowBox[{"B", "[", 
       RowBox[{"{", 
        RowBox[{"i2", ",", "i3"}], "}"}], "]"}], 
      SuperscriptBox["x", "2"], 
      SuperscriptBox[
       RowBox[{"k", "[", "2", "]"}], "3"]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ex", "[", "18", "]"}], "=", 
     RowBox[{
      RowBox[{"7", 
       RowBox[{"A", "[", 
        RowBox[{"{", "i", "}"}], "]"}], 
       RowBox[{"A", "[", 
        RowBox[{"{", "i", "}"}], "]"}], 
       RowBox[{"B", "[", 
        RowBox[{"{", "j", "}"}], "]"}], 
       RowBox[{"B", "[", 
        RowBox[{"{", "k", "}"}], "]"}]}], "+", 
      RowBox[{"8", 
       SuperscriptBox["x", "2"], 
       RowBox[{"A", "[", 
        RowBox[{"{", 
         RowBox[{"i1", ",", "i1"}], "}"}], "]"}], 
       RowBox[{"B", "[", 
        RowBox[{"{", 
         RowBox[{"i2", ",", "i3"}], "}"}], "]"}], 
       RowBox[{"B", "[", 
        RowBox[{"{", 
         RowBox[{"i2", ",", "i3"}], "}"}], "]"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ex", "[", "19", "]"}], "=", 
     RowBox[{
      RowBox[{"A", "[", 
       RowBox[{"{", "i", "}"}], "]"}], 
      RowBox[{"A", "[", 
       RowBox[{"{", "j", "}"}], "]"}], 
      RowBox[{"A", "[", 
       RowBox[{"{", "k", "}"}], "]"}], 
      RowBox[{"A", "[", 
       RowBox[{"{", "l", "}"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ex", "[", "20", "]"}], "=", 
     RowBox[{"A", "[", 
      RowBox[{"4", ",", 
       RowBox[{"{", 
        RowBox[{"i1", ",", "i2", ",", "i3", ",", "i4", ",", "i5", ",", "i5"}],
         "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ex", "[", "21", "]"}], "=", 
     RowBox[{"A", "[", 
      RowBox[{"2", ",", 
       RowBox[{"{", 
        RowBox[{"i1", ",", "i2", ",", "i3", ",", "i4", ",", "i5", ",", "i6"}],
         "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ex", "[", "22", "]"}], "=", 
     RowBox[{
      RowBox[{"A", "[", 
       RowBox[{"{", "i", "}"}], "]"}], 
      RowBox[{"B", "[", 
       RowBox[{"{", "j", "}"}], "]"}], 
      RowBox[{"F", "[", 
       RowBox[{"{", "k", "}"}], "]"}], 
      RowBox[{"Y", "[", 
       RowBox[{"{", "l", "}"}], "]"}]}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.7373691525626*^9, 3.73736916620849*^9}, {
   3.73736945251611*^9, 3.7373694553461123`*^9}, {3.73736959640558*^9, 
   3.73736959899459*^9}, {3.737369695526411*^9, 3.7373696987394*^9}, {
   3.737374132238474*^9, 3.7373741424026623`*^9}, {3.737374816994177*^9, 
   3.737374817973929*^9}, {3.7373886493364487`*^9, 3.737388725634396*^9}, {
   3.7373888277202387`*^9, 3.7373888592901163`*^9}, {3.737389051308626*^9, 
   3.7373890800048113`*^9}, {3.7373895218844643`*^9, 3.737389528926162*^9}, {
   3.73744474814159*^9, 3.7374447817411346`*^9}, {3.737445465304863*^9, 
   3.737445477826214*^9}, {3.7374455344986057`*^9, 3.737445536067367*^9}, {
   3.737445791960108*^9, 3.737445802677148*^9}, 3.737446356492975*^9, {
   3.7374580562816057`*^9, 3.7374580612720613`*^9}, {3.737458145437759*^9, 
   3.7374581669209003`*^9}, {3.7376025864905787`*^9, 3.737602586993412*^9}, {
   3.737993351329473*^9, 3.737993438496719*^9}, {3.7379937921265097`*^9, 
   3.737993794020381*^9}, {3.738391733073759*^9, 3.738391740401639*^9}},
 CellLabel->"In[23]:=",ExpressionUUID->"af962f22-3a9b-47ef-85fa-26b5fd0f4f9f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"tracelessPart", "[", 
     RowBox[{"ex", "[", "ii", "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"ii", ",", "0", ",", "22"}], "}"}]}], "]"}], "//", 
  "TableForm"}]], "Input",
 CellChangeTimes->{{3.737993996174065*^9, 3.7379940008185*^9}},
 CellLabel->"In[45]:=",ExpressionUUID->"a1551173-3cf2-4cbd-aace-ec52eb0b4ddc"],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {"1"},
     {
      RowBox[{"k", "[", "2", "]"}]},
     {
      RowBox[{"A", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "i", "}"}]}], "]"}]},
     {
      RowBox[{
       RowBox[{"-", 
        FractionBox["17", "9"]}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{"A", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "j", "}"}]}], "]"}], " ", 
          RowBox[{"B", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "i", "}"}]}], "]"}], " ", 
          RowBox[{"X", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
          RowBox[{"Y", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "p0", "}"}]}], "]"}]}], "+", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{"A", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "i", "}"}]}], "]"}], " ", 
          RowBox[{"B", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "j", "}"}]}], "]"}], " ", 
          RowBox[{"X", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
          RowBox[{"Y", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "p0", "}"}]}], "]"}]}], "-", 
         FractionBox[
          RowBox[{
           RowBox[{"A", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
           RowBox[{"B", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
           RowBox[{"X", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "p1", "}"}]}], "]"}], " ", 
           RowBox[{"Y", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "p1", "}"}]}], "]"}], " ", 
           RowBox[{"\[Delta]", "[", 
            RowBox[{"{", 
             RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "d"]}], ")"}]}]},
     {
      RowBox[{
       RowBox[{"-", "1.305`"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{"A", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "j", "}"}]}], "]"}], " ", 
          RowBox[{"B", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "i", "}"}]}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "p0", "}"}]}], "]"}], "2"]}], "+", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{"A", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "i", "}"}]}], "]"}], " ", 
          RowBox[{"B", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "j", "}"}]}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "p0", "}"}]}], "]"}], "2"]}], "-", 
         FractionBox[
          RowBox[{
           RowBox[{"A", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
           RowBox[{"B", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
           SuperscriptBox[
            RowBox[{"X", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p1", "}"}]}], "]"}], "2"], " ", 
           RowBox[{"\[Delta]", "[", 
            RowBox[{"{", 
             RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "d"]}], ")"}]}]},
     {
      RowBox[{"3.01`", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"A", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}]}], "]"}], "-", 
         
         FractionBox[
          RowBox[{
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"1", ",", 
              RowBox[{"{", 
               RowBox[{"k", ",", "l"}], "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"1", ",", 
              RowBox[{"{", 
               RowBox[{"j", ",", "l"}], "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"1", ",", 
              RowBox[{"{", 
               RowBox[{"j", ",", "k"}], "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "l"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"1", ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "l"}], "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"1", ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "k"}], "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"1", ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "j"}], "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"k", ",", "l"}], "}"}], "]"}]}]}], 
          RowBox[{"4", "+", "d"}]], "+", 
         FractionBox[
          RowBox[{
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"2", ",", 
              RowBox[{"{", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "l"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"2", ",", 
              RowBox[{"{", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "k"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"2", ",", 
              RowBox[{"{", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"k", ",", "l"}], "}"}], "]"}]}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"2", "+", "d"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"4", "+", "d"}], ")"}]}]]}], ")"}]}]},
     {"\<\"\\!\\(\\*StyleBox[\\\"Please\\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\" \\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\"check\\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\" \\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\"the\\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\" \\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\"exponents\\\",FontColor->RGBColor[1, 0, 0]]\\)\\!\
\\(\\*StyleBox[\\\" \\\",FontColor->RGBColor[1, 0, 0]]\\)\\!\\(\\*StyleBox[\\\
\"on\\\",FontColor->RGBColor[1, 0, 0]]\\)\\!\\(\\*StyleBox[\\\" \
\\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\"tensors\\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\" \\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\"or\\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\" \\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\"the\\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\" \\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\"number\\\",FontColor->RGBColor[1, 0, 0]]\\)\\!\\(\
\\*StyleBox[\\\" \\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\"of\\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\" \\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\"repeated\\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\" \\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\"indices\\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\".\\\",FontColor->RGBColor[1, 0, 0]]\\)\"\>"},
     {
      RowBox[{"7", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          FractionBox["1", "6"], " ", 
          RowBox[{"A", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "k", "}"}]}], "]"}], " ", 
          RowBox[{"B", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "j", "}"}]}], "]"}], " ", 
          RowBox[{"X", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "i", "}"}]}], "]"}]}], "+", 
         RowBox[{
          FractionBox["1", "6"], " ", 
          RowBox[{"A", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "j", "}"}]}], "]"}], " ", 
          RowBox[{"B", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "k", "}"}]}], "]"}], " ", 
          RowBox[{"X", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "i", "}"}]}], "]"}]}], "+", 
         RowBox[{
          FractionBox["1", "6"], " ", 
          RowBox[{"A", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "k", "}"}]}], "]"}], " ", 
          RowBox[{"B", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "i", "}"}]}], "]"}], " ", 
          RowBox[{"X", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "j", "}"}]}], "]"}]}], "+", 
         RowBox[{
          FractionBox["1", "6"], " ", 
          RowBox[{"A", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "i", "}"}]}], "]"}], " ", 
          RowBox[{"B", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "k", "}"}]}], "]"}], " ", 
          RowBox[{"X", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "j", "}"}]}], "]"}]}], "+", 
         RowBox[{
          FractionBox["1", "6"], " ", 
          RowBox[{"A", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "j", "}"}]}], "]"}], " ", 
          RowBox[{"B", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "i", "}"}]}], "]"}], " ", 
          RowBox[{"X", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "k", "}"}]}], "]"}]}], "+", 
         RowBox[{
          FractionBox["1", "6"], " ", 
          RowBox[{"A", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "i", "}"}]}], "]"}], " ", 
          RowBox[{"B", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "j", "}"}]}], "]"}], " ", 
          RowBox[{"X", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "k", "}"}]}], "]"}]}], "-", 
         FractionBox[
          RowBox[{
           RowBox[{
            FractionBox["1", "3"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"A", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
               RowBox[{"B", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
               RowBox[{"X", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", "k", "}"}]}], "]"}], " ", 
               RowBox[{"\[Delta]", "[", 
                RowBox[{"{", 
                 RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{"A", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
               RowBox[{"B", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
               RowBox[{"X", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", "j", "}"}]}], "]"}], " ", 
               RowBox[{"\[Delta]", "[", 
                RowBox[{"{", 
                 RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{"A", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
               RowBox[{"B", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
               RowBox[{"X", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", "i", "}"}]}], "]"}], " ", 
               RowBox[{"\[Delta]", "[", 
                RowBox[{"{", 
                 RowBox[{"j", ",", "k"}], "}"}], "]"}]}]}], ")"}]}], "+", 
           RowBox[{
            FractionBox["1", "3"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"A", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
               RowBox[{"B", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", "k", "}"}]}], "]"}], " ", 
               RowBox[{"X", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
               RowBox[{"\[Delta]", "[", 
                RowBox[{"{", 
                 RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{"A", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
               RowBox[{"B", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", "j", "}"}]}], "]"}], " ", 
               RowBox[{"X", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
               RowBox[{"\[Delta]", "[", 
                RowBox[{"{", 
                 RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{"A", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
               RowBox[{"B", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", "i", "}"}]}], "]"}], " ", 
               RowBox[{"X", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
               RowBox[{"\[Delta]", "[", 
                RowBox[{"{", 
                 RowBox[{"j", ",", "k"}], "}"}], "]"}]}]}], ")"}]}], "+", 
           RowBox[{
            FractionBox["1", "3"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"A", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", "k", "}"}]}], "]"}], " ", 
               RowBox[{"B", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
               RowBox[{"X", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
               RowBox[{"\[Delta]", "[", 
                RowBox[{"{", 
                 RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{"A", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", "j", "}"}]}], "]"}], " ", 
               RowBox[{"B", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
               RowBox[{"X", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
               RowBox[{"\[Delta]", "[", 
                RowBox[{"{", 
                 RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{"A", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", "i", "}"}]}], "]"}], " ", 
               RowBox[{"B", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
               RowBox[{"X", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
               RowBox[{"\[Delta]", "[", 
                RowBox[{"{", 
                 RowBox[{"j", ",", "k"}], "}"}], "]"}]}]}], ")"}]}]}], 
          RowBox[{"2", "+", "d"}]]}], ")"}]}]},
     {"\<\"\\!\\(\\*StyleBox[\\\"Please\\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\" \\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\"check\\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\" \\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\"the\\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\" \\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\"exponents\\\",FontColor->RGBColor[1, 0, 0]]\\)\\!\
\\(\\*StyleBox[\\\" \\\",FontColor->RGBColor[1, 0, 0]]\\)\\!\\(\\*StyleBox[\\\
\"on\\\",FontColor->RGBColor[1, 0, 0]]\\)\\!\\(\\*StyleBox[\\\" \
\\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\"tensors\\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\" \\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\"or\\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\" \\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\"the\\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\" \\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\"number\\\",FontColor->RGBColor[1, 0, 0]]\\)\\!\\(\
\\*StyleBox[\\\" \\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\"of\\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\" \\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\"repeated\\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\" \\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\"indices\\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\".\\\",FontColor->RGBColor[1, 0, 0]]\\)\"\>"},
     {
      RowBox[{"3", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          FractionBox["1", "3"], " ", 
          RowBox[{"A", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", 
             RowBox[{"j", ",", "l"}], "}"}]}], "]"}], " ", 
          RowBox[{"B", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "p0"}], "}"}]}], "]"}], " ", 
          RowBox[{"Y", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "p0", "}"}]}], "]"}]}], "+", 
         RowBox[{
          FractionBox["1", "3"], " ", 
          RowBox[{"A", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "l"}], "}"}]}], "]"}], " ", 
          RowBox[{"B", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", 
             RowBox[{"j", ",", "p0"}], "}"}]}], "]"}], " ", 
          RowBox[{"Y", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "p0", "}"}]}], "]"}]}], "+", 
         RowBox[{
          FractionBox["1", "3"], " ", 
          RowBox[{"A", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "j"}], "}"}]}], "]"}], " ", 
          RowBox[{"B", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", 
             RowBox[{"l", ",", "p0"}], "}"}]}], "]"}], " ", 
          RowBox[{"Y", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "p0", "}"}]}], "]"}]}], "-", 
         FractionBox[
          RowBox[{
           RowBox[{
            FractionBox["1", "3"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"A", "[", 
                RowBox[{"1", ",", 
                 RowBox[{"{", "}"}]}], "]"}], " ", 
               RowBox[{"B", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", 
                  RowBox[{"l", ",", "p0"}], "}"}]}], "]"}], " ", 
               RowBox[{"Y", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
               RowBox[{"\[Delta]", "[", 
                RowBox[{"{", 
                 RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{"A", "[", 
                RowBox[{"1", ",", 
                 RowBox[{"{", "}"}]}], "]"}], " ", 
               RowBox[{"B", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", 
                  RowBox[{"j", ",", "p0"}], "}"}]}], "]"}], " ", 
               RowBox[{"Y", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
               RowBox[{"\[Delta]", "[", 
                RowBox[{"{", 
                 RowBox[{"i", ",", "l"}], "}"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{"A", "[", 
                RowBox[{"1", ",", 
                 RowBox[{"{", "}"}]}], "]"}], " ", 
               RowBox[{"B", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", 
                  RowBox[{"i", ",", "p0"}], "}"}]}], "]"}], " ", 
               RowBox[{"Y", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
               RowBox[{"\[Delta]", "[", 
                RowBox[{"{", 
                 RowBox[{"j", ",", "l"}], "}"}], "]"}]}]}], ")"}]}], "+", 
           RowBox[{
            FractionBox["2", "3"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"A", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", 
                  RowBox[{"l", ",", "p0"}], "}"}]}], "]"}], " ", 
               RowBox[{"B", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", 
                  RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
               RowBox[{"Y", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", "p1", "}"}]}], "]"}], " ", 
               RowBox[{"\[Delta]", "[", 
                RowBox[{"{", 
                 RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{"A", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", 
                  RowBox[{"j", ",", "p0"}], "}"}]}], "]"}], " ", 
               RowBox[{"B", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", 
                  RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
               RowBox[{"Y", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", "p1", "}"}]}], "]"}], " ", 
               RowBox[{"\[Delta]", "[", 
                RowBox[{"{", 
                 RowBox[{"i", ",", "l"}], "}"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{"A", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", 
                  RowBox[{"i", ",", "p0"}], "}"}]}], "]"}], " ", 
               RowBox[{"B", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", 
                  RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
               RowBox[{"Y", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", "p1", "}"}]}], "]"}], " ", 
               RowBox[{"\[Delta]", "[", 
                RowBox[{"{", 
                 RowBox[{"j", ",", "l"}], "}"}], "]"}]}]}], ")"}]}]}], 
          RowBox[{"2", "+", "d"}]]}], ")"}]}]},
     {
      RowBox[{"4", " ", 
       RowBox[{"j", "[", 
        RowBox[{"2", ",", "1"}], "]"}], " ", 
       RowBox[{"\[Alpha]", "[", "3", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", 
             RowBox[{
             "e", ",", "i", ",", "j", ",", "k", ",", "n", ",", "p", ",", "p0",
               ",", "p1", ",", "p2"}], "}"}]}], "]"}], " ", 
          RowBox[{"B", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", 
             RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
          RowBox[{"Y", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "p2", "}"}]}], "]"}]}], "-", 
         FractionBox[
          RowBox[{
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"1", ",", 
              RowBox[{"{", 
               RowBox[{
               "j", ",", "k", ",", "n", ",", "p", ",", "p0", ",", "p1", ",", 
                "p2"}], "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"e", ",", "i"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"1", ",", 
              RowBox[{"{", 
               RowBox[{
               "i", ",", "k", ",", "n", ",", "p", ",", "p0", ",", "p1", ",", 
                "p2"}], "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"e", ",", "j"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"1", ",", 
              RowBox[{"{", 
               RowBox[{
               "i", ",", "j", ",", "n", ",", "p", ",", "p0", ",", "p1", ",", 
                "p2"}], "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"e", ",", "k"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"1", ",", 
              RowBox[{"{", 
               RowBox[{
               "i", ",", "j", ",", "k", ",", "p", ",", "p0", ",", "p1", ",", 
                "p2"}], "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"e", ",", "n"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"1", ",", 
              RowBox[{"{", 
               RowBox[{
               "i", ",", "j", ",", "k", ",", "n", ",", "p0", ",", "p1", ",", 
                "p2"}], "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"e", ",", "p"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"1", ",", 
              RowBox[{"{", 
               RowBox[{
               "e", ",", "k", ",", "n", ",", "p", ",", "p0", ",", "p1", ",", 
                "p2"}], "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"1", ",", 
              RowBox[{"{", 
               RowBox[{
               "e", ",", "j", ",", "n", ",", "p", ",", "p0", ",", "p1", ",", 
                "p2"}], "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"1", ",", 
              RowBox[{"{", 
               RowBox[{
               "e", ",", "j", ",", "k", ",", "p", ",", "p0", ",", "p1", ",", 
                "p2"}], "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "n"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"1", ",", 
              RowBox[{"{", 
               RowBox[{
               "e", ",", "j", ",", "k", ",", "n", ",", "p0", ",", "p1", ",", 
                "p2"}], "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "p"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"1", ",", 
              RowBox[{"{", 
               RowBox[{
               "e", ",", "i", ",", "n", ",", "p", ",", "p0", ",", "p1", ",", 
                "p2"}], "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"1", ",", 
              RowBox[{"{", 
               RowBox[{
               "e", ",", "i", ",", "k", ",", "p", ",", "p0", ",", "p1", ",", 
                "p2"}], "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"j", ",", "n"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"1", ",", 
              RowBox[{"{", 
               RowBox[{
               "e", ",", "i", ",", "k", ",", "n", ",", "p0", ",", "p1", ",", 
                "p2"}], "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"j", ",", "p"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"1", ",", 
              RowBox[{"{", 
               RowBox[{
               "e", ",", "i", ",", "j", ",", "p", ",", "p0", ",", "p1", ",", 
                "p2"}], "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"k", ",", "n"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"1", ",", 
              RowBox[{"{", 
               RowBox[{
               "e", ",", "i", ",", "j", ",", "n", ",", "p0", ",", "p1", ",", 
                "p2"}], "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"k", ",", "p"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"1", ",", 
              RowBox[{"{", 
               RowBox[{
               "e", ",", "i", ",", "j", ",", "k", ",", "p0", ",", "p1", ",", 
                "p2"}], "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"n", ",", "p"}], "}"}], "]"}]}]}], 
          RowBox[{"8", "+", "d"}]], "+", 
         FractionBox[
          RowBox[{
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"2", ",", 
              RowBox[{"{", 
               RowBox[{"n", ",", "p", ",", "p0", ",", "p1", ",", "p2"}], 
               "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"e", ",", "k"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"2", ",", 
              RowBox[{"{", 
               RowBox[{"k", ",", "p", ",", "p0", ",", "p1", ",", "p2"}], 
               "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"e", ",", "n"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"2", ",", 
              RowBox[{"{", 
               RowBox[{"k", ",", "n", ",", "p0", ",", "p1", ",", "p2"}], 
               "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"e", ",", "p"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"2", ",", 
              RowBox[{"{", 
               RowBox[{"n", ",", "p", ",", "p0", ",", "p1", ",", "p2"}], 
               "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"e", ",", "j"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"2", ",", 
              RowBox[{"{", 
               RowBox[{"j", ",", "p", ",", "p0", ",", "p1", ",", "p2"}], 
               "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"e", ",", "n"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"2", ",", 
              RowBox[{"{", 
               RowBox[{"j", ",", "n", ",", "p0", ",", "p1", ",", "p2"}], 
               "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"e", ",", "p"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"2", ",", 
              RowBox[{"{", 
               RowBox[{"k", ",", "p", ",", "p0", ",", "p1", ",", "p2"}], 
               "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"e", ",", "j"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "n"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"2", ",", 
              RowBox[{"{", 
               RowBox[{"j", ",", "p", ",", "p0", ",", "p1", ",", "p2"}], 
               "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"e", ",", "k"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "n"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"2", ",", 
              RowBox[{"{", 
               RowBox[{"j", ",", "k", ",", "p0", ",", "p1", ",", "p2"}], 
               "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"e", ",", "p"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "n"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"2", ",", 
              RowBox[{"{", 
               RowBox[{"k", ",", "n", ",", "p0", ",", "p1", ",", "p2"}], 
               "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"e", ",", "j"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "p"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"2", ",", 
              RowBox[{"{", 
               RowBox[{"j", ",", "n", ",", "p0", ",", "p1", ",", "p2"}], 
               "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"e", ",", "k"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "p"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"2", ",", 
              RowBox[{"{", 
               RowBox[{"j", ",", "k", ",", "p0", ",", "p1", ",", "p2"}], 
               "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"e", ",", "n"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "p"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"2", ",", 
              RowBox[{"{", 
               RowBox[{"n", ",", "p", ",", "p0", ",", "p1", ",", "p2"}], 
               "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"e", ",", "i"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"2", ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "p", ",", "p0", ",", "p1", ",", "p2"}], 
               "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"e", ",", "n"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"2", ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "n", ",", "p0", ",", "p1", ",", "p2"}], 
               "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"e", ",", "p"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"2", ",", 
              RowBox[{"{", 
               RowBox[{"e", ",", "p", ",", "p0", ",", "p1", ",", "p2"}], 
               "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "n"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"2", ",", 
              RowBox[{"{", 
               RowBox[{"e", ",", "n", ",", "p0", ",", "p1", ",", "p2"}], 
               "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "p"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"2", ",", 
              RowBox[{"{", 
               RowBox[{"k", ",", "p", ",", "p0", ",", "p1", ",", "p2"}], 
               "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"e", ",", "i"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"j", ",", "n"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"2", ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "p", ",", "p0", ",", "p1", ",", "p2"}], 
               "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"e", ",", "k"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"j", ",", "n"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"2", ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "k", ",", "p0", ",", "p1", ",", "p2"}], 
               "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"e", ",", "p"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"j", ",", "n"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"2", ",", 
              RowBox[{"{", 
               RowBox[{"e", ",", "p", ",", "p0", ",", "p1", ",", "p2"}], 
               "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "k"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"j", ",", "n"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"2", ",", 
              RowBox[{"{", 
               RowBox[{"e", ",", "k", ",", "p0", ",", "p1", ",", "p2"}], 
               "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "p"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"j", ",", "n"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"2", ",", 
              RowBox[{"{", 
               RowBox[{"k", ",", "n", ",", "p0", ",", "p1", ",", "p2"}], 
               "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"e", ",", "i"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"j", ",", "p"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"2", ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "n", ",", "p0", ",", "p1", ",", "p2"}], 
               "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"e", ",", "k"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"j", ",", "p"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"2", ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "k", ",", "p0", ",", "p1", ",", "p2"}], 
               "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"e", ",", "n"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"j", ",", "p"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"2", ",", 
              RowBox[{"{", 
               RowBox[{"e", ",", "n", ",", "p0", ",", "p1", ",", "p2"}], 
               "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "k"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"j", ",", "p"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"2", ",", 
              RowBox[{"{", 
               RowBox[{"e", ",", "k", ",", "p0", ",", "p1", ",", "p2"}], 
               "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "n"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"j", ",", "p"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"2", ",", 
              RowBox[{"{", 
               RowBox[{"j", ",", "p", ",", "p0", ",", "p1", ",", "p2"}], 
               "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"e", ",", "i"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"k", ",", "n"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"2", ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "p", ",", "p0", ",", "p1", ",", "p2"}], 
               "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"e", ",", "j"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"k", ",", "n"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"2", ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "j", ",", "p0", ",", "p1", ",", "p2"}], 
               "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"e", ",", "p"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"k", ",", "n"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"2", ",", 
              RowBox[{"{", 
               RowBox[{"e", ",", "p", ",", "p0", ",", "p1", ",", "p2"}], 
               "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"k", ",", "n"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"2", ",", 
              RowBox[{"{", 
               RowBox[{"e", ",", "j", ",", "p0", ",", "p1", ",", "p2"}], 
               "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "p"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"k", ",", "n"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"2", ",", 
              RowBox[{"{", 
               RowBox[{"e", ",", "i", ",", "p0", ",", "p1", ",", "p2"}], 
               "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"j", ",", "p"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"k", ",", "n"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"2", ",", 
              RowBox[{"{", 
               RowBox[{"j", ",", "n", ",", "p0", ",", "p1", ",", "p2"}], 
               "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"e", ",", "i"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"k", ",", "p"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"2", ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "n", ",", "p0", ",", "p1", ",", "p2"}], 
               "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"e", ",", "j"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"k", ",", "p"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"2", ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "j", ",", "p0", ",", "p1", ",", "p2"}], 
               "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"e", ",", "n"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"k", ",", "p"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"2", ",", 
              RowBox[{"{", 
               RowBox[{"e", ",", "n", ",", "p0", ",", "p1", ",", "p2"}], 
               "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"k", ",", "p"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"2", ",", 
              RowBox[{"{", 
               RowBox[{"e", ",", "j", ",", "p0", ",", "p1", ",", "p2"}], 
               "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "n"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"k", ",", "p"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"2", ",", 
              RowBox[{"{", 
               RowBox[{"e", ",", "i", ",", "p0", ",", "p1", ",", "p2"}], 
               "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"j", ",", "n"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"k", ",", "p"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"2", ",", 
              RowBox[{"{", 
               RowBox[{"j", ",", "k", ",", "p0", ",", "p1", ",", "p2"}], 
               "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"e", ",", "i"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"n", ",", "p"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"2", ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "k", ",", "p0", ",", "p1", ",", "p2"}], 
               "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"e", ",", "j"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"n", ",", "p"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"2", ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "j", ",", "p0", ",", "p1", ",", "p2"}], 
               "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"e", ",", "k"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"n", ",", "p"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"2", ",", 
              RowBox[{"{", 
               RowBox[{"e", ",", "k", ",", "p0", ",", "p1", ",", "p2"}], 
               "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"n", ",", "p"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"2", ",", 
              RowBox[{"{", 
               RowBox[{"e", ",", "j", ",", "p0", ",", "p1", ",", "p2"}], 
               "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "k"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"n", ",", "p"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"2", ",", 
              RowBox[{"{", 
               RowBox[{"e", ",", "i", ",", "p0", ",", "p1", ",", "p2"}], 
               "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"j", ",", "k"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"n", ",", "p"}], "}"}], "]"}]}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"6", "+", "d"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"8", "+", "d"}], ")"}]}]], "-", 
         FractionBox[
          RowBox[{
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"3", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1", ",", "p2"}], "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"e", ",", "p"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "n"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"3", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1", ",", "p2"}], "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"e", ",", "n"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "p"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"3", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1", ",", "p2"}], "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"e", ",", "p"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "k"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"j", ",", "n"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"3", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1", ",", "p2"}], "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"e", ",", "k"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "p"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"j", ",", "n"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"3", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1", ",", "p2"}], "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"e", ",", "n"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "k"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"j", ",", "p"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"3", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1", ",", "p2"}], "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"e", ",", "k"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "n"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"j", ",", "p"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"3", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1", ",", "p2"}], "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"e", ",", "p"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"k", ",", "n"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"3", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1", ",", "p2"}], "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"e", ",", "j"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "p"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"k", ",", "n"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"3", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1", ",", "p2"}], "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"e", ",", "i"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"j", ",", "p"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"k", ",", "n"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"3", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1", ",", "p2"}], "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"e", ",", "n"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"k", ",", "p"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"3", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1", ",", "p2"}], "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"e", ",", "j"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "n"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"k", ",", "p"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"3", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1", ",", "p2"}], "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"e", ",", "i"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"j", ",", "n"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"k", ",", "p"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"3", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1", ",", "p2"}], "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"e", ",", "k"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"n", ",", "p"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"3", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1", ",", "p2"}], "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"e", ",", "j"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "k"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"n", ",", "p"}], "}"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"3", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1", ",", "p2"}], "}"}]}], "]"}], " ", 
            RowBox[{"B", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"p0", ",", "p1"}], "}"}]}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p2", "}"}]}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"e", ",", "i"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"j", ",", "k"}], "}"}], "]"}], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"n", ",", "p"}], "}"}], "]"}]}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"4", "+", "d"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"6", "+", "d"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"8", "+", "d"}], ")"}]}]]}], ")"}]}]},
     {
      RowBox[{"9", " ", 
       SuperscriptBox[
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "p0", "}"}]}], "]"}], "2"]}]},
     {
      RowBox[{"59", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          FractionBox["1", "3"], " ", 
          RowBox[{"A", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "k", "}"}]}], "]"}], " ", 
          RowBox[{"B", "[", 
           RowBox[{"1", ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "j"}], "}"}]}], "]"}]}], "+", 
         RowBox[{
          FractionBox["1", "3"], " ", 
          RowBox[{"A", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "j", "}"}]}], "]"}], " ", 
          RowBox[{"B", "[", 
           RowBox[{"1", ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "k"}], "}"}]}], "]"}]}], "+", 
         RowBox[{
          FractionBox["1", "3"], " ", 
          RowBox[{"A", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "i", "}"}]}], "]"}], " ", 
          RowBox[{"B", "[", 
           RowBox[{"1", ",", 
            RowBox[{"{", 
             RowBox[{"j", ",", "k"}], "}"}]}], "]"}]}], "-", 
         FractionBox[
          RowBox[{
           RowBox[{
            FractionBox["2", "3"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"A", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
               RowBox[{"B", "[", 
                RowBox[{"1", ",", 
                 RowBox[{"{", 
                  RowBox[{"k", ",", "p0"}], "}"}]}], "]"}], " ", 
               RowBox[{"\[Delta]", "[", 
                RowBox[{"{", 
                 RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{"A", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
               RowBox[{"B", "[", 
                RowBox[{"1", ",", 
                 RowBox[{"{", 
                  RowBox[{"j", ",", "p0"}], "}"}]}], "]"}], " ", 
               RowBox[{"\[Delta]", "[", 
                RowBox[{"{", 
                 RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{"A", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
               RowBox[{"B", "[", 
                RowBox[{"1", ",", 
                 RowBox[{"{", 
                  RowBox[{"i", ",", "p0"}], "}"}]}], "]"}], " ", 
               RowBox[{"\[Delta]", "[", 
                RowBox[{"{", 
                 RowBox[{"j", ",", "k"}], "}"}], "]"}]}]}], ")"}]}], "+", 
           RowBox[{
            FractionBox["1", "3"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"A", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", "k", "}"}]}], "]"}], " ", 
               RowBox[{"B", "[", 
                RowBox[{"2", ",", 
                 RowBox[{"{", "}"}]}], "]"}], " ", 
               RowBox[{"\[Delta]", "[", 
                RowBox[{"{", 
                 RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{"A", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", "j", "}"}]}], "]"}], " ", 
               RowBox[{"B", "[", 
                RowBox[{"2", ",", 
                 RowBox[{"{", "}"}]}], "]"}], " ", 
               RowBox[{"\[Delta]", "[", 
                RowBox[{"{", 
                 RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{"A", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"{", "i", "}"}]}], "]"}], " ", 
               RowBox[{"B", "[", 
                RowBox[{"2", ",", 
                 RowBox[{"{", "}"}]}], "]"}], " ", 
               RowBox[{"\[Delta]", "[", 
                RowBox[{"{", 
                 RowBox[{"j", ",", "k"}], "}"}], "]"}]}]}], ")"}]}]}], 
          RowBox[{"2", "+", "d"}]]}], ")"}]}]},
     {
      RowBox[{
       RowBox[{"-", "4"}], " ", 
       SuperscriptBox[
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"B", "[", 
         RowBox[{"1", ",", 
          RowBox[{"{", 
           RowBox[{"p1", ",", "p2"}], "}"}]}], "]"}], "2"]}]},
     {"\<\"\\!\\(\\*StyleBox[\\\"Please\\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\" \\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\"check\\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\" \\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\"the\\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\" \\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\"exponents\\\",FontColor->RGBColor[1, 0, 0]]\\)\\!\
\\(\\*StyleBox[\\\" \\\",FontColor->RGBColor[1, 0, 0]]\\)\\!\\(\\*StyleBox[\\\
\"on\\\",FontColor->RGBColor[1, 0, 0]]\\)\\!\\(\\*StyleBox[\\\" \
\\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\"tensors\\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\" \\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\"or\\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\" \\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\"the\\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\" \\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\"number\\\",FontColor->RGBColor[1, 0, 0]]\\)\\!\\(\
\\*StyleBox[\\\" \\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\"of\\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\" \\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\"repeated\\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\" \\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\"indices\\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\".\\\",FontColor->RGBColor[1, 0, 0]]\\)\"\>"},
     {
      RowBox[{
       FractionBox["1", "6"], " ", 
       SuperscriptBox["x", "2"], " ", 
       RowBox[{"A", "[", 
        RowBox[{"1", ",", 
         RowBox[{"{", "}"}]}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{"B", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", 
           RowBox[{"p1", ",", "p2"}], "}"}]}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"k", "[", "2", "]"}], "3"]}]},
     {"\<\"\\!\\(\\*StyleBox[\\\"Please\\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\" \\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\"check\\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\" \\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\"the\\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\" \\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\"exponents\\\",FontColor->RGBColor[1, 0, 0]]\\)\\!\
\\(\\*StyleBox[\\\" \\\",FontColor->RGBColor[1, 0, 0]]\\)\\!\\(\\*StyleBox[\\\
\"on\\\",FontColor->RGBColor[1, 0, 0]]\\)\\!\\(\\*StyleBox[\\\" \
\\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\"tensors\\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\" \\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\"or\\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\" \\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\"the\\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\" \\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\"number\\\",FontColor->RGBColor[1, 0, 0]]\\)\\!\\(\
\\*StyleBox[\\\" \\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\"of\\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\" \\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\"repeated\\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\" \\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\"indices\\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\".\\\",FontColor->RGBColor[1, 0, 0]]\\)\"\>"},
     {"\<\"\\!\\(\\*StyleBox[\\\"Please\\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\" \\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\"check\\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\" \\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\"the\\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\" \\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\"exponents\\\",FontColor->RGBColor[1, 0, 0]]\\)\\!\
\\(\\*StyleBox[\\\" \\\",FontColor->RGBColor[1, 0, 0]]\\)\\!\\(\\*StyleBox[\\\
\"on\\\",FontColor->RGBColor[1, 0, 0]]\\)\\!\\(\\*StyleBox[\\\" \
\\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\"tensors\\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\" \\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\"or\\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\" \\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\"the\\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\" \\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\"number\\\",FontColor->RGBColor[1, 0, 0]]\\)\\!\\(\
\\*StyleBox[\\\" \\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\"of\\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\" \\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\"repeated\\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\" \\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\"indices\\\",FontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*StyleBox[\\\".\\\",FontColor->RGBColor[1, 0, 0]]\\)\"\>"},
     {
      RowBox[{
       RowBox[{"8", " ", 
        SuperscriptBox["x", "2"], " ", 
        RowBox[{"A", "[", 
         RowBox[{"1", ",", 
          RowBox[{"{", "}"}]}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{"B", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", 
            RowBox[{"p1", ",", "p2"}], "}"}]}], "]"}], "2"]}], "+", 
       RowBox[{"7", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"A", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
           RowBox[{"B", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "j", "}"}]}], "]"}], " ", 
           RowBox[{"B", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "k", "}"}]}], "]"}]}], "-", 
          FractionBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p1", "}"}]}], "]"}], "2"], " ", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"{", 
              RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "d"]}], ")"}]}]}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "i", "}"}]}], "]"}], " ", 
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "j", "}"}]}], "]"}], " ", 
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "k", "}"}]}], "]"}], " ", 
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "l", "}"}]}], "]"}]}], "-", 
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "k", "}"}]}], "]"}], " ", 
          RowBox[{"A", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "l", "}"}]}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{"A", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "j", "}"}]}], "]"}], " ", 
          RowBox[{"A", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "l", "}"}]}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{"A", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "j", "}"}]}], "]"}], " ", 
          RowBox[{"A", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "k", "}"}]}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{"A", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i", ",", "l"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "i", "}"}]}], "]"}], " ", 
          RowBox[{"A", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "l", "}"}]}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{"A", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "i", "}"}]}], "]"}], " ", 
          RowBox[{"A", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "k", "}"}]}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{"A", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "i", "}"}]}], "]"}], " ", 
          RowBox[{"A", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", "j", "}"}]}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{"A", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"k", ",", "l"}], "}"}], "]"}]}]}], 
        RowBox[{"4", "+", "d"}]], "+", 
       FractionBox[
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"A", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"A", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "p1", "}"}]}], "]"}], "2"], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i", ",", "l"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"A", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"A", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "p1", "}"}]}], "]"}], "2"], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i", ",", "k"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"A", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"A", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "p1", "}"}]}], "]"}], "2"], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"k", ",", "l"}], "}"}], "]"}]}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"2", "+", "d"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"4", "+", "d"}], ")"}]}]]}]},
     {
      RowBox[{
       RowBox[{"A", "[", 
        RowBox[{"5", ",", 
         RowBox[{"{", 
          RowBox[{"i1", ",", "i2", ",", "i3", ",", "i4"}], "}"}]}], "]"}], 
       "-", 
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"6", ",", 
            RowBox[{"{", 
             RowBox[{"i3", ",", "i4"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i2"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"6", ",", 
            RowBox[{"{", 
             RowBox[{"i2", ",", "i4"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i3"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"6", ",", 
            RowBox[{"{", 
             RowBox[{"i2", ",", "i3"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i4"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"6", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i4"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i3"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"6", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i3"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i4"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"6", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i2"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i3", ",", "i4"}], "}"}], "]"}]}]}], 
        RowBox[{"4", "+", "d"}]], "+", 
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"7", ",", 
            RowBox[{"{", "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i4"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i3"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"7", ",", 
            RowBox[{"{", "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i3"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i4"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"7", ",", 
            RowBox[{"{", "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i2"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i3", ",", "i4"}], "}"}], "]"}]}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"2", "+", "d"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"4", "+", "d"}], ")"}]}]]}]},
     {
      RowBox[{
       RowBox[{"A", "[", 
        RowBox[{"2", ",", 
         RowBox[{"{", 
          RowBox[{
          "i1", ",", "i2", ",", "i3", ",", "i4", ",", "i5", ",", "i6"}], 
          "}"}]}], "]"}], "-", 
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"3", ",", 
            RowBox[{"{", 
             RowBox[{"i3", ",", "i4", ",", "i5", ",", "i6"}], "}"}]}], "]"}], 
          " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i2"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"3", ",", 
            RowBox[{"{", 
             RowBox[{"i2", ",", "i4", ",", "i5", ",", "i6"}], "}"}]}], "]"}], 
          " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i3"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"3", ",", 
            RowBox[{"{", 
             RowBox[{"i2", ",", "i3", ",", "i5", ",", "i6"}], "}"}]}], "]"}], 
          " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i4"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"3", ",", 
            RowBox[{"{", 
             RowBox[{"i2", ",", "i3", ",", "i4", ",", "i6"}], "}"}]}], "]"}], 
          " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i5"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"3", ",", 
            RowBox[{"{", 
             RowBox[{"i2", ",", "i3", ",", "i4", ",", "i5"}], "}"}]}], "]"}], 
          " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i6"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"3", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i4", ",", "i5", ",", "i6"}], "}"}]}], "]"}], 
          " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i3"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"3", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i3", ",", "i5", ",", "i6"}], "}"}]}], "]"}], 
          " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i4"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"3", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i3", ",", "i4", ",", "i6"}], "}"}]}], "]"}], 
          " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i5"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"3", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i3", ",", "i4", ",", "i5"}], "}"}]}], "]"}], 
          " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i6"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"3", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i2", ",", "i5", ",", "i6"}], "}"}]}], "]"}], 
          " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i3", ",", "i4"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"3", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i2", ",", "i4", ",", "i6"}], "}"}]}], "]"}], 
          " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i3", ",", "i5"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"3", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i2", ",", "i4", ",", "i5"}], "}"}]}], "]"}], 
          " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i3", ",", "i6"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"3", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i2", ",", "i3", ",", "i6"}], "}"}]}], "]"}], 
          " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i4", ",", "i5"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"3", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i2", ",", "i3", ",", "i5"}], "}"}]}], "]"}], 
          " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i4", ",", "i6"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"3", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i2", ",", "i3", ",", "i4"}], "}"}]}], "]"}], 
          " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i5", ",", "i6"}], "}"}], "]"}]}]}], 
        RowBox[{"8", "+", "d"}]], "+", 
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i5", ",", "i6"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i4"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i3"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i4", ",", "i6"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i5"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i3"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i4", ",", "i5"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i6"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i3"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i5", ",", "i6"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i3"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i4"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i3", ",", "i6"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i5"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i4"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i3", ",", "i5"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i6"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i4"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i4", ",", "i6"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i3"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i5"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i3", ",", "i6"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i4"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i5"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i3", ",", "i4"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i6"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i5"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i4", ",", "i5"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i3"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i6"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i3", ",", "i5"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i4"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i6"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i3", ",", "i4"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i5"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i6"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i5", ",", "i6"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i2"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i3", ",", "i4"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i2", ",", "i6"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i5"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i3", ",", "i4"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i2", ",", "i5"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i6"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i3", ",", "i4"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i6"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i5"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i3", ",", "i4"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i5"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i6"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i3", ",", "i4"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i4", ",", "i6"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i2"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i3", ",", "i5"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i2", ",", "i6"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i4"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i3", ",", "i5"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i2", ",", "i4"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i6"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i3", ",", "i5"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i6"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i4"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i3", ",", "i5"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i4"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i6"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i3", ",", "i5"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i4", ",", "i5"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i2"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i3", ",", "i6"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i2", ",", "i5"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i4"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i3", ",", "i6"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i2", ",", "i4"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i5"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i3", ",", "i6"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i5"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i4"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i3", ",", "i6"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i4"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i5"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i3", ",", "i6"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i3", ",", "i6"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i2"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i4", ",", "i5"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i2", ",", "i6"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i3"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i4", ",", "i5"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i2", ",", "i3"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i6"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i4", ",", "i5"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i6"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i3"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i4", ",", "i5"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i3"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i6"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i4", ",", "i5"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i2"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i3", ",", "i6"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i4", ",", "i5"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i3", ",", "i5"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i2"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i4", ",", "i6"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i2", ",", "i5"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i3"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i4", ",", "i6"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i2", ",", "i3"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i5"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i4", ",", "i6"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i5"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i3"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i4", ",", "i6"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i3"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i5"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i4", ",", "i6"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i2"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i3", ",", "i5"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i4", ",", "i6"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i3", ",", "i4"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i2"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i5", ",", "i6"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i2", ",", "i4"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i3"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i5", ",", "i6"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i2", ",", "i3"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i4"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i5", ",", "i6"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i4"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i3"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i5", ",", "i6"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i3"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i4"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i5", ",", "i6"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"4", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i2"}], "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i3", ",", "i4"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i5", ",", "i6"}], "}"}], "]"}]}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"6", "+", "d"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"8", "+", "d"}], ")"}]}]], "-", 
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"5", ",", 
            RowBox[{"{", "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i6"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i5"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i3", ",", "i4"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"5", ",", 
            RowBox[{"{", "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i5"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i6"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i3", ",", "i4"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"5", ",", 
            RowBox[{"{", "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i6"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i4"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i3", ",", "i5"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"5", ",", 
            RowBox[{"{", "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i4"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i6"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i3", ",", "i5"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"5", ",", 
            RowBox[{"{", "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i5"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i4"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i3", ",", "i6"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"5", ",", 
            RowBox[{"{", "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i4"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i5"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i3", ",", "i6"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"5", ",", 
            RowBox[{"{", "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i6"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i3"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i4", ",", "i5"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"5", ",", 
            RowBox[{"{", "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i3"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i6"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i4", ",", "i5"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"5", ",", 
            RowBox[{"{", "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i2"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i3", ",", "i6"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i4", ",", "i5"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"5", ",", 
            RowBox[{"{", "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i5"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i3"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i4", ",", "i6"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"5", ",", 
            RowBox[{"{", "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i3"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i5"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i4", ",", "i6"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"5", ",", 
            RowBox[{"{", "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i2"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i3", ",", "i5"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i4", ",", "i6"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"5", ",", 
            RowBox[{"{", "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i4"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i3"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i5", ",", "i6"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"5", ",", 
            RowBox[{"{", "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i3"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i4"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i5", ",", "i6"}], "}"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"A", "[", 
           RowBox[{"5", ",", 
            RowBox[{"{", "}"}]}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i2"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i3", ",", "i4"}], "}"}], "]"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i5", ",", "i6"}], "}"}], "]"}]}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"4", "+", "d"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"6", "+", "d"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"8", "+", "d"}], ")"}]}]]}]},
     {
      RowBox[{
       RowBox[{
        FractionBox["1", "24"], " ", 
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "l", "}"}]}], "]"}], " ", 
        RowBox[{"B", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "k", "}"}]}], "]"}], " ", 
        RowBox[{"F", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "j", "}"}]}], "]"}], " ", 
        RowBox[{"Y", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "i", "}"}]}], "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "24"], " ", 
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "k", "}"}]}], "]"}], " ", 
        RowBox[{"B", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "l", "}"}]}], "]"}], " ", 
        RowBox[{"F", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "j", "}"}]}], "]"}], " ", 
        RowBox[{"Y", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "i", "}"}]}], "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "24"], " ", 
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "l", "}"}]}], "]"}], " ", 
        RowBox[{"B", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "j", "}"}]}], "]"}], " ", 
        RowBox[{"F", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "k", "}"}]}], "]"}], " ", 
        RowBox[{"Y", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "i", "}"}]}], "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "24"], " ", 
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "j", "}"}]}], "]"}], " ", 
        RowBox[{"B", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "l", "}"}]}], "]"}], " ", 
        RowBox[{"F", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "k", "}"}]}], "]"}], " ", 
        RowBox[{"Y", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "i", "}"}]}], "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "24"], " ", 
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "k", "}"}]}], "]"}], " ", 
        RowBox[{"B", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "j", "}"}]}], "]"}], " ", 
        RowBox[{"F", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "l", "}"}]}], "]"}], " ", 
        RowBox[{"Y", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "i", "}"}]}], "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "24"], " ", 
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "j", "}"}]}], "]"}], " ", 
        RowBox[{"B", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "k", "}"}]}], "]"}], " ", 
        RowBox[{"F", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "l", "}"}]}], "]"}], " ", 
        RowBox[{"Y", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "i", "}"}]}], "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "24"], " ", 
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "l", "}"}]}], "]"}], " ", 
        RowBox[{"B", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "k", "}"}]}], "]"}], " ", 
        RowBox[{"F", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "i", "}"}]}], "]"}], " ", 
        RowBox[{"Y", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "j", "}"}]}], "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "24"], " ", 
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "k", "}"}]}], "]"}], " ", 
        RowBox[{"B", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "l", "}"}]}], "]"}], " ", 
        RowBox[{"F", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "i", "}"}]}], "]"}], " ", 
        RowBox[{"Y", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "j", "}"}]}], "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "24"], " ", 
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "l", "}"}]}], "]"}], " ", 
        RowBox[{"B", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "i", "}"}]}], "]"}], " ", 
        RowBox[{"F", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "k", "}"}]}], "]"}], " ", 
        RowBox[{"Y", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "j", "}"}]}], "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "24"], " ", 
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "i", "}"}]}], "]"}], " ", 
        RowBox[{"B", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "l", "}"}]}], "]"}], " ", 
        RowBox[{"F", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "k", "}"}]}], "]"}], " ", 
        RowBox[{"Y", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "j", "}"}]}], "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "24"], " ", 
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "k", "}"}]}], "]"}], " ", 
        RowBox[{"B", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "i", "}"}]}], "]"}], " ", 
        RowBox[{"F", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "l", "}"}]}], "]"}], " ", 
        RowBox[{"Y", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "j", "}"}]}], "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "24"], " ", 
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "i", "}"}]}], "]"}], " ", 
        RowBox[{"B", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "k", "}"}]}], "]"}], " ", 
        RowBox[{"F", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "l", "}"}]}], "]"}], " ", 
        RowBox[{"Y", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "j", "}"}]}], "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "24"], " ", 
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "l", "}"}]}], "]"}], " ", 
        RowBox[{"B", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "j", "}"}]}], "]"}], " ", 
        RowBox[{"F", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "i", "}"}]}], "]"}], " ", 
        RowBox[{"Y", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "k", "}"}]}], "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "24"], " ", 
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "j", "}"}]}], "]"}], " ", 
        RowBox[{"B", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "l", "}"}]}], "]"}], " ", 
        RowBox[{"F", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "i", "}"}]}], "]"}], " ", 
        RowBox[{"Y", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "k", "}"}]}], "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "24"], " ", 
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "l", "}"}]}], "]"}], " ", 
        RowBox[{"B", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "i", "}"}]}], "]"}], " ", 
        RowBox[{"F", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "j", "}"}]}], "]"}], " ", 
        RowBox[{"Y", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "k", "}"}]}], "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "24"], " ", 
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "i", "}"}]}], "]"}], " ", 
        RowBox[{"B", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "l", "}"}]}], "]"}], " ", 
        RowBox[{"F", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "j", "}"}]}], "]"}], " ", 
        RowBox[{"Y", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "k", "}"}]}], "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "24"], " ", 
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "j", "}"}]}], "]"}], " ", 
        RowBox[{"B", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "i", "}"}]}], "]"}], " ", 
        RowBox[{"F", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "l", "}"}]}], "]"}], " ", 
        RowBox[{"Y", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "k", "}"}]}], "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "24"], " ", 
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "i", "}"}]}], "]"}], " ", 
        RowBox[{"B", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "j", "}"}]}], "]"}], " ", 
        RowBox[{"F", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "l", "}"}]}], "]"}], " ", 
        RowBox[{"Y", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "k", "}"}]}], "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "24"], " ", 
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "k", "}"}]}], "]"}], " ", 
        RowBox[{"B", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "j", "}"}]}], "]"}], " ", 
        RowBox[{"F", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "i", "}"}]}], "]"}], " ", 
        RowBox[{"Y", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "l", "}"}]}], "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "24"], " ", 
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "j", "}"}]}], "]"}], " ", 
        RowBox[{"B", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "k", "}"}]}], "]"}], " ", 
        RowBox[{"F", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "i", "}"}]}], "]"}], " ", 
        RowBox[{"Y", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "l", "}"}]}], "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "24"], " ", 
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "k", "}"}]}], "]"}], " ", 
        RowBox[{"B", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "i", "}"}]}], "]"}], " ", 
        RowBox[{"F", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "j", "}"}]}], "]"}], " ", 
        RowBox[{"Y", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "l", "}"}]}], "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "24"], " ", 
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "i", "}"}]}], "]"}], " ", 
        RowBox[{"B", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "k", "}"}]}], "]"}], " ", 
        RowBox[{"F", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "j", "}"}]}], "]"}], " ", 
        RowBox[{"Y", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "l", "}"}]}], "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "24"], " ", 
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "j", "}"}]}], "]"}], " ", 
        RowBox[{"B", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "i", "}"}]}], "]"}], " ", 
        RowBox[{"F", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "k", "}"}]}], "]"}], " ", 
        RowBox[{"Y", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "l", "}"}]}], "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "24"], " ", 
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "i", "}"}]}], "]"}], " ", 
        RowBox[{"B", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "j", "}"}]}], "]"}], " ", 
        RowBox[{"F", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "k", "}"}]}], "]"}], " ", 
        RowBox[{"Y", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "l", "}"}]}], "]"}]}], "-", 
       FractionBox[
        RowBox[{
         RowBox[{
          FractionBox["1", "6"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "l", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "k", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "k", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "l", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "l", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "j", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "j", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "l", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "k", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "j", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "l"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "j", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "k", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "l"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "l", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "i", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "i", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "l", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "k", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "i", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "i", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "k", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "j", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "i", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"k", ",", "l"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "i", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "j", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"k", ",", "l"}], "}"}], "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          FractionBox["1", "6"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "l", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "k", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "k", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "l", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "l", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "j", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "j", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "l", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "k", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "j", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "l"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "j", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "k", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "l"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "l", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "i", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "i", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "l", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "k", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "i", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "i", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "k", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "j", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "i", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"k", ",", "l"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "i", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "j", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"k", ",", "l"}], "}"}], "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          FractionBox["1", "6"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "l", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "k", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "k", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "l", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "l", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "j", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "j", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "l", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "k", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "j", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "l"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "j", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "k", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "l"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "l", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "i", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "i", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "l", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "k", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "i", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "i", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "k", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "j", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "i", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"k", ",", "l"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "i", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "j", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"k", ",", "l"}], "}"}], "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          FractionBox["1", "6"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "l", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "k", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "k", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "l", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "l", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "j", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "j", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "l", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "k", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "j", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "l"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "j", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "k", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "l"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "l", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "i", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "i", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "l", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "k", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "i", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "i", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "k", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "j", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "i", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"k", ",", "l"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "i", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "j", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"k", ",", "l"}], "}"}], "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          FractionBox["1", "6"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "l", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "k", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "k", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "l", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "l", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "j", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "j", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "l", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "k", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "j", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "l"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "j", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "k", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "l"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "l", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "i", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "i", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "l", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "k", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "i", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "i", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "k", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "j", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "i", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"k", ",", "l"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "i", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "j", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"k", ",", "l"}], "}"}], "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          FractionBox["1", "6"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "l", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "k", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "k", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "l", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "l", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "j", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "j", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "l", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "k", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "j", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "l"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "j", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "k", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "l"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "l", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "i", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "i", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "l", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "k", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "i", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "i", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "k", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "j", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "i", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"k", ",", "l"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "i", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "j", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"k", ",", "l"}], "}"}], "]"}]}]}], ")"}]}]}], 
        RowBox[{"4", "+", "d"}]], "+", 
       FractionBox[
        RowBox[{
         RowBox[{
          FractionBox["1", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p1", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p1", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "l"}], "}"}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p1", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p1", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "k"}], "}"}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p1", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p1", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"k", ",", "l"}], "}"}], "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          FractionBox["1", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p1", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p1", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "l"}], "}"}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p1", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p1", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "k"}], "}"}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p1", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p1", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"k", ",", "l"}], "}"}], "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          FractionBox["1", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p1", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p1", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "l"}], "}"}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p1", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p1", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "k"}], "}"}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"B", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p0", "}"}]}], "]"}], " ", 
             RowBox[{"F", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p1", "}"}]}], "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "p1", "}"}]}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"k", ",", "l"}], "}"}], "]"}]}]}], ")"}]}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"2", "+", "d"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"4", "+", "d"}], ")"}]}]]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.5599999999999999]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   Column],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.73760311368307*^9, 3.7376036309278708`*^9, 3.7376043317655487`*^9, 
   3.737610246525948*^9, 3.7376130781002817`*^9, 3.7376346752678223`*^9, 
   3.737993160057568*^9, {3.737993434694747*^9, 3.73799344132187*^9}, 
   3.737993738409307*^9, {3.737993781006988*^9, 3.737993801375782*^9}, 
   3.7379940047758303`*^9, 3.7379943469521217`*^9, 3.738390896150928*^9},
 CellLabel->
  "Out[45]//TableForm=",ExpressionUUID->"ce0267df-436b-459c-a2f0-\
dcd74b29ed08"]
}, Open  ]],

Cell["Examples on tracefreerepresentation", "Text",
 CellChangeTimes->{{3.738391765136648*^9, 3.738391793389008*^9}},
 FontColor->RGBColor[
  1, 0, 0],ExpressionUUID->"5bbf6c62-a3b8-493d-bdf5-96e6a7a850a4"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "0", "]"}], "=", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["7.83", "6"]}], 
    RowBox[{"A", "[", 
     RowBox[{"{", "i", "}"}], "]"}], 
    RowBox[{"A", "[", 
     RowBox[{"{", "j", "}"}], "]"}], 
    RowBox[{"X", "[", 
     RowBox[{"{", "k", "}"}], "]"}], 
    RowBox[{"X", "[", 
     RowBox[{"{", "k", "}"}], "]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.738391857889352*^9, 3.738391887055889*^9}},
 CellLabel->"In[62]:=",ExpressionUUID->"8f673131-d650-4540-9c4b-3178548034f1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tracefreerepresentation", "[", 
  RowBox[{"ex", "[", "0", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.738391892656783*^9, 3.73839190950347*^9}},
 CellLabel->"In[64]:=",ExpressionUUID->"6297edf0-1c2f-405c-a654-f690128584c1"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"1.305`", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"A", "[", 
        RowBox[{"1", ",", 
         RowBox[{"{", "}"}]}], "]"}], " ", 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
      RowBox[{"d", " ", 
       RowBox[{"\[Upsilon]", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "j"}], "}"}]}], "]"}]}]}], ")"}]}], 
   "d"]}]], "Output",
 CellChangeTimes->{{3.7383918978611183`*^9, 3.738391910494563*^9}},
 CellLabel->"Out[64]=",ExpressionUUID->"c4175745-4e16-4b56-b599-7930cecb7606"]
}, Open  ]],

Cell[BoxData[
 StyleBox[
  RowBox[{
   RowBox[{"Verification", " ", "with", " ", 
    RowBox[{"eqs", ".", " ", 
     RowBox[{"(", "2.10", ")"}]}]}], " ", "-", 
   RowBox[{
    RowBox[{"(", "2.14", ")"}], " ", "of", " ", "Garz\[OAcute]", " ", "and", 
    " ", "Santos", " ", "2007", " ", 
    RowBox[{"J", ".", " ", "Phys", ".", " ", 
     RowBox[{"A", ":", " ", 
      RowBox[{
       RowBox[{"Math", ".", " ", "Theor", ".", " ", "40"}], " ", 
       "14927"}]}]}]}]}], "Subsection"]], "Input",
 CellChangeTimes->{{3.737603160087296*^9, 3.737603160088921*^9}, {
  3.7376032211547318`*^9, 
  3.737603266482952*^9}},ExpressionUUID->"64c56400-0a29-4fe3-b10c-\
4827a6de3143"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Deftracefreetensor", "[", "1", "]"}], "\[IndentingNewLine]", 
 RowBox[{"Deftracefreetensor", "[", 
  RowBox[{"V", "[", 
   RowBox[{"{", "i", "}"}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Deftracefreetensor", "[", 
  RowBox[{"V", "[", 
   RowBox[{"1", ",", 
    RowBox[{"{", "}"}]}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Deftracefreetensor", "[", 
  RowBox[{
   RowBox[{"V", "[", 
    RowBox[{"{", "i", "}"}], "]"}], 
   RowBox[{"V", "[", 
    RowBox[{"{", "j", "}"}], "]"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Deftracefreetensor", "[", 
  RowBox[{"V", "[", 
   RowBox[{"1", ",", 
    RowBox[{"{", "i", "}"}]}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Deftracefreetensor", "[", 
  RowBox[{
   RowBox[{"V", "[", 
    RowBox[{"{", "i", "}"}], "]"}], 
   RowBox[{"V", "[", 
    RowBox[{"{", "j", "}"}], "]"}], 
   RowBox[{"V", "[", 
    RowBox[{"{", "k", "}"}], "]"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Deftracefreetensor", "[", 
  RowBox[{"V", "[", 
   RowBox[{"2", ",", 
    RowBox[{"{", "}"}]}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Deftracefreetensor", "[", 
  RowBox[{
   RowBox[{"V", "[", 
    RowBox[{"1", ",", 
     RowBox[{"{", "}"}]}], "]"}], 
   RowBox[{"V", "[", 
    RowBox[{"{", "i", "}"}], "]"}], 
   RowBox[{"V", "[", 
    RowBox[{"{", "j", "}"}], "]"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Deftracefreetensor", "[", 
  RowBox[{
   RowBox[{"V", "[", 
    RowBox[{"{", "i", "}"}], "]"}], 
   RowBox[{"V", "[", 
    RowBox[{"{", "j", "}"}], "]"}], 
   RowBox[{"V", "[", 
    RowBox[{"{", "k", "}"}], "]"}], 
   RowBox[{"V", "[", 
    RowBox[{"{", "l", "}"}], "]"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.7376032770025797`*^9, 3.737603299589365*^9}, {
  3.737613130366026*^9, 3.737613164901965*^9}, {3.73761324398298*^9, 
  3.737613340865583*^9}, {3.737613723630876*^9, 
  3.73761372460535*^9}},ExpressionUUID->"29cba61b-3b41-4c7f-bf59-\
f0253e22f45b"],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{3.737613727262025*^9, 
  3.737634691872418*^9},ExpressionUUID->"bc966267-d3fa-4301-9312-\
df22ab5f39bd"],

Cell[BoxData[
 RowBox[{"V", "[", 
  RowBox[{"0", ",", 
   RowBox[{"{", "i", "}"}]}], "]"}]], "Output",
 CellChangeTimes->{3.737613727262025*^9, 
  3.737634691884809*^9},ExpressionUUID->"aee4ef19-cd93-4708-99e8-\
c8cf96d23d30"],

Cell[BoxData[
 RowBox[{"V", "[", 
  RowBox[{"1", ",", 
   RowBox[{"{", "}"}]}], "]"}]], "Output",
 CellChangeTimes->{3.737613727262025*^9, 
  3.7376346918928432`*^9},ExpressionUUID->"ef1d8902-46f8-4820-a5c7-\
223286afcc16"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"V", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", "i", "}"}]}], "]"}], " ", 
   RowBox[{"V", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", "j", "}"}]}], "]"}]}], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"V", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
    RowBox[{"\[Delta]", "[", 
     RowBox[{"{", 
      RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "d"]}]], "Output",
 CellChangeTimes->{3.737613727262025*^9, 
  3.737634691901276*^9},ExpressionUUID->"7fb2c20f-1bef-415f-ae2c-\
ed5571c8969a"],

Cell[BoxData[
 RowBox[{"V", "[", 
  RowBox[{"1", ",", 
   RowBox[{"{", "i", "}"}]}], "]"}]], "Output",
 CellChangeTimes->{3.737613727262025*^9, 
  3.737634691909924*^9},ExpressionUUID->"7d0781dc-53c0-4031-aee1-\
2b8a16b8ece2"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"V", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", "i", "}"}]}], "]"}], " ", 
   RowBox[{"V", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", "j", "}"}]}], "]"}], " ", 
   RowBox[{"V", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", "k", "}"}]}], "]"}]}], "-", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"2", "+", "d"}]], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"V", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "k", "}"}]}], "]"}], " ", 
      SuperscriptBox[
       RowBox[{"V", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"V", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "j", "}"}]}], "]"}], " ", 
      SuperscriptBox[
       RowBox[{"V", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"V", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "i", "}"}]}], "]"}], " ", 
      SuperscriptBox[
       RowBox[{"V", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"j", ",", "k"}], "}"}], "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.737613727262025*^9, 
  3.737634691918271*^9},ExpressionUUID->"efb9ba90-ad52-4a74-b950-\
24ce7b7434e9"],

Cell[BoxData[
 RowBox[{"V", "[", 
  RowBox[{"2", ",", 
   RowBox[{"{", "}"}]}], "]"}]], "Output",
 CellChangeTimes->{3.737613727262025*^9, 
  3.737634691927204*^9},ExpressionUUID->"8f9ceb7d-7dda-44f5-b0d3-\
70e03d79e321"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"V", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", "i", "}"}]}], "]"}], " ", 
   RowBox[{"V", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", "j", "}"}]}], "]"}], " ", 
   RowBox[{"V", "[", 
    RowBox[{"1", ",", 
     RowBox[{"{", "}"}]}], "]"}]}], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"V", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
    RowBox[{"V", "[", 
     RowBox[{"1", ",", 
      RowBox[{"{", "}"}]}], "]"}], " ", 
    RowBox[{"\[Delta]", "[", 
     RowBox[{"{", 
      RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "d"]}]], "Output",
 CellChangeTimes->{3.737613727262025*^9, 
  3.7376346919400673`*^9},ExpressionUUID->"ab294a24-9f11-41bb-a63e-\
3fbb859d69b6"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"V", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", "i", "}"}]}], "]"}], " ", 
   RowBox[{"V", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", "j", "}"}]}], "]"}], " ", 
   RowBox[{"V", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", "k", "}"}]}], "]"}], " ", 
   RowBox[{"V", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", "l", "}"}]}], "]"}]}], "-", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"4", "+", "d"}]], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"V", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "k", "}"}]}], "]"}], " ", 
      RowBox[{"V", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "l", "}"}]}], "]"}], " ", 
      SuperscriptBox[
       RowBox[{"V", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"V", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "j", "}"}]}], "]"}], " ", 
      RowBox[{"V", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "l", "}"}]}], "]"}], " ", 
      SuperscriptBox[
       RowBox[{"V", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"V", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "j", "}"}]}], "]"}], " ", 
      RowBox[{"V", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "k", "}"}]}], "]"}], " ", 
      SuperscriptBox[
       RowBox[{"V", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"i", ",", "l"}], "}"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"V", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "i", "}"}]}], "]"}], " ", 
      RowBox[{"V", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "l", "}"}]}], "]"}], " ", 
      SuperscriptBox[
       RowBox[{"V", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"V", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "i", "}"}]}], "]"}], " ", 
      RowBox[{"V", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "k", "}"}]}], "]"}], " ", 
      SuperscriptBox[
       RowBox[{"V", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"V", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "i", "}"}]}], "]"}], " ", 
      RowBox[{"V", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "j", "}"}]}], "]"}], " ", 
      SuperscriptBox[
       RowBox[{"V", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"k", ",", "l"}], "}"}], "]"}]}]}], ")"}]}], "+", 
  RowBox[{
   FractionBox["1", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2", "+", "d"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"4", "+", "d"}], ")"}]}]], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"V", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"V", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "p1", "}"}]}], "]"}], "2"], " ", 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"i", ",", "l"}], "}"}], "]"}], " ", 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"V", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"V", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "p1", "}"}]}], "]"}], "2"], " ", 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"i", ",", "k"}], "}"}], "]"}], " ", 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"V", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "p0", "}"}]}], "]"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"V", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "p1", "}"}]}], "]"}], "2"], " ", 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"k", ",", "l"}], "}"}], "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.737613727262025*^9, 
  3.737634691949377*^9},ExpressionUUID->"6128de4d-b7c9-47c7-822f-\
6f958b523540"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Deftracefreetensor", "[", 
  RowBox[{"V", "[", 
   RowBox[{"{", 
    RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}], "]"}], "]"}]], "Input",\

 CellChangeTimes->{{3.737613877372513*^9, 
  3.7376138857634068`*^9}},ExpressionUUID->"c27c3374-0cf5-4eea-8a8f-\
d31a91d46611"],

Cell[BoxData[
 RowBox[{
  RowBox[{"V", "[", 
   RowBox[{"0", ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}]}], "]"}], "-", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"4", "+", "d"}]], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"V", "[", 
       RowBox[{"1", ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "l"}], "}"}]}], "]"}], " ", 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"V", "[", 
       RowBox[{"1", ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "l"}], "}"}]}], "]"}], " ", 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"V", "[", 
       RowBox[{"1", ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "k"}], "}"}]}], "]"}], " ", 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"i", ",", "l"}], "}"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"V", "[", 
       RowBox[{"1", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "l"}], "}"}]}], "]"}], " ", 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"V", "[", 
       RowBox[{"1", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "k"}], "}"}]}], "]"}], " ", 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"V", "[", 
       RowBox[{"1", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "j"}], "}"}]}], "]"}], " ", 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"k", ",", "l"}], "}"}], "]"}]}]}], ")"}]}], "+", 
  RowBox[{
   FractionBox["1", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2", "+", "d"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"4", "+", "d"}], ")"}]}]], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"V", "[", 
       RowBox[{"2", ",", 
        RowBox[{"{", "}"}]}], "]"}], " ", 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"i", ",", "l"}], "}"}], "]"}], " ", 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"V", "[", 
       RowBox[{"2", ",", 
        RowBox[{"{", "}"}]}], "]"}], " ", 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"i", ",", "k"}], "}"}], "]"}], " ", 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"V", "[", 
       RowBox[{"2", ",", 
        RowBox[{"{", "}"}]}], "]"}], " ", 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"k", ",", "l"}], "}"}], "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.7376138920847073`*^9},ExpressionUUID->"8121bbda-1c9f-45e5-a682-\
6853ac0e0255"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{"Clear", "[", "ex", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "0", "]"}], "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "1", "]"}], "=", 
   RowBox[{"k", "[", "2", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "2", "]"}], "=", 
   RowBox[{"A", "[", 
    RowBox[{"{", "i", "}"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "3", "]"}], "=", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["17", "9"]}], 
    RowBox[{"A", "[", 
     RowBox[{"{", "i", "}"}], "]"}], 
    RowBox[{"B", "[", 
     RowBox[{"{", "j", "}"}], "]"}], 
    RowBox[{"X", "[", 
     RowBox[{"{", "k", "}"}], "]"}], 
    RowBox[{"Y", "[", 
     RowBox[{"{", "k", "}"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "4", "]"}], "=", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["7.83", "6"]}], 
    RowBox[{"A", "[", 
     RowBox[{"{", "i", "}"}], "]"}], 
    RowBox[{"B", "[", 
     RowBox[{"{", "j", "}"}], "]"}], 
    RowBox[{"X", "[", 
     RowBox[{"{", "k", "}"}], "]"}], 
    RowBox[{"X", "[", 
     RowBox[{"{", "k", "}"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "5", "]"}], "=", 
   RowBox[{"3.01", " ", 
    RowBox[{"A", "[", 
     RowBox[{"{", 
      RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "6", "]"}], "=", 
   RowBox[{"3", " ", 
    RowBox[{"A", "[", 
     RowBox[{"{", 
      RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}], "]"}], 
    RowBox[{"B", "[", 
     RowBox[{"{", "k", "}"}], "]"}], 
    RowBox[{"Y", "[", 
     RowBox[{"{", "k", "}"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "7", "]"}], "=", 
   RowBox[{"7", 
    RowBox[{"A", "[", 
     RowBox[{"{", "i", "}"}], "]"}], 
    RowBox[{"B", "[", 
     RowBox[{"{", "j", "}"}], "]"}], 
    RowBox[{"X", "[", 
     RowBox[{"{", "k", "}"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "8", "]"}], "=", 
   RowBox[{
    FractionBox["2", "3"], 
    RowBox[{"A", "[", 
     RowBox[{"{", "i", "}"}], "]"}], 
    RowBox[{"B", "[", 
     RowBox[{"{", "j", "}"}], "]"}], 
    SuperscriptBox[
     RowBox[{"X", "[", 
      RowBox[{"{", "k", "}"}], "]"}], "3"]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "9", "]"}], "=", 
   RowBox[{"3", " ", 
    RowBox[{"A", "[", 
     RowBox[{"{", 
      RowBox[{"i", ",", "j"}], "}"}], "]"}], 
    RowBox[{"B", "[", 
     RowBox[{"{", 
      RowBox[{"k", ",", "l"}], "}"}], "]"}], 
    RowBox[{"Y", "[", 
     RowBox[{"{", "k", "}"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "10", "]"}], "=", 
   RowBox[{"4", 
    RowBox[{"j", "[", 
     RowBox[{"2", ",", "1"}], "]"}], 
    RowBox[{"\[Alpha]", "[", "3", "]"}], 
    RowBox[{"A", "[", 
     RowBox[{"{", 
      RowBox[{
      "e", ",", "i", ",", "j", ",", "k", ",", "l", ",", "m", ",", "n", ",", 
       "o", ",", "p"}], "}"}], "]"}], 
    RowBox[{"B", "[", 
     RowBox[{"{", 
      RowBox[{"m", ",", "l"}], "}"}], "]"}], 
    RowBox[{"Y", "[", 
     RowBox[{"{", "o", "}"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "11", "]"}], "=", 
   RowBox[{"9", 
    SuperscriptBox[
     RowBox[{"A", "[", 
      RowBox[{"{", "i", "}"}], "]"}], "2"]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "12", "]"}], "=", 
   RowBox[{"59", 
    RowBox[{"A", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", "i", "}"}]}], "]"}], 
    RowBox[{"B", "[", 
     RowBox[{"1", ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "k"}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "13", "]"}], "=", 
   RowBox[{
    RowBox[{"-", "4"}], 
    SuperscriptBox[
     RowBox[{"A", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", "i", "}"}]}], "]"}], "2"], 
    SuperscriptBox[
     RowBox[{"B", "[", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "k"}], "}"}]}], "]"}], "2"]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "14", "]"}], "=", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["4", "7"]}], 
    SuperscriptBox[
     RowBox[{"A", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", "i", "}"}]}], "]"}], "3"], 
    SuperscriptBox[
     RowBox[{"B", "[", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "k"}], "}"}]}], "]"}], "2"]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "15", "]"}], "=", 
   RowBox[{"A", "[", 
    RowBox[{"1", ",", 
     RowBox[{"{", "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "16", "]"}], "=", 
   RowBox[{"A", "[", 
    RowBox[{"2", ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "k"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "17", "]"}], "=", 
   RowBox[{"23", 
    RowBox[{"A", "[", 
     RowBox[{"{", "i", "}"}], "]"}], 
    RowBox[{"A", "[", 
     RowBox[{"{", 
      RowBox[{"j", ",", "k"}], "}"}], "]"}], 
    RowBox[{"X", "[", 
     RowBox[{"{", "k", "}"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "18", "]"}], "=", 
   RowBox[{
    RowBox[{"V", "[", 
     RowBox[{"{", "i1", "}"}], "]"}], 
    RowBox[{"V", "[", 
     RowBox[{"{", "i2", "}"}], "]"}], 
    RowBox[{"V", "[", 
     RowBox[{"{", "i2", "}"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "19", "]"}], "=", 
   RowBox[{
    RowBox[{"V", "[", 
     RowBox[{"{", "i1", "}"}], "]"}], 
    SuperscriptBox[
     RowBox[{"V", "[", 
      RowBox[{"{", "i2", "}"}], "]"}], "2"], 
    SuperscriptBox[
     RowBox[{"V", "[", 
      RowBox[{"{", "i3", "}"}], "]"}], "2"]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.737892735149995*^9, 3.737892736612054*^9}, 
   3.737893943544862*^9, {3.73789398034558*^9, 3.73789406099951*^9}, {
   3.737895098048336*^9, 3.737895181115974*^9}, {3.737895339521645*^9, 
   3.737895351389059*^9}, {3.737957341130851*^9, 3.737957371834449*^9}, {
   3.737957641165019*^9, 3.7379576791162453`*^9}, {3.737957742492796*^9, 
   3.7379577488450003`*^9}, {3.737960165983613*^9, 3.737960215929529*^9}, {
   3.738042824788301*^9, 3.738042865202031*^9}, {3.7380469392311907`*^9, 
   3.738046976332068*^9}, {3.738341362329399*^9, 3.738341378586492*^9}, {
   3.738364642836412*^9, 
   3.738364683654894*^9}},ExpressionUUID->"b77e978c-99db-48ab-96ef-\
97e536ae412a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"tensorattributes", "[", 
     RowBox[{"ex", "[", "ii", "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"ii", ",", "0", ",", "19"}], "}"}]}], "]"}], "*)"}]], "Input",
 CellChangeTimes->{
  3.7379615887031116`*^9, {3.738364802577963*^9, 
   3.738364837952672*^9}},ExpressionUUID->"3bdf8027-2f98-486b-9ef1-\
09bd23755a99"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"constantfactor", "\[Rule]", "1"}], ",", 
     RowBox[{"tensorialpart", "\[Rule]", "1"}], ",", 
     RowBox[{"freeindices", "\[Rule]", 
      RowBox[{"{", "}"}]}], ",", 
     RowBox[{"tensorialparthavingfreeindices", "\[Rule]", "1"}], ",", 
     RowBox[{"tensorialpartNOThavingfreeindices", "\[Rule]", "1"}], ",", 
     RowBox[{"tensornames$havingfreeindices", "\[Rule]", 
      RowBox[{"{", "}"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"constantfactor", "\[Rule]", 
      RowBox[{"k", "[", "2", "]"}]}], ",", 
     RowBox[{"tensorialpart", "\[Rule]", "1"}], ",", 
     RowBox[{"freeindices", "\[Rule]", 
      RowBox[{"{", "}"}]}], ",", 
     RowBox[{"tensorialparthavingfreeindices", "\[Rule]", "1"}], ",", 
     RowBox[{"tensorialpartNOThavingfreeindices", "\[Rule]", "1"}], ",", 
     RowBox[{"tensornames$havingfreeindices", "\[Rule]", 
      RowBox[{"{", "}"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"constantfactor", "\[Rule]", "1"}], ",", 
     RowBox[{"tensorialpart", "\[Rule]", 
      RowBox[{"A", "[", 
       RowBox[{"{", "i", "}"}], "]"}]}], ",", 
     RowBox[{"freeindices", "\[Rule]", 
      RowBox[{"{", "i", "}"}]}], ",", 
     RowBox[{"tensorialparthavingfreeindices", "\[Rule]", 
      RowBox[{"A", "[", 
       RowBox[{"{", "i", "}"}], "]"}]}], ",", 
     RowBox[{"tensorialpartNOThavingfreeindices", "\[Rule]", "1"}], ",", 
     RowBox[{"tensornames$havingfreeindices", "\[Rule]", 
      RowBox[{"{", "A", "}"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"constantfactor", "\[Rule]", 
      RowBox[{"-", 
       FractionBox["17", "9"]}]}], ",", 
     RowBox[{"tensorialpart", "\[Rule]", 
      RowBox[{
       RowBox[{"A", "[", 
        RowBox[{"{", "i", "}"}], "]"}], " ", 
       RowBox[{"B", "[", 
        RowBox[{"{", "j", "}"}], "]"}], " ", 
       RowBox[{"X", "[", 
        RowBox[{"{", "k", "}"}], "]"}], " ", 
       RowBox[{"Y", "[", 
        RowBox[{"{", "k", "}"}], "]"}]}]}], ",", 
     RowBox[{"freeindices", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"i", ",", "j"}], "}"}]}], ",", 
     RowBox[{"tensorialparthavingfreeindices", "\[Rule]", 
      RowBox[{
       RowBox[{"A", "[", 
        RowBox[{"{", "i", "}"}], "]"}], " ", 
       RowBox[{"B", "[", 
        RowBox[{"{", "j", "}"}], "]"}]}]}], ",", 
     RowBox[{"tensorialpartNOThavingfreeindices", "\[Rule]", 
      RowBox[{
       RowBox[{"X", "[", 
        RowBox[{"{", "k", "}"}], "]"}], " ", 
       RowBox[{"Y", "[", 
        RowBox[{"{", "k", "}"}], "]"}]}]}], ",", 
     RowBox[{"tensornames$havingfreeindices", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"A", ",", "B"}], "}"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"constantfactor", "\[Rule]", 
      RowBox[{"-", "1.305`"}]}], ",", 
     RowBox[{"tensorialpart", "\[Rule]", 
      RowBox[{
       RowBox[{"A", "[", 
        RowBox[{"{", "i", "}"}], "]"}], " ", 
       RowBox[{"B", "[", 
        RowBox[{"{", "j", "}"}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{"X", "[", 
         RowBox[{"{", "k", "}"}], "]"}], "2"]}]}], ",", 
     RowBox[{"freeindices", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"i", ",", "j"}], "}"}]}], ",", 
     RowBox[{"tensorialparthavingfreeindices", "\[Rule]", 
      RowBox[{
       RowBox[{"A", "[", 
        RowBox[{"{", "i", "}"}], "]"}], " ", 
       RowBox[{"B", "[", 
        RowBox[{"{", "j", "}"}], "]"}]}]}], ",", 
     RowBox[{"tensorialpartNOThavingfreeindices", "\[Rule]", 
      SuperscriptBox[
       RowBox[{"X", "[", 
        RowBox[{"{", "k", "}"}], "]"}], "2"]}], ",", 
     RowBox[{"tensornames$havingfreeindices", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"A", ",", "B"}], "}"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"constantfactor", "\[Rule]", "3.01`"}], ",", 
     RowBox[{"tensorialpart", "\[Rule]", 
      RowBox[{"A", "[", 
       RowBox[{"{", 
        RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}], "]"}]}], ",", 
     RowBox[{"freeindices", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}]}], ",", 
     RowBox[{"tensorialparthavingfreeindices", "\[Rule]", 
      RowBox[{"A", "[", 
       RowBox[{"{", 
        RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}], "]"}]}], ",", 
     RowBox[{"tensorialpartNOThavingfreeindices", "\[Rule]", "1"}], ",", 
     RowBox[{"tensornames$havingfreeindices", "\[Rule]", 
      RowBox[{"{", "A", "}"}]}]}], "}"}], 
   ",", "\<\"\\!\\(\\*\\nStyleBox[\\\"Please\\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"check\\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"the\\\",\\nFontColor->RGBColor[1, 0, 0]]\\)\\!\
\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"exponents\\\",\\nFontColor->RGBColor[1, 0, 0]]\
\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"on\\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"tensors\\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"or\\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"the\\\",\\nFontColor->RGBColor[1, 0, 0]]\\)\\!\
\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"number\\\",\\nFontColor->RGBColor[1, 0, 0]]\\)\
\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"of\\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"repeated\\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"indices\\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\".\\\",\\nFontColor->RGBColor[1, 0, 0]]\\)\"\>",
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"constantfactor", "\[Rule]", "7"}], ",", 
     RowBox[{"tensorialpart", "\[Rule]", 
      RowBox[{
       RowBox[{"A", "[", 
        RowBox[{"{", "i", "}"}], "]"}], " ", 
       RowBox[{"B", "[", 
        RowBox[{"{", "j", "}"}], "]"}], " ", 
       RowBox[{"X", "[", 
        RowBox[{"{", "k", "}"}], "]"}]}]}], ",", 
     RowBox[{"freeindices", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"i", ",", "j", ",", "k"}], "}"}]}], ",", 
     RowBox[{"tensorialparthavingfreeindices", "\[Rule]", 
      RowBox[{
       RowBox[{"A", "[", 
        RowBox[{"{", "i", "}"}], "]"}], " ", 
       RowBox[{"B", "[", 
        RowBox[{"{", "j", "}"}], "]"}], " ", 
       RowBox[{"X", "[", 
        RowBox[{"{", "k", "}"}], "]"}]}]}], ",", 
     RowBox[{"tensorialpartNOThavingfreeindices", "\[Rule]", "1"}], ",", 
     RowBox[{"tensornames$havingfreeindices", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"A", ",", "B", ",", "X"}], "}"}]}]}], "}"}], 
   ",", "\<\"\\!\\(\\*\\nStyleBox[\\\"Please\\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"check\\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"the\\\",\\nFontColor->RGBColor[1, 0, 0]]\\)\\!\
\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"exponents\\\",\\nFontColor->RGBColor[1, 0, 0]]\
\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"on\\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"tensors\\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"or\\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"the\\\",\\nFontColor->RGBColor[1, 0, 0]]\\)\\!\
\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"number\\\",\\nFontColor->RGBColor[1, 0, 0]]\\)\
\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"of\\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"repeated\\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"indices\\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\".\\\",\\nFontColor->RGBColor[1, 0, 0]]\\)\"\>",
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"constantfactor", "\[Rule]", "3"}], ",", 
     RowBox[{"tensorialpart", "\[Rule]", 
      RowBox[{
       RowBox[{"A", "[", 
        RowBox[{"{", 
         RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
       RowBox[{"B", "[", 
        RowBox[{"{", 
         RowBox[{"k", ",", "l"}], "}"}], "]"}], " ", 
       RowBox[{"Y", "[", 
        RowBox[{"{", "k", "}"}], "]"}]}]}], ",", 
     RowBox[{"freeindices", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"i", ",", "j", ",", "l"}], "}"}]}], ",", 
     RowBox[{"tensorialparthavingfreeindices", "\[Rule]", 
      RowBox[{
       RowBox[{"A", "[", 
        RowBox[{"{", 
         RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
       RowBox[{"B", "[", 
        RowBox[{"{", 
         RowBox[{"k", ",", "l"}], "}"}], "]"}]}]}], ",", 
     RowBox[{"tensorialpartNOThavingfreeindices", "\[Rule]", 
      RowBox[{"Y", "[", 
       RowBox[{"{", "k", "}"}], "]"}]}], ",", 
     RowBox[{"tensornames$havingfreeindices", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"A", ",", "B"}], "}"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"constantfactor", "\[Rule]", 
      RowBox[{"4", " ", 
       RowBox[{"j", "[", 
        RowBox[{"2", ",", "1"}], "]"}], " ", 
       RowBox[{"\[Alpha]", "[", "3", "]"}]}]}], ",", 
     RowBox[{"tensorialpart", "\[Rule]", 
      RowBox[{
       RowBox[{"A", "[", 
        RowBox[{"{", 
         RowBox[{
         "e", ",", "i", ",", "j", ",", "k", ",", "l", ",", "m", ",", "n", ",",
           "o", ",", "p"}], "}"}], "]"}], " ", 
       RowBox[{"B", "[", 
        RowBox[{"{", 
         RowBox[{"m", ",", "l"}], "}"}], "]"}], " ", 
       RowBox[{"Y", "[", 
        RowBox[{"{", "o", "}"}], "]"}]}]}], ",", 
     RowBox[{"freeindices", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"e", ",", "i", ",", "j", ",", "k", ",", "n", ",", "p"}], 
       "}"}]}], ",", 
     RowBox[{"tensorialparthavingfreeindices", "\[Rule]", 
      RowBox[{"A", "[", 
       RowBox[{"{", 
        RowBox[{
        "e", ",", "i", ",", "j", ",", "k", ",", "l", ",", "m", ",", "n", ",", 
         "o", ",", "p"}], "}"}], "]"}]}], ",", 
     RowBox[{"tensorialpartNOThavingfreeindices", "\[Rule]", 
      RowBox[{
       RowBox[{"B", "[", 
        RowBox[{"{", 
         RowBox[{"m", ",", "l"}], "}"}], "]"}], " ", 
       RowBox[{"Y", "[", 
        RowBox[{"{", "o", "}"}], "]"}]}]}], ",", 
     RowBox[{"tensornames$havingfreeindices", "\[Rule]", 
      RowBox[{"{", "A", "}"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"constantfactor", "\[Rule]", "9"}], ",", 
     RowBox[{"tensorialpart", "\[Rule]", 
      SuperscriptBox[
       RowBox[{"A", "[", 
        RowBox[{"{", "i", "}"}], "]"}], "2"]}], ",", 
     RowBox[{"freeindices", "\[Rule]", 
      RowBox[{"{", "}"}]}], ",", 
     RowBox[{"tensorialparthavingfreeindices", "\[Rule]", "1"}], ",", 
     RowBox[{"tensorialpartNOThavingfreeindices", "\[Rule]", 
      SuperscriptBox[
       RowBox[{"A", "[", 
        RowBox[{"{", "i", "}"}], "]"}], "2"]}], ",", 
     RowBox[{"tensornames$havingfreeindices", "\[Rule]", 
      RowBox[{"{", "}"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"constantfactor", "\[Rule]", "59"}], ",", 
     RowBox[{"tensorialpart", "\[Rule]", 
      RowBox[{
       RowBox[{"A", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "i", "}"}]}], "]"}], " ", 
       RowBox[{"B", "[", 
        RowBox[{"1", ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "k"}], "}"}]}], "]"}]}]}], ",", 
     RowBox[{"freeindices", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"i", ",", "j", ",", "k"}], "}"}]}], ",", 
     RowBox[{"tensorialparthavingfreeindices", "\[Rule]", 
      RowBox[{
       RowBox[{"A", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "i", "}"}]}], "]"}], " ", 
       RowBox[{"B", "[", 
        RowBox[{"1", ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "k"}], "}"}]}], "]"}]}]}], ",", 
     RowBox[{"tensorialpartNOThavingfreeindices", "\[Rule]", "1"}], ",", 
     RowBox[{"tensornames$havingfreeindices", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"A", ",", "B"}], "}"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"constantfactor", "\[Rule]", 
      RowBox[{"-", "4"}]}], ",", 
     RowBox[{"tensorialpart", "\[Rule]", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "i", "}"}]}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"B", "[", 
         RowBox[{"1", ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "k"}], "}"}]}], "]"}], "2"]}]}], ",", 
     RowBox[{"freeindices", "\[Rule]", 
      RowBox[{"{", "}"}]}], ",", 
     RowBox[{"tensorialparthavingfreeindices", "\[Rule]", "1"}], ",", 
     RowBox[{"tensorialpartNOThavingfreeindices", "\[Rule]", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"A", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "i", "}"}]}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"B", "[", 
         RowBox[{"1", ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "k"}], "}"}]}], "]"}], "2"]}]}], ",", 
     RowBox[{"tensornames$havingfreeindices", "\[Rule]", 
      RowBox[{"{", "}"}]}]}], "}"}], 
   ",", "\<\"\\!\\(\\*\\nStyleBox[\\\"Please\\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"check\\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"the\\\",\\nFontColor->RGBColor[1, 0, 0]]\\)\\!\
\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"exponents\\\",\\nFontColor->RGBColor[1, 0, 0]]\
\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"on\\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"tensors\\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"or\\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"the\\\",\\nFontColor->RGBColor[1, 0, 0]]\\)\\!\
\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"number\\\",\\nFontColor->RGBColor[1, 0, 0]]\\)\
\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"of\\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"repeated\\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"indices\\\",\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\".\\\",\\nFontColor->RGBColor[1, 0, 0]]\\)\"\>",
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"constantfactor", "\[Rule]", "1"}], ",", 
     RowBox[{"tensorialpart", "\[Rule]", 
      RowBox[{"A", "[", 
       RowBox[{"1", ",", 
        RowBox[{"{", "}"}]}], "]"}]}], ",", 
     RowBox[{"freeindices", "\[Rule]", 
      RowBox[{"{", "}"}]}], ",", 
     RowBox[{"tensorialparthavingfreeindices", "\[Rule]", "1"}], ",", 
     RowBox[{"tensorialpartNOThavingfreeindices", "\[Rule]", 
      RowBox[{"A", "[", 
       RowBox[{"1", ",", 
        RowBox[{"{", "}"}]}], "]"}]}], ",", 
     RowBox[{"tensornames$havingfreeindices", "\[Rule]", 
      RowBox[{"{", "}"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"constantfactor", "\[Rule]", "1"}], ",", 
     RowBox[{"tensorialpart", "\[Rule]", 
      RowBox[{"A", "[", 
       RowBox[{"2", ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "k"}], "}"}]}], "]"}]}], ",", 
     RowBox[{"freeindices", "\[Rule]", 
      RowBox[{"{", "}"}]}], ",", 
     RowBox[{"tensorialparthavingfreeindices", "\[Rule]", "1"}], ",", 
     RowBox[{"tensorialpartNOThavingfreeindices", "\[Rule]", 
      RowBox[{"A", "[", 
       RowBox[{"2", ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "k"}], "}"}]}], "]"}]}], ",", 
     RowBox[{"tensornames$havingfreeindices", "\[Rule]", 
      RowBox[{"{", "}"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"constantfactor", "\[Rule]", "23"}], ",", 
     RowBox[{"tensorialpart", "\[Rule]", 
      RowBox[{
       RowBox[{"A", "[", 
        RowBox[{"{", "i", "}"}], "]"}], " ", 
       RowBox[{"A", "[", 
        RowBox[{"{", 
         RowBox[{"j", ",", "k"}], "}"}], "]"}], " ", 
       RowBox[{"X", "[", 
        RowBox[{"{", "k", "}"}], "]"}]}]}], ",", 
     RowBox[{"freeindices", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"i", ",", "j"}], "}"}]}], ",", 
     RowBox[{"tensorialparthavingfreeindices", "\[Rule]", 
      RowBox[{
       RowBox[{"A", "[", 
        RowBox[{"{", "i", "}"}], "]"}], " ", 
       RowBox[{"A", "[", 
        RowBox[{"{", 
         RowBox[{"j", ",", "k"}], "}"}], "]"}]}]}], ",", 
     RowBox[{"tensorialpartNOThavingfreeindices", "\[Rule]", 
      RowBox[{"X", "[", 
       RowBox[{"{", "k", "}"}], "]"}]}], ",", 
     RowBox[{"tensornames$havingfreeindices", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"A", ",", "A"}], "}"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"constantfactor", "\[Rule]", "1"}], ",", 
     RowBox[{"tensorialpart", "\[Rule]", 
      RowBox[{
       RowBox[{"V", "[", 
        RowBox[{"{", "i1", "}"}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{"V", "[", 
         RowBox[{"{", "i2", "}"}], "]"}], "2"]}]}], ",", 
     RowBox[{"freeindices", "\[Rule]", 
      RowBox[{"{", "i1", "}"}]}], ",", 
     RowBox[{"tensorialparthavingfreeindices", "\[Rule]", 
      RowBox[{"V", "[", 
       RowBox[{"{", "i1", "}"}], "]"}]}], ",", 
     RowBox[{"tensorialpartNOThavingfreeindices", "\[Rule]", 
      SuperscriptBox[
       RowBox[{"V", "[", 
        RowBox[{"{", "i2", "}"}], "]"}], "2"]}], ",", 
     RowBox[{"tensornames$havingfreeindices", "\[Rule]", 
      RowBox[{"{", "V", "}"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"constantfactor", "\[Rule]", "1"}], ",", 
     RowBox[{"tensorialpart", "\[Rule]", 
      RowBox[{
       RowBox[{"V", "[", 
        RowBox[{"{", "i1", "}"}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{"V", "[", 
         RowBox[{"{", "i2", "}"}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"V", "[", 
         RowBox[{"{", "i3", "}"}], "]"}], "2"]}]}], ",", 
     RowBox[{"freeindices", "\[Rule]", 
      RowBox[{"{", "i1", "}"}]}], ",", 
     RowBox[{"tensorialparthavingfreeindices", "\[Rule]", 
      RowBox[{"V", "[", 
       RowBox[{"{", "i1", "}"}], "]"}]}], ",", 
     RowBox[{"tensorialpartNOThavingfreeindices", "\[Rule]", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"V", "[", 
         RowBox[{"{", "i2", "}"}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"V", "[", 
         RowBox[{"{", "i3", "}"}], "]"}], "2"]}]}], ",", 
     RowBox[{"tensornames$havingfreeindices", "\[Rule]", 
      RowBox[{"{", "V", "}"}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7379613950758953`*^9, 
  3.738364811603814*^9},ExpressionUUID->"8f38dc6e-36b2-400d-be3a-\
8f81f6c82d64"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{"Clear", "[", "ex", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "0", "]"}], "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "1", "]"}], "=", 
   RowBox[{"k", "[", "2", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "2", "]"}], "=", 
   RowBox[{"A", "[", 
    RowBox[{"{", "i", "}"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "3", "]"}], "=", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["17", "9"]}], 
    RowBox[{"A", "[", 
     RowBox[{"{", "i", "}"}], "]"}], 
    RowBox[{"B", "[", 
     RowBox[{"{", "j", "}"}], "]"}], 
    RowBox[{"X", "[", 
     RowBox[{"{", "k", "}"}], "]"}], 
    RowBox[{"Y", "[", 
     RowBox[{"{", "k", "}"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "4", "]"}], "=", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["7.83", "6"]}], 
    RowBox[{"A", "[", 
     RowBox[{"{", "i", "}"}], "]"}], 
    RowBox[{"B", "[", 
     RowBox[{"{", "j", "}"}], "]"}], 
    RowBox[{"X", "[", 
     RowBox[{"{", "k", "}"}], "]"}], 
    RowBox[{"X", "[", 
     RowBox[{"{", "k", "}"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "5", "]"}], "=", 
   RowBox[{"3.01", " ", 
    RowBox[{"A", "[", 
     RowBox[{"{", 
      RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "6", "]"}], "=", 
   RowBox[{"3", " ", 
    RowBox[{"A", "[", 
     RowBox[{"{", 
      RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}], "]"}], 
    RowBox[{"B", "[", 
     RowBox[{"{", "k", "}"}], "]"}], 
    RowBox[{"Y", "[", 
     RowBox[{"{", "k", "}"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "7", "]"}], "=", 
   RowBox[{"7", 
    RowBox[{"A", "[", 
     RowBox[{"{", "i", "}"}], "]"}], 
    RowBox[{"B", "[", 
     RowBox[{"{", "j", "}"}], "]"}], 
    RowBox[{"X", "[", 
     RowBox[{"{", "k", "}"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "8", "]"}], "=", 
   RowBox[{
    FractionBox["2", "3"], 
    RowBox[{"A", "[", 
     RowBox[{"{", "i", "}"}], "]"}], 
    RowBox[{"B", "[", 
     RowBox[{"{", "j", "}"}], "]"}], 
    SuperscriptBox[
     RowBox[{"X", "[", 
      RowBox[{"{", "k", "}"}], "]"}], "3"]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "9", "]"}], "=", 
   RowBox[{"3", " ", 
    RowBox[{"A", "[", 
     RowBox[{"{", 
      RowBox[{"i", ",", "j"}], "}"}], "]"}], 
    RowBox[{"B", "[", 
     RowBox[{"{", 
      RowBox[{"k", ",", "l"}], "}"}], "]"}], 
    RowBox[{"Y", "[", 
     RowBox[{"{", "k", "}"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"ex", "[", "10", "]"}], "=", 
    RowBox[{"4", 
     RowBox[{"j", "[", 
      RowBox[{"2", ",", "1"}], "]"}], 
     RowBox[{"\[Alpha]", "[", "3", "]"}], 
     RowBox[{"A", "[", 
      RowBox[{"{", 
       RowBox[{
       "e", ",", "i", ",", "j", ",", "k", ",", "l", ",", "m", ",", "n", ",", 
        "o", ",", "p"}], "}"}], "]"}], 
     RowBox[{"B", "[", 
      RowBox[{"{", 
       RowBox[{"m", ",", "l"}], "}"}], "]"}], 
     RowBox[{"Y", "[", 
      RowBox[{"{", "o", "}"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
  StyleBox[
   RowBox[{"(*", 
    RowBox[{
    "tracefreerepresentation", " ", "does", " ", "not", " ", "work", " ", 
     "for", " ", 
     RowBox[{
      RowBox[{"ex", "[", "10", "]"}], "!"}]}], "*)"}],
   FontColor->RGBColor[1, 0, 0]]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "11", "]"}], "=", 
   RowBox[{"9", 
    SuperscriptBox[
     RowBox[{"A", "[", 
      RowBox[{"{", "i", "}"}], "]"}], "2"]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "12", "]"}], "=", 
   RowBox[{"59", 
    RowBox[{"A", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", "i", "}"}]}], "]"}], 
    RowBox[{"B", "[", 
     RowBox[{"1", ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "k"}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "13", "]"}], "=", 
   RowBox[{
    RowBox[{"-", "4"}], 
    SuperscriptBox[
     RowBox[{"A", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", "i", "}"}]}], "]"}], "2"], 
    SuperscriptBox[
     RowBox[{"B", "[", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "k"}], "}"}]}], "]"}], "2"]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "14", "]"}], "=", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["4", "7"]}], 
    SuperscriptBox[
     RowBox[{"A", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", "i", "}"}]}], "]"}], "3"], 
    SuperscriptBox[
     RowBox[{"B", "[", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "k"}], "}"}]}], "]"}], "2"]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.737892735149995*^9, 3.737892736612054*^9}, 
   3.737893943544862*^9, {3.73789398034558*^9, 3.73789406099951*^9}, {
   3.737895098048336*^9, 3.737895181115974*^9}, {3.737895339521645*^9, 
   3.737895351389059*^9}, {3.737957341130851*^9, 3.737957371834449*^9}, {
   3.737957641165019*^9, 3.7379576791162453`*^9}, {3.737957742492796*^9, 
   3.7379577488450003`*^9}, {3.737960165983613*^9, 3.737960215929529*^9}, {
   3.738322520838855*^9, 
   3.7383225409435043`*^9}},ExpressionUUID->"c53e77e2-0bbd-4bdd-a0bf-\
5f399b3bd5e6"],

Cell[BoxData[
 StyleBox[
  RowBox[{
   RowBox[{"Verification", " ", "with", " ", 
    RowBox[{"eqs", ".", " ", 
     RowBox[{"(", "2.10", ")"}]}]}], " ", "-", 
   RowBox[{
    RowBox[{"(", "2.14", ")"}], " ", "of", " ", "Garz\[OAcute]", " ", "and", 
    " ", "Santos", " ", "2007", " ", 
    RowBox[{"J", ".", " ", "Phys", ".", " ", 
     RowBox[{"A", ":", " ", 
      RowBox[{
       RowBox[{"Math", ".", " ", "Theor", ".", " ", "40"}], " ", 
       "14927"}]}]}]}]}], "Subsection"]], "Input",
 CellChangeTimes->{{3.737603160087296*^9, 3.737603160088921*^9}, {
  3.7376032211547318`*^9, 
  3.737603266482952*^9}},ExpressionUUID->"8b6331c0-20b4-4da8-9c8b-\
1e20538604f1"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "1", "]"}], "=", 
   RowBox[{"V", "[", 
    RowBox[{"{", "i", "}"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "2", "]"}], "=", 
   RowBox[{
    RowBox[{"V", "[", 
     RowBox[{"{", "i", "}"}], "]"}], 
    RowBox[{"V", "[", 
     RowBox[{"{", "j", "}"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "3", "]"}], "=", 
   RowBox[{
    RowBox[{"V", "[", 
     RowBox[{"{", "i", "}"}], "]"}], 
    RowBox[{"V", "[", 
     RowBox[{"{", "j", "}"}], "]"}], 
    RowBox[{"V", "[", 
     RowBox[{"{", "k", "}"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "4", "]"}], "=", 
   RowBox[{
    RowBox[{"V", "[", 
     RowBox[{"{", "i", "}"}], "]"}], 
    RowBox[{"V", "[", 
     RowBox[{"{", "j", "}"}], "]"}], 
    RowBox[{"V", "[", 
     RowBox[{"{", "k", "}"}], "]"}], 
    RowBox[{"V", "[", 
     RowBox[{"{", "l", "}"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ex", "[", "5", "]"}], "=", 
   RowBox[{
    RowBox[{"V", "[", 
     RowBox[{"{", "i", "}"}], "]"}], 
    RowBox[{"V", "[", 
     RowBox[{"{", "i", "}"}], "]"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.738322842584318*^9, 3.7383229241330214`*^9}},
 CellLabel->"In[87]:=",ExpressionUUID->"d417d1cd-dadd-4070-aaa0-db71bf7e525e"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"tracefreerepresentation", "[", 
  RowBox[{"ex", "[", "1", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Expand", "[", 
  RowBox[{"tracefreerepresentation", "[", 
   RowBox[{"ex", "[", "2", "]"}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Collect", "[", 
  RowBox[{
   RowBox[{"tracefreerepresentation", "[", 
    RowBox[{"ex", "[", "3", "]"}], "]"}], ",", 
   RowBox[{"\[Upsilon]", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "j", ",", "k"}], "}"}]}], "]"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Collect", "[", 
  RowBox[{
   RowBox[{"tracefreerepresentation", "[", 
    RowBox[{"ex", "[", "4", "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Upsilon]", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}]}], "]"}], ",", 
     RowBox[{"V", "[", 
      RowBox[{"2", ",", 
       RowBox[{"{", "}"}]}], "]"}]}], "}"}], ",", "Factor"}], "]"}]}], "Input",\

 CellChangeTimes->{{3.738322926841844*^9, 3.738323011086883*^9}, {
  3.738323196983568*^9, 3.738323198992836*^9}, {3.7383948387494173`*^9, 
  3.738394843805303*^9}},
 CellLabel->"In[92]:=",ExpressionUUID->"5a55b17f-c75e-4683-baa5-9ab65829dc45"],

Cell[BoxData[
 RowBox[{"V", "[", 
  RowBox[{"0", ",", 
   RowBox[{"{", "i", "}"}]}], "]"}]], "Output",
 CellChangeTimes->{{3.7383229371923447`*^9, 3.738323012266961*^9}, 
   3.738323201436507*^9, 3.73839485265442*^9},
 CellLabel->"Out[92]=",ExpressionUUID->"a3fad2ee-e5e8-4a6d-9e0e-3dcc3430f405"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    RowBox[{"V", "[", 
     RowBox[{"1", ",", 
      RowBox[{"{", "}"}]}], "]"}], " ", 
    RowBox[{"\[Delta]", "[", 
     RowBox[{"{", 
      RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "d"], "+", 
  RowBox[{"\[Upsilon]", "[", 
   RowBox[{"0", ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "j"}], "}"}]}], "]"}]}]], "Output",
 CellChangeTimes->{{3.7383229371923447`*^9, 3.738323012266961*^9}, 
   3.738323201436507*^9, 3.7383948526572123`*^9},
 CellLabel->"Out[93]=",ExpressionUUID->"6cb523fe-f69f-4d1b-a40d-cae5cb3184fd"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    RowBox[{
     RowBox[{"V", "[", 
      RowBox[{"1", ",", 
       RowBox[{"{", "k", "}"}]}], "]"}], " ", 
     RowBox[{"\[Delta]", "[", 
      RowBox[{"{", 
       RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"V", "[", 
      RowBox[{"1", ",", 
       RowBox[{"{", "j", "}"}]}], "]"}], " ", 
     RowBox[{"\[Delta]", "[", 
      RowBox[{"{", 
       RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"V", "[", 
      RowBox[{"1", ",", 
       RowBox[{"{", "i", "}"}]}], "]"}], " ", 
     RowBox[{"\[Delta]", "[", 
      RowBox[{"{", 
       RowBox[{"j", ",", "k"}], "}"}], "]"}]}]}], 
   RowBox[{"2", "+", "d"}]], "+", 
  RowBox[{"\[Upsilon]", "[", 
   RowBox[{"0", ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "j", ",", "k"}], "}"}]}], "]"}]}]], "Output",
 CellChangeTimes->{{3.7383229371923447`*^9, 3.738323012266961*^9}, 
   3.738323201436507*^9, 3.738394852675878*^9},
 CellLabel->"Out[94]=",ExpressionUUID->"27e0e044-9ecc-42fb-a60a-eef444b9385e"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    RowBox[{"V", "[", 
     RowBox[{"2", ",", 
      RowBox[{"{", "}"}]}], "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"i", ",", "l"}], "}"}], "]"}], " ", 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"i", ",", "k"}], "}"}], "]"}], " ", 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"j", ",", "l"}], "}"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"k", ",", "l"}], "}"}], "]"}]}]}], ")"}]}], 
   RowBox[{"d", " ", 
    RowBox[{"(", 
     RowBox[{"2", "+", "d"}], ")"}]}]], "+", 
  RowBox[{"\[Upsilon]", "[", 
   RowBox[{"0", ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}]}], "]"}], "+", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"4", "+", "d"}]], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"k", ",", "l"}], "}"}], "]"}], " ", 
      RowBox[{"\[Upsilon]", "[", 
       RowBox[{"1", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "j"}], "}"}]}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"j", ",", "l"}], "}"}], "]"}], " ", 
      RowBox[{"\[Upsilon]", "[", 
       RowBox[{"1", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "k"}], "}"}]}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"j", ",", "k"}], "}"}], "]"}], " ", 
      RowBox[{"\[Upsilon]", "[", 
       RowBox[{"1", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "l"}], "}"}]}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"i", ",", "l"}], "}"}], "]"}], " ", 
      RowBox[{"\[Upsilon]", "[", 
       RowBox[{"1", ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "k"}], "}"}]}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"i", ",", "k"}], "}"}], "]"}], " ", 
      RowBox[{"\[Upsilon]", "[", 
       RowBox[{"1", ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "l"}], "}"}]}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"\[Delta]", "[", 
       RowBox[{"{", 
        RowBox[{"i", ",", "j"}], "}"}], "]"}], " ", 
      RowBox[{"\[Upsilon]", "[", 
       RowBox[{"1", ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "l"}], "}"}]}], "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.7383229371923447`*^9, 3.738323012266961*^9}, 
   3.738323201436507*^9, 3.738394852709536*^9},
 CellLabel->"Out[95]=",ExpressionUUID->"5a461b7f-1b4c-4840-9c47-78011bb6ad7f"]
}, Open  ]],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Upsilon]", "[", 
    RowBox[{"n", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["i", "1"], 
         SubscriptBox["i", "2"]}], "..."}], 
       SubscriptBox["i", "n"]}], "}"}]}], "]"}], TraditionalForm]],
  ExpressionUUID->"fb251079-ab40-4797-9e00-62da55ac229e"],
 "=",
 Cell[BoxData[
  FormBox[
   RowBox[{"Y", "[", 
    RowBox[{
     RowBox[{"2", "n"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["i", "1"], 
         SubscriptBox["i", "2"]}], "..."}], 
       SubscriptBox["i", "n"]}], "}"}]}], "]"}], TraditionalForm]],
  ExpressionUUID->"a170e160-65dd-4ef8-9d14-4af790d26a0f"],
 ", where \[Upsilon] is the Henning\[CloseCurlyQuote]s notation for traceless \
tensor while ",
 Cell[BoxData[
  FormBox["Y", TraditionalForm]],ExpressionUUID->
  "7880d5d9-386d-4ce8-91a6-1aab74bd676d"],
 " are Ikenberry polynomials used in Garz\[OAcute] and Santos 2007 J. Phys. \
A: Math. Theor. 40 14927."
}], "Text",
 CellChangeTimes->{{3.7383948757726603`*^9, 3.7383951458540382`*^9}},
 FontColor->RGBColor[1, 0, 0],
 Background->RGBColor[
  0.87, 0.94, 1],ExpressionUUID->"ade116fd-b84d-4cab-a2ac-20755758cca9"]
}, Closed]],

Cell[CellGroupData[{

Cell["Production terms for Maxwell molecules", "Section",
 CellChangeTimes->{{3.7371074161472597`*^9, 
  3.7371074255235243`*^9}},ExpressionUUID->"7cd28e81-93c4-436d-8d2c-\
569ad6d6f273"],

Cell[CellGroupData[{

Cell["Initial Setup", "Subsection",
 CellChangeTimes->{{3.678793230036002*^9, 3.678793245115932*^9}, {
  3.737108629527525*^9, 3.737108646809474*^9}},
 Background->RGBColor[
  1, 1, 0.85],ExpressionUUID->"58daf40b-fa86-4281-b168-52d360f5c3c7"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Unprotect", "[", "C", "]"}], ";"}], "\n", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "\[Sigma]", ",", "q", ",", "delta", ",", "\[Delta]", ",", "C", ",", "C1", 
   ",", "w0", ",", "f", ",", "f1", ",", "scale", ",", "result", ",", "factor",
    ",", "range", ",", "CollIntegral", ",", "g", ",", "CC", ",", "CC1", ",", 
   "gg"}], "]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"range", "[", 
     RowBox[{"i_", ",", "j_"}], "]"}], "=", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"j", "<", "i"}], "||", 
       RowBox[{"j", "\[LessEqual]", "0"}], "||", 
       RowBox[{"i", "<", "0"}]}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"i", "\[Equal]", "0"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"1", ",", "j"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"i", ",", "j"}], "]"}]}], "]"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"factor", "=", 
     FractionBox[
      RowBox[{"m", " ", "\[Nu]"}], 
      RowBox[{"n", " ", "\[CapitalOmega]d"}]]}], ";"}], "*)"}], "\n", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
     RowBox[{"C", "[", "ix_", "]"}], "=", 
     RowBox[{
      RowBox[{"h", "[", "ix", "]"}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"g", "[", "ix", "]"}]}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"C1", "[", "ix_", "]"}], "=", 
     RowBox[{
      RowBox[{"h", "[", "ix", "]"}], "-", 
      RowBox[{
       FractionBox["1", "2"], 
       RowBox[{"g", "[", "ix", "]"}]}]}]}], ";"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gg", "[", "idx_", "]"}], ":=", 
  RowBox[{
   UnderoverscriptBox["\[Product]", 
    RowBox[{"ii", "=", "1"}], 
    RowBox[{"Length", "[", "idx", "]"}]], 
   RowBox[{"g", "[", 
    RowBox[{"{", 
     RowBox[{"idx", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}], 
     "}"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CC", "[", "idx_", "]"}], ":=", 
  RowBox[{
   UnderoverscriptBox["\[Product]", 
    RowBox[{"ii", "=", "1"}], 
    RowBox[{"Length", "[", "idx", "]"}]], 
   RowBox[{"C", "[", 
    RowBox[{"{", 
     RowBox[{"idx", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}], 
     "}"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CC1", "[", "idx_", "]"}], ":=", 
  RowBox[{
   UnderoverscriptBox["\[Product]", 
    RowBox[{"ii", "=", "1"}], 
    RowBox[{"Length", "[", "idx", "]"}]], 
   RowBox[{"C1", "[", 
    RowBox[{"{", 
     RowBox[{"idx", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}], 
     "}"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Delta", "[", 
   RowBox[{"idx1_", ",", "idx2_"}], "]"}], ":=", 
  RowBox[{
   UnderoverscriptBox["\[Product]", 
    RowBox[{"ii", "=", "1"}], 
    RowBox[{"Length", "[", "idx1", "]"}]], 
   RowBox[{"\[Delta]", "[", 
    RowBox[{"Sort", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
       "idx1", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}], ",", 
       RowBox[{
       "idx2", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}]}], 
      "}"}], "]"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"B", "[", "r_", "]"}], ":=", 
  RowBox[{"\[CapitalOmega]d", " ", 
   SuperscriptBox["\[Pi]", 
    RowBox[{
     RowBox[{"-", "1"}], "/", "2"}]], " ", 
   FractionBox[
    RowBox[{
     RowBox[{"Gamma", "[", 
      FractionBox["d", "2"], "]"}], 
     RowBox[{"Gamma", "[", 
      RowBox[{"r", "+", 
       FractionBox["1", "2"]}], "]"}]}], 
    RowBox[{"Gamma", "[", 
     RowBox[{"r", "+", 
      FractionBox["d", "2"]}], "]"}]]}]}]}], "Input",
 CellChangeTimes->{{3.678793566398316*^9, 3.6787936300029488`*^9}, {
   3.678794664796734*^9, 3.678794672044536*^9}, {3.678795330881616*^9, 
   3.678795348384506*^9}, {3.678795523702887*^9, 3.678795533335165*^9}, {
   3.678795593303163*^9, 3.6787955944713984`*^9}, {3.678795873118597*^9, 
   3.678795874829154*^9}, {3.678795994748912*^9, 3.6787959975487547`*^9}, {
   3.678864561988936*^9, 3.6788645867888536`*^9}, {3.7367867210219793`*^9, 
   3.736786744736203*^9}, {3.737107163363463*^9, 3.737107176303791*^9}, {
   3.737108479869174*^9, 3.737108480570177*^9}, {3.737108545885765*^9, 
   3.737108611408107*^9}, 3.7371092758574123`*^9, {3.7371138036383743`*^9, 
   3.7371138406604548`*^9}, 3.737186430518361*^9, {3.737186476292027*^9, 
   3.737186537086095*^9}, {3.737186676482334*^9, 3.737186682092225*^9}, {
   3.7371867797983007`*^9, 3.737186796030458*^9}, 
   3.7372726401373787`*^9},ExpressionUUID->"795b2209-9fb9-404f-ba19-\
c72c146152d9"],

Cell[BoxData[{
 RowBox[{"Clear", "[", 
  RowBox[{"gtable", ",", "forreplacing$g"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gtable", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"g", "[", 
       RowBox[{"{", 
        RowBox[{"ToExpression", "[", 
         RowBox[{"\"\<j\>\"", "<>", 
          RowBox[{"ToString", "[", "ii", "]"}]}], "]"}], "}"}], "]"}], "2"], 
     ",", 
     RowBox[{"{", 
      RowBox[{"ii", ",", "0", ",", "9"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"forreplacing$g", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"1", ",", 
     RowBox[{"Length", "[", "gtable", "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
   "forreplacing$g", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
   "=", 
   RowBox[{"gtable", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
    "forreplacing$g", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}],
     "=", 
    RowBox[{
     RowBox[{"forreplacing$g", "\[LeftDoubleBracket]", 
      RowBox[{"ii", "-", "1"}], "\[RightDoubleBracket]"}], "*", 
     RowBox[{
     "gtable", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}]}]}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"ii", ",", "2", ",", 
     RowBox[{"Length", "[", "gtable", "]"}]}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"replace$gsq", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"2", "ii"}]], "\[Rule]", 
      RowBox[{
      "forreplacing$g", "\[LeftDoubleBracket]", "ii", 
       "\[RightDoubleBracket]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"ii", ",", "1", ",", 
       RowBox[{"Length", "[", "gtable", "]"}]}], "}"}]}], "]"}]}], 
  ";"}]}], "Input",ExpressionUUID->"6e6df7b5-f01b-49fc-8aab-02612b33f0c6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"zeroReplacements", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Sigma]", "[", 
       RowBox[{"{", 
        RowBox[{"s0", ",", "s0"}], "}"}], "]"}], "\[Rule]", "0"}], ",", " ", 
     RowBox[{
      RowBox[{"\[Sigma]", "[", 
       RowBox[{"{", 
        RowBox[{"s1", ",", "s1"}], "}"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"m", "[", 
       RowBox[{"{", 
        RowBox[{"i1", ",", "s0", ",", "s0"}], "}"}], "]"}], "\[Rule]", "0"}], 
     ",", 
     RowBox[{
      RowBox[{"m", "[", 
       RowBox[{"{", 
        RowBox[{"i2", ",", "s0", ",", "s0"}], "}"}], "]"}], "\[Rule]", "0"}], 
     ",", 
     RowBox[{
      RowBox[{"m", "[", 
       RowBox[{"{", 
        RowBox[{"i3", ",", "s0", ",", "s0"}], "}"}], "]"}], "\[Rule]", "0"}], 
     ",", 
     RowBox[{
      RowBox[{"m", "[", 
       RowBox[{"{", 
        RowBox[{"i1", ",", "s1", ",", "s1"}], "}"}], "]"}], "\[Rule]", "0"}], 
     ",", 
     RowBox[{
      RowBox[{"m", "[", 
       RowBox[{"{", 
        RowBox[{"i2", ",", "s1", ",", "s1"}], "}"}], "]"}], "\[Rule]", "0"}], 
     ",", 
     RowBox[{
      RowBox[{"m", "[", 
       RowBox[{"{", 
        RowBox[{"i3", ",", "s1", ",", "s1"}], "}"}], "]"}], "\[Rule]", "0"}], 
     ",", 
     RowBox[{
      RowBox[{"m", "[", 
       RowBox[{"{", 
        RowBox[{"s0", ",", "s1", ",", "s1"}], "}"}], "]"}], "\[Rule]", "0"}], 
     ",", " ", 
     RowBox[{
      RowBox[{"m", "[", 
       RowBox[{"{", 
        RowBox[{"s0", ",", "s2", ",", "s2"}], "}"}], "]"}], "\[Rule]", "0"}], 
     ",", 
     RowBox[{
      RowBox[{"m", "[", 
       RowBox[{"{", 
        RowBox[{"s0", ",", "s0", ",", "s1"}], "}"}], "]"}], "\[Rule]", "0"}], 
     ",", 
     RowBox[{
      RowBox[{"m", "[", 
       RowBox[{"{", 
        RowBox[{"s0", ",", "s0", ",", "s2"}], "}"}], "]"}], "\[Rule]", "0"}], 
     ",", 
     RowBox[{
      RowBox[{"m", "[", 
       RowBox[{"{", 
        RowBox[{"s1", ",", "s2", ",", "s2"}], "}"}], "]"}], "\[Rule]", "0"}], 
     ",", 
     RowBox[{
      RowBox[{"R", "[", 
       RowBox[{"{", 
        RowBox[{"s0", ",", "s0"}], "}"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"R", "[", 
       RowBox[{"{", 
        RowBox[{"s1", ",", "s1"}], "}"}], "]"}], "\[Rule]", "0"}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.6787968161562843`*^9, 
  3.6787968286049013`*^9}},ExpressionUUID->"e37e29a8-9eac-4ce0-a9a7-\
f6a985aec7ab"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Production Term for ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["C", "2"], TraditionalForm]],ExpressionUUID->
  "1f6b7556-2784-4bfc-9cfe-6d073b657ad5"]
}], "Subsection",
 CellChangeTimes->{{3.540736884072311*^9, 3.5407369043909597`*^9}, {
  3.542452633864394*^9, 3.542452671646845*^9}, {3.737272427807934*^9, 
  3.737272430722102*^9}},
 TextAlignment->Center,
 FontColor->RGBColor[0.5, 0, 0.5],
 Background->RGBColor[
  1, 1, 0.85],ExpressionUUID->"bacc94fd-c629-4076-83fb-e2a74cf4f515"],

Cell[BoxData[{
 RowBox[{"Clear", "[", 
  RowBox[{"w0", ",", "g"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"idx", "=", 
   RowBox[{"{", 
    RowBox[{"i1", ",", "i2"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"nn", "=", 
    RowBox[{"Length", "[", "idx", "]"}]}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   StyleBox[
    RowBox[{
    "raw", " ", "form", " ", "of", " ", "integrand", " ", "without", " ", 
     "factor", " ", 
     FractionBox[
      RowBox[{"m", " ", "\[Nu]"}], 
      RowBox[{"n", " ", "\[CapitalOmega]d"}]], " ", "and", " ", "f", " ", 
     "f1", " ", "in", " ", "the", " ", "collision", " ", "integral"}],
    FontColor->RGBColor[1, 0.5, 0]], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"P1", "=", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"\[Beta]", "=", "1"}], "nn"], 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"\[Gamma]", "=", "0"}], 
       RowBox[{"\[Beta]", "/", "2"}]], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], "\[Beta]"], 
       SuperscriptBox["w0", "\[Beta]"], 
       RowBox[{"Binomial", "[", 
        RowBox[{"nn", ",", "\[Beta]"}], "]"}], 
       RowBox[{"Delta", "[", 
        RowBox[{
         RowBox[{"idx", "\[LeftDoubleBracket]", 
          RowBox[{"range", "[", 
           RowBox[{"1", ",", "\[Gamma]"}], "]"}], "\[RightDoubleBracket]"}], 
         ",", 
         RowBox[{"idx", "\[LeftDoubleBracket]", 
          RowBox[{"range", "[", 
           RowBox[{
            RowBox[{"\[Gamma]", "+", "1"}], ",", 
            RowBox[{"2", "\[Gamma]"}]}], "]"}], "\[RightDoubleBracket]"}]}], 
        "]"}], 
       RowBox[{"\[Alpha]", "[", 
        RowBox[{"\[Gamma]", ",", "\[Beta]"}], "]"}], 
       SuperscriptBox["g", 
        RowBox[{"2", "\[Gamma]"}]], 
       RowBox[{"gg", "[", 
        RowBox[{"idx", "\[LeftDoubleBracket]", 
         RowBox[{"range", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"2", "\[Gamma]"}], "+", "1"}], ",", "\[Beta]"}], "]"}], 
         "\[RightDoubleBracket]"}], "]"}], 
       RowBox[{"CC", "[", 
        RowBox[{"idx", "\[LeftDoubleBracket]", 
         RowBox[{"range", "[", 
          RowBox[{
           RowBox[{"\[Beta]", "+", "1"}], ",", "nn"}], "]"}], 
         "\[RightDoubleBracket]"}], "]"}]}]}]}]}], 
   RowBox[{"(*", 
    RowBox[{"f", " ", "f1"}], "*)"}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   StyleBox[
    RowBox[{"symmetrization", " ", "of", " ", "the", " ", "indices"}],
    FontColor->RGBColor[1, 0.5, 0]], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"perm", "=", 
   RowBox[{
    RowBox[{"Permutations", "[", "idx", "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{"i2", "\[Rule]", "i1"}], "}"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CollInt", "=", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{"CollInt", "+=", 
    RowBox[{"P1", "/.", 
     RowBox[{"Thread", "[", 
      RowBox[{"idx", "\[Rule]", 
       RowBox[{
       "perm", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}]}], 
      "]"}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{"ii", ",", "1", ",", 
     RowBox[{"Length", "[", "perm", "]"}]}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CollIntegralP1", "=", 
    RowBox[{"ExpandAll", "[", 
     RowBox[{
      FractionBox["CollInt", 
       RowBox[{"Length", "[", "perm", "]"}]], "/.", "replace$gsq"}], "]"}]}], 
   ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   StyleBox[
    RowBox[{
     RowBox[{"main", " ", "working", " ", 
      RowBox[{"steps", ":", " ", 
       RowBox[{
        RowBox[{
        "1.", " ", "integrate", " ", "directions", " ", "in", " ", "h"}], "-",
         "vectors"}]}]}], ";", " ", 
     RowBox[{
      RowBox[{
      "2.", " ", "integrate", " ", "directions", " ", "in", " ", "g"}], "-", 
      "vectors"}], ";", " ", 
     RowBox[{
     "3.", " ", "integrate", " ", "Gauss", " ", "integrals", " ", "in", " ", 
      "h"}], ";", " ", 
     RowBox[{
     "4.", " ", "perform", " ", "contractions", " ", "on", " ", "\[Delta]"}]}],
    FontColor->RGBColor[1, 0.5, 0]], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g", "[", "idx_", "]"}], ":=", 
  RowBox[{
   RowBox[{"CC", "[", "idx", "]"}], "-", 
   RowBox[{"CC1", "[", "idx", "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CollIntegralP1", "=", 
    RowBox[{"Expand", "[", "CollIntegralP1", "]"}]}], ";"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   StyleBox[
    RowBox[{"Integration", " ", "over", " ", "C", " ", "and", " ", "C1"}],
    FontColor->RGBColor[1, 0.5, 0]], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"resultP1", "=", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Einstein", "[", 
        RowBox[{"intoverCC1", "[", 
         RowBox[{
         "CollIntegralP1", "\[LeftDoubleBracket]", "ii", 
          "\[RightDoubleBracket]"}], "]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"ii", ",", "1", ",", 
         RowBox[{"Length", "[", "CollIntegralP1", "]"}]}], "}"}]}], "]"}]}], 
    "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.537993578189455*^9, 3.537993610797545*^9}, {
   3.537993771670854*^9, 3.537993779038876*^9}, {3.5379938261036*^9, 
   3.537993894920753*^9}, 3.537993985202799*^9, {3.537994016572002*^9, 
   3.537994037555522*^9}, {3.537994388113123*^9, 3.5379944406823893`*^9}, {
   3.5379944716672297`*^9, 3.537994535484898*^9}, {3.5379946435344*^9, 
   3.537994670999247*^9}, {3.537994822992545*^9, 3.537994848706256*^9}, {
   3.537994948252141*^9, 3.5379951325767097`*^9}, {3.537995185554933*^9, 
   3.537995241802492*^9}, {3.537995276222849*^9, 3.537995281348686*^9}, {
   3.53799533558186*^9, 3.5379953402203913`*^9}, {3.537995373317173*^9, 
   3.537995389189156*^9}, {3.537995463503443*^9, 3.537995586335116*^9}, {
   3.537995620905704*^9, 3.537995685353702*^9}, {3.537995731882414*^9, 
   3.537995740818839*^9}, {3.53799608412899*^9, 3.537996120582891*^9}, {
   3.537996373868025*^9, 3.537996470581868*^9}, {3.537996552739531*^9, 
   3.537996599754401*^9}, {3.537996699014799*^9, 3.537996718444993*^9}, {
   3.5379967905373993`*^9, 3.537996835526949*^9}, {3.537996969586375*^9, 
   3.537997008865888*^9}, {3.537997054707327*^9, 3.5379970594661016`*^9}, {
   3.537997228824871*^9, 3.537997383715749*^9}, {3.537997495969655*^9, 
   3.537997504978291*^9}, {3.538049111849923*^9, 3.538049145198148*^9}, {
   3.538049184515108*^9, 3.538049258034523*^9}, {3.5380493781370897`*^9, 
   3.538049391682486*^9}, {3.538049424567073*^9, 3.538049487235387*^9}, {
   3.538049594582995*^9, 3.538049743296955*^9}, {3.538050939370043*^9, 
   3.5380509982737083`*^9}, {3.5380676731372538`*^9, 3.538067723150732*^9}, 
   3.53806785052652*^9, {3.538067941214231*^9, 3.538067990711932*^9}, {
   3.538068029462811*^9, 3.538068153307399*^9}, {3.53806855796034*^9, 
   3.538068627746333*^9}, {3.53806869188647*^9, 3.538068751511098*^9}, {
   3.538068919982791*^9, 3.538068952563477*^9}, {3.538120345641403*^9, 
   3.538120421155457*^9}, 3.538120780664413*^9, {3.538120852906658*^9, 
   3.538120953903056*^9}, {3.538121002642786*^9, 3.538121148063637*^9}, {
   3.538126353936679*^9, 3.538126386984695*^9}, {3.538126473001809*^9, 
   3.5381265005530252`*^9}, {3.538126537649548*^9, 3.538126555161577*^9}, {
   3.5381266439234133`*^9, 3.538126715750491*^9}, 3.538127882474265*^9, {
   3.538130944351671*^9, 3.538131077658307*^9}, {3.538131942442205*^9, 
   3.538132013760786*^9}, {3.538132283894219*^9, 3.538132360880001*^9}, {
   3.538133348588627*^9, 3.538133377632154*^9}, {3.53813341458228*^9, 
   3.538133595785343*^9}, {3.538133693428665*^9, 3.538133893912404*^9}, {
   3.538133930459076*^9, 3.538134125076247*^9}, {3.53813417768613*^9, 
   3.538134217260666*^9}, {3.538134259339695*^9, 3.538134264398603*^9}, {
   3.538137299532156*^9, 3.538137342311903*^9}, {3.538137430398448*^9, 
   3.538137473144889*^9}, {3.5381376929555693`*^9, 3.5381377022975807`*^9}, {
   3.5381379513516703`*^9, 3.538137995917336*^9}, {3.538138048946089*^9, 
   3.53813805994525*^9}, {3.538138121394474*^9, 3.5381381959580793`*^9}, {
   3.5381382502615757`*^9, 3.538138273902351*^9}, {3.5381383210109873`*^9, 
   3.538138336804418*^9}, 3.538138516977003*^9, {3.5381618433477077`*^9, 
   3.538161932597952*^9}, {3.538161987860311*^9, 3.5381620846113997`*^9}, {
   3.5381621539329453`*^9, 3.538162195795615*^9}, {3.538162226745761*^9, 
   3.538162260756913*^9}, {3.538162294790723*^9, 3.538162558108499*^9}, {
   3.5382004503666887`*^9, 3.538200516536386*^9}, {3.5382005504900503`*^9, 
   3.538200576308169*^9}, {3.538200918185061*^9, 3.5382009209833603`*^9}, 
   3.538200954918594*^9, {3.5382012679264*^9, 3.538201268242012*^9}, {
   3.5382013070166893`*^9, 3.538201311732603*^9}, 3.53820156656705*^9, {
   3.538201655677127*^9, 3.538201682767631*^9}, 3.538201919512535*^9, 
   3.538243145787212*^9, 3.53824318144276*^9, {3.538243282594778*^9, 
   3.5382432941723957`*^9}, {3.5382433354676323`*^9, 
   3.5382433373488293`*^9}, {3.538243583835874*^9, 3.538243588737722*^9}, {
   3.538244168454702*^9, 3.538244180740324*^9}, {3.538244332583802*^9, 
   3.538244339379407*^9}, 3.5382449465768633`*^9, {3.5388070078690643`*^9, 
   3.538807099973749*^9}, {3.538807180708592*^9, 3.5388071828035707`*^9}, 
   3.5388074844694977`*^9, {3.538807551230954*^9, 3.538807553504488*^9}, {
   3.538808873941285*^9, 3.538808875477491*^9}, {3.538808927009503*^9, 
   3.5388089304970512`*^9}, {3.538808998699823*^9, 3.538809020477653*^9}, {
   3.538809124555171*^9, 3.538809131039702*^9}, 3.538809175971305*^9, {
   3.538809338238731*^9, 3.5388093394879303`*^9}, 3.5388093971728573`*^9, {
   3.53881066031894*^9, 3.538810687713526*^9}, 3.538810748528813*^9, {
   3.5388107917831078`*^9, 3.538810794089106*^9}, {3.538811661821177*^9, 
   3.538811724776244*^9}, 3.538817331517233*^9, {3.5388192046322308`*^9, 
   3.538819214494584*^9}, {3.5392665470358353`*^9, 3.5392665745099287`*^9}, {
   3.539266610562613*^9, 3.539266615983183*^9}, {3.5392666830721903`*^9, 
   3.539266815780409*^9}, 3.539266848624251*^9, 3.539266890598507*^9, {
   3.539267060053648*^9, 3.539267072703176*^9}, 3.5392677537069807`*^9, 
   3.539267788390932*^9, {3.539268495010467*^9, 3.539268496663838*^9}, 
   3.539269140585288*^9, 3.539269235639429*^9, {3.539269355353408*^9, 
   3.539269383630211*^9}, {3.539269638969858*^9, 3.539269750991323*^9}, {
   3.53926979106437*^9, 3.539269810113697*^9}, {3.5392701517950487`*^9, 
   3.5392701920043097`*^9}, 3.539278908980487*^9, 3.539278996527172*^9, {
   3.539326343054734*^9, 3.539326435401582*^9}, {3.539326569957453*^9, 
   3.539326575804747*^9}, {3.539326991237306*^9, 3.5393270082806168`*^9}, {
   3.539329433774241*^9, 3.5393294960187607`*^9}, {3.5393305017074823`*^9, 
   3.539330556642144*^9}, 3.539330888641615*^9, {3.539339971597237*^9, 
   3.5393399876891327`*^9}, {3.5393400782346582`*^9, 3.539340081023357*^9}, {
   3.5393401448438396`*^9, 3.539340145504077*^9}, {3.539347774329233*^9, 
   3.539347843122929*^9}, 3.539366432292687*^9, {3.539367245443975*^9, 
   3.539367246347004*^9}, {3.540734202771955*^9, 3.5407342043103733`*^9}, {
   3.540736418761684*^9, 3.5407364226194553`*^9}, {3.540737768596367*^9, 
   3.540737768892754*^9}, {3.542388724376953*^9, 3.542388781889929*^9}, {
   3.542388924988758*^9, 3.542388987923122*^9}, {3.5423890458105783`*^9, 
   3.542389193224463*^9}, {3.542389272963728*^9, 3.54238930706011*^9}, {
   3.542437641275167*^9, 3.542437699202085*^9}, {3.542437730796095*^9, 
   3.5424378902358*^9}, 3.542437945897581*^9, {3.5424379882249823`*^9, 
   3.5424380665457783`*^9}, 3.5424381121082697`*^9, {3.542438249182868*^9, 
   3.5424382662648687`*^9}, 3.542438305697894*^9, {3.542439075760028*^9, 
   3.5424390838844147`*^9}, {3.542439173737357*^9, 3.542439220087296*^9}, {
   3.542443352398711*^9, 3.542443381775426*^9}, {3.542443447124556*^9, 
   3.542443480430725*^9}, {3.542443613406389*^9, 3.542443649481735*^9}, 
   3.542443699901371*^9, {3.5424462578396807`*^9, 3.542446274257043*^9}, {
   3.542446401017707*^9, 3.542446413600088*^9}, {3.5424464659327908`*^9, 
   3.5424464878337793`*^9}, {3.5424465291804132`*^9, 3.5424465329099913`*^9}, 
   3.542446742755765*^9, {3.542446778102816*^9, 3.542446785282056*^9}, {
   3.542446834089986*^9, 3.542446884468789*^9}, {3.542446919291979*^9, 
   3.542446939944065*^9}, {3.542446976270124*^9, 3.5424469866004257`*^9}, {
   3.542447056705858*^9, 3.5424470898445673`*^9}, {3.5424471344029417`*^9, 
   3.542447174506599*^9}, {3.5424472312410507`*^9, 3.54244726772272*^9}, {
   3.5424473125427227`*^9, 3.5424473254819317`*^9}, {3.5424473695330887`*^9, 
   3.542447388671294*^9}, 3.542448224058323*^9, {3.542451548746708*^9, 
   3.5424515774216213`*^9}, {3.5424519211077013`*^9, 3.542451928153799*^9}, {
   3.54245299950036*^9, 3.542453001194194*^9}, {3.542455811416429*^9, 
   3.542455815394039*^9}, {3.542622812244008*^9, 3.542622822000717*^9}, {
   3.542622859825048*^9, 3.542622931786152*^9}, {3.54269829979911*^9, 
   3.542698305254208*^9}, {3.542699025561718*^9, 3.542699026123849*^9}, {
   3.5426990707182913`*^9, 3.542699088670185*^9}, {3.542700118933394*^9, 
   3.542700121036415*^9}, 3.542700827765305*^9, {3.5429174051788473`*^9, 
   3.542917524367551*^9}, 3.5429176869021387`*^9, {3.542969166437325*^9, 
   3.542969172344721*^9}, {3.548190436221043*^9, 3.548190445993956*^9}, 
   3.548190491401569*^9, {3.548190752747745*^9, 3.548190753292897*^9}, {
   3.54901721401657*^9, 3.549017214311965*^9}, {3.549017247695644*^9, 
   3.5490173217517653`*^9}, {3.5490175863059607`*^9, 3.549017586840351*^9}, {
   3.64364096822392*^9, 3.643640983650118*^9}, 3.643641025520862*^9, {
   3.6436415353816833`*^9, 3.643641602069047*^9}, {3.643641636036574*^9, 
   3.643641702536974*^9}, 3.643641788051527*^9, {3.6436418353044577`*^9, 
   3.643641843368132*^9}, {3.678793251829185*^9, 3.678793285790352*^9}, 
   3.6787994439458447`*^9, {3.678862755048066*^9, 3.6788627561980753`*^9}, 
   3.678865112211464*^9, {3.681391437897203*^9, 3.681391452879457*^9}, {
   3.737108210053956*^9, 3.737108249563664*^9}, {3.7371084042540083`*^9, 
   3.7371084083262463`*^9}, 3.737109292446753*^9, {3.737109749523717*^9, 
   3.737109805554154*^9}, {3.737110028644668*^9, 3.737110070179446*^9}, {
   3.737110150417325*^9, 3.737110151300057*^9}, 3.737110382136352*^9, {
   3.737110458359399*^9, 3.737110460309579*^9}, {3.737110702040637*^9, 
   3.737110703878584*^9}, {3.7371117587819138`*^9, 3.73711177306219*^9}, {
   3.737113682711214*^9, 3.7371136853064327`*^9}, {3.7371138793370953`*^9, 
   3.737113881349288*^9}, {3.73718694545557*^9, 3.737186984864314*^9}, {
   3.737187015838509*^9, 3.7371870332629213`*^9}, {3.737187072238668*^9, 
   3.7371870800135736`*^9}, {3.737189762748537*^9, 3.737189763128755*^9}, {
   3.737189800186709*^9, 3.737189804667068*^9}, {3.7371898409234247`*^9, 
   3.737189845354582*^9}, 3.737190240046109*^9, {3.7371903718842573`*^9, 
   3.737190380979869*^9}, {3.737191435152549*^9, 3.737191467949527*^9}, {
   3.737191521249221*^9, 3.73719156092738*^9}, {3.737191766050044*^9, 
   3.7371917689123497`*^9}, 3.737197927456336*^9, {3.737198159489818*^9, 
   3.737198159886495*^9}, {3.737200386075508*^9, 3.7372003868555098`*^9}, {
   3.737264960908597*^9, 3.7372649614648647`*^9}, 3.7372710196476183`*^9, {
   3.737271124669427*^9, 3.737271139070385*^9}, {3.737271449376149*^9, 
   3.737271450701746*^9}, {3.737272473365141*^9, 3.737272503208777*^9}, {
   3.7372725472818527`*^9, 3.737272573132128*^9}, {3.737272872657456*^9, 
   3.737272875955984*^9}, {3.7372733706656847`*^9, 
   3.737273389942986*^9}},ExpressionUUID->"1d3cc1e2-1686-4e2e-827b-\
6725d0cc0654"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"factor", "=", 
    RowBox[{"(*", "m", "*)"}], 
    FractionBox["\[Nu]", 
     RowBox[{"n", " ", "\[CapitalOmega]d"}]]}], ";"}], "\[IndentingNewLine]", 
  
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"resultP1", "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{"FullSimplify", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"factor", " ", "resultP1"}], "/.", "replace\[Alpha]"}], "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\[Nu]", "\[Rule]", 
            RowBox[{
             FractionBox[
              RowBox[{"d", "+", "2"}], "2"], "\[Nu]0"}]}], ",", 
           RowBox[{"w0", "\[Rule]", 
            FractionBox[
             RowBox[{"1", "+", "e"}], "2"]}]}], "}"}]}], "]"}], "/.", 
       RowBox[{"{", 
        RowBox[{"\[Nu]0", "\[Rule]", 
         RowBox[{
          FractionBox[
           RowBox[{"4", "d"}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"d", "+", "2"}], ")"}], 
            RowBox[{"(", 
             RowBox[{"1", "-", 
              SuperscriptBox["e", "2"]}], ")"}]}]], 
          RowBox[{"\[Nu]", "[", 
           RowBox[{"2", ",", "0"}], "]"}]}]}], "}"}]}], "]"}]}], ";"}], 
   "*)"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"resultP1form1", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"factor", " ", "resultP1"}], "/.", "replace\[Alpha]"}], "/.", 
       "gammareplacements"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\[Nu]", "\[Rule]", 
         RowBox[{
          FractionBox[
           RowBox[{"d", "+", "2"}], "2"], "\[Nu]0"}]}], ",", 
        RowBox[{"w0", "\[Rule]", 
         FractionBox[
          RowBox[{"1", "+", "e"}], "2"]}]}], "}"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{"\[Nu]0", "\[Rule]", 
       RowBox[{
        FractionBox[
         RowBox[{"4", "d"}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"d", "+", "2"}], ")"}], 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            SuperscriptBox["e", "2"]}], ")"}]}]], 
        RowBox[{"\[Nu]", "[", 
         RowBox[{"2", ",", "0"}], "]"}]}]}], "}"}]}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.737272917319312*^9, 3.737272919047133*^9}, {
  3.73727297093484*^9, 3.73727298523519*^9}, {3.737273051179839*^9, 
  3.737273105514578*^9}, {3.737273137272187*^9, 3.737273225397573*^9}, {
  3.737287885671035*^9, 3.737287942083939*^9}, {3.738395407325705*^9, 
  3.738395413184523*^9}, {3.7384094669747753`*^9, 
  3.738409571695676*^9}},ExpressionUUID->"2daaa0fd-fab5-4a72-9a73-\
6f1c79fa154f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   StyleBox[
    RowBox[{
     RowBox[{"Eq", ".", " ", 
      SubscriptBox[
       RowBox[{"(", "2.17", ")"}], "1"]}], " ", "of", " ", "Garz\[OAcute]", 
     " ", "and", " ", "Santos", " ", "2007", " ", 
     RowBox[{"J", ".", " ", "Phys", ".", " ", 
      RowBox[{"A", ":", " ", 
       RowBox[{
        RowBox[{"Math", ".", " ", "Theor", ".", " ", 
         StyleBox["40",
          FontWeight->"Bold"]}], " ", "14927"}]}]}]}],
    FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"resultP1form1", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Rho]", "[", 
       RowBox[{"n_", ",", "li_"}], "]"}], "\[Rule]", 
      RowBox[{"m", " ", 
       RowBox[{"M", "[", 
        RowBox[{
         RowBox[{"2", "n"}], ",", "li"}], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"\[Upsilon]", "[", 
       RowBox[{"n_", ",", "li_"}], "]"}], "\[Rule]", 
      RowBox[{"m", " ", 
       RowBox[{"M", "[", 
        RowBox[{
         RowBox[{"2", "n"}], ",", "li"}], "]"}]}]}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.7383954198929977`*^9, 3.738395424674985*^9}, {
   3.738395505793868*^9, 3.738395508613287*^9}, {3.7383955414619293`*^9, 
   3.738395555856544*^9}, {3.738395587057211*^9, 3.7383956011687737`*^9}, 
   3.738409579548064*^9, 3.738476901292836*^9, {3.738477034345357*^9, 
   3.7384770436567698`*^9}, 
   3.738477140620887*^9},ExpressionUUID->"9b2b0340-6df6-4e6d-acbd-\
3f60ff1ff6e9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{"M", "[", 
    RowBox[{"2", ",", 
     RowBox[{"{", "}"}]}], "]"}]}], " ", 
  RowBox[{"\[Nu]", "[", 
   RowBox[{"2", ",", "0"}], "]"}]}]], "Output",
 CellChangeTimes->{3.738395432074239*^9, 3.738409580508007*^9, 
  3.738476406266837*^9, 3.738476902624423*^9, 3.744960072766611*^9, 
  3.744961197964808*^9, 3.745014250562142*^9, 3.745017809873291*^9, 
  3.7451223257558727`*^9},ExpressionUUID->"8b078f8d-a903-42cc-b9f2-\
8f8af02ae2a2"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", 
  StyleBox[
   RowBox[{"To", " ", "write", " ", "in", " ", "the", " ", "paper"}],
   FontColor->RGBColor[1, 0, 0]], "*)"}]], "Input",
 CellChangeTimes->{{3.7386586823153467`*^9, 
  3.738658701506856*^9}},ExpressionUUID->"5071a0d1-97d7-4b53-94b4-\
f0f31d8e60b5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"m", " ", "resultP1form1"}], "/.", "replace\[Rho]u"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"\[Nu]", "[", 
     RowBox[{"2", ",", "0"}], "]"}], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"d", "+", "2"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["e", "2"]}], ")"}]}], 
      RowBox[{"4", "d"}]], "\[Nu]0"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.7386578360385*^9, 3.738657846809463*^9}, {
  3.738658331516347*^9, 3.7386583356480417`*^9}, {3.7449601134808693`*^9, 
  3.744960145015485*^9}},ExpressionUUID->"62873740-ba4e-48ff-8255-\
ec1f61cab869"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["1", "4"]}], " ", 
  RowBox[{"(", 
   RowBox[{"2", "+", "d"}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{"1", "-", 
    SuperscriptBox["e", "2"]}], ")"}], " ", "\[Theta]", " ", "\[Nu]0", " ", 
  "\[Rho]"}]], "Output",
 CellChangeTimes->{3.73865784809802*^9, 3.738658336606635*^9, 
  3.738658392160564*^9, 3.73865866394027*^9, 3.744960072828071*^9, 
  3.744960146494595*^9, 3.744961198009416*^9, 3.745014250617482*^9, 
  3.745017809912673*^9, 
  3.745122325807073*^9},ExpressionUUID->"1a5f6d40-a08a-4318-b5dd-\
995f7c8cd187"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Production Term for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["C", "i"], 
    SubscriptBox["C", "j"]}], TraditionalForm]],ExpressionUUID->
  "809d9d4d-81c9-41ae-9cec-6735f7c031ff"]
}], "Subsection",
 CellChangeTimes->{{3.540736884072311*^9, 3.5407369043909597`*^9}, {
  3.542452633864394*^9, 3.542452671646845*^9}, {3.737272427807934*^9, 
  3.737272430722102*^9}, {3.737273281718402*^9, 3.7372732969187727`*^9}},
 TextAlignment->Center,
 FontColor->RGBColor[0.5, 0, 0.5],
 Background->RGBColor[
  1, 1, 0.85],ExpressionUUID->"de4b754c-ccce-4759-ab35-4cf2b3ccc74a"],

Cell[BoxData[{
 RowBox[{"Clear", "[", 
  RowBox[{"w0", ",", "g"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"idx", "=", 
   RowBox[{"{", 
    RowBox[{"i1", ",", "i2"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"nn", "=", 
    RowBox[{"Length", "[", "idx", "]"}]}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   StyleBox[
    RowBox[{
    "raw", " ", "form", " ", "of", " ", "integrand", " ", "without", " ", 
     "factor", " ", 
     FractionBox[
      RowBox[{"m", " ", "\[Nu]"}], 
      RowBox[{"n", " ", "\[CapitalOmega]d"}]], " ", "and", " ", "f", " ", 
     "f1", " ", "in", " ", "the", " ", "collision", " ", "integral"}],
    FontColor->RGBColor[1, 0.5, 0]], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Pij0", "=", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"\[Beta]", "=", "1"}], "nn"], 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"\[Gamma]", "=", "0"}], 
       RowBox[{"\[Beta]", "/", "2"}]], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], "\[Beta]"], 
       SuperscriptBox["w0", "\[Beta]"], 
       RowBox[{"Binomial", "[", 
        RowBox[{"nn", ",", "\[Beta]"}], "]"}], 
       RowBox[{"Delta", "[", 
        RowBox[{
         RowBox[{"idx", "\[LeftDoubleBracket]", 
          RowBox[{"range", "[", 
           RowBox[{"1", ",", "\[Gamma]"}], "]"}], "\[RightDoubleBracket]"}], 
         ",", 
         RowBox[{"idx", "\[LeftDoubleBracket]", 
          RowBox[{"range", "[", 
           RowBox[{
            RowBox[{"\[Gamma]", "+", "1"}], ",", 
            RowBox[{"2", "\[Gamma]"}]}], "]"}], "\[RightDoubleBracket]"}]}], 
        "]"}], 
       RowBox[{"\[Alpha]", "[", 
        RowBox[{"\[Gamma]", ",", "\[Beta]"}], "]"}], 
       SuperscriptBox["g", 
        RowBox[{"2", "\[Gamma]"}]], 
       RowBox[{"gg", "[", 
        RowBox[{"idx", "\[LeftDoubleBracket]", 
         RowBox[{"range", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"2", "\[Gamma]"}], "+", "1"}], ",", "\[Beta]"}], "]"}], 
         "\[RightDoubleBracket]"}], "]"}], 
       RowBox[{"CC", "[", 
        RowBox[{"idx", "\[LeftDoubleBracket]", 
         RowBox[{"range", "[", 
          RowBox[{
           RowBox[{"\[Beta]", "+", "1"}], ",", "nn"}], "]"}], 
         "\[RightDoubleBracket]"}], "]"}]}]}]}]}], 
   RowBox[{"(*", 
    RowBox[{"f", " ", "f1"}], "*)"}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   StyleBox[
    RowBox[{"symmetrization", " ", "of", " ", "the", " ", "indices"}],
    FontColor->RGBColor[1, 0.5, 0]], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"perm", "=", 
   RowBox[{"Permutations", "[", "idx", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CollInt", "=", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{"CollInt", "+=", 
    RowBox[{"Pij0", "/.", 
     RowBox[{"Thread", "[", 
      RowBox[{"idx", "\[Rule]", 
       RowBox[{
       "perm", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}]}], 
      "]"}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{"ii", ",", "1", ",", 
     RowBox[{"Length", "[", "perm", "]"}]}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CollIntegralPij0", "=", 
    RowBox[{"ExpandAll", "[", 
     RowBox[{
      FractionBox["CollInt", 
       RowBox[{"Length", "[", "perm", "]"}]], "/.", "replace$gsq"}], "]"}]}], 
   ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   StyleBox[
    RowBox[{
     RowBox[{"main", " ", "working", " ", 
      RowBox[{"steps", ":", " ", 
       RowBox[{
        RowBox[{
        "1.", " ", "integrate", " ", "directions", " ", "in", " ", "h"}], "-",
         "vectors"}]}]}], ";", " ", 
     RowBox[{
      RowBox[{
      "2.", " ", "integrate", " ", "directions", " ", "in", " ", "g"}], "-", 
      "vectors"}], ";", " ", 
     RowBox[{
     "3.", " ", "integrate", " ", "Gauss", " ", "integrals", " ", "in", " ", 
      "h"}], ";", " ", 
     RowBox[{
     "4.", " ", "perform", " ", "contractions", " ", "on", " ", "\[Delta]"}]}],
    FontColor->RGBColor[1, 0.5, 0]], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g", "[", "idx_", "]"}], ":=", 
  RowBox[{
   RowBox[{"CC", "[", "idx", "]"}], "-", 
   RowBox[{"CC1", "[", "idx", "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CollIntegralPij0", "=", 
    RowBox[{"Expand", "[", "CollIntegralPij0", "]"}]}], ";"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   StyleBox[
    RowBox[{"Integration", " ", "over", " ", "C", " ", "and", " ", "C1"}],
    FontColor->RGBColor[1, 0.5, 0]], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"resultPij0", "=", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Einstein", "[", 
         RowBox[{"intoverCC1", "[", 
          RowBox[{
          "CollIntegralPij0", "\[LeftDoubleBracket]", "ii", 
           "\[RightDoubleBracket]"}], "]"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"ii", ",", "1", ",", 
          RowBox[{"Length", "[", "CollIntegralPij0", "]"}]}], "}"}]}], 
       "]"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"list\[Rho]Pij0", "=", 
   RowBox[{"DeleteDuplicates", "[", 
    RowBox[{"Extract", "[", 
     RowBox[{"resultPij0", ",", 
      RowBox[{"Position", "[", 
       RowBox[{"resultPij0", ",", 
        RowBox[{"\[Rho]", "[", 
         RowBox[{"_", ",", "_"}], "]"}]}], "]"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"replace\[Rho]Pij0", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
      "list\[Rho]Pij0", "\[LeftDoubleBracket]", "ii", 
       "\[RightDoubleBracket]"}], "\[Rule]", 
      RowBox[{"tracefreerepresentation", "[", 
       RowBox[{
       "list\[Rho]Pij0", "\[LeftDoubleBracket]", "ii", 
        "\[RightDoubleBracket]"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"ii", ",", "1", ",", 
       RowBox[{"Length", "[", "list\[Rho]Pij0", "]"}]}], "}"}]}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.537993578189455*^9, 3.537993610797545*^9}, {
   3.537993771670854*^9, 3.537993779038876*^9}, {3.5379938261036*^9, 
   3.537993894920753*^9}, 3.537993985202799*^9, {3.537994016572002*^9, 
   3.537994037555522*^9}, {3.537994388113123*^9, 3.5379944406823893`*^9}, {
   3.5379944716672297`*^9, 3.537994535484898*^9}, {3.5379946435344*^9, 
   3.537994670999247*^9}, {3.537994822992545*^9, 3.537994848706256*^9}, {
   3.537994948252141*^9, 3.5379951325767097`*^9}, {3.537995185554933*^9, 
   3.537995241802492*^9}, {3.537995276222849*^9, 3.537995281348686*^9}, {
   3.53799533558186*^9, 3.5379953402203913`*^9}, {3.537995373317173*^9, 
   3.537995389189156*^9}, {3.537995463503443*^9, 3.537995586335116*^9}, {
   3.537995620905704*^9, 3.537995685353702*^9}, {3.537995731882414*^9, 
   3.537995740818839*^9}, {3.53799608412899*^9, 3.537996120582891*^9}, {
   3.537996373868025*^9, 3.537996470581868*^9}, {3.537996552739531*^9, 
   3.537996599754401*^9}, {3.537996699014799*^9, 3.537996718444993*^9}, {
   3.5379967905373993`*^9, 3.537996835526949*^9}, {3.537996969586375*^9, 
   3.537997008865888*^9}, {3.537997054707327*^9, 3.5379970594661016`*^9}, {
   3.537997228824871*^9, 3.537997383715749*^9}, {3.537997495969655*^9, 
   3.537997504978291*^9}, {3.538049111849923*^9, 3.538049145198148*^9}, {
   3.538049184515108*^9, 3.538049258034523*^9}, {3.5380493781370897`*^9, 
   3.538049391682486*^9}, {3.538049424567073*^9, 3.538049487235387*^9}, {
   3.538049594582995*^9, 3.538049743296955*^9}, {3.538050939370043*^9, 
   3.5380509982737083`*^9}, {3.5380676731372538`*^9, 3.538067723150732*^9}, 
   3.53806785052652*^9, {3.538067941214231*^9, 3.538067990711932*^9}, {
   3.538068029462811*^9, 3.538068153307399*^9}, {3.53806855796034*^9, 
   3.538068627746333*^9}, {3.53806869188647*^9, 3.538068751511098*^9}, {
   3.538068919982791*^9, 3.538068952563477*^9}, {3.538120345641403*^9, 
   3.538120421155457*^9}, 3.538120780664413*^9, {3.538120852906658*^9, 
   3.538120953903056*^9}, {3.538121002642786*^9, 3.538121148063637*^9}, {
   3.538126353936679*^9, 3.538126386984695*^9}, {3.538126473001809*^9, 
   3.5381265005530252`*^9}, {3.538126537649548*^9, 3.538126555161577*^9}, {
   3.5381266439234133`*^9, 3.538126715750491*^9}, 3.538127882474265*^9, {
   3.538130944351671*^9, 3.538131077658307*^9}, {3.538131942442205*^9, 
   3.538132013760786*^9}, {3.538132283894219*^9, 3.538132360880001*^9}, {
   3.538133348588627*^9, 3.538133377632154*^9}, {3.53813341458228*^9, 
   3.538133595785343*^9}, {3.538133693428665*^9, 3.538133893912404*^9}, {
   3.538133930459076*^9, 3.538134125076247*^9}, {3.53813417768613*^9, 
   3.538134217260666*^9}, {3.538134259339695*^9, 3.538134264398603*^9}, {
   3.538137299532156*^9, 3.538137342311903*^9}, {3.538137430398448*^9, 
   3.538137473144889*^9}, {3.5381376929555693`*^9, 3.5381377022975807`*^9}, {
   3.5381379513516703`*^9, 3.538137995917336*^9}, {3.538138048946089*^9, 
   3.53813805994525*^9}, {3.538138121394474*^9, 3.5381381959580793`*^9}, {
   3.5381382502615757`*^9, 3.538138273902351*^9}, {3.5381383210109873`*^9, 
   3.538138336804418*^9}, 3.538138516977003*^9, {3.5381618433477077`*^9, 
   3.538161932597952*^9}, {3.538161987860311*^9, 3.5381620846113997`*^9}, {
   3.5381621539329453`*^9, 3.538162195795615*^9}, {3.538162226745761*^9, 
   3.538162260756913*^9}, {3.538162294790723*^9, 3.538162558108499*^9}, {
   3.5382004503666887`*^9, 3.538200516536386*^9}, {3.5382005504900503`*^9, 
   3.538200576308169*^9}, {3.538200918185061*^9, 3.5382009209833603`*^9}, 
   3.538200954918594*^9, {3.5382012679264*^9, 3.538201268242012*^9}, {
   3.5382013070166893`*^9, 3.538201311732603*^9}, 3.53820156656705*^9, {
   3.538201655677127*^9, 3.538201682767631*^9}, 3.538201919512535*^9, 
   3.538243145787212*^9, 3.53824318144276*^9, {3.538243282594778*^9, 
   3.5382432941723957`*^9}, {3.5382433354676323`*^9, 
   3.5382433373488293`*^9}, {3.538243583835874*^9, 3.538243588737722*^9}, {
   3.538244168454702*^9, 3.538244180740324*^9}, {3.538244332583802*^9, 
   3.538244339379407*^9}, 3.5382449465768633`*^9, {3.5388070078690643`*^9, 
   3.538807099973749*^9}, {3.538807180708592*^9, 3.5388071828035707`*^9}, 
   3.5388074844694977`*^9, {3.538807551230954*^9, 3.538807553504488*^9}, {
   3.538808873941285*^9, 3.538808875477491*^9}, {3.538808927009503*^9, 
   3.5388089304970512`*^9}, {3.538808998699823*^9, 3.538809020477653*^9}, {
   3.538809124555171*^9, 3.538809131039702*^9}, 3.538809175971305*^9, {
   3.538809338238731*^9, 3.5388093394879303`*^9}, 3.5388093971728573`*^9, {
   3.53881066031894*^9, 3.538810687713526*^9}, 3.538810748528813*^9, {
   3.5388107917831078`*^9, 3.538810794089106*^9}, {3.538811661821177*^9, 
   3.538811724776244*^9}, 3.538817331517233*^9, {3.5388192046322308`*^9, 
   3.538819214494584*^9}, {3.5392665470358353`*^9, 3.5392665745099287`*^9}, {
   3.539266610562613*^9, 3.539266615983183*^9}, {3.5392666830721903`*^9, 
   3.539266815780409*^9}, 3.539266848624251*^9, 3.539266890598507*^9, {
   3.539267060053648*^9, 3.539267072703176*^9}, 3.5392677537069807`*^9, 
   3.539267788390932*^9, {3.539268495010467*^9, 3.539268496663838*^9}, 
   3.539269140585288*^9, 3.539269235639429*^9, {3.539269355353408*^9, 
   3.539269383630211*^9}, {3.539269638969858*^9, 3.539269750991323*^9}, {
   3.53926979106437*^9, 3.539269810113697*^9}, {3.5392701517950487`*^9, 
   3.5392701920043097`*^9}, 3.539278908980487*^9, 3.539278996527172*^9, {
   3.539326343054734*^9, 3.539326435401582*^9}, {3.539326569957453*^9, 
   3.539326575804747*^9}, {3.539326991237306*^9, 3.5393270082806168`*^9}, {
   3.539329433774241*^9, 3.5393294960187607`*^9}, {3.5393305017074823`*^9, 
   3.539330556642144*^9}, 3.539330888641615*^9, {3.539339971597237*^9, 
   3.5393399876891327`*^9}, {3.5393400782346582`*^9, 3.539340081023357*^9}, {
   3.5393401448438396`*^9, 3.539340145504077*^9}, {3.539347774329233*^9, 
   3.539347843122929*^9}, 3.539366432292687*^9, {3.539367245443975*^9, 
   3.539367246347004*^9}, {3.540734202771955*^9, 3.5407342043103733`*^9}, {
   3.540736418761684*^9, 3.5407364226194553`*^9}, {3.540737768596367*^9, 
   3.540737768892754*^9}, {3.542388724376953*^9, 3.542388781889929*^9}, {
   3.542388924988758*^9, 3.542388987923122*^9}, {3.5423890458105783`*^9, 
   3.542389193224463*^9}, {3.542389272963728*^9, 3.54238930706011*^9}, {
   3.542437641275167*^9, 3.542437699202085*^9}, {3.542437730796095*^9, 
   3.5424378902358*^9}, 3.542437945897581*^9, {3.5424379882249823`*^9, 
   3.5424380665457783`*^9}, 3.5424381121082697`*^9, {3.542438249182868*^9, 
   3.5424382662648687`*^9}, 3.542438305697894*^9, {3.542439075760028*^9, 
   3.5424390838844147`*^9}, {3.542439173737357*^9, 3.542439220087296*^9}, {
   3.542443352398711*^9, 3.542443381775426*^9}, {3.542443447124556*^9, 
   3.542443480430725*^9}, {3.542443613406389*^9, 3.542443649481735*^9}, 
   3.542443699901371*^9, {3.5424462578396807`*^9, 3.542446274257043*^9}, {
   3.542446401017707*^9, 3.542446413600088*^9}, {3.5424464659327908`*^9, 
   3.5424464878337793`*^9}, {3.5424465291804132`*^9, 3.5424465329099913`*^9}, 
   3.542446742755765*^9, {3.542446778102816*^9, 3.542446785282056*^9}, {
   3.542446834089986*^9, 3.542446884468789*^9}, {3.542446919291979*^9, 
   3.542446939944065*^9}, {3.542446976270124*^9, 3.5424469866004257`*^9}, {
   3.542447056705858*^9, 3.5424470898445673`*^9}, {3.5424471344029417`*^9, 
   3.542447174506599*^9}, {3.5424472312410507`*^9, 3.54244726772272*^9}, {
   3.5424473125427227`*^9, 3.5424473254819317`*^9}, {3.5424473695330887`*^9, 
   3.542447388671294*^9}, 3.542448224058323*^9, {3.542451548746708*^9, 
   3.5424515774216213`*^9}, {3.5424519211077013`*^9, 3.542451928153799*^9}, {
   3.54245299950036*^9, 3.542453001194194*^9}, {3.542455811416429*^9, 
   3.542455815394039*^9}, {3.542622812244008*^9, 3.542622822000717*^9}, {
   3.542622859825048*^9, 3.542622931786152*^9}, {3.54269829979911*^9, 
   3.542698305254208*^9}, {3.542699025561718*^9, 3.542699026123849*^9}, {
   3.5426990707182913`*^9, 3.542699088670185*^9}, {3.542700118933394*^9, 
   3.542700121036415*^9}, 3.542700827765305*^9, {3.5429174051788473`*^9, 
   3.542917524367551*^9}, 3.5429176869021387`*^9, {3.542969166437325*^9, 
   3.542969172344721*^9}, {3.548190436221043*^9, 3.548190445993956*^9}, 
   3.548190491401569*^9, {3.548190752747745*^9, 3.548190753292897*^9}, {
   3.54901721401657*^9, 3.549017214311965*^9}, {3.549017247695644*^9, 
   3.5490173217517653`*^9}, {3.5490175863059607`*^9, 3.549017586840351*^9}, {
   3.64364096822392*^9, 3.643640983650118*^9}, 3.643641025520862*^9, {
   3.6436415353816833`*^9, 3.643641602069047*^9}, {3.643641636036574*^9, 
   3.643641702536974*^9}, 3.643641788051527*^9, {3.6436418353044577`*^9, 
   3.643641843368132*^9}, {3.678793251829185*^9, 3.678793285790352*^9}, 
   3.6787994439458447`*^9, {3.678862755048066*^9, 3.6788627561980753`*^9}, 
   3.678865112211464*^9, {3.681391437897203*^9, 3.681391452879457*^9}, {
   3.737108210053956*^9, 3.737108249563664*^9}, {3.7371084042540083`*^9, 
   3.7371084083262463`*^9}, 3.737109292446753*^9, {3.737109749523717*^9, 
   3.737109805554154*^9}, {3.737110028644668*^9, 3.737110070179446*^9}, {
   3.737110150417325*^9, 3.737110151300057*^9}, 3.737110382136352*^9, {
   3.737110458359399*^9, 3.737110460309579*^9}, {3.737110702040637*^9, 
   3.737110703878584*^9}, {3.7371117587819138`*^9, 3.73711177306219*^9}, {
   3.737113682711214*^9, 3.7371136853064327`*^9}, {3.7371138793370953`*^9, 
   3.737113881349288*^9}, {3.73718694545557*^9, 3.737186984864314*^9}, {
   3.737187015838509*^9, 3.7371870332629213`*^9}, {3.737187072238668*^9, 
   3.7371870800135736`*^9}, {3.737189762748537*^9, 3.737189763128755*^9}, {
   3.737189800186709*^9, 3.737189804667068*^9}, {3.7371898409234247`*^9, 
   3.737189845354582*^9}, 3.737190240046109*^9, {3.7371903718842573`*^9, 
   3.737190380979869*^9}, {3.737191435152549*^9, 3.737191467949527*^9}, {
   3.737191521249221*^9, 3.73719156092738*^9}, {3.737191766050044*^9, 
   3.7371917689123497`*^9}, 3.737197927456336*^9, {3.737198159489818*^9, 
   3.737198159886495*^9}, {3.737200386075508*^9, 3.7372003868555098`*^9}, {
   3.737264960908597*^9, 3.7372649614648647`*^9}, 3.7372710196476183`*^9, {
   3.737271124669427*^9, 3.737271139070385*^9}, {3.737271449376149*^9, 
   3.737271450701746*^9}, {3.737272473365141*^9, 3.737272503208777*^9}, {
   3.7372725472818527`*^9, 3.737272573132128*^9}, {3.737272872657456*^9, 
   3.737272875955984*^9}, {3.73727330346493*^9, 3.737273333526195*^9}, {
   3.737273441415806*^9, 3.73727346055801*^9}, {3.738396788506775*^9, 
   3.738396792615591*^9}, {3.738396838807775*^9, 3.738396881515554*^9}, {
   3.738397086236014*^9, 
   3.738397096880761*^9}},ExpressionUUID->"f23c6598-1dfd-40f2-8b15-\
b21c145e72da"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"factor", "=", 
    RowBox[{"(*", "m", "*)"}], 
    FractionBox["\[Nu]", 
     RowBox[{"n", " ", "\[CapitalOmega]d"}]]}], ";"}], "\[IndentingNewLine]", 
  
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"resultPij0form1", "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{"FullSimplify", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"factor", " ", "resultPij0"}], "/.", "replace\[Rho]Pij0"}],
           "/.", "replace\[Alpha]"}], "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\[Nu]", "\[Rule]", 
            RowBox[{
             FractionBox[
              RowBox[{"d", "+", "2"}], "2"], "\[Nu]0"}]}], ",", 
           RowBox[{"w0", "\[Rule]", 
            FractionBox[
             RowBox[{"1", "+", "e"}], "2"]}]}], "}"}]}], "]"}], "/.", 
       RowBox[{"{", 
        RowBox[{"\[Nu]0", "\[Rule]", 
         RowBox[{
          FractionBox[
           RowBox[{"2", "d"}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", "e"}], ")"}], 
            RowBox[{"(", 
             RowBox[{"d", "+", "1", "-", "e"}], ")"}]}]], 
          RowBox[{"\[Nu]", "[", 
           RowBox[{"0", ",", "2"}], "]"}]}]}], "}"}]}], "]"}]}], ";"}], 
   "*)"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"resultPij0form1", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"factor", " ", "resultPij0"}], "/.", "replace\[Rho]Pij0"}], "/.",
         "replace\[Alpha]"}], "/.", "gammareplacements"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\[Nu]", "\[Rule]", 
         RowBox[{
          FractionBox[
           RowBox[{"d", "+", "2"}], "2"], "\[Nu]0"}]}], ",", 
        RowBox[{"w0", "\[Rule]", 
         FractionBox[
          RowBox[{"1", "+", "e"}], "2"]}]}], "}"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{"\[Nu]0", "\[Rule]", 
       RowBox[{
        FractionBox[
         RowBox[{"2", "d"}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", "e"}], ")"}], 
          RowBox[{"(", 
           RowBox[{"d", "+", "1", "-", "e"}], ")"}]}]], 
        RowBox[{"\[Nu]", "[", 
         RowBox[{"0", ",", "2"}], "]"}]}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.737272917319312*^9, 3.737272919047133*^9}, {
   3.73727297093484*^9, 3.73727298523519*^9}, {3.737273051179839*^9, 
   3.737273105514578*^9}, {3.737273137272187*^9, 3.737273225397573*^9}, 
   3.7372734650377493`*^9, 3.7372736090084267`*^9, {3.737273660475463*^9, 
   3.737273777624713*^9}, 3.738395699297328*^9, {3.7383960772383204`*^9, 
   3.738396078243876*^9}, {3.738396678794359*^9, 3.738396711670636*^9}, {
   3.738396763385541*^9, 3.738396783144718*^9}, {3.7383968961843367`*^9, 
   3.738396900581313*^9}, {3.738409604096253*^9, 3.7384096562703657`*^9}, 
   3.738658738279801*^9},ExpressionUUID->"f86a08a1-ec65-43be-94ef-\
39231851c8d7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   StyleBox[
    RowBox[{
     RowBox[{"Eq", ".", " ", 
      SubscriptBox[
       RowBox[{"(", "2.17", ")"}], "2"]}], " ", "of", " ", "Garz\[OAcute]", 
     " ", "and", " ", "Santos", " ", "2007", " ", 
     RowBox[{"J", ".", " ", "Phys", ".", " ", 
      RowBox[{"A", ":", " ", 
       RowBox[{
        RowBox[{"Math", ".", " ", "Theor", ".", " ", 
         StyleBox["40",
          FontWeight->"Bold"]}], " ", "14927"}]}]}]}],
    FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{"resultPij0form1", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Rho]", "[", 
         RowBox[{"n_", ",", "li_"}], "]"}], "\[Rule]", 
        RowBox[{"m", " ", 
         RowBox[{"M", "[", 
          RowBox[{
           RowBox[{"2", "n"}], ",", "li"}], "]"}]}]}], ",", 
       RowBox[{
        RowBox[{"\[Upsilon]", "[", 
         RowBox[{"n_", ",", "li_"}], "]"}], "\[Rule]", 
        RowBox[{"m", " ", 
         RowBox[{"M", "[", 
          RowBox[{
           RowBox[{"2", "n"}], ",", "li"}], "]"}]}]}]}], "}"}]}], ",", 
    RowBox[{"\[Delta]", "[", 
     RowBox[{"{", 
      RowBox[{"i1", ",", "i2"}], "}"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7383954198929977`*^9, 3.738395424674985*^9}, {
   3.738395505793868*^9, 3.738395508613287*^9}, {3.7383955414619293`*^9, 
   3.738395555856544*^9}, {3.738395587057211*^9, 3.7383956011687737`*^9}, {
   3.738397306746271*^9, 3.738397407307046*^9}, 3.7383974728312073`*^9, 
   3.738476878961607*^9, {3.7384770973693323`*^9, 
   3.738477102649075*^9}},ExpressionUUID->"feab9b4e-12ef-44ad-b1f1-\
455a4075d64e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    RowBox[{"M", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", 
       RowBox[{"i1", ",", "i2"}], "}"}]}], "]"}]}], " ", 
   RowBox[{"\[Nu]", "[", 
    RowBox[{"0", ",", "2"}], "]"}]}], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"2", "+", "d"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "e"}], ")"}], " ", 
    RowBox[{"M", "[", 
     RowBox[{"2", ",", 
      RowBox[{"{", "}"}]}], "]"}], " ", 
    RowBox[{"\[Delta]", "[", 
     RowBox[{"{", 
      RowBox[{"i1", ",", "i2"}], "}"}], "]"}], " ", 
    RowBox[{"\[Nu]", "[", 
     RowBox[{"0", ",", "2"}], "]"}]}], 
   RowBox[{"2", " ", "d", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "d", "-", "e"}], ")"}]}]]}]], "Output",
 CellChangeTimes->{3.738658746965289*^9, 3.7449601752607117`*^9, 
  3.7450142507126503`*^9, 3.745017810006732*^9, 
  3.745122325898946*^9},ExpressionUUID->"4c70733a-d2dc-4b64-a22e-\
b5874134f77b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   StyleBox[
    RowBox[{
     RowBox[{"Eq", ".", " ", 
      SubscriptBox[
       RowBox[{"(", "2.17", ")"}], "2"]}], " ", "of", " ", "Garz\[OAcute]", 
     " ", "and", " ", "Santos", " ", "2007", " ", 
     RowBox[{"J", ".", " ", "Phys", ".", " ", 
      RowBox[{"A", ":", " ", 
       RowBox[{
        RowBox[{"Math", ".", " ", "Theor", ".", " ", 
         StyleBox["40",
          FontWeight->"Bold"]}], " ", "14927"}]}]}]}],
    FontColor->RGBColor[1, 0, 0]], "*)"}], 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"resultPij0form1", "-", 
       RowBox[{
        FractionBox["1", "d"], 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i1", ",", "i2"}], "}"}], "]"}], "resultP1form1"}]}], ")"}],
      "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Rho]", "[", 
         RowBox[{"n_", ",", "li_"}], "]"}], "\[Rule]", 
        RowBox[{"m", " ", 
         RowBox[{"M", "[", 
          RowBox[{
           RowBox[{"2", "n"}], ",", "li"}], "]"}]}]}], ",", 
       RowBox[{
        RowBox[{"\[Upsilon]", "[", 
         RowBox[{"n_", ",", "li_"}], "]"}], "\[Rule]", 
        RowBox[{"m", " ", 
         RowBox[{"M", "[", 
          RowBox[{
           RowBox[{"2", "n"}], ",", "li"}], "]"}]}]}]}], "}"}]}], "/.", 
    RowBox[{
     RowBox[{"\[Nu]", "[", 
      RowBox[{"2", ",", "0"}], "]"}], "\[Rule]", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"d", "+", "2"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"1", "-", "e"}], ")"}]}], 
       RowBox[{"2", 
        RowBox[{"(", 
         RowBox[{"d", "+", "1", "-", "e"}], ")"}]}]], " ", 
      RowBox[{"\[Nu]", "[", 
       RowBox[{"0", ",", "2"}], "]"}]}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7384764270774384`*^9, 3.7384765405230703`*^9}, {
   3.738476625536312*^9, 3.7384766567434063`*^9}, {3.738476689831773*^9, 
   3.7384766901837473`*^9}, {3.738476727060902*^9, 3.7384767433083773`*^9}, {
   3.738476787980031*^9, 3.738476852663743*^9}, 
   3.738477132481758*^9},ExpressionUUID->"547e05fb-2f39-412a-87c3-\
14c8f13af903"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{"M", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", 
      RowBox[{"i1", ",", "i2"}], "}"}]}], "]"}]}], " ", 
  RowBox[{"\[Nu]", "[", 
   RowBox[{"0", ",", "2"}], "]"}]}]], "Output",
 CellChangeTimes->{{3.738476453892292*^9, 3.738476485516283*^9}, {
   3.738476525172441*^9, 3.738476542259104*^9}, 3.738476626822283*^9, {
   3.738476814278892*^9, 3.7384768409276953`*^9}, 3.738658759711294*^9, 
   3.744960175295512*^9, 3.745014250751726*^9, 3.74501781004742*^9, 
   3.745122325939918*^9},ExpressionUUID->"879a5bb6-513d-4222-9410-\
5f1d30f7d158"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   StyleBox[
    RowBox[{"To", " ", "write", " ", "in", " ", "the", " ", "paper"}],
    FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Pij0paper", "=", 
     RowBox[{
      RowBox[{"Collect", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"m", " ", "resultPij0form1"}], "/.", "replace\[Rho]u"}], "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\[Nu]", "[", 
            RowBox[{"0", ",", "2"}], "]"}], "\[Rule]", 
           RowBox[{
            FractionBox[
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "+", "e"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"d", "+", "1", "-", "e"}], ")"}]}], 
             RowBox[{"2", "d"}]], " ", "\[Nu]0"}]}], "}"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Sigma]", "[", 
          RowBox[{"{", 
           RowBox[{"i1", ",", "i2"}], "}"}], "]"}], "}"}], ",", "Simplify"}], 
       "]"}], "/.", 
      RowBox[{
       RowBox[{"\[Delta]", "[", "_", "]"}], "\[Rule]", "0"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"Pij0paper", "-", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "\[Nu]\[Sigma]"}], " ", "\[Nu]0", " ", 
        RowBox[{"\[Sigma]", "[", 
         RowBox[{"{", 
          RowBox[{"i1", ",", "i2"}], "}"}], "]"}]}], ")"}]}], "/.", 
     RowBox[{"\[Nu]\[Sigma]", "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", "e"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"d", "+", "1", "-", "e"}], ")"}]}], 
       RowBox[{"2", "d"}]]}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.738658765880584*^9, 3.7386588072315273`*^9}, {
  3.7386589325724583`*^9, 3.738658984166459*^9}, {3.738659015529743*^9, 
  3.738659015663054*^9}, {3.744960238409787*^9, 3.74496028431374*^9}, {
  3.7449603230971107`*^9, 3.744960332967382*^9}, {3.744960401552895*^9, 
  3.744960408599859*^9}, {3.744960709665028*^9, 
  3.744960714680257*^9}},ExpressionUUID->"8b7a84c0-1f11-497b-a8ca-\
501ab5bb8b38"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.744960715511757*^9, 3.745014250785572*^9, 
  3.745017810080883*^9, 
  3.745122325973844*^9},ExpressionUUID->"ed53907f-2199-483a-a84e-\
53e9be79e341"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Production Term for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["C", "2"], 
    SubscriptBox["C", "i"]}], TraditionalForm]],ExpressionUUID->
  "da3439fc-ddda-4e69-8f5a-b50598c19e26"]
}], "Subsection",
 CellChangeTimes->{{3.540736884072311*^9, 3.5407369043909597`*^9}, {
  3.542452633864394*^9, 3.542452671646845*^9}, {3.737272427807934*^9, 
  3.737272430722102*^9}, {3.737273281718402*^9, 3.7372732969187727`*^9}, {
  3.7384017425560913`*^9, 3.73840174518649*^9}, {3.7384024868866043`*^9, 
  3.7384024963124943`*^9}},
 TextAlignment->Center,
 FontColor->RGBColor[0.5, 0, 0.5],
 Background->RGBColor[
  1, 1, 0.85],ExpressionUUID->"f2ca2172-5ab5-4aa4-8fd8-33b57708e3aa"],

Cell[BoxData[{
 RowBox[{"Clear", "[", 
  RowBox[{"w0", ",", "g"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"idx", "=", 
   RowBox[{"{", 
    RowBox[{"i1", ",", "i2", ",", "i3"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"nn", "=", 
    RowBox[{"Length", "[", "idx", "]"}]}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   StyleBox[
    RowBox[{
    "raw", " ", "form", " ", "of", " ", "integrand", " ", "without", " ", 
     "factor", " ", 
     FractionBox[
      RowBox[{"m", " ", "\[Nu]"}], 
      RowBox[{"n", " ", "\[CapitalOmega]d"}]], " ", "and", " ", "f", " ", 
     "f1", " ", "in", " ", "the", " ", "collision", " ", "integral"}],
    FontColor->RGBColor[1, 0.5, 0]], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Pi1", "=", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"\[Beta]", "=", "1"}], "nn"], 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"\[Gamma]", "=", "0"}], 
       RowBox[{"\[Beta]", "/", "2"}]], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], "\[Beta]"], 
       SuperscriptBox["w0", "\[Beta]"], 
       RowBox[{"Binomial", "[", 
        RowBox[{"nn", ",", "\[Beta]"}], "]"}], 
       RowBox[{"Delta", "[", 
        RowBox[{
         RowBox[{"idx", "\[LeftDoubleBracket]", 
          RowBox[{"range", "[", 
           RowBox[{"1", ",", "\[Gamma]"}], "]"}], "\[RightDoubleBracket]"}], 
         ",", 
         RowBox[{"idx", "\[LeftDoubleBracket]", 
          RowBox[{"range", "[", 
           RowBox[{
            RowBox[{"\[Gamma]", "+", "1"}], ",", 
            RowBox[{"2", "\[Gamma]"}]}], "]"}], "\[RightDoubleBracket]"}]}], 
        "]"}], 
       RowBox[{"\[Alpha]", "[", 
        RowBox[{"\[Gamma]", ",", "\[Beta]"}], "]"}], 
       SuperscriptBox["g", 
        RowBox[{"2", "\[Gamma]"}]], 
       RowBox[{"gg", "[", 
        RowBox[{"idx", "\[LeftDoubleBracket]", 
         RowBox[{"range", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"2", "\[Gamma]"}], "+", "1"}], ",", "\[Beta]"}], "]"}], 
         "\[RightDoubleBracket]"}], "]"}], 
       RowBox[{"CC", "[", 
        RowBox[{"idx", "\[LeftDoubleBracket]", 
         RowBox[{"range", "[", 
          RowBox[{
           RowBox[{"\[Beta]", "+", "1"}], ",", "nn"}], "]"}], 
         "\[RightDoubleBracket]"}], "]"}]}]}]}]}], 
   RowBox[{"(*", 
    RowBox[{"f", " ", "f1"}], "*)"}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   StyleBox[
    RowBox[{"symmetrization", " ", "of", " ", "the", " ", "indices"}],
    FontColor->RGBColor[1, 0.5, 0]], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"perm", "=", 
   RowBox[{
    RowBox[{"Permutations", "[", "idx", "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{"i3", "\[Rule]", "i2"}], "}"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CollInt", "=", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{"CollInt", "+=", 
    RowBox[{"Pi1", "/.", 
     RowBox[{"Thread", "[", 
      RowBox[{"idx", "\[Rule]", 
       RowBox[{
       "perm", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}]}], 
      "]"}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{"ii", ",", "1", ",", 
     RowBox[{"Length", "[", "perm", "]"}]}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CollIntegralPi1", "=", 
    RowBox[{"ExpandAll", "[", 
     RowBox[{
      FractionBox["CollInt", 
       RowBox[{"Length", "[", "perm", "]"}]], "/.", "replace$gsq"}], "]"}]}], 
   ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   StyleBox[
    RowBox[{
     RowBox[{"main", " ", "working", " ", 
      RowBox[{"steps", ":", " ", 
       RowBox[{
        RowBox[{
        "1.", " ", "integrate", " ", "directions", " ", "in", " ", "h"}], "-",
         "vectors"}]}]}], ";", " ", 
     RowBox[{
      RowBox[{
      "2.", " ", "integrate", " ", "directions", " ", "in", " ", "g"}], "-", 
      "vectors"}], ";", " ", 
     RowBox[{
     "3.", " ", "integrate", " ", "Gauss", " ", "integrals", " ", "in", " ", 
      "h"}], ";", " ", 
     RowBox[{
     "4.", " ", "perform", " ", "contractions", " ", "on", " ", "\[Delta]"}]}],
    FontColor->RGBColor[1, 0.5, 0]], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g", "[", "idx_", "]"}], ":=", 
  RowBox[{
   RowBox[{"CC", "[", "idx", "]"}], "-", 
   RowBox[{"CC1", "[", "idx", "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CollIntegralPi1", "=", 
    RowBox[{"Expand", "[", "CollIntegralPi1", "]"}]}], ";"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   StyleBox[
    RowBox[{"Integration", " ", "over", " ", "C", " ", "and", " ", "C1"}],
    FontColor->RGBColor[1, 0.5, 0]], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"resultPi1", "=", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Einstein", "[", 
         RowBox[{"intoverCC1", "[", 
          RowBox[{
          "CollIntegralPi1", "\[LeftDoubleBracket]", "ii", 
           "\[RightDoubleBracket]"}], "]"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"ii", ",", "1", ",", 
          RowBox[{"Length", "[", "CollIntegralPi1", "]"}]}], "}"}]}], "]"}]}],
      "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"list\[Rho]Pi1", "=", 
   RowBox[{"DeleteDuplicates", "[", 
    RowBox[{"Extract", "[", 
     RowBox[{"resultPi1", ",", 
      RowBox[{"Position", "[", 
       RowBox[{"resultPi1", ",", 
        RowBox[{"\[Rho]", "[", 
         RowBox[{"_", ",", "_"}], "]"}]}], "]"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"replace\[Rho]Pi1", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
      "list\[Rho]Pi1", "\[LeftDoubleBracket]", "ii", 
       "\[RightDoubleBracket]"}], "\[Rule]", 
      RowBox[{"tracefreerepresentation", "[", 
       RowBox[{
       "list\[Rho]Pi1", "\[LeftDoubleBracket]", "ii", 
        "\[RightDoubleBracket]"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"ii", ",", "1", ",", 
       RowBox[{"Length", "[", "list\[Rho]Pi1", "]"}]}], "}"}]}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.537993578189455*^9, 3.537993610797545*^9}, {
   3.537993771670854*^9, 3.537993779038876*^9}, {3.5379938261036*^9, 
   3.537993894920753*^9}, 3.537993985202799*^9, {3.537994016572002*^9, 
   3.537994037555522*^9}, {3.537994388113123*^9, 3.5379944406823893`*^9}, {
   3.5379944716672297`*^9, 3.537994535484898*^9}, {3.5379946435344*^9, 
   3.537994670999247*^9}, {3.537994822992545*^9, 3.537994848706256*^9}, {
   3.537994948252141*^9, 3.5379951325767097`*^9}, {3.537995185554933*^9, 
   3.537995241802492*^9}, {3.537995276222849*^9, 3.537995281348686*^9}, {
   3.53799533558186*^9, 3.5379953402203913`*^9}, {3.537995373317173*^9, 
   3.537995389189156*^9}, {3.537995463503443*^9, 3.537995586335116*^9}, {
   3.537995620905704*^9, 3.537995685353702*^9}, {3.537995731882414*^9, 
   3.537995740818839*^9}, {3.53799608412899*^9, 3.537996120582891*^9}, {
   3.537996373868025*^9, 3.537996470581868*^9}, {3.537996552739531*^9, 
   3.537996599754401*^9}, {3.537996699014799*^9, 3.537996718444993*^9}, {
   3.5379967905373993`*^9, 3.537996835526949*^9}, {3.537996969586375*^9, 
   3.537997008865888*^9}, {3.537997054707327*^9, 3.5379970594661016`*^9}, {
   3.537997228824871*^9, 3.537997383715749*^9}, {3.537997495969655*^9, 
   3.537997504978291*^9}, {3.538049111849923*^9, 3.538049145198148*^9}, {
   3.538049184515108*^9, 3.538049258034523*^9}, {3.5380493781370897`*^9, 
   3.538049391682486*^9}, {3.538049424567073*^9, 3.538049487235387*^9}, {
   3.538049594582995*^9, 3.538049743296955*^9}, {3.538050939370043*^9, 
   3.5380509982737083`*^9}, {3.5380676731372538`*^9, 3.538067723150732*^9}, 
   3.53806785052652*^9, {3.538067941214231*^9, 3.538067990711932*^9}, {
   3.538068029462811*^9, 3.538068153307399*^9}, {3.53806855796034*^9, 
   3.538068627746333*^9}, {3.53806869188647*^9, 3.538068751511098*^9}, {
   3.538068919982791*^9, 3.538068952563477*^9}, {3.538120345641403*^9, 
   3.538120421155457*^9}, 3.538120780664413*^9, {3.538120852906658*^9, 
   3.538120953903056*^9}, {3.538121002642786*^9, 3.538121148063637*^9}, {
   3.538126353936679*^9, 3.538126386984695*^9}, {3.538126473001809*^9, 
   3.5381265005530252`*^9}, {3.538126537649548*^9, 3.538126555161577*^9}, {
   3.5381266439234133`*^9, 3.538126715750491*^9}, 3.538127882474265*^9, {
   3.538130944351671*^9, 3.538131077658307*^9}, {3.538131942442205*^9, 
   3.538132013760786*^9}, {3.538132283894219*^9, 3.538132360880001*^9}, {
   3.538133348588627*^9, 3.538133377632154*^9}, {3.53813341458228*^9, 
   3.538133595785343*^9}, {3.538133693428665*^9, 3.538133893912404*^9}, {
   3.538133930459076*^9, 3.538134125076247*^9}, {3.53813417768613*^9, 
   3.538134217260666*^9}, {3.538134259339695*^9, 3.538134264398603*^9}, {
   3.538137299532156*^9, 3.538137342311903*^9}, {3.538137430398448*^9, 
   3.538137473144889*^9}, {3.5381376929555693`*^9, 3.5381377022975807`*^9}, {
   3.5381379513516703`*^9, 3.538137995917336*^9}, {3.538138048946089*^9, 
   3.53813805994525*^9}, {3.538138121394474*^9, 3.5381381959580793`*^9}, {
   3.5381382502615757`*^9, 3.538138273902351*^9}, {3.5381383210109873`*^9, 
   3.538138336804418*^9}, 3.538138516977003*^9, {3.5381618433477077`*^9, 
   3.538161932597952*^9}, {3.538161987860311*^9, 3.5381620846113997`*^9}, {
   3.5381621539329453`*^9, 3.538162195795615*^9}, {3.538162226745761*^9, 
   3.538162260756913*^9}, {3.538162294790723*^9, 3.538162558108499*^9}, {
   3.5382004503666887`*^9, 3.538200516536386*^9}, {3.5382005504900503`*^9, 
   3.538200576308169*^9}, {3.538200918185061*^9, 3.5382009209833603`*^9}, 
   3.538200954918594*^9, {3.5382012679264*^9, 3.538201268242012*^9}, {
   3.5382013070166893`*^9, 3.538201311732603*^9}, 3.53820156656705*^9, {
   3.538201655677127*^9, 3.538201682767631*^9}, 3.538201919512535*^9, 
   3.538243145787212*^9, 3.53824318144276*^9, {3.538243282594778*^9, 
   3.5382432941723957`*^9}, {3.5382433354676323`*^9, 
   3.5382433373488293`*^9}, {3.538243583835874*^9, 3.538243588737722*^9}, {
   3.538244168454702*^9, 3.538244180740324*^9}, {3.538244332583802*^9, 
   3.538244339379407*^9}, 3.5382449465768633`*^9, {3.5388070078690643`*^9, 
   3.538807099973749*^9}, {3.538807180708592*^9, 3.5388071828035707`*^9}, 
   3.5388074844694977`*^9, {3.538807551230954*^9, 3.538807553504488*^9}, {
   3.538808873941285*^9, 3.538808875477491*^9}, {3.538808927009503*^9, 
   3.5388089304970512`*^9}, {3.538808998699823*^9, 3.538809020477653*^9}, {
   3.538809124555171*^9, 3.538809131039702*^9}, 3.538809175971305*^9, {
   3.538809338238731*^9, 3.5388093394879303`*^9}, 3.5388093971728573`*^9, {
   3.53881066031894*^9, 3.538810687713526*^9}, 3.538810748528813*^9, {
   3.5388107917831078`*^9, 3.538810794089106*^9}, {3.538811661821177*^9, 
   3.538811724776244*^9}, 3.538817331517233*^9, {3.5388192046322308`*^9, 
   3.538819214494584*^9}, {3.5392665470358353`*^9, 3.5392665745099287`*^9}, {
   3.539266610562613*^9, 3.539266615983183*^9}, {3.5392666830721903`*^9, 
   3.539266815780409*^9}, 3.539266848624251*^9, 3.539266890598507*^9, {
   3.539267060053648*^9, 3.539267072703176*^9}, 3.5392677537069807`*^9, 
   3.539267788390932*^9, {3.539268495010467*^9, 3.539268496663838*^9}, 
   3.539269140585288*^9, 3.539269235639429*^9, {3.539269355353408*^9, 
   3.539269383630211*^9}, {3.539269638969858*^9, 3.539269750991323*^9}, {
   3.53926979106437*^9, 3.539269810113697*^9}, {3.5392701517950487`*^9, 
   3.5392701920043097`*^9}, 3.539278908980487*^9, 3.539278996527172*^9, {
   3.539326343054734*^9, 3.539326435401582*^9}, {3.539326569957453*^9, 
   3.539326575804747*^9}, {3.539326991237306*^9, 3.5393270082806168`*^9}, {
   3.539329433774241*^9, 3.5393294960187607`*^9}, {3.5393305017074823`*^9, 
   3.539330556642144*^9}, 3.539330888641615*^9, {3.539339971597237*^9, 
   3.5393399876891327`*^9}, {3.5393400782346582`*^9, 3.539340081023357*^9}, {
   3.5393401448438396`*^9, 3.539340145504077*^9}, {3.539347774329233*^9, 
   3.539347843122929*^9}, 3.539366432292687*^9, {3.539367245443975*^9, 
   3.539367246347004*^9}, {3.540734202771955*^9, 3.5407342043103733`*^9}, {
   3.540736418761684*^9, 3.5407364226194553`*^9}, {3.540737768596367*^9, 
   3.540737768892754*^9}, {3.542388724376953*^9, 3.542388781889929*^9}, {
   3.542388924988758*^9, 3.542388987923122*^9}, {3.5423890458105783`*^9, 
   3.542389193224463*^9}, {3.542389272963728*^9, 3.54238930706011*^9}, {
   3.542437641275167*^9, 3.542437699202085*^9}, {3.542437730796095*^9, 
   3.5424378902358*^9}, 3.542437945897581*^9, {3.5424379882249823`*^9, 
   3.5424380665457783`*^9}, 3.5424381121082697`*^9, {3.542438249182868*^9, 
   3.5424382662648687`*^9}, 3.542438305697894*^9, {3.542439075760028*^9, 
   3.5424390838844147`*^9}, {3.542439173737357*^9, 3.542439220087296*^9}, {
   3.542443352398711*^9, 3.542443381775426*^9}, {3.542443447124556*^9, 
   3.542443480430725*^9}, {3.542443613406389*^9, 3.542443649481735*^9}, 
   3.542443699901371*^9, {3.5424462578396807`*^9, 3.542446274257043*^9}, {
   3.542446401017707*^9, 3.542446413600088*^9}, {3.5424464659327908`*^9, 
   3.5424464878337793`*^9}, {3.5424465291804132`*^9, 3.5424465329099913`*^9}, 
   3.542446742755765*^9, {3.542446778102816*^9, 3.542446785282056*^9}, {
   3.542446834089986*^9, 3.542446884468789*^9}, {3.542446919291979*^9, 
   3.542446939944065*^9}, {3.542446976270124*^9, 3.5424469866004257`*^9}, {
   3.542447056705858*^9, 3.5424470898445673`*^9}, {3.5424471344029417`*^9, 
   3.542447174506599*^9}, {3.5424472312410507`*^9, 3.54244726772272*^9}, {
   3.5424473125427227`*^9, 3.5424473254819317`*^9}, {3.5424473695330887`*^9, 
   3.542447388671294*^9}, 3.542448224058323*^9, {3.542451548746708*^9, 
   3.5424515774216213`*^9}, {3.5424519211077013`*^9, 3.542451928153799*^9}, {
   3.54245299950036*^9, 3.542453001194194*^9}, {3.542455811416429*^9, 
   3.542455815394039*^9}, {3.542622812244008*^9, 3.542622822000717*^9}, {
   3.542622859825048*^9, 3.542622931786152*^9}, {3.54269829979911*^9, 
   3.542698305254208*^9}, {3.542699025561718*^9, 3.542699026123849*^9}, {
   3.5426990707182913`*^9, 3.542699088670185*^9}, {3.542700118933394*^9, 
   3.542700121036415*^9}, 3.542700827765305*^9, {3.5429174051788473`*^9, 
   3.542917524367551*^9}, 3.5429176869021387`*^9, {3.542969166437325*^9, 
   3.542969172344721*^9}, {3.548190436221043*^9, 3.548190445993956*^9}, 
   3.548190491401569*^9, {3.548190752747745*^9, 3.548190753292897*^9}, {
   3.54901721401657*^9, 3.549017214311965*^9}, {3.549017247695644*^9, 
   3.5490173217517653`*^9}, {3.5490175863059607`*^9, 3.549017586840351*^9}, {
   3.64364096822392*^9, 3.643640983650118*^9}, 3.643641025520862*^9, {
   3.6436415353816833`*^9, 3.643641602069047*^9}, {3.643641636036574*^9, 
   3.643641702536974*^9}, 3.643641788051527*^9, {3.6436418353044577`*^9, 
   3.643641843368132*^9}, {3.678793251829185*^9, 3.678793285790352*^9}, 
   3.6787994439458447`*^9, {3.678862755048066*^9, 3.6788627561980753`*^9}, 
   3.678865112211464*^9, {3.681391437897203*^9, 3.681391452879457*^9}, {
   3.737108210053956*^9, 3.737108249563664*^9}, {3.7371084042540083`*^9, 
   3.7371084083262463`*^9}, 3.737109292446753*^9, {3.737109749523717*^9, 
   3.737109805554154*^9}, {3.737110028644668*^9, 3.737110070179446*^9}, {
   3.737110150417325*^9, 3.737110151300057*^9}, 3.737110382136352*^9, {
   3.737110458359399*^9, 3.737110460309579*^9}, {3.737110702040637*^9, 
   3.737110703878584*^9}, {3.7371117587819138`*^9, 3.73711177306219*^9}, {
   3.737113682711214*^9, 3.7371136853064327`*^9}, {3.7371138793370953`*^9, 
   3.737113881349288*^9}, {3.73718694545557*^9, 3.737186984864314*^9}, {
   3.737187015838509*^9, 3.7371870332629213`*^9}, {3.737187072238668*^9, 
   3.7371870800135736`*^9}, {3.737189762748537*^9, 3.737189763128755*^9}, {
   3.737189800186709*^9, 3.737189804667068*^9}, {3.7371898409234247`*^9, 
   3.737189845354582*^9}, 3.737190240046109*^9, {3.7371903718842573`*^9, 
   3.737190380979869*^9}, {3.737191435152549*^9, 3.737191467949527*^9}, {
   3.737191521249221*^9, 3.73719156092738*^9}, {3.737191766050044*^9, 
   3.7371917689123497`*^9}, 3.737197927456336*^9, {3.737198159489818*^9, 
   3.737198159886495*^9}, {3.737200386075508*^9, 3.7372003868555098`*^9}, {
   3.737264960908597*^9, 3.7372649614648647`*^9}, 3.7372710196476183`*^9, {
   3.737271124669427*^9, 3.737271139070385*^9}, {3.737271449376149*^9, 
   3.737271450701746*^9}, {3.737272473365141*^9, 3.737272503208777*^9}, {
   3.7372725472818527`*^9, 3.737272573132128*^9}, {3.737272872657456*^9, 
   3.737272875955984*^9}, {3.73727330346493*^9, 3.737273333526195*^9}, {
   3.737273441415806*^9, 3.73727346055801*^9}, {3.738396788506775*^9, 
   3.738396792615591*^9}, {3.738396838807775*^9, 3.738396881515554*^9}, {
   3.738397086236014*^9, 3.738397096880761*^9}, {3.738401749460299*^9, 
   3.738401774943083*^9}, {3.7384024562326727`*^9, 3.738402456251067*^9}, {
   3.738402538623505*^9, 
   3.738402542567286*^9}},ExpressionUUID->"ee771499-3952-47ac-8dcf-\
1d1b74e7143c"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"factor", "=", 
    RowBox[{"(*", "m", "*)"}], 
    FractionBox["\[Nu]", 
     RowBox[{"n", " ", "\[CapitalOmega]d"}]]}], ";"}], "\[IndentingNewLine]", 
  
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"resultPi1form1", "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{"FullSimplify", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"factor", " ", "resultPi1"}], "/.", "replace\[Rho]Pi1"}], "/.",
           "replace\[Alpha]"}], "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\[Nu]", "\[Rule]", 
            RowBox[{
             FractionBox[
              RowBox[{"d", "+", "2"}], "2"], "\[Nu]0"}]}], ",", 
           RowBox[{"w0", "\[Rule]", 
            FractionBox[
             RowBox[{"1", "+", "e"}], "2"]}]}], "}"}]}], "]"}], "/.", 
       RowBox[{"{", 
        RowBox[{"\[Nu]0", "\[Rule]", 
         RowBox[{
          FractionBox[
           RowBox[{"8", "d"}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", "e"}], ")"}], 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"5", "d"}], "+", "4", "-", 
              RowBox[{"e", 
               RowBox[{"(", 
                RowBox[{"d", "+", "8"}], ")"}]}]}], ")"}]}]], 
          RowBox[{"\[Nu]", "[", 
           RowBox[{"2", ",", "1"}], "]"}]}]}], "}"}]}], "]"}]}], ";"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"resultPi1form1", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"factor", " ", "resultPi1"}], "/.", "replace\[Rho]Pi1"}], "/.",
         "replace\[Alpha]"}], "/.", "gammareplacements"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\[Nu]", "\[Rule]", 
         RowBox[{
          FractionBox[
           RowBox[{"d", "+", "2"}], "2"], "\[Nu]0"}]}], ",", 
        RowBox[{"w0", "\[Rule]", 
         FractionBox[
          RowBox[{"1", "+", "e"}], "2"]}]}], "}"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{"\[Nu]0", "\[Rule]", 
       RowBox[{
        FractionBox[
         RowBox[{"8", "d"}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", "e"}], ")"}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"5", "d"}], "+", "4", "-", 
            RowBox[{"e", 
             RowBox[{"(", 
              RowBox[{"d", "+", "8"}], ")"}]}]}], ")"}]}]], 
        RowBox[{"\[Nu]", "[", 
         RowBox[{"2", ",", "1"}], "]"}]}]}], "}"}]}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.737272917319312*^9, 3.737272919047133*^9}, {
   3.73727297093484*^9, 3.73727298523519*^9}, {3.737273051179839*^9, 
   3.737273105514578*^9}, {3.737273137272187*^9, 3.737273225397573*^9}, 
   3.7372734650377493`*^9, 3.7372736090084267`*^9, {3.737273660475463*^9, 
   3.737273777624713*^9}, 3.738395699297328*^9, {3.7383960772383204`*^9, 
   3.738396078243876*^9}, {3.738396678794359*^9, 3.738396711670636*^9}, {
   3.738396763385541*^9, 3.738396783144718*^9}, {3.7383968961843367`*^9, 
   3.738396900581313*^9}, {3.738401908839529*^9, 3.7384019088444757`*^9}, 
   3.73840197000576*^9, {3.7384020287743187`*^9, 3.738402054020152*^9}, {
   3.738402456253022*^9, 3.738402456254902*^9}, {3.738402610441186*^9, 
   3.738402656391753*^9}, {3.738409777263929*^9, 3.738409817023192*^9}, 
   3.738476933354168*^9},ExpressionUUID->"295c7c0e-dfa5-4cf2-aa5d-\
dda46609632f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   StyleBox[
    RowBox[{
     RowBox[{"Eq", ".", " ", 
      SubscriptBox[
       RowBox[{"(", "2.20", ")"}], "1"]}], " ", "of", " ", "Garz\[OAcute]", 
     " ", "and", " ", "Santos", " ", "2007", " ", 
     RowBox[{"J", ".", " ", "Phys", ".", " ", 
      RowBox[{"A", ":", " ", 
       RowBox[{
        RowBox[{"Math", ".", " ", "Theor", ".", " ", 
         StyleBox["40",
          FontWeight->"Bold"]}], " ", "14927"}]}]}]}],
    FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"resultPi1form1", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Rho]", "[", 
       RowBox[{"n_", ",", "li_"}], "]"}], "\[Rule]", 
      RowBox[{"m", " ", 
       RowBox[{"M", "[", 
        RowBox[{
         RowBox[{"2", "n"}], ",", "li"}], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"\[Upsilon]", "[", 
       RowBox[{"n_", ",", "li_"}], "]"}], "\[Rule]", 
      RowBox[{"m", " ", 
       RowBox[{"M", "[", 
        RowBox[{
         RowBox[{"2", "n"}], ",", "li"}], "]"}]}]}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.7383954198929977`*^9, 3.738395424674985*^9}, {
   3.738395505793868*^9, 3.738395508613287*^9}, {3.7383955414619293`*^9, 
   3.738395555856544*^9}, {3.738395587057211*^9, 3.7383956011687737`*^9}, {
   3.738397306746271*^9, 3.738397407307046*^9}, 3.7383974728312073`*^9, 
   3.7384019088503523`*^9, {3.738402075667809*^9, 3.7384021822473383`*^9}, {
   3.738402221796605*^9, 3.7384022477042303`*^9}, {3.738402391753244*^9, 
   3.7384023975098352`*^9}, 3.738402456258939*^9, {3.738402690566793*^9, 
   3.738402732471015*^9}, 3.738476918764895*^9, {3.738477155998571*^9, 
   3.7384771629063873`*^9}},ExpressionUUID->"9cf0c9fa-e4b1-4b43-a2dc-\
11d1fe49f855"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{"M", "[", 
    RowBox[{"2", ",", 
     RowBox[{"{", "i1", "}"}]}], "]"}]}], " ", 
  RowBox[{"\[Nu]", "[", 
   RowBox[{"2", ",", "1"}], "]"}]}]], "Output",
 CellChangeTimes->{
  3.73840240663183*^9, {3.738402723240535*^9, 3.738402733826964*^9}, 
   3.738409822907814*^9, 3.738476936137705*^9, 3.7449605399069767`*^9, 
   3.744960789845016*^9, 3.745014250858822*^9, 3.745017810153666*^9, 
   3.745122326046175*^9},ExpressionUUID->"db6f91d0-44f8-44af-975e-\
59c3325b0ab5"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", 
  StyleBox[
   RowBox[{"To", " ", "write", " ", "in", " ", "the", " ", "paper"}],
   FontColor->RGBColor[1, 0, 0]], "*)"}]], "Input",ExpressionUUID->"295b03de-\
3ed5-4a4f-8e30-5c72450358b6"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Pi1paper", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"m", " ", "resultPi1form1"}], "/.", "replace\[Rho]u"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[Nu]", "[", 
       RowBox[{"2", ",", "1"}], "]"}], "\[Rule]", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", "e"}], ")"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"5", "d"}], "+", "4", "-", 
           RowBox[{"e", 
            RowBox[{"(", 
             RowBox[{"d", "+", "8"}], ")"}]}]}], ")"}]}], 
        RowBox[{"8", "d"}]], "\[Nu]0"}]}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"Pi1paper", "-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "2"}], "\[Nu]q", " ", "\[Nu]0", " ", 
      RowBox[{"q", "[", 
       RowBox[{"{", "i1", "}"}], "]"}]}], ")"}]}], "/.", 
   RowBox[{"\[Nu]q", "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", "e"}], ")"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"5", "d"}], "+", "4", "-", 
        RowBox[{"e", 
         RowBox[{"(", 
          RowBox[{"d", "+", "8"}], ")"}]}]}], ")"}]}], 
     RowBox[{"8", "d"}]]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.7386590478810062`*^9, 3.738659067499036*^9}, {
  3.744960529841593*^9, 
  3.744960692857225*^9}},ExpressionUUID->"ea6a6086-c731-44d4-ab88-\
f3804cfe8192"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.738659068517996*^9, 3.738659175047983*^9, 3.738664018639947*^9, 
   3.7449605399797*^9, 3.7449605806587276`*^9, {3.744960667952683*^9, 
   3.744960694311408*^9}, 3.744960789885562*^9, 3.7450142509020443`*^9, 
   3.745017810188114*^9, 
   3.745122326090723*^9},ExpressionUUID->"328c1b31-cbf7-4b63-9a39-\
b8e6da6a1a08"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Production Term for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["C", "i"], 
    SubscriptBox["C", "j"], 
    SubscriptBox["C", "k"]}], TraditionalForm]],ExpressionUUID->
  "71175de9-9d50-42d6-b5fa-0a48079ff1a3"]
}], "Subsection",
 CellChangeTimes->{{3.540736884072311*^9, 3.5407369043909597`*^9}, {
  3.542452633864394*^9, 3.542452671646845*^9}, {3.737272427807934*^9, 
  3.737272430722102*^9}, {3.737273281718402*^9, 3.7372732969187727`*^9}, {
  3.7384017425560913`*^9, 3.73840174518649*^9}},
 TextAlignment->Center,
 FontColor->RGBColor[0.5, 0, 0.5],
 Background->RGBColor[
  1, 1, 0.85],ExpressionUUID->"2f0877ae-8327-4666-ad9a-20554d489859"],

Cell[BoxData[{
 RowBox[{"Clear", "[", 
  RowBox[{"w0", ",", "g"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"idx", "=", 
   RowBox[{"{", 
    RowBox[{"i1", ",", "i2", ",", "i3"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"nn", "=", 
    RowBox[{"Length", "[", "idx", "]"}]}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   StyleBox[
    RowBox[{
    "raw", " ", "form", " ", "of", " ", "integrand", " ", "without", " ", 
     "factor", " ", 
     FractionBox[
      RowBox[{"m", " ", "\[Nu]"}], 
      RowBox[{"n", " ", "\[CapitalOmega]d"}]], " ", "and", " ", "f", " ", 
     "f1", " ", "in", " ", "the", " ", "collision", " ", "integral"}],
    FontColor->RGBColor[1, 0.5, 0]], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Pijk0", "=", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"\[Beta]", "=", "1"}], "nn"], 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"\[Gamma]", "=", "0"}], 
       RowBox[{"\[Beta]", "/", "2"}]], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], "\[Beta]"], 
       SuperscriptBox["w0", "\[Beta]"], 
       RowBox[{"Binomial", "[", 
        RowBox[{"nn", ",", "\[Beta]"}], "]"}], 
       RowBox[{"Delta", "[", 
        RowBox[{
         RowBox[{"idx", "\[LeftDoubleBracket]", 
          RowBox[{"range", "[", 
           RowBox[{"1", ",", "\[Gamma]"}], "]"}], "\[RightDoubleBracket]"}], 
         ",", 
         RowBox[{"idx", "\[LeftDoubleBracket]", 
          RowBox[{"range", "[", 
           RowBox[{
            RowBox[{"\[Gamma]", "+", "1"}], ",", 
            RowBox[{"2", "\[Gamma]"}]}], "]"}], "\[RightDoubleBracket]"}]}], 
        "]"}], 
       RowBox[{"\[Alpha]", "[", 
        RowBox[{"\[Gamma]", ",", "\[Beta]"}], "]"}], 
       SuperscriptBox["g", 
        RowBox[{"2", "\[Gamma]"}]], 
       RowBox[{"gg", "[", 
        RowBox[{"idx", "\[LeftDoubleBracket]", 
         RowBox[{"range", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"2", "\[Gamma]"}], "+", "1"}], ",", "\[Beta]"}], "]"}], 
         "\[RightDoubleBracket]"}], "]"}], 
       RowBox[{"CC", "[", 
        RowBox[{"idx", "\[LeftDoubleBracket]", 
         RowBox[{"range", "[", 
          RowBox[{
           RowBox[{"\[Beta]", "+", "1"}], ",", "nn"}], "]"}], 
         "\[RightDoubleBracket]"}], "]"}]}]}]}]}], 
   RowBox[{"(*", 
    RowBox[{"f", " ", "f1"}], "*)"}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   StyleBox[
    RowBox[{"symmetrization", " ", "of", " ", "the", " ", "indices"}],
    FontColor->RGBColor[1, 0.5, 0]], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"perm", "=", 
   RowBox[{"Permutations", "[", "idx", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CollInt", "=", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{"CollInt", "+=", 
    RowBox[{"Pijk0", "/.", 
     RowBox[{"Thread", "[", 
      RowBox[{"idx", "\[Rule]", 
       RowBox[{
       "perm", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}]}], 
      "]"}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{"ii", ",", "1", ",", 
     RowBox[{"Length", "[", "perm", "]"}]}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CollIntegralPijk0", "=", 
    RowBox[{"ExpandAll", "[", 
     RowBox[{
      FractionBox["CollInt", 
       RowBox[{"Length", "[", "perm", "]"}]], "/.", "replace$gsq"}], "]"}]}], 
   ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   StyleBox[
    RowBox[{
     RowBox[{"main", " ", "working", " ", 
      RowBox[{"steps", ":", " ", 
       RowBox[{
        RowBox[{
        "1.", " ", "integrate", " ", "directions", " ", "in", " ", "h"}], "-",
         "vectors"}]}]}], ";", " ", 
     RowBox[{
      RowBox[{
      "2.", " ", "integrate", " ", "directions", " ", "in", " ", "g"}], "-", 
      "vectors"}], ";", " ", 
     RowBox[{
     "3.", " ", "integrate", " ", "Gauss", " ", "integrals", " ", "in", " ", 
      "h"}], ";", " ", 
     RowBox[{
     "4.", " ", "perform", " ", "contractions", " ", "on", " ", "\[Delta]"}]}],
    FontColor->RGBColor[1, 0.5, 0]], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g", "[", "idx_", "]"}], ":=", 
  RowBox[{
   RowBox[{"CC", "[", "idx", "]"}], "-", 
   RowBox[{"CC1", "[", "idx", "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CollIntegralPijk0", "=", 
    RowBox[{"Expand", "[", "CollIntegralPijk0", "]"}]}], ";"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   StyleBox[
    RowBox[{"Integration", " ", "over", " ", "C", " ", "and", " ", "C1"}],
    FontColor->RGBColor[1, 0.5, 0]], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"resultPijk0", "=", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Einstein", "[", 
         RowBox[{"intoverCC1", "[", 
          RowBox[{
          "CollIntegralPijk0", "\[LeftDoubleBracket]", "ii", 
           "\[RightDoubleBracket]"}], "]"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"ii", ",", "1", ",", 
          RowBox[{"Length", "[", "CollIntegralPijk0", "]"}]}], "}"}]}], 
       "]"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"list\[Rho]Pijk0", "=", 
   RowBox[{"DeleteDuplicates", "[", 
    RowBox[{"Extract", "[", 
     RowBox[{"resultPijk0", ",", 
      RowBox[{"Position", "[", 
       RowBox[{"resultPijk0", ",", 
        RowBox[{"\[Rho]", "[", 
         RowBox[{"_", ",", "_"}], "]"}]}], "]"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"replace\[Rho]Pijk0", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
      "list\[Rho]Pijk0", "\[LeftDoubleBracket]", "ii", 
       "\[RightDoubleBracket]"}], "\[Rule]", 
      RowBox[{"tracefreerepresentation", "[", 
       RowBox[{
       "list\[Rho]Pijk0", "\[LeftDoubleBracket]", "ii", 
        "\[RightDoubleBracket]"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"ii", ",", "1", ",", 
       RowBox[{"Length", "[", "list\[Rho]Pijk0", "]"}]}], "}"}]}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.537993578189455*^9, 3.537993610797545*^9}, {
   3.537993771670854*^9, 3.537993779038876*^9}, {3.5379938261036*^9, 
   3.537993894920753*^9}, 3.537993985202799*^9, {3.537994016572002*^9, 
   3.537994037555522*^9}, {3.537994388113123*^9, 3.5379944406823893`*^9}, {
   3.5379944716672297`*^9, 3.537994535484898*^9}, {3.5379946435344*^9, 
   3.537994670999247*^9}, {3.537994822992545*^9, 3.537994848706256*^9}, {
   3.537994948252141*^9, 3.5379951325767097`*^9}, {3.537995185554933*^9, 
   3.537995241802492*^9}, {3.537995276222849*^9, 3.537995281348686*^9}, {
   3.53799533558186*^9, 3.5379953402203913`*^9}, {3.537995373317173*^9, 
   3.537995389189156*^9}, {3.537995463503443*^9, 3.537995586335116*^9}, {
   3.537995620905704*^9, 3.537995685353702*^9}, {3.537995731882414*^9, 
   3.537995740818839*^9}, {3.53799608412899*^9, 3.537996120582891*^9}, {
   3.537996373868025*^9, 3.537996470581868*^9}, {3.537996552739531*^9, 
   3.537996599754401*^9}, {3.537996699014799*^9, 3.537996718444993*^9}, {
   3.5379967905373993`*^9, 3.537996835526949*^9}, {3.537996969586375*^9, 
   3.537997008865888*^9}, {3.537997054707327*^9, 3.5379970594661016`*^9}, {
   3.537997228824871*^9, 3.537997383715749*^9}, {3.537997495969655*^9, 
   3.537997504978291*^9}, {3.538049111849923*^9, 3.538049145198148*^9}, {
   3.538049184515108*^9, 3.538049258034523*^9}, {3.5380493781370897`*^9, 
   3.538049391682486*^9}, {3.538049424567073*^9, 3.538049487235387*^9}, {
   3.538049594582995*^9, 3.538049743296955*^9}, {3.538050939370043*^9, 
   3.5380509982737083`*^9}, {3.5380676731372538`*^9, 3.538067723150732*^9}, 
   3.53806785052652*^9, {3.538067941214231*^9, 3.538067990711932*^9}, {
   3.538068029462811*^9, 3.538068153307399*^9}, {3.53806855796034*^9, 
   3.538068627746333*^9}, {3.53806869188647*^9, 3.538068751511098*^9}, {
   3.538068919982791*^9, 3.538068952563477*^9}, {3.538120345641403*^9, 
   3.538120421155457*^9}, 3.538120780664413*^9, {3.538120852906658*^9, 
   3.538120953903056*^9}, {3.538121002642786*^9, 3.538121148063637*^9}, {
   3.538126353936679*^9, 3.538126386984695*^9}, {3.538126473001809*^9, 
   3.5381265005530252`*^9}, {3.538126537649548*^9, 3.538126555161577*^9}, {
   3.5381266439234133`*^9, 3.538126715750491*^9}, 3.538127882474265*^9, {
   3.538130944351671*^9, 3.538131077658307*^9}, {3.538131942442205*^9, 
   3.538132013760786*^9}, {3.538132283894219*^9, 3.538132360880001*^9}, {
   3.538133348588627*^9, 3.538133377632154*^9}, {3.53813341458228*^9, 
   3.538133595785343*^9}, {3.538133693428665*^9, 3.538133893912404*^9}, {
   3.538133930459076*^9, 3.538134125076247*^9}, {3.53813417768613*^9, 
   3.538134217260666*^9}, {3.538134259339695*^9, 3.538134264398603*^9}, {
   3.538137299532156*^9, 3.538137342311903*^9}, {3.538137430398448*^9, 
   3.538137473144889*^9}, {3.5381376929555693`*^9, 3.5381377022975807`*^9}, {
   3.5381379513516703`*^9, 3.538137995917336*^9}, {3.538138048946089*^9, 
   3.53813805994525*^9}, {3.538138121394474*^9, 3.5381381959580793`*^9}, {
   3.5381382502615757`*^9, 3.538138273902351*^9}, {3.5381383210109873`*^9, 
   3.538138336804418*^9}, 3.538138516977003*^9, {3.5381618433477077`*^9, 
   3.538161932597952*^9}, {3.538161987860311*^9, 3.5381620846113997`*^9}, {
   3.5381621539329453`*^9, 3.538162195795615*^9}, {3.538162226745761*^9, 
   3.538162260756913*^9}, {3.538162294790723*^9, 3.538162558108499*^9}, {
   3.5382004503666887`*^9, 3.538200516536386*^9}, {3.5382005504900503`*^9, 
   3.538200576308169*^9}, {3.538200918185061*^9, 3.5382009209833603`*^9}, 
   3.538200954918594*^9, {3.5382012679264*^9, 3.538201268242012*^9}, {
   3.5382013070166893`*^9, 3.538201311732603*^9}, 3.53820156656705*^9, {
   3.538201655677127*^9, 3.538201682767631*^9}, 3.538201919512535*^9, 
   3.538243145787212*^9, 3.53824318144276*^9, {3.538243282594778*^9, 
   3.5382432941723957`*^9}, {3.5382433354676323`*^9, 
   3.5382433373488293`*^9}, {3.538243583835874*^9, 3.538243588737722*^9}, {
   3.538244168454702*^9, 3.538244180740324*^9}, {3.538244332583802*^9, 
   3.538244339379407*^9}, 3.5382449465768633`*^9, {3.5388070078690643`*^9, 
   3.538807099973749*^9}, {3.538807180708592*^9, 3.5388071828035707`*^9}, 
   3.5388074844694977`*^9, {3.538807551230954*^9, 3.538807553504488*^9}, {
   3.538808873941285*^9, 3.538808875477491*^9}, {3.538808927009503*^9, 
   3.5388089304970512`*^9}, {3.538808998699823*^9, 3.538809020477653*^9}, {
   3.538809124555171*^9, 3.538809131039702*^9}, 3.538809175971305*^9, {
   3.538809338238731*^9, 3.5388093394879303`*^9}, 3.5388093971728573`*^9, {
   3.53881066031894*^9, 3.538810687713526*^9}, 3.538810748528813*^9, {
   3.5388107917831078`*^9, 3.538810794089106*^9}, {3.538811661821177*^9, 
   3.538811724776244*^9}, 3.538817331517233*^9, {3.5388192046322308`*^9, 
   3.538819214494584*^9}, {3.5392665470358353`*^9, 3.5392665745099287`*^9}, {
   3.539266610562613*^9, 3.539266615983183*^9}, {3.5392666830721903`*^9, 
   3.539266815780409*^9}, 3.539266848624251*^9, 3.539266890598507*^9, {
   3.539267060053648*^9, 3.539267072703176*^9}, 3.5392677537069807`*^9, 
   3.539267788390932*^9, {3.539268495010467*^9, 3.539268496663838*^9}, 
   3.539269140585288*^9, 3.539269235639429*^9, {3.539269355353408*^9, 
   3.539269383630211*^9}, {3.539269638969858*^9, 3.539269750991323*^9}, {
   3.53926979106437*^9, 3.539269810113697*^9}, {3.5392701517950487`*^9, 
   3.5392701920043097`*^9}, 3.539278908980487*^9, 3.539278996527172*^9, {
   3.539326343054734*^9, 3.539326435401582*^9}, {3.539326569957453*^9, 
   3.539326575804747*^9}, {3.539326991237306*^9, 3.5393270082806168`*^9}, {
   3.539329433774241*^9, 3.5393294960187607`*^9}, {3.5393305017074823`*^9, 
   3.539330556642144*^9}, 3.539330888641615*^9, {3.539339971597237*^9, 
   3.5393399876891327`*^9}, {3.5393400782346582`*^9, 3.539340081023357*^9}, {
   3.5393401448438396`*^9, 3.539340145504077*^9}, {3.539347774329233*^9, 
   3.539347843122929*^9}, 3.539366432292687*^9, {3.539367245443975*^9, 
   3.539367246347004*^9}, {3.540734202771955*^9, 3.5407342043103733`*^9}, {
   3.540736418761684*^9, 3.5407364226194553`*^9}, {3.540737768596367*^9, 
   3.540737768892754*^9}, {3.542388724376953*^9, 3.542388781889929*^9}, {
   3.542388924988758*^9, 3.542388987923122*^9}, {3.5423890458105783`*^9, 
   3.542389193224463*^9}, {3.542389272963728*^9, 3.54238930706011*^9}, {
   3.542437641275167*^9, 3.542437699202085*^9}, {3.542437730796095*^9, 
   3.5424378902358*^9}, 3.542437945897581*^9, {3.5424379882249823`*^9, 
   3.5424380665457783`*^9}, 3.5424381121082697`*^9, {3.542438249182868*^9, 
   3.5424382662648687`*^9}, 3.542438305697894*^9, {3.542439075760028*^9, 
   3.5424390838844147`*^9}, {3.542439173737357*^9, 3.542439220087296*^9}, {
   3.542443352398711*^9, 3.542443381775426*^9}, {3.542443447124556*^9, 
   3.542443480430725*^9}, {3.542443613406389*^9, 3.542443649481735*^9}, 
   3.542443699901371*^9, {3.5424462578396807`*^9, 3.542446274257043*^9}, {
   3.542446401017707*^9, 3.542446413600088*^9}, {3.5424464659327908`*^9, 
   3.5424464878337793`*^9}, {3.5424465291804132`*^9, 3.5424465329099913`*^9}, 
   3.542446742755765*^9, {3.542446778102816*^9, 3.542446785282056*^9}, {
   3.542446834089986*^9, 3.542446884468789*^9}, {3.542446919291979*^9, 
   3.542446939944065*^9}, {3.542446976270124*^9, 3.5424469866004257`*^9}, {
   3.542447056705858*^9, 3.5424470898445673`*^9}, {3.5424471344029417`*^9, 
   3.542447174506599*^9}, {3.5424472312410507`*^9, 3.54244726772272*^9}, {
   3.5424473125427227`*^9, 3.5424473254819317`*^9}, {3.5424473695330887`*^9, 
   3.542447388671294*^9}, 3.542448224058323*^9, {3.542451548746708*^9, 
   3.5424515774216213`*^9}, {3.5424519211077013`*^9, 3.542451928153799*^9}, {
   3.54245299950036*^9, 3.542453001194194*^9}, {3.542455811416429*^9, 
   3.542455815394039*^9}, {3.542622812244008*^9, 3.542622822000717*^9}, {
   3.542622859825048*^9, 3.542622931786152*^9}, {3.54269829979911*^9, 
   3.542698305254208*^9}, {3.542699025561718*^9, 3.542699026123849*^9}, {
   3.5426990707182913`*^9, 3.542699088670185*^9}, {3.542700118933394*^9, 
   3.542700121036415*^9}, 3.542700827765305*^9, {3.5429174051788473`*^9, 
   3.542917524367551*^9}, 3.5429176869021387`*^9, {3.542969166437325*^9, 
   3.542969172344721*^9}, {3.548190436221043*^9, 3.548190445993956*^9}, 
   3.548190491401569*^9, {3.548190752747745*^9, 3.548190753292897*^9}, {
   3.54901721401657*^9, 3.549017214311965*^9}, {3.549017247695644*^9, 
   3.5490173217517653`*^9}, {3.5490175863059607`*^9, 3.549017586840351*^9}, {
   3.64364096822392*^9, 3.643640983650118*^9}, 3.643641025520862*^9, {
   3.6436415353816833`*^9, 3.643641602069047*^9}, {3.643641636036574*^9, 
   3.643641702536974*^9}, 3.643641788051527*^9, {3.6436418353044577`*^9, 
   3.643641843368132*^9}, {3.678793251829185*^9, 3.678793285790352*^9}, 
   3.6787994439458447`*^9, {3.678862755048066*^9, 3.6788627561980753`*^9}, 
   3.678865112211464*^9, {3.681391437897203*^9, 3.681391452879457*^9}, {
   3.737108210053956*^9, 3.737108249563664*^9}, {3.7371084042540083`*^9, 
   3.7371084083262463`*^9}, 3.737109292446753*^9, {3.737109749523717*^9, 
   3.737109805554154*^9}, {3.737110028644668*^9, 3.737110070179446*^9}, {
   3.737110150417325*^9, 3.737110151300057*^9}, 3.737110382136352*^9, {
   3.737110458359399*^9, 3.737110460309579*^9}, {3.737110702040637*^9, 
   3.737110703878584*^9}, {3.7371117587819138`*^9, 3.73711177306219*^9}, {
   3.737113682711214*^9, 3.7371136853064327`*^9}, {3.7371138793370953`*^9, 
   3.737113881349288*^9}, {3.73718694545557*^9, 3.737186984864314*^9}, {
   3.737187015838509*^9, 3.7371870332629213`*^9}, {3.737187072238668*^9, 
   3.7371870800135736`*^9}, {3.737189762748537*^9, 3.737189763128755*^9}, {
   3.737189800186709*^9, 3.737189804667068*^9}, {3.7371898409234247`*^9, 
   3.737189845354582*^9}, 3.737190240046109*^9, {3.7371903718842573`*^9, 
   3.737190380979869*^9}, {3.737191435152549*^9, 3.737191467949527*^9}, {
   3.737191521249221*^9, 3.73719156092738*^9}, {3.737191766050044*^9, 
   3.7371917689123497`*^9}, 3.737197927456336*^9, {3.737198159489818*^9, 
   3.737198159886495*^9}, {3.737200386075508*^9, 3.7372003868555098`*^9}, {
   3.737264960908597*^9, 3.7372649614648647`*^9}, 3.7372710196476183`*^9, {
   3.737271124669427*^9, 3.737271139070385*^9}, {3.737271449376149*^9, 
   3.737271450701746*^9}, {3.737272473365141*^9, 3.737272503208777*^9}, {
   3.7372725472818527`*^9, 3.737272573132128*^9}, {3.737272872657456*^9, 
   3.737272875955984*^9}, {3.73727330346493*^9, 3.737273333526195*^9}, {
   3.737273441415806*^9, 3.73727346055801*^9}, {3.738396788506775*^9, 
   3.738396792615591*^9}, {3.738396838807775*^9, 3.738396881515554*^9}, {
   3.738397086236014*^9, 3.738397096880761*^9}, {3.738401749460299*^9, 
   3.738401774943083*^9}},ExpressionUUID->"d02a4fb9-2698-4016-b447-\
a3aca71071f0"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"factor", "=", 
    RowBox[{"(*", "m", "*)"}], 
    FractionBox["\[Nu]", 
     RowBox[{"n", " ", "\[CapitalOmega]d"}]]}], ";"}], "\[IndentingNewLine]", 
  
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"resultPijk0form1", "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"FullSimplify", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"factor", " ", "resultPijk0"}], "/.", 
            "replace\[Rho]Pijk0"}], "/.", "replace\[Alpha]"}], "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"\[Nu]", "\[Rule]", 
             RowBox[{
              FractionBox[
               RowBox[{"d", "+", "2"}], "2"], "\[Nu]0"}]}], ",", 
            RowBox[{"w0", "\[Rule]", 
             FractionBox[
              RowBox[{"1", "+", "e"}], "2"]}]}], "}"}]}], "]"}], "/.", 
        RowBox[{"{", 
         RowBox[{"\[Nu]0", "\[Rule]", 
          RowBox[{
           FractionBox[
            RowBox[{"2", "d"}], 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "+", "e"}], ")"}], 
             RowBox[{"(", 
              RowBox[{"d", "+", "1", "-", "e"}], ")"}]}]], 
           RowBox[{"\[Nu]", "[", 
            RowBox[{"0", ",", "2"}], "]"}]}]}], "}"}]}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\[Nu]", "[", 
          RowBox[{"0", ",", "2"}], "]"}], "\[Rule]", 
         RowBox[{
          FractionBox["2", "3"], 
          RowBox[{"\[Nu]", "[", 
           RowBox[{"0", ",", "3"}], "]"}]}]}], "}"}]}], "]"}]}], ";"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"resultPijk0form1", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"factor", " ", "resultPijk0"}], "/.", 
          "replace\[Rho]Pijk0"}], "/.", "replace\[Alpha]"}], "/.", 
        "gammareplacements"}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\[Nu]", "\[Rule]", 
          RowBox[{
           FractionBox[
            RowBox[{"d", "+", "2"}], "2"], "\[Nu]0"}]}], ",", 
         RowBox[{"w0", "\[Rule]", 
          FractionBox[
           RowBox[{"1", "+", "e"}], "2"]}]}], "}"}]}], "/.", 
      RowBox[{"{", 
       RowBox[{"\[Nu]0", "\[Rule]", 
        RowBox[{
         FractionBox[
          RowBox[{"2", "d"}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", "e"}], ")"}], 
           RowBox[{"(", 
            RowBox[{"d", "+", "1", "-", "e"}], ")"}]}]], 
         RowBox[{"\[Nu]", "[", 
          RowBox[{"0", ",", "2"}], "]"}]}]}], "}"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Nu]", "[", 
        RowBox[{"0", ",", "2"}], "]"}], "\[Rule]", 
       RowBox[{
        FractionBox["2", "3"], 
        RowBox[{"\[Nu]", "[", 
         RowBox[{"0", ",", "3"}], "]"}]}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.737272917319312*^9, 3.737272919047133*^9}, {
   3.73727297093484*^9, 3.73727298523519*^9}, {3.737273051179839*^9, 
   3.737273105514578*^9}, {3.737273137272187*^9, 3.737273225397573*^9}, 
   3.7372734650377493`*^9, 3.7372736090084267`*^9, {3.737273660475463*^9, 
   3.737273777624713*^9}, 3.738395699297328*^9, {3.7383960772383204`*^9, 
   3.738396078243876*^9}, {3.738396678794359*^9, 3.738396711670636*^9}, {
   3.738396763385541*^9, 3.738396783144718*^9}, {3.7383968961843367`*^9, 
   3.738396900581313*^9}, {3.738401908839529*^9, 3.7384019088444757`*^9}, 
   3.73840197000576*^9, {3.7384020287743187`*^9, 3.738402054020152*^9}, {
   3.738409846609623*^9, 
   3.7384099103874903`*^9}},ExpressionUUID->"63d494fa-f8ad-4bc0-a389-\
b02a5d2b1100"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   StyleBox[
    RowBox[{
     RowBox[{"Eq", ".", " ", 
      SubscriptBox[
       RowBox[{"(", "2.20", ")"}], "2"]}], " ", "of", " ", "Garz\[OAcute]", 
     " ", "and", " ", "Santos", " ", "2007", " ", 
     RowBox[{"J", ".", " ", "Phys", ".", " ", 
      RowBox[{"A", ":", " ", 
       RowBox[{
        RowBox[{"Math", ".", " ", "Theor", ".", " ", 
         StyleBox["40",
          FontWeight->"Bold"]}], " ", "14927"}]}]}]}],
    FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{"resultPijk0form1", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Rho]", "[", 
         RowBox[{"n_", ",", "li_"}], "]"}], "\[Rule]", 
        RowBox[{"m", " ", 
         RowBox[{"M", "[", 
          RowBox[{
           RowBox[{"2", "n"}], ",", "li"}], "]"}]}]}], ",", 
       RowBox[{
        RowBox[{"\[Upsilon]", "[", 
         RowBox[{"n_", ",", "li_"}], "]"}], "\[Rule]", 
        RowBox[{"m", " ", 
         RowBox[{"M", "[", 
          RowBox[{
           RowBox[{"2", "n"}], ",", "li"}], "]"}]}]}]}], "}"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"M", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"i1", ",", "i2", ",", "i3"}], "}"}]}], "]"}], "}"}], ",", 
    "Simplify"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7383954198929977`*^9, 3.738395424674985*^9}, {
   3.738395505793868*^9, 3.738395508613287*^9}, {3.7383955414619293`*^9, 
   3.738395555856544*^9}, {3.738395587057211*^9, 3.7383956011687737`*^9}, {
   3.738397306746271*^9, 3.738397407307046*^9}, 3.7383974728312073`*^9, 
   3.7384019088503523`*^9, {3.738402075667809*^9, 3.7384021822473383`*^9}, {
   3.738402221796605*^9, 3.7384022477042303`*^9}, {3.738402391753244*^9, 
   3.7384023975098352`*^9}, 3.738476996318331*^9, {3.738477189084216*^9, 
   3.7384771921699257`*^9}},ExpressionUUID->"903b6a62-552f-481c-a091-\
b806935eb21e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    RowBox[{"M", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", 
       RowBox[{"i1", ",", "i2", ",", "i3"}], "}"}]}], "]"}]}], " ", 
   RowBox[{"\[Nu]", "[", 
    RowBox[{"0", ",", "3"}], "]"}]}], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "4"}], "+", 
      RowBox[{"d", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "5"}], "+", "e"}], ")"}]}], "+", 
      RowBox[{"8", " ", "e"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"M", "[", 
        RowBox[{"2", ",", 
         RowBox[{"{", "i3", "}"}]}], "]"}], " ", 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"i1", ",", "i2"}], "}"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"M", "[", 
        RowBox[{"2", ",", 
         RowBox[{"{", "i2", "}"}]}], "]"}], " ", 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"i1", ",", "i3"}], "}"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"M", "[", 
        RowBox[{"2", ",", 
         RowBox[{"{", "i1", "}"}]}], "]"}], " ", 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"i2", ",", "i3"}], "}"}], "]"}]}]}], ")"}], " ", 
    RowBox[{"\[Nu]", "[", 
     RowBox[{"0", ",", "3"}], "]"}]}], 
   RowBox[{"6", " ", 
    RowBox[{"(", 
     RowBox[{"2", "+", "d"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "d", "-", "e"}], ")"}]}]]}]], "Output",
 CellChangeTimes->{3.738476999032482*^9, 3.744960807920513*^9, 
  3.7450142510526114`*^9, 3.745017810325251*^9, 
  3.7451223262393637`*^9},ExpressionUUID->"c21ecca2-7cfe-410a-932a-\
fb8983c8d8d3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   StyleBox[
    RowBox[{
     RowBox[{"Eq", ".", " ", 
      SubscriptBox[
       RowBox[{"(", "2.20", ")"}], "2"]}], " ", "of", " ", "Garz\[OAcute]", 
     " ", "and", " ", "Santos", " ", "2007", " ", 
     RowBox[{"J", ".", " ", "Phys", ".", " ", 
      RowBox[{"A", ":", " ", 
       RowBox[{
        RowBox[{"Math", ".", " ", "Theor", ".", " ", 
         StyleBox["40",
          FontWeight->"Bold"]}], " ", "14927"}]}]}]}],
    FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"resultPijk0form1", "-", 
       RowBox[{
        FractionBox["1", 
         RowBox[{"d", "+", "2"}]], "3", " ", 
        RowBox[{"sym", "[", 
         RowBox[{"resultPi1form1", " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i2", ",", "i3"}], "}"}], "]"}]}], "]"}]}]}], ")"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Rho]", "[", 
         RowBox[{"n_", ",", "li_"}], "]"}], "\[Rule]", 
        RowBox[{"m", " ", 
         RowBox[{"M", "[", 
          RowBox[{
           RowBox[{"2", "n"}], ",", "li"}], "]"}]}]}], ",", 
       RowBox[{
        RowBox[{"\[Upsilon]", "[", 
         RowBox[{"n_", ",", "li_"}], "]"}], "\[Rule]", 
        RowBox[{"m", " ", 
         RowBox[{"M", "[", 
          RowBox[{
           RowBox[{"2", "n"}], ",", "li"}], "]"}]}]}]}], "}"}]}], "/.", 
    RowBox[{
     RowBox[{"\[Nu]", "[", 
      RowBox[{"2", ",", "1"}], "]"}], "\[Rule]", 
     RowBox[{
      FractionBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"5", "d"}], "+", "4", "-", 
         RowBox[{"e", 
          RowBox[{"(", 
           RowBox[{"d", "+", "8"}], ")"}]}]}], ")"}], 
       RowBox[{"6", 
        RowBox[{"(", 
         RowBox[{"d", "+", "1", "-", "e"}], ")"}]}]], 
      RowBox[{"\[Nu]", "[", 
       RowBox[{"0", ",", "3"}], "]"}]}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.738477231978531*^9, 3.7384772396425943`*^9}, {
  3.738477372012148*^9, 3.738477380460511*^9}, {3.7384774317951813`*^9, 
  3.738477454978406*^9}, {3.738477567745249*^9, 
  3.738477638544319*^9}},ExpressionUUID->"e14d08c5-b4de-4799-9904-\
95d053cbfbf8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{"M", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", 
      RowBox[{"i1", ",", "i2", ",", "i3"}], "}"}]}], "]"}]}], " ", 
  RowBox[{"\[Nu]", "[", 
   RowBox[{"0", ",", "3"}], "]"}]}]], "Output",
 CellChangeTimes->{{3.7384774356392517`*^9, 3.738477455532263*^9}, {
   3.738477618156156*^9, 3.738477640275126*^9}, 3.744960807953198*^9, 
   3.745014251085931*^9, 3.7450178103493137`*^9, 
   3.745122326265389*^9},ExpressionUUID->"72e4ff64-7428-4057-9b05-\
29e1dea1eb93"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   StyleBox[
    RowBox[{"To", " ", "write", " ", "in", " ", "the", " ", "paper"}],
    FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Pijk0paper", "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"m", " ", "resultPijk0form1"}], "/.", "replace\[Rho]u"}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Nu]", "[", 
           RowBox[{"0", ",", "3"}], "]"}], "\[Rule]", 
          RowBox[{
           FractionBox[
            RowBox[{"6", 
             RowBox[{"(", 
              RowBox[{"d", "+", "1", "-", "e"}], ")"}]}], 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"5", "d"}], "+", "4", "-", 
              RowBox[{"e", 
               RowBox[{"(", 
                RowBox[{"d", "+", "8"}], ")"}]}]}], ")"}]], 
           RowBox[{"\[Nu]", "[", 
            RowBox[{"2", ",", "1"}], "]"}]}]}], "}"}]}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\[Nu]", "[", 
          RowBox[{"2", ",", "1"}], "]"}], "\[Rule]", 
         RowBox[{
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", "e"}], ")"}], 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"5", "d"}], "+", "4", "-", 
              RowBox[{"e", 
               RowBox[{"(", 
                RowBox[{"d", "+", "8"}], ")"}]}]}], ")"}]}], 
           RowBox[{"8", "d"}]], "\[Nu]0"}]}], "}"}]}], "/.", 
      RowBox[{
       RowBox[{"\[Delta]", "[", "_", "]"}], "\[Rule]", "0"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"Pijk0paper", "-", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "\[Nu]m"}], " ", "\[Nu]0", " ", 
        RowBox[{"m", "[", 
         RowBox[{"{", 
          RowBox[{"i1", ",", "i2", ",", "i3"}], "}"}], "]"}]}], ")"}]}], "/.", 
     RowBox[{"\[Nu]m", "\[Rule]", 
      FractionBox[
       RowBox[{"3", 
        RowBox[{"(", 
         RowBox[{"1", "+", "e"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"d", "+", "1", "-", "e"}], ")"}]}], 
       RowBox[{"4", "d"}]]}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.738664044507187*^9, 3.738664094846385*^9}, {
   3.7386641499511003`*^9, 3.7386641511992083`*^9}, {3.7386642626241627`*^9, 
   3.738664262860812*^9}, {3.738664299485209*^9, 3.738664325373002*^9}, {
   3.7386643675167*^9, 3.738664379534623*^9}, 3.738666621393475*^9, 
   3.738666662570964*^9, {3.744961021737647*^9, 
   3.744961030178007*^9}},ExpressionUUID->"a75ba929-6fa8-4f91-b52a-\
816a8b2d1c37"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.744961035074525*^9, 3.745014251119389*^9, 
  3.7450178103808527`*^9, 
  3.7451223263069553`*^9},ExpressionUUID->"6826b9bb-7278-4e90-bf0f-\
198e538621ec"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Production Term for ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["C", "4"], TraditionalForm]],ExpressionUUID->
  "0df94722-156d-409a-aed5-cb0eae14d56b"]
}], "Subsection",
 CellChangeTimes->{{3.540736884072311*^9, 3.5407369043909597`*^9}, {
  3.542452633864394*^9, 3.542452671646845*^9}, {3.737272427807934*^9, 
  3.737272430722102*^9}, {3.737273281718402*^9, 3.7372732969187727`*^9}, {
  3.7384017425560913`*^9, 3.73840174518649*^9}, {3.738402807640226*^9, 
  3.738402810504265*^9}, {3.738403527084269*^9, 3.7384035371509523`*^9}},
 TextAlignment->Center,
 FontColor->RGBColor[0.5, 0, 0.5],
 Background->RGBColor[
  1, 1, 0.85],ExpressionUUID->"51ac4468-d9d6-4380-bdcf-2e163646c95e"],

Cell[BoxData[{
 RowBox[{"Clear", "[", 
  RowBox[{"w0", ",", "g"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"idx", "=", 
   RowBox[{"{", 
    RowBox[{"i1", ",", "i2", ",", "i3", ",", "i4"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"nn", "=", 
    RowBox[{"Length", "[", "idx", "]"}]}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   StyleBox[
    RowBox[{
    "raw", " ", "form", " ", "of", " ", "integrand", " ", "without", " ", 
     "factor", " ", 
     FractionBox[
      RowBox[{"m", " ", "\[Nu]"}], 
      RowBox[{"n", " ", "\[CapitalOmega]d"}]], " ", "and", " ", "f", " ", 
     "f1", " ", "in", " ", "the", " ", "collision", " ", "integral"}],
    FontColor->RGBColor[1, 0.5, 0]], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"P2", "=", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"\[Beta]", "=", "1"}], "nn"], 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"\[Gamma]", "=", "0"}], 
       RowBox[{"\[Beta]", "/", "2"}]], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], "\[Beta]"], 
       SuperscriptBox["w0", "\[Beta]"], 
       RowBox[{"Binomial", "[", 
        RowBox[{"nn", ",", "\[Beta]"}], "]"}], 
       RowBox[{"Delta", "[", 
        RowBox[{
         RowBox[{"idx", "\[LeftDoubleBracket]", 
          RowBox[{"range", "[", 
           RowBox[{"1", ",", "\[Gamma]"}], "]"}], "\[RightDoubleBracket]"}], 
         ",", 
         RowBox[{"idx", "\[LeftDoubleBracket]", 
          RowBox[{"range", "[", 
           RowBox[{
            RowBox[{"\[Gamma]", "+", "1"}], ",", 
            RowBox[{"2", "\[Gamma]"}]}], "]"}], "\[RightDoubleBracket]"}]}], 
        "]"}], 
       RowBox[{"\[Alpha]", "[", 
        RowBox[{"\[Gamma]", ",", "\[Beta]"}], "]"}], 
       SuperscriptBox["g", 
        RowBox[{"2", "\[Gamma]"}]], 
       RowBox[{"gg", "[", 
        RowBox[{"idx", "\[LeftDoubleBracket]", 
         RowBox[{"range", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"2", "\[Gamma]"}], "+", "1"}], ",", "\[Beta]"}], "]"}], 
         "\[RightDoubleBracket]"}], "]"}], 
       RowBox[{"CC", "[", 
        RowBox[{"idx", "\[LeftDoubleBracket]", 
         RowBox[{"range", "[", 
          RowBox[{
           RowBox[{"\[Beta]", "+", "1"}], ",", "nn"}], "]"}], 
         "\[RightDoubleBracket]"}], "]"}]}]}]}]}], 
   RowBox[{"(*", 
    RowBox[{"f", " ", "f1"}], "*)"}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   StyleBox[
    RowBox[{"symmetrization", " ", "of", " ", "the", " ", "indices"}],
    FontColor->RGBColor[1, 0.5, 0]], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"perm", "=", 
   RowBox[{
    RowBox[{"Permutations", "[", "idx", "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"i4", "\[Rule]", "i3"}], ",", 
      RowBox[{"i2", "\[Rule]", "i1"}]}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CollInt", "=", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{"CollInt", "+=", 
    RowBox[{"P2", "/.", 
     RowBox[{"Thread", "[", 
      RowBox[{"idx", "\[Rule]", 
       RowBox[{
       "perm", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}]}], 
      "]"}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{"ii", ",", "1", ",", 
     RowBox[{"Length", "[", "perm", "]"}]}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CollIntegralP2", "=", 
    RowBox[{"ExpandAll", "[", 
     RowBox[{
      FractionBox["CollInt", 
       RowBox[{"Length", "[", "perm", "]"}]], "/.", "replace$gsq"}], "]"}]}], 
   ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   StyleBox[
    RowBox[{
     RowBox[{"main", " ", "working", " ", 
      RowBox[{"steps", ":", " ", 
       RowBox[{
        RowBox[{
        "1.", " ", "integrate", " ", "directions", " ", "in", " ", "h"}], "-",
         "vectors"}]}]}], ";", " ", 
     RowBox[{
      RowBox[{
      "2.", " ", "integrate", " ", "directions", " ", "in", " ", "g"}], "-", 
      "vectors"}], ";", " ", 
     RowBox[{
     "3.", " ", "integrate", " ", "Gauss", " ", "integrals", " ", "in", " ", 
      "h"}], ";", " ", 
     RowBox[{
     "4.", " ", "perform", " ", "contractions", " ", "on", " ", "\[Delta]"}]}],
    FontColor->RGBColor[1, 0.5, 0]], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g", "[", "idx_", "]"}], ":=", 
  RowBox[{
   RowBox[{"CC", "[", "idx", "]"}], "-", 
   RowBox[{"CC1", "[", "idx", "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CollIntegralP2", "=", 
    RowBox[{"Expand", "[", "CollIntegralP2", "]"}]}], ";"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   StyleBox[
    RowBox[{"Integration", " ", "over", " ", "C", " ", "and", " ", "C1"}],
    FontColor->RGBColor[1, 0.5, 0]], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"resultP2", "=", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Einstein", "[", 
         RowBox[{"intoverCC1", "[", 
          RowBox[{
          "CollIntegralP2", "\[LeftDoubleBracket]", "ii", 
           "\[RightDoubleBracket]"}], "]"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"ii", ",", "1", ",", 
          RowBox[{"Length", "[", "CollIntegralP2", "]"}]}], "}"}]}], "]"}]}], 
     "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"list\[Rho]P2", "=", 
   RowBox[{"DeleteDuplicates", "[", 
    RowBox[{"Extract", "[", 
     RowBox[{"resultP2", ",", 
      RowBox[{"Position", "[", 
       RowBox[{"resultP2", ",", 
        RowBox[{"\[Rho]", "[", 
         RowBox[{"_", ",", "_"}], "]"}]}], "]"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"replace\[Rho]P2", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
      "list\[Rho]P2", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}],
       "\[Rule]", 
      RowBox[{"tracefreerepresentation", "[", 
       RowBox[{
       "list\[Rho]P2", "\[LeftDoubleBracket]", "ii", 
        "\[RightDoubleBracket]"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"ii", ",", "1", ",", 
       RowBox[{"Length", "[", "list\[Rho]P2", "]"}]}], "}"}]}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.537993578189455*^9, 3.537993610797545*^9}, {
   3.537993771670854*^9, 3.537993779038876*^9}, {3.5379938261036*^9, 
   3.537993894920753*^9}, 3.537993985202799*^9, {3.537994016572002*^9, 
   3.537994037555522*^9}, {3.537994388113123*^9, 3.5379944406823893`*^9}, {
   3.5379944716672297`*^9, 3.537994535484898*^9}, {3.5379946435344*^9, 
   3.537994670999247*^9}, {3.537994822992545*^9, 3.537994848706256*^9}, {
   3.537994948252141*^9, 3.5379951325767097`*^9}, {3.537995185554933*^9, 
   3.537995241802492*^9}, {3.537995276222849*^9, 3.537995281348686*^9}, {
   3.53799533558186*^9, 3.5379953402203913`*^9}, {3.537995373317173*^9, 
   3.537995389189156*^9}, {3.537995463503443*^9, 3.537995586335116*^9}, {
   3.537995620905704*^9, 3.537995685353702*^9}, {3.537995731882414*^9, 
   3.537995740818839*^9}, {3.53799608412899*^9, 3.537996120582891*^9}, {
   3.537996373868025*^9, 3.537996470581868*^9}, {3.537996552739531*^9, 
   3.537996599754401*^9}, {3.537996699014799*^9, 3.537996718444993*^9}, {
   3.5379967905373993`*^9, 3.537996835526949*^9}, {3.537996969586375*^9, 
   3.537997008865888*^9}, {3.537997054707327*^9, 3.5379970594661016`*^9}, {
   3.537997228824871*^9, 3.537997383715749*^9}, {3.537997495969655*^9, 
   3.537997504978291*^9}, {3.538049111849923*^9, 3.538049145198148*^9}, {
   3.538049184515108*^9, 3.538049258034523*^9}, {3.5380493781370897`*^9, 
   3.538049391682486*^9}, {3.538049424567073*^9, 3.538049487235387*^9}, {
   3.538049594582995*^9, 3.538049743296955*^9}, {3.538050939370043*^9, 
   3.5380509982737083`*^9}, {3.5380676731372538`*^9, 3.538067723150732*^9}, 
   3.53806785052652*^9, {3.538067941214231*^9, 3.538067990711932*^9}, {
   3.538068029462811*^9, 3.538068153307399*^9}, {3.53806855796034*^9, 
   3.538068627746333*^9}, {3.53806869188647*^9, 3.538068751511098*^9}, {
   3.538068919982791*^9, 3.538068952563477*^9}, {3.538120345641403*^9, 
   3.538120421155457*^9}, 3.538120780664413*^9, {3.538120852906658*^9, 
   3.538120953903056*^9}, {3.538121002642786*^9, 3.538121148063637*^9}, {
   3.538126353936679*^9, 3.538126386984695*^9}, {3.538126473001809*^9, 
   3.5381265005530252`*^9}, {3.538126537649548*^9, 3.538126555161577*^9}, {
   3.5381266439234133`*^9, 3.538126715750491*^9}, 3.538127882474265*^9, {
   3.538130944351671*^9, 3.538131077658307*^9}, {3.538131942442205*^9, 
   3.538132013760786*^9}, {3.538132283894219*^9, 3.538132360880001*^9}, {
   3.538133348588627*^9, 3.538133377632154*^9}, {3.53813341458228*^9, 
   3.538133595785343*^9}, {3.538133693428665*^9, 3.538133893912404*^9}, {
   3.538133930459076*^9, 3.538134125076247*^9}, {3.53813417768613*^9, 
   3.538134217260666*^9}, {3.538134259339695*^9, 3.538134264398603*^9}, {
   3.538137299532156*^9, 3.538137342311903*^9}, {3.538137430398448*^9, 
   3.538137473144889*^9}, {3.5381376929555693`*^9, 3.5381377022975807`*^9}, {
   3.5381379513516703`*^9, 3.538137995917336*^9}, {3.538138048946089*^9, 
   3.53813805994525*^9}, {3.538138121394474*^9, 3.5381381959580793`*^9}, {
   3.5381382502615757`*^9, 3.538138273902351*^9}, {3.5381383210109873`*^9, 
   3.538138336804418*^9}, 3.538138516977003*^9, {3.5381618433477077`*^9, 
   3.538161932597952*^9}, {3.538161987860311*^9, 3.5381620846113997`*^9}, {
   3.5381621539329453`*^9, 3.538162195795615*^9}, {3.538162226745761*^9, 
   3.538162260756913*^9}, {3.538162294790723*^9, 3.538162558108499*^9}, {
   3.5382004503666887`*^9, 3.538200516536386*^9}, {3.5382005504900503`*^9, 
   3.538200576308169*^9}, {3.538200918185061*^9, 3.5382009209833603`*^9}, 
   3.538200954918594*^9, {3.5382012679264*^9, 3.538201268242012*^9}, {
   3.5382013070166893`*^9, 3.538201311732603*^9}, 3.53820156656705*^9, {
   3.538201655677127*^9, 3.538201682767631*^9}, 3.538201919512535*^9, 
   3.538243145787212*^9, 3.53824318144276*^9, {3.538243282594778*^9, 
   3.5382432941723957`*^9}, {3.5382433354676323`*^9, 
   3.5382433373488293`*^9}, {3.538243583835874*^9, 3.538243588737722*^9}, {
   3.538244168454702*^9, 3.538244180740324*^9}, {3.538244332583802*^9, 
   3.538244339379407*^9}, 3.5382449465768633`*^9, {3.5388070078690643`*^9, 
   3.538807099973749*^9}, {3.538807180708592*^9, 3.5388071828035707`*^9}, 
   3.5388074844694977`*^9, {3.538807551230954*^9, 3.538807553504488*^9}, {
   3.538808873941285*^9, 3.538808875477491*^9}, {3.538808927009503*^9, 
   3.5388089304970512`*^9}, {3.538808998699823*^9, 3.538809020477653*^9}, {
   3.538809124555171*^9, 3.538809131039702*^9}, 3.538809175971305*^9, {
   3.538809338238731*^9, 3.5388093394879303`*^9}, 3.5388093971728573`*^9, {
   3.53881066031894*^9, 3.538810687713526*^9}, 3.538810748528813*^9, {
   3.5388107917831078`*^9, 3.538810794089106*^9}, {3.538811661821177*^9, 
   3.538811724776244*^9}, 3.538817331517233*^9, {3.5388192046322308`*^9, 
   3.538819214494584*^9}, {3.5392665470358353`*^9, 3.5392665745099287`*^9}, {
   3.539266610562613*^9, 3.539266615983183*^9}, {3.5392666830721903`*^9, 
   3.539266815780409*^9}, 3.539266848624251*^9, 3.539266890598507*^9, {
   3.539267060053648*^9, 3.539267072703176*^9}, 3.5392677537069807`*^9, 
   3.539267788390932*^9, {3.539268495010467*^9, 3.539268496663838*^9}, 
   3.539269140585288*^9, 3.539269235639429*^9, {3.539269355353408*^9, 
   3.539269383630211*^9}, {3.539269638969858*^9, 3.539269750991323*^9}, {
   3.53926979106437*^9, 3.539269810113697*^9}, {3.5392701517950487`*^9, 
   3.5392701920043097`*^9}, 3.539278908980487*^9, 3.539278996527172*^9, {
   3.539326343054734*^9, 3.539326435401582*^9}, {3.539326569957453*^9, 
   3.539326575804747*^9}, {3.539326991237306*^9, 3.5393270082806168`*^9}, {
   3.539329433774241*^9, 3.5393294960187607`*^9}, {3.5393305017074823`*^9, 
   3.539330556642144*^9}, 3.539330888641615*^9, {3.539339971597237*^9, 
   3.5393399876891327`*^9}, {3.5393400782346582`*^9, 3.539340081023357*^9}, {
   3.5393401448438396`*^9, 3.539340145504077*^9}, {3.539347774329233*^9, 
   3.539347843122929*^9}, 3.539366432292687*^9, {3.539367245443975*^9, 
   3.539367246347004*^9}, {3.540734202771955*^9, 3.5407342043103733`*^9}, {
   3.540736418761684*^9, 3.5407364226194553`*^9}, {3.540737768596367*^9, 
   3.540737768892754*^9}, {3.542388724376953*^9, 3.542388781889929*^9}, {
   3.542388924988758*^9, 3.542388987923122*^9}, {3.5423890458105783`*^9, 
   3.542389193224463*^9}, {3.542389272963728*^9, 3.54238930706011*^9}, {
   3.542437641275167*^9, 3.542437699202085*^9}, {3.542437730796095*^9, 
   3.5424378902358*^9}, 3.542437945897581*^9, {3.5424379882249823`*^9, 
   3.5424380665457783`*^9}, 3.5424381121082697`*^9, {3.542438249182868*^9, 
   3.5424382662648687`*^9}, 3.542438305697894*^9, {3.542439075760028*^9, 
   3.5424390838844147`*^9}, {3.542439173737357*^9, 3.542439220087296*^9}, {
   3.542443352398711*^9, 3.542443381775426*^9}, {3.542443447124556*^9, 
   3.542443480430725*^9}, {3.542443613406389*^9, 3.542443649481735*^9}, 
   3.542443699901371*^9, {3.5424462578396807`*^9, 3.542446274257043*^9}, {
   3.542446401017707*^9, 3.542446413600088*^9}, {3.5424464659327908`*^9, 
   3.5424464878337793`*^9}, {3.5424465291804132`*^9, 3.5424465329099913`*^9}, 
   3.542446742755765*^9, {3.542446778102816*^9, 3.542446785282056*^9}, {
   3.542446834089986*^9, 3.542446884468789*^9}, {3.542446919291979*^9, 
   3.542446939944065*^9}, {3.542446976270124*^9, 3.5424469866004257`*^9}, {
   3.542447056705858*^9, 3.5424470898445673`*^9}, {3.5424471344029417`*^9, 
   3.542447174506599*^9}, {3.5424472312410507`*^9, 3.54244726772272*^9}, {
   3.5424473125427227`*^9, 3.5424473254819317`*^9}, {3.5424473695330887`*^9, 
   3.542447388671294*^9}, 3.542448224058323*^9, {3.542451548746708*^9, 
   3.5424515774216213`*^9}, {3.5424519211077013`*^9, 3.542451928153799*^9}, {
   3.54245299950036*^9, 3.542453001194194*^9}, {3.542455811416429*^9, 
   3.542455815394039*^9}, {3.542622812244008*^9, 3.542622822000717*^9}, {
   3.542622859825048*^9, 3.542622931786152*^9}, {3.54269829979911*^9, 
   3.542698305254208*^9}, {3.542699025561718*^9, 3.542699026123849*^9}, {
   3.5426990707182913`*^9, 3.542699088670185*^9}, {3.542700118933394*^9, 
   3.542700121036415*^9}, 3.542700827765305*^9, {3.5429174051788473`*^9, 
   3.542917524367551*^9}, 3.5429176869021387`*^9, {3.542969166437325*^9, 
   3.542969172344721*^9}, {3.548190436221043*^9, 3.548190445993956*^9}, 
   3.548190491401569*^9, {3.548190752747745*^9, 3.548190753292897*^9}, {
   3.54901721401657*^9, 3.549017214311965*^9}, {3.549017247695644*^9, 
   3.5490173217517653`*^9}, {3.5490175863059607`*^9, 3.549017586840351*^9}, {
   3.64364096822392*^9, 3.643640983650118*^9}, 3.643641025520862*^9, {
   3.6436415353816833`*^9, 3.643641602069047*^9}, {3.643641636036574*^9, 
   3.643641702536974*^9}, 3.643641788051527*^9, {3.6436418353044577`*^9, 
   3.643641843368132*^9}, {3.678793251829185*^9, 3.678793285790352*^9}, 
   3.6787994439458447`*^9, {3.678862755048066*^9, 3.6788627561980753`*^9}, 
   3.678865112211464*^9, {3.681391437897203*^9, 3.681391452879457*^9}, {
   3.737108210053956*^9, 3.737108249563664*^9}, {3.7371084042540083`*^9, 
   3.7371084083262463`*^9}, 3.737109292446753*^9, {3.737109749523717*^9, 
   3.737109805554154*^9}, {3.737110028644668*^9, 3.737110070179446*^9}, {
   3.737110150417325*^9, 3.737110151300057*^9}, 3.737110382136352*^9, {
   3.737110458359399*^9, 3.737110460309579*^9}, {3.737110702040637*^9, 
   3.737110703878584*^9}, {3.7371117587819138`*^9, 3.73711177306219*^9}, {
   3.737113682711214*^9, 3.7371136853064327`*^9}, {3.7371138793370953`*^9, 
   3.737113881349288*^9}, {3.73718694545557*^9, 3.737186984864314*^9}, {
   3.737187015838509*^9, 3.7371870332629213`*^9}, {3.737187072238668*^9, 
   3.7371870800135736`*^9}, {3.737189762748537*^9, 3.737189763128755*^9}, {
   3.737189800186709*^9, 3.737189804667068*^9}, {3.7371898409234247`*^9, 
   3.737189845354582*^9}, 3.737190240046109*^9, {3.7371903718842573`*^9, 
   3.737190380979869*^9}, {3.737191435152549*^9, 3.737191467949527*^9}, {
   3.737191521249221*^9, 3.73719156092738*^9}, {3.737191766050044*^9, 
   3.7371917689123497`*^9}, 3.737197927456336*^9, {3.737198159489818*^9, 
   3.737198159886495*^9}, {3.737200386075508*^9, 3.7372003868555098`*^9}, {
   3.737264960908597*^9, 3.7372649614648647`*^9}, 3.7372710196476183`*^9, {
   3.737271124669427*^9, 3.737271139070385*^9}, {3.737271449376149*^9, 
   3.737271450701746*^9}, {3.737272473365141*^9, 3.737272503208777*^9}, {
   3.7372725472818527`*^9, 3.737272573132128*^9}, {3.737272872657456*^9, 
   3.737272875955984*^9}, {3.73727330346493*^9, 3.737273333526195*^9}, {
   3.737273441415806*^9, 3.73727346055801*^9}, {3.738396788506775*^9, 
   3.738396792615591*^9}, {3.738396838807775*^9, 3.738396881515554*^9}, {
   3.738397086236014*^9, 3.738397096880761*^9}, {3.738401749460299*^9, 
   3.738401774943083*^9}, {3.738402799046348*^9, 3.7384027990656652`*^9}, {
   3.738402857208009*^9, 3.738402868058693*^9}, {3.738403076747941*^9, 
   3.738403077732795*^9}, {3.738403519410316*^9, 3.738403520197288*^9}, {
   3.7384035538847313`*^9, 
   3.738403571932852*^9}},ExpressionUUID->"33fd4fd3-2e83-4b69-b714-\
723df4d9405d"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"factor", "=", 
    RowBox[{"(*", "m", "*)"}], 
    FractionBox["\[Nu]", 
     RowBox[{"n", " ", "\[CapitalOmega]d"}]]}], ";"}], "\[IndentingNewLine]", 
  
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"resultP2form1", "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{"FullSimplify", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"factor", " ", "resultP2"}], "/.", "replace\[Rho]P2"}], "/.",
          "replace\[Alpha]"}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Nu]", "\[Rule]", 
           RowBox[{
            FractionBox[
             RowBox[{"d", "+", "2"}], "2"], "\[Nu]0"}]}], ",", 
          RowBox[{"w0", "\[Rule]", 
           FractionBox[
            RowBox[{"1", "+", "e"}], "2"]}]}], "}"}]}], "]"}], 
      RowBox[{"(*", 
       RowBox[{"/.", 
        RowBox[{"{", 
         RowBox[{"\[Nu]0", "\[Rule]", 
          RowBox[{
           FractionBox[
            RowBox[{"16", "d"}], 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "+", "e"}], ")"}], 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"12", "d"}], "+", "9", "-", 
               RowBox[{"e", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"4", "d"}], "+", "17"}], ")"}]}], "+", 
               RowBox[{"3", 
                SuperscriptBox["e", "2"]}], "-", 
               RowBox[{"3", 
                SuperscriptBox["e", "3"]}]}], ")"}]}]], 
           RowBox[{"\[Nu]", "[", 
            RowBox[{"4", ",", "0"}], "]"}]}]}], "}"}]}], "*)"}], "]"}]}], 
    ";"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"resultP2form1", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"factor", " ", "resultP2"}], "/.", "replace\[Rho]P2"}], "/.", 
      "replace\[Alpha]"}], "/.", "gammareplacements"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[Nu]", "\[Rule]", 
       RowBox[{
        FractionBox[
         RowBox[{"d", "+", "2"}], "2"], "\[Nu]0"}]}], ",", 
      RowBox[{"w0", "\[Rule]", 
       FractionBox[
        RowBox[{"1", "+", "e"}], "2"]}]}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.737272917319312*^9, 3.737272919047133*^9}, {
   3.73727297093484*^9, 3.73727298523519*^9}, {3.737273051179839*^9, 
   3.737273105514578*^9}, {3.737273137272187*^9, 3.737273225397573*^9}, 
   3.7372734650377493`*^9, 3.7372736090084267`*^9, {3.737273660475463*^9, 
   3.737273777624713*^9}, 3.738395699297328*^9, {3.7383960772383204`*^9, 
   3.738396078243876*^9}, {3.738396678794359*^9, 3.738396711670636*^9}, {
   3.738396763385541*^9, 3.738396783144718*^9}, {3.7383968961843367`*^9, 
   3.738396900581313*^9}, {3.738401908839529*^9, 3.7384019088444757`*^9}, 
   3.73840197000576*^9, {3.7384020287743187`*^9, 3.738402054020152*^9}, {
   3.738402799068179*^9, 3.738402799070344*^9}, {3.738403076763228*^9, 
   3.738403076765703*^9}, {3.738403519436068*^9, 3.738403519438476*^9}, {
   3.7384036011960497`*^9, 3.738403662477068*^9}, 3.738403829724758*^9, 
   3.738405073462091*^9, {3.738410076400373*^9, 3.738410097007518*^9}, {
   3.738410151281904*^9, 
   3.738410171921365*^9}},ExpressionUUID->"786216b8-dba0-4506-8e18-\
8c79cd2fc8fe"],

Cell[BoxData[
 RowBox[{
  RowBox[{"resultforP2", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Einstein", "[", 
       RowBox[{"Expand", "[", 
        RowBox[{"resultP2form1", "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"\[Rho]", "[", 
             RowBox[{"n_", ",", "li_"}], "]"}], "\[Rule]", 
            RowBox[{"m", " ", 
             RowBox[{"M", "[", 
              RowBox[{
               RowBox[{"2", "n"}], ",", "li"}], "]"}]}]}], ",", 
           RowBox[{
            RowBox[{"\[Upsilon]", "[", 
             RowBox[{"n_", ",", "li_"}], "]"}], "\[Rule]", 
            RowBox[{"m", " ", 
             RowBox[{"M", "[", 
              RowBox[{
               RowBox[{"2", "n"}], ",", "li"}], "]"}]}]}]}], "}"}]}], "]"}], 
       "]"}], "/.", 
      RowBox[{
       RowBox[{"M", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"s0", ",", "s0"}], "}"}]}], "]"}], "\[Rule]", "0"}]}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"M", "[", 
        RowBox[{"4", ",", 
         RowBox[{"{", "}"}]}], "]"}], ",", 
       SuperscriptBox[
        RowBox[{"M", "[", 
         RowBox[{"2", ",", 
          RowBox[{"{", "}"}]}], "]"}], "2"], ",", 
       SuperscriptBox[
        RowBox[{"M", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", 
           RowBox[{"s0", ",", "s1"}], "}"}]}], "]"}], "2"], ",", 
       RowBox[{
        RowBox[{"M", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", 
           RowBox[{"s0", ",", "s1"}], "}"}]}], "]"}], " ", 
        RowBox[{"M", "[", 
         RowBox[{"2", ",", 
          RowBox[{"{", "}"}]}], "]"}]}]}], "}"}], ",", "Simplify"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.738403707713942*^9, 3.7384037386040907`*^9}, {
   3.738403772383342*^9, 3.738403774653079*^9}, {3.738403878144779*^9, 
   3.738403904646881*^9}, {3.7384039609931393`*^9, 3.7384039821744347`*^9}, {
   3.738404036835162*^9, 3.738404079565806*^9}, {3.738404168667548*^9, 
   3.738404170687194*^9}, {3.738404272899145*^9, 3.738404328196933*^9}, {
   3.738404457443948*^9, 3.738404467073352*^9}, {3.738404833159171*^9, 
   3.738404835203217*^9}, {3.7384050199124393`*^9, 3.738405067812273*^9}, 
   3.738478078371821*^9},ExpressionUUID->"1504f8a3-d97f-4b9d-b6f0-\
1e8598f7c543"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   StyleBox[
    RowBox[{
     RowBox[{"Eq", ".", " ", 
      SubscriptBox[
       RowBox[{"(", "2.23", ")"}], "2"]}], " ", "of", " ", "Garz\[OAcute]", 
     " ", "and", " ", "Santos", " ", "2007", " ", 
     RowBox[{"J", ".", " ", "Phys", ".", " ", 
      RowBox[{"A", ":", " ", 
       RowBox[{
        RowBox[{"Math", ".", " ", "Theor", ".", " ", 
         StyleBox["40",
          FontWeight->"Bold"]}], " ", "14927"}]}]}]}],
    FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"expP2Paper", "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"\[Nu]", "[", 
          RowBox[{"4", ",", "0"}], "]"}]}], 
        RowBox[{"M", "[", 
         RowBox[{"4", ",", 
          RowBox[{"{", "}"}]}], "]"}]}], "+", 
       RowBox[{
        FractionBox["\[Lambda]1", "n"], 
        SuperscriptBox[
         RowBox[{"M", "[", 
          RowBox[{"2", ",", 
           RowBox[{"{", "}"}]}], "]"}], "2"]}], "-", 
       RowBox[{
        FractionBox["\[Lambda]2", "n"], 
        RowBox[{"M", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", 
           RowBox[{"s0", ",", "s1"}], "}"}]}], "]"}], 
        RowBox[{"M", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", 
           RowBox[{"s0", ",", "s1"}], "}"}]}], "]"}]}]}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Nu]", "[", 
          RowBox[{"4", ",", "0"}], "]"}], "\[Rule]", 
         RowBox[{
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", "e"}], ")"}], 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"12", "d"}], "+", "9", "-", 
              RowBox[{"e", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", "d"}], "+", "17"}], ")"}]}], "+", 
              RowBox[{"3", 
               SuperscriptBox["e", "2"]}], "-", 
              RowBox[{"3", 
               SuperscriptBox["e", "3"]}]}], ")"}]}], 
           RowBox[{"16", "d"}]], "\[Nu]0"}]}], ",", 
        RowBox[{"\[Lambda]1", "\[Rule]", 
         RowBox[{
          FractionBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"1", "+", "e"}], ")"}], "2"], 
            RowBox[{"(", 
             RowBox[{"d", "+", "2"}], ")"}], 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", "d"}], "-", "1", "-", 
              RowBox[{"6", "e"}], "+", 
              RowBox[{"3", 
               SuperscriptBox["e", "2"]}]}], ")"}]}], 
           RowBox[{"16", 
            SuperscriptBox["d", "2"]}]], "\[Nu]0"}]}], ",", 
        RowBox[{"\[Lambda]2", "\[Rule]", 
         RowBox[{
          FractionBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"1", "+", "e"}], ")"}], "2"], 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"6", "e"}], "-", 
              RowBox[{"3", 
               SuperscriptBox["e", "2"]}]}], ")"}]}], 
           RowBox[{"8", "d"}]], "\[Nu]0"}]}]}], "}"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"resultforP2", "-", "expP2Paper"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.7383954198929977`*^9, 3.738395424674985*^9}, {
   3.738395505793868*^9, 3.738395508613287*^9}, {3.7383955414619293`*^9, 
   3.738395555856544*^9}, {3.738395587057211*^9, 3.7383956011687737`*^9}, {
   3.738397306746271*^9, 3.738397407307046*^9}, 3.7383974728312073`*^9, 
   3.7384019088503523`*^9, {3.738402075667809*^9, 3.7384021822473383`*^9}, {
   3.738402221796605*^9, 3.7384022477042303`*^9}, {3.738402391753244*^9, 
   3.7384023975098352`*^9}, 3.7384027990732927`*^9, 3.7384030767677307`*^9, 
   3.738403519440118*^9, {3.738404523424667*^9, 3.738404820996208*^9}, {
   3.738405120549934*^9, 3.7384051210736713`*^9}, {3.738410113794365*^9, 
   3.738410114098439*^9}, {3.738410261445817*^9, 3.738410261842965*^9}, {
   3.7384780173810368`*^9, 3.7384780202243*^9}, {3.744961646401243*^9, 
   3.744961648375904*^9}},ExpressionUUID->"46b9b5d4-2312-4dae-8b88-\
258e6e7f18a8"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.744961649705923*^9, 3.7450142514551277`*^9, 
  3.745017816324101*^9, 
  3.745122352318089*^9},ExpressionUUID->"0b11e851-c694-466e-8051-\
fc9443f67eaa"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   StyleBox[
    RowBox[{"To", " ", "write", " ", "in", " ", "the", " ", "paper"}],
    FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"P2towrite", "=", 
     RowBox[{
      RowBox[{"Collect", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Einstein", "[", 
            RowBox[{"Expand", "[", 
             RowBox[{"m", " ", "resultP2form1"}], "]"}], "]"}], "/.", 
           RowBox[{
            RowBox[{"\[Upsilon]", "[", 
             RowBox[{"n_", ",", 
              RowBox[{"{", 
               RowBox[{"s0", ",", "s0"}], "}"}]}], "]"}], "\[Rule]", "0"}]}], 
          "/.", "replace\[Rho]u"}], "/.", 
         RowBox[{"n", "\[Rule]", 
          FractionBox["\[Rho]", "m"]}]}], ",", 
        RowBox[{"{", 
         RowBox[{"u2", ",", 
          RowBox[{"\[Sigma]", "[", 
           RowBox[{"{", 
            RowBox[{"s0", ",", "s0"}], "}"}], "]"}], ",", " ", 
          SuperscriptBox[
           RowBox[{"\[Sigma]", "[", 
            RowBox[{"{", 
             RowBox[{"s0", ",", "s1"}], "}"}], "]"}], "2"]}], "}"}], ",", 
        "Simplify"}], "]"}], "/.", 
      RowBox[{"u2", "\[Rule]", 
       RowBox[{"d", 
        RowBox[{"(", 
         RowBox[{"d", "+", "2"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"1", "+", "\[CapitalDelta]"}], ")"}], "\[Rho]", " ", 
        SuperscriptBox["\[Theta]", "2"]}]}]}]}], ";"}], "\[IndentingNewLine]",
    "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"P2towrite", "-", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "\[Nu]0"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"\[Alpha]0", "+", 
             RowBox[{"\[Alpha]1", " ", "\[CapitalDelta]"}]}], ")"}], " ", 
           "\[Rho]", " ", 
           SuperscriptBox["\[Theta]", "2"]}], "+", 
          RowBox[{"d", 
           RowBox[{"(", 
            RowBox[{"d", "+", "2"}], ")"}], "c0", 
           FractionBox[
            RowBox[{
             RowBox[{"\[Sigma]", "[", 
              RowBox[{"{", 
               RowBox[{"s0", ",", "s1"}], "}"}], "]"}], " ", 
             RowBox[{"\[Sigma]", "[", 
              RowBox[{"{", 
               RowBox[{"s0", ",", "s1"}], "}"}], "]"}]}], "\[Rho]"]}]}], 
         ")"}]}], ")"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Alpha]0", "\[Rule]", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", 
            SuperscriptBox["e", "2"]}], ")"}], 
          RowBox[{"(", 
           RowBox[{"d", "+", "2"}], ")"}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"4", " ", "d"}], "+", "5", "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["e", "2"]}]}], ")"}]}], "8"]}], " ", ",", 
       "\[IndentingNewLine]", 
       RowBox[{"\[Alpha]1", "\[Rule]", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", "e"}], ")"}], 
          RowBox[{"(", 
           RowBox[{"d", "+", "2"}], ")"}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", "d"}], "+", "3"}], ")"}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", "d"}], "+", "17"}], ")"}], " ", "e"}], "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["e", "2"]}], "-", 
            RowBox[{"3", " ", 
             SuperscriptBox["e", "3"]}]}], ")"}]}], "16"]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"c0", "\[Rule]", 
        FractionBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "+", "e"}], ")"}], "2"], 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"6", "e"}], "-", 
            RowBox[{"3", 
             SuperscriptBox["e", "2"]}]}], ")"}]}], 
         RowBox[{"8", 
          SuperscriptBox["d", "2"], 
          RowBox[{"(", 
           RowBox[{"d", "+", "2"}], ")"}]}]]}]}], "}"}]}], "]"}]}]}]], "Input",\

 CellChangeTimes->{
  3.738664826399189*^9, {3.73866486631916*^9, 3.7386649637144527`*^9}, {
   3.738665002264349*^9, 3.738665022622917*^9}, {3.738665072118774*^9, 
   3.738665136298582*^9}, {3.738665190016629*^9, 3.7386651932212477`*^9}, {
   3.738665235879674*^9, 3.738665252008293*^9}, {3.738665326521793*^9, 
   3.73866535775142*^9}, {3.738665467046234*^9, 3.738665493375386*^9}, {
   3.738665552180814*^9, 3.738665588241974*^9}, {3.744961468202613*^9, 
   3.744961496834815*^9}, {3.7449615473223143`*^9, 3.744961588009522*^9}, 
   3.744962101026815*^9, 3.744962533451145*^9, {3.74498536603482*^9, 
   3.7449853775519047`*^9}, {3.745017860657229*^9, 3.7450178882168427`*^9}, {
   3.745019015905355*^9, 3.745019033144712*^9}, {3.745019744812155*^9, 
   3.745019748240836*^9}, 
   3.74502186160664*^9},ExpressionUUID->"99a7b0fc-ea3a-440d-8dd0-\
9c47182bd750"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.738664964381884*^9, 3.738665024016605*^9, {3.738665074123617*^9, 
   3.738665085798345*^9}, 3.738665149211368*^9, 3.738665194627501*^9, {
   3.738665555588543*^9, 3.738665601517111*^9}, 3.744961401108526*^9, {
   3.744961574342915*^9, 3.7449615887849894`*^9}, 3.744962102899261*^9, {
   3.7449625359083433`*^9, 3.7449625436045237`*^9}, 3.744985378981225*^9, 
   3.7450142515898*^9, 3.74501781641647*^9, 3.745017889250784*^9, 
   3.745019034761372*^9, 3.745019749932951*^9, 3.745021863396934*^9, 
   3.74512235242731*^9},ExpressionUUID->"69c5c538-c327-4a4e-b12a-\
492cea5a1885"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Alpha]0", ",", "\[Alpha]1"}], "}"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Alpha]0", "\[Rule]", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", 
            SuperscriptBox["e", "2"]}], ")"}], 
          RowBox[{"(", 
           RowBox[{"d", "+", "2"}], ")"}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"4", " ", "d"}], "+", "5", "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["e", "2"]}]}], ")"}]}], "8"]}], " ", ",", 
       "\[IndentingNewLine]", 
       RowBox[{"\[Alpha]1", "\[Rule]", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", "e"}], ")"}], 
          RowBox[{"(", 
           RowBox[{"d", "+", "2"}], ")"}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"12", "d"}], "+", "9", "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"17", "+", 
               RowBox[{"4", " ", "d"}]}], ")"}], " ", "e"}], "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["e", "2"]}], "-", 
            RowBox[{"3", " ", 
             SuperscriptBox["e", "3"]}]}], ")"}]}], "16"]}]}], "}"}]}], "/.", 
    
    RowBox[{"d", "\[Rule]", "3"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"e", ",", "0", ",", "1"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.744985468024858*^9, 3.7449855241776257`*^9}, {
  3.744985837816737*^9, 3.744985868423882*^9}, {3.7450178963869*^9, 
  3.745017904666326*^9}},ExpressionUUID->"338060bc-5dfd-494e-8943-\
23e7a780d50f"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwV1Ak01FscB3DLS6Joo2aSZcxMUSghqfG7r9KiKMb6kpc8JCqlBa0SWcv2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      "]], 
     LineBox[CompressedData["
1:eJwV1nk4lN0bB/CRkogsEQrFUDFPIgqV+/RaokXZVYpkTWT7WUoJKS8RkRBS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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.744985861892762*^9, 3.744985872173568*^9}, 
   3.745014251903808*^9, 3.745017816471498*^9, 3.74501790591903*^9, 
   3.745122352702018*^9},ExpressionUUID->"10d8b1e5-59ea-4156-83e7-\
a97f3b40abce"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Production Term for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["C", "2"], 
    SubscriptBox["C", "i"], 
    SubscriptBox["C", "j"]}], TraditionalForm]],ExpressionUUID->
  "d51e97c7-5e05-4eeb-8234-eb8ded973302"]
}], "Subsection",
 CellChangeTimes->{{3.540736884072311*^9, 3.5407369043909597`*^9}, {
  3.542452633864394*^9, 3.542452671646845*^9}, {3.737272427807934*^9, 
  3.737272430722102*^9}, {3.737273281718402*^9, 3.7372732969187727`*^9}, {
  3.7384017425560913`*^9, 3.73840174518649*^9}, {3.738402807640226*^9, 
  3.738402810504265*^9}, {3.738403095497416*^9, 3.7384031039467993`*^9}},
 TextAlignment->Center,
 FontColor->RGBColor[0.5, 0, 0.5],
 Background->RGBColor[
  1, 1, 0.85],ExpressionUUID->"d6b5f773-5ce8-4dc5-9389-f32e97ea0c76"],

Cell[BoxData[{
 RowBox[{"Clear", "[", 
  RowBox[{"w0", ",", "g"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"idx", "=", 
   RowBox[{"{", 
    RowBox[{"i1", ",", "i2", ",", "i3", ",", "i4"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"nn", "=", 
    RowBox[{"Length", "[", "idx", "]"}]}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   StyleBox[
    RowBox[{
    "raw", " ", "form", " ", "of", " ", "integrand", " ", "without", " ", 
     "factor", " ", 
     FractionBox[
      RowBox[{"m", " ", "\[Nu]"}], 
      RowBox[{"n", " ", "\[CapitalOmega]d"}]], " ", "and", " ", "f", " ", 
     "f1", " ", "in", " ", "the", " ", "collision", " ", "integral"}],
    FontColor->RGBColor[1, 0.5, 0]], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Pij1", "=", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"\[Beta]", "=", "1"}], "nn"], 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"\[Gamma]", "=", "0"}], 
       RowBox[{"\[Beta]", "/", "2"}]], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], "\[Beta]"], 
       SuperscriptBox["w0", "\[Beta]"], 
       RowBox[{"Binomial", "[", 
        RowBox[{"nn", ",", "\[Beta]"}], "]"}], 
       RowBox[{"Delta", "[", 
        RowBox[{
         RowBox[{"idx", "\[LeftDoubleBracket]", 
          RowBox[{"range", "[", 
           RowBox[{"1", ",", "\[Gamma]"}], "]"}], "\[RightDoubleBracket]"}], 
         ",", 
         RowBox[{"idx", "\[LeftDoubleBracket]", 
          RowBox[{"range", "[", 
           RowBox[{
            RowBox[{"\[Gamma]", "+", "1"}], ",", 
            RowBox[{"2", "\[Gamma]"}]}], "]"}], "\[RightDoubleBracket]"}]}], 
        "]"}], 
       RowBox[{"\[Alpha]", "[", 
        RowBox[{"\[Gamma]", ",", "\[Beta]"}], "]"}], 
       SuperscriptBox["g", 
        RowBox[{"2", "\[Gamma]"}]], 
       RowBox[{"gg", "[", 
        RowBox[{"idx", "\[LeftDoubleBracket]", 
         RowBox[{"range", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"2", "\[Gamma]"}], "+", "1"}], ",", "\[Beta]"}], "]"}], 
         "\[RightDoubleBracket]"}], "]"}], 
       RowBox[{"CC", "[", 
        RowBox[{"idx", "\[LeftDoubleBracket]", 
         RowBox[{"range", "[", 
          RowBox[{
           RowBox[{"\[Beta]", "+", "1"}], ",", "nn"}], "]"}], 
         "\[RightDoubleBracket]"}], "]"}]}]}]}]}], 
   RowBox[{"(*", 
    RowBox[{"f", " ", "f1"}], "*)"}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   StyleBox[
    RowBox[{"symmetrization", " ", "of", " ", "the", " ", "indices"}],
    FontColor->RGBColor[1, 0.5, 0]], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"perm", "=", 
   RowBox[{
    RowBox[{"Permutations", "[", "idx", "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{"i4", "\[Rule]", "i3"}], "}"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CollInt", "=", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{"CollInt", "+=", 
    RowBox[{"Pij1", "/.", 
     RowBox[{"Thread", "[", 
      RowBox[{"idx", "\[Rule]", 
       RowBox[{
       "perm", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}]}], 
      "]"}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{"ii", ",", "1", ",", 
     RowBox[{"Length", "[", "perm", "]"}]}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CollIntegralPij1", "=", 
    RowBox[{"ExpandAll", "[", 
     RowBox[{
      FractionBox["CollInt", 
       RowBox[{"Length", "[", "perm", "]"}]], "/.", "replace$gsq"}], "]"}]}], 
   ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   StyleBox[
    RowBox[{
     RowBox[{"main", " ", "working", " ", 
      RowBox[{"steps", ":", " ", 
       RowBox[{
        RowBox[{
        "1.", " ", "integrate", " ", "directions", " ", "in", " ", "h"}], "-",
         "vectors"}]}]}], ";", " ", 
     RowBox[{
      RowBox[{
      "2.", " ", "integrate", " ", "directions", " ", "in", " ", "g"}], "-", 
      "vectors"}], ";", " ", 
     RowBox[{
     "3.", " ", "integrate", " ", "Gauss", " ", "integrals", " ", "in", " ", 
      "h"}], ";", " ", 
     RowBox[{
     "4.", " ", "perform", " ", "contractions", " ", "on", " ", "\[Delta]"}]}],
    FontColor->RGBColor[1, 0.5, 0]], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g", "[", "idx_", "]"}], ":=", 
  RowBox[{
   RowBox[{"CC", "[", "idx", "]"}], "-", 
   RowBox[{"CC1", "[", "idx", "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CollIntegralPij1", "=", 
    RowBox[{"Expand", "[", "CollIntegralPij1", "]"}]}], ";"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   StyleBox[
    RowBox[{"Integration", " ", "over", " ", "C", " ", "and", " ", "C1"}],
    FontColor->RGBColor[1, 0.5, 0]], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"resultPij1", "=", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Einstein", "[", 
         RowBox[{"intoverCC1", "[", 
          RowBox[{
          "CollIntegralPij1", "\[LeftDoubleBracket]", "ii", 
           "\[RightDoubleBracket]"}], "]"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"ii", ",", "1", ",", 
          RowBox[{"Length", "[", "CollIntegralPij1", "]"}]}], "}"}]}], 
       "]"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"list\[Rho]Pij1", "=", 
   RowBox[{"DeleteDuplicates", "[", 
    RowBox[{"Extract", "[", 
     RowBox[{"resultPij1", ",", 
      RowBox[{"Position", "[", 
       RowBox[{"resultPij1", ",", 
        RowBox[{"\[Rho]", "[", 
         RowBox[{"_", ",", "_"}], "]"}]}], "]"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"replace\[Rho]Pij1", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
      "list\[Rho]Pij1", "\[LeftDoubleBracket]", "ii", 
       "\[RightDoubleBracket]"}], "\[Rule]", 
      RowBox[{"tracefreerepresentation", "[", 
       RowBox[{
       "list\[Rho]Pij1", "\[LeftDoubleBracket]", "ii", 
        "\[RightDoubleBracket]"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"ii", ",", "1", ",", 
       RowBox[{"Length", "[", "list\[Rho]Pij1", "]"}]}], "}"}]}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.537993578189455*^9, 3.537993610797545*^9}, {
   3.537993771670854*^9, 3.537993779038876*^9}, {3.5379938261036*^9, 
   3.537993894920753*^9}, 3.537993985202799*^9, {3.537994016572002*^9, 
   3.537994037555522*^9}, {3.537994388113123*^9, 3.5379944406823893`*^9}, {
   3.5379944716672297`*^9, 3.537994535484898*^9}, {3.5379946435344*^9, 
   3.537994670999247*^9}, {3.537994822992545*^9, 3.537994848706256*^9}, {
   3.537994948252141*^9, 3.5379951325767097`*^9}, {3.537995185554933*^9, 
   3.537995241802492*^9}, {3.537995276222849*^9, 3.537995281348686*^9}, {
   3.53799533558186*^9, 3.5379953402203913`*^9}, {3.537995373317173*^9, 
   3.537995389189156*^9}, {3.537995463503443*^9, 3.537995586335116*^9}, {
   3.537995620905704*^9, 3.537995685353702*^9}, {3.537995731882414*^9, 
   3.537995740818839*^9}, {3.53799608412899*^9, 3.537996120582891*^9}, {
   3.537996373868025*^9, 3.537996470581868*^9}, {3.537996552739531*^9, 
   3.537996599754401*^9}, {3.537996699014799*^9, 3.537996718444993*^9}, {
   3.5379967905373993`*^9, 3.537996835526949*^9}, {3.537996969586375*^9, 
   3.537997008865888*^9}, {3.537997054707327*^9, 3.5379970594661016`*^9}, {
   3.537997228824871*^9, 3.537997383715749*^9}, {3.537997495969655*^9, 
   3.537997504978291*^9}, {3.538049111849923*^9, 3.538049145198148*^9}, {
   3.538049184515108*^9, 3.538049258034523*^9}, {3.5380493781370897`*^9, 
   3.538049391682486*^9}, {3.538049424567073*^9, 3.538049487235387*^9}, {
   3.538049594582995*^9, 3.538049743296955*^9}, {3.538050939370043*^9, 
   3.5380509982737083`*^9}, {3.5380676731372538`*^9, 3.538067723150732*^9}, 
   3.53806785052652*^9, {3.538067941214231*^9, 3.538067990711932*^9}, {
   3.538068029462811*^9, 3.538068153307399*^9}, {3.53806855796034*^9, 
   3.538068627746333*^9}, {3.53806869188647*^9, 3.538068751511098*^9}, {
   3.538068919982791*^9, 3.538068952563477*^9}, {3.538120345641403*^9, 
   3.538120421155457*^9}, 3.538120780664413*^9, {3.538120852906658*^9, 
   3.538120953903056*^9}, {3.538121002642786*^9, 3.538121148063637*^9}, {
   3.538126353936679*^9, 3.538126386984695*^9}, {3.538126473001809*^9, 
   3.5381265005530252`*^9}, {3.538126537649548*^9, 3.538126555161577*^9}, {
   3.5381266439234133`*^9, 3.538126715750491*^9}, 3.538127882474265*^9, {
   3.538130944351671*^9, 3.538131077658307*^9}, {3.538131942442205*^9, 
   3.538132013760786*^9}, {3.538132283894219*^9, 3.538132360880001*^9}, {
   3.538133348588627*^9, 3.538133377632154*^9}, {3.53813341458228*^9, 
   3.538133595785343*^9}, {3.538133693428665*^9, 3.538133893912404*^9}, {
   3.538133930459076*^9, 3.538134125076247*^9}, {3.53813417768613*^9, 
   3.538134217260666*^9}, {3.538134259339695*^9, 3.538134264398603*^9}, {
   3.538137299532156*^9, 3.538137342311903*^9}, {3.538137430398448*^9, 
   3.538137473144889*^9}, {3.5381376929555693`*^9, 3.5381377022975807`*^9}, {
   3.5381379513516703`*^9, 3.538137995917336*^9}, {3.538138048946089*^9, 
   3.53813805994525*^9}, {3.538138121394474*^9, 3.5381381959580793`*^9}, {
   3.5381382502615757`*^9, 3.538138273902351*^9}, {3.5381383210109873`*^9, 
   3.538138336804418*^9}, 3.538138516977003*^9, {3.5381618433477077`*^9, 
   3.538161932597952*^9}, {3.538161987860311*^9, 3.5381620846113997`*^9}, {
   3.5381621539329453`*^9, 3.538162195795615*^9}, {3.538162226745761*^9, 
   3.538162260756913*^9}, {3.538162294790723*^9, 3.538162558108499*^9}, {
   3.5382004503666887`*^9, 3.538200516536386*^9}, {3.5382005504900503`*^9, 
   3.538200576308169*^9}, {3.538200918185061*^9, 3.5382009209833603`*^9}, 
   3.538200954918594*^9, {3.5382012679264*^9, 3.538201268242012*^9}, {
   3.5382013070166893`*^9, 3.538201311732603*^9}, 3.53820156656705*^9, {
   3.538201655677127*^9, 3.538201682767631*^9}, 3.538201919512535*^9, 
   3.538243145787212*^9, 3.53824318144276*^9, {3.538243282594778*^9, 
   3.5382432941723957`*^9}, {3.5382433354676323`*^9, 
   3.5382433373488293`*^9}, {3.538243583835874*^9, 3.538243588737722*^9}, {
   3.538244168454702*^9, 3.538244180740324*^9}, {3.538244332583802*^9, 
   3.538244339379407*^9}, 3.5382449465768633`*^9, {3.5388070078690643`*^9, 
   3.538807099973749*^9}, {3.538807180708592*^9, 3.5388071828035707`*^9}, 
   3.5388074844694977`*^9, {3.538807551230954*^9, 3.538807553504488*^9}, {
   3.538808873941285*^9, 3.538808875477491*^9}, {3.538808927009503*^9, 
   3.5388089304970512`*^9}, {3.538808998699823*^9, 3.538809020477653*^9}, {
   3.538809124555171*^9, 3.538809131039702*^9}, 3.538809175971305*^9, {
   3.538809338238731*^9, 3.5388093394879303`*^9}, 3.5388093971728573`*^9, {
   3.53881066031894*^9, 3.538810687713526*^9}, 3.538810748528813*^9, {
   3.5388107917831078`*^9, 3.538810794089106*^9}, {3.538811661821177*^9, 
   3.538811724776244*^9}, 3.538817331517233*^9, {3.5388192046322308`*^9, 
   3.538819214494584*^9}, {3.5392665470358353`*^9, 3.5392665745099287`*^9}, {
   3.539266610562613*^9, 3.539266615983183*^9}, {3.5392666830721903`*^9, 
   3.539266815780409*^9}, 3.539266848624251*^9, 3.539266890598507*^9, {
   3.539267060053648*^9, 3.539267072703176*^9}, 3.5392677537069807`*^9, 
   3.539267788390932*^9, {3.539268495010467*^9, 3.539268496663838*^9}, 
   3.539269140585288*^9, 3.539269235639429*^9, {3.539269355353408*^9, 
   3.539269383630211*^9}, {3.539269638969858*^9, 3.539269750991323*^9}, {
   3.53926979106437*^9, 3.539269810113697*^9}, {3.5392701517950487`*^9, 
   3.5392701920043097`*^9}, 3.539278908980487*^9, 3.539278996527172*^9, {
   3.539326343054734*^9, 3.539326435401582*^9}, {3.539326569957453*^9, 
   3.539326575804747*^9}, {3.539326991237306*^9, 3.5393270082806168`*^9}, {
   3.539329433774241*^9, 3.5393294960187607`*^9}, {3.5393305017074823`*^9, 
   3.539330556642144*^9}, 3.539330888641615*^9, {3.539339971597237*^9, 
   3.5393399876891327`*^9}, {3.5393400782346582`*^9, 3.539340081023357*^9}, {
   3.5393401448438396`*^9, 3.539340145504077*^9}, {3.539347774329233*^9, 
   3.539347843122929*^9}, 3.539366432292687*^9, {3.539367245443975*^9, 
   3.539367246347004*^9}, {3.540734202771955*^9, 3.5407342043103733`*^9}, {
   3.540736418761684*^9, 3.5407364226194553`*^9}, {3.540737768596367*^9, 
   3.540737768892754*^9}, {3.542388724376953*^9, 3.542388781889929*^9}, {
   3.542388924988758*^9, 3.542388987923122*^9}, {3.5423890458105783`*^9, 
   3.542389193224463*^9}, {3.542389272963728*^9, 3.54238930706011*^9}, {
   3.542437641275167*^9, 3.542437699202085*^9}, {3.542437730796095*^9, 
   3.5424378902358*^9}, 3.542437945897581*^9, {3.5424379882249823`*^9, 
   3.5424380665457783`*^9}, 3.5424381121082697`*^9, {3.542438249182868*^9, 
   3.5424382662648687`*^9}, 3.542438305697894*^9, {3.542439075760028*^9, 
   3.5424390838844147`*^9}, {3.542439173737357*^9, 3.542439220087296*^9}, {
   3.542443352398711*^9, 3.542443381775426*^9}, {3.542443447124556*^9, 
   3.542443480430725*^9}, {3.542443613406389*^9, 3.542443649481735*^9}, 
   3.542443699901371*^9, {3.5424462578396807`*^9, 3.542446274257043*^9}, {
   3.542446401017707*^9, 3.542446413600088*^9}, {3.5424464659327908`*^9, 
   3.5424464878337793`*^9}, {3.5424465291804132`*^9, 3.5424465329099913`*^9}, 
   3.542446742755765*^9, {3.542446778102816*^9, 3.542446785282056*^9}, {
   3.542446834089986*^9, 3.542446884468789*^9}, {3.542446919291979*^9, 
   3.542446939944065*^9}, {3.542446976270124*^9, 3.5424469866004257`*^9}, {
   3.542447056705858*^9, 3.5424470898445673`*^9}, {3.5424471344029417`*^9, 
   3.542447174506599*^9}, {3.5424472312410507`*^9, 3.54244726772272*^9}, {
   3.5424473125427227`*^9, 3.5424473254819317`*^9}, {3.5424473695330887`*^9, 
   3.542447388671294*^9}, 3.542448224058323*^9, {3.542451548746708*^9, 
   3.5424515774216213`*^9}, {3.5424519211077013`*^9, 3.542451928153799*^9}, {
   3.54245299950036*^9, 3.542453001194194*^9}, {3.542455811416429*^9, 
   3.542455815394039*^9}, {3.542622812244008*^9, 3.542622822000717*^9}, {
   3.542622859825048*^9, 3.542622931786152*^9}, {3.54269829979911*^9, 
   3.542698305254208*^9}, {3.542699025561718*^9, 3.542699026123849*^9}, {
   3.5426990707182913`*^9, 3.542699088670185*^9}, {3.542700118933394*^9, 
   3.542700121036415*^9}, 3.542700827765305*^9, {3.5429174051788473`*^9, 
   3.542917524367551*^9}, 3.5429176869021387`*^9, {3.542969166437325*^9, 
   3.542969172344721*^9}, {3.548190436221043*^9, 3.548190445993956*^9}, 
   3.548190491401569*^9, {3.548190752747745*^9, 3.548190753292897*^9}, {
   3.54901721401657*^9, 3.549017214311965*^9}, {3.549017247695644*^9, 
   3.5490173217517653`*^9}, {3.5490175863059607`*^9, 3.549017586840351*^9}, {
   3.64364096822392*^9, 3.643640983650118*^9}, 3.643641025520862*^9, {
   3.6436415353816833`*^9, 3.643641602069047*^9}, {3.643641636036574*^9, 
   3.643641702536974*^9}, 3.643641788051527*^9, {3.6436418353044577`*^9, 
   3.643641843368132*^9}, {3.678793251829185*^9, 3.678793285790352*^9}, 
   3.6787994439458447`*^9, {3.678862755048066*^9, 3.6788627561980753`*^9}, 
   3.678865112211464*^9, {3.681391437897203*^9, 3.681391452879457*^9}, {
   3.737108210053956*^9, 3.737108249563664*^9}, {3.7371084042540083`*^9, 
   3.7371084083262463`*^9}, 3.737109292446753*^9, {3.737109749523717*^9, 
   3.737109805554154*^9}, {3.737110028644668*^9, 3.737110070179446*^9}, {
   3.737110150417325*^9, 3.737110151300057*^9}, 3.737110382136352*^9, {
   3.737110458359399*^9, 3.737110460309579*^9}, {3.737110702040637*^9, 
   3.737110703878584*^9}, {3.7371117587819138`*^9, 3.73711177306219*^9}, {
   3.737113682711214*^9, 3.7371136853064327`*^9}, {3.7371138793370953`*^9, 
   3.737113881349288*^9}, {3.73718694545557*^9, 3.737186984864314*^9}, {
   3.737187015838509*^9, 3.7371870332629213`*^9}, {3.737187072238668*^9, 
   3.7371870800135736`*^9}, {3.737189762748537*^9, 3.737189763128755*^9}, {
   3.737189800186709*^9, 3.737189804667068*^9}, {3.7371898409234247`*^9, 
   3.737189845354582*^9}, 3.737190240046109*^9, {3.7371903718842573`*^9, 
   3.737190380979869*^9}, {3.737191435152549*^9, 3.737191467949527*^9}, {
   3.737191521249221*^9, 3.73719156092738*^9}, {3.737191766050044*^9, 
   3.7371917689123497`*^9}, 3.737197927456336*^9, {3.737198159489818*^9, 
   3.737198159886495*^9}, {3.737200386075508*^9, 3.7372003868555098`*^9}, {
   3.737264960908597*^9, 3.7372649614648647`*^9}, 3.7372710196476183`*^9, {
   3.737271124669427*^9, 3.737271139070385*^9}, {3.737271449376149*^9, 
   3.737271450701746*^9}, {3.737272473365141*^9, 3.737272503208777*^9}, {
   3.7372725472818527`*^9, 3.737272573132128*^9}, {3.737272872657456*^9, 
   3.737272875955984*^9}, {3.73727330346493*^9, 3.737273333526195*^9}, {
   3.737273441415806*^9, 3.73727346055801*^9}, {3.738396788506775*^9, 
   3.738396792615591*^9}, {3.738396838807775*^9, 3.738396881515554*^9}, {
   3.738397086236014*^9, 3.738397096880761*^9}, {3.738401749460299*^9, 
   3.738401774943083*^9}, {3.738402799046348*^9, 3.7384027990656652`*^9}, {
   3.738402857208009*^9, 3.738402868058693*^9}, {3.738403076747941*^9, 
   3.738403077732795*^9}, {3.738403109771039*^9, 
   3.738403121530373*^9}},ExpressionUUID->"77c986e4-31bc-49c8-9ba3-\
ed530ab8ddf2"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"factor", "=", 
    RowBox[{"(*", "m", "*)"}], 
    FractionBox["\[Nu]", 
     RowBox[{"n", " ", "\[CapitalOmega]d"}]]}], ";"}], "\[IndentingNewLine]", 
  
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"resultPij1form1", "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{"FullSimplify", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"factor", " ", "resultPij1"}], "/.", "replace\[Rho]Pij1"}], 
         "/.", "replace\[Alpha]"}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Nu]", "\[Rule]", 
           RowBox[{
            FractionBox[
             RowBox[{"d", "+", "2"}], "2"], "\[Nu]0"}]}], ",", 
          RowBox[{"w0", "\[Rule]", 
           FractionBox[
            RowBox[{"1", "+", "e"}], "2"]}]}], "}"}]}], "]"}], 
      RowBox[{"(*", 
       RowBox[{"/.", 
        RowBox[{"{", 
         RowBox[{"\[Nu]0", "\[Rule]", 
          RowBox[{
           FractionBox[
            RowBox[{"8", "d", 
             RowBox[{"(", 
              RowBox[{"d", "+", "4"}], ")"}]}], 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "+", "e"}], ")"}], 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"7", 
                SuperscriptBox["d", "2"]}], "+", 
               RowBox[{"31", "d"}], "+", "18", "-", 
               RowBox[{"e", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["d", "2"], "+", 
                  RowBox[{"14", "d"}], "+", "34"}], ")"}]}], "+", 
               RowBox[{"3", 
                SuperscriptBox["e", "2"], 
                RowBox[{"(", 
                 RowBox[{"d", "+", "2"}], ")"}]}], "-", 
               RowBox[{"6", 
                SuperscriptBox["e", "3"]}]}], ")"}]}]], 
           RowBox[{"\[Nu]", "[", 
            RowBox[{"2", ",", "2"}], "]"}]}]}], "}"}]}], "*)"}], "]"}]}], 
    ";"}], "*)"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"resultPij1form1", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"factor", " ", "resultPij1"}], "/.", "replace\[Rho]Pij1"}], "/.",
       "replace\[Alpha]"}], "/.", "gammareplacements"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[Nu]", "\[Rule]", 
       RowBox[{
        FractionBox[
         RowBox[{"d", "+", "2"}], "2"], "\[Nu]0"}]}], ",", 
      RowBox[{"w0", "\[Rule]", 
       FractionBox[
        RowBox[{"1", "+", "e"}], "2"]}]}], "}"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.737272917319312*^9, 3.737272919047133*^9}, {
   3.73727297093484*^9, 3.73727298523519*^9}, {3.737273051179839*^9, 
   3.737273105514578*^9}, {3.737273137272187*^9, 3.737273225397573*^9}, 
   3.7372734650377493`*^9, 3.7372736090084267`*^9, {3.737273660475463*^9, 
   3.737273777624713*^9}, 3.738395699297328*^9, {3.7383960772383204`*^9, 
   3.738396078243876*^9}, {3.738396678794359*^9, 3.738396711670636*^9}, {
   3.738396763385541*^9, 3.738396783144718*^9}, {3.7383968961843367`*^9, 
   3.738396900581313*^9}, {3.738401908839529*^9, 3.7384019088444757`*^9}, 
   3.73840197000576*^9, {3.7384020287743187`*^9, 3.738402054020152*^9}, {
   3.738402799068179*^9, 3.738402799070344*^9}, {3.738403076763228*^9, 
   3.738403076765703*^9}, {3.738403245852635*^9, 3.738403356059643*^9}, 
   3.738405196064578*^9, {3.738409980706715*^9, 
   3.7384100119119368`*^9}},ExpressionUUID->"06f8f6a5-49e5-4964-9b5a-\
818689737251"],

Cell[BoxData[
 RowBox[{
  RowBox[{"resultforPij1", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Einstein", "[", 
       RowBox[{"Expand", "[", 
        RowBox[{"resultPij1form1", "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"\[Rho]", "[", 
             RowBox[{"n_", ",", "li_"}], "]"}], "\[Rule]", 
            RowBox[{"m", " ", 
             RowBox[{"M", "[", 
              RowBox[{
               RowBox[{"2", "n"}], ",", "li"}], "]"}]}]}], ",", 
           RowBox[{
            RowBox[{"\[Upsilon]", "[", 
             RowBox[{"n_", ",", "li_"}], "]"}], "\[Rule]", 
            RowBox[{"m", " ", 
             RowBox[{"M", "[", 
              RowBox[{
               RowBox[{"2", "n"}], ",", "li"}], "]"}]}]}]}], "}"}]}], "]"}], 
       "]"}], "/.", 
      RowBox[{
       RowBox[{"M", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"s0", ",", "s0"}], "}"}]}], "]"}], "\[Rule]", "0"}]}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"M", "[", 
        RowBox[{"2", ",", 
         RowBox[{"{", 
          RowBox[{"i1", ",", "i2"}], "}"}]}], "]"}], ",", 
       RowBox[{
        RowBox[{"M", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", 
           RowBox[{"i1", ",", "s0"}], "}"}]}], "]"}], " ", 
        RowBox[{"M", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", 
           RowBox[{"i2", ",", "s0"}], "}"}]}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"M", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", 
           RowBox[{"i1", ",", "i2"}], "}"}]}], "]"}], " ", 
        RowBox[{"M", "[", 
         RowBox[{"2", ",", 
          RowBox[{"{", "}"}]}], "]"}]}], ",", 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"i1", ",", "i2"}], "}"}], "]"}]}], "}"}], ",", "Simplify"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.73840523021183*^9, 3.73840532046945*^9}, {
   3.738405421533681*^9, 3.738405460682692*^9}, 3.7384062972919817`*^9, 
   3.738478114821638*^9},ExpressionUUID->"2427fd29-5ed6-428d-af2f-\
58340a2a60c4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   StyleBox[
    RowBox[{
     RowBox[{"Eq", ".", " ", 
      RowBox[{"(", "2.24", ")"}]}], " ", "of", " ", "Garz\[OAcute]", " ", 
     "and", " ", "Santos", " ", "2007", " ", 
     RowBox[{"J", ".", " ", "Phys", ".", " ", 
      RowBox[{"A", ":", " ", 
       RowBox[{
        RowBox[{"Math", ".", " ", "Theor", ".", " ", 
         StyleBox["40",
          FontWeight->"Bold"]}], " ", "14927"}]}]}]}],
    FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"expPij1Paper", "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"\[Nu]", "[", 
          RowBox[{"2", ",", "2"}], "]"}]}], 
        RowBox[{"M", "[", 
         RowBox[{"2", ",", 
          RowBox[{"{", 
           RowBox[{"i1", ",", "i2"}], "}"}]}], "]"}]}], "+", 
       RowBox[{
        FractionBox["\[Lambda]3", "n"], 
        RowBox[{"M", "[", 
         RowBox[{"2", ",", 
          RowBox[{"{", "}"}]}], "]"}], 
        RowBox[{"M", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", 
           RowBox[{"i1", ",", "i2"}], "}"}]}], "]"}]}], "-", 
       RowBox[{
        FractionBox["\[Lambda]4", "n"], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"M", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", 
              RowBox[{"i1", ",", "s0"}], "}"}]}], "]"}], " ", 
           RowBox[{"M", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", 
              RowBox[{"i2", ",", "s0"}], "}"}]}], "]"}]}], "-", 
          RowBox[{
           FractionBox["1", "d"], 
           RowBox[{"M", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", 
              RowBox[{"s0", ",", "s1"}], "}"}]}], "]"}], 
           RowBox[{"M", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", 
              RowBox[{"s0", ",", "s1"}], "}"}]}], "]"}], " ", 
           RowBox[{"\[Delta]", "[", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i2"}], "}"}], "]"}]}]}], ")"}]}]}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Nu]", "[", 
          RowBox[{"2", ",", "2"}], "]"}], "\[Rule]", 
         RowBox[{
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", "e"}], ")"}], 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"7", 
               SuperscriptBox["d", "2"]}], "+", 
              RowBox[{"31", "d"}], "+", "18", "-", 
              RowBox[{"e", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["d", "2"], "+", 
                 RowBox[{"14", "d"}], "+", "34"}], ")"}]}], "+", 
              RowBox[{"3", 
               SuperscriptBox["e", "2"], 
               RowBox[{"(", 
                RowBox[{"d", "+", "2"}], ")"}]}], "-", 
              RowBox[{"6", 
               SuperscriptBox["e", "3"]}]}], ")"}]}], 
           RowBox[{"8", "d", 
            RowBox[{"(", 
             RowBox[{"d", "+", "4"}], ")"}]}]], "\[Nu]0"}]}], ",", 
        RowBox[{"\[Lambda]3", "\[Rule]", 
         RowBox[{
          FractionBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"1", "+", "e"}], ")"}], "2"], 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["d", "2"], "+", 
              RowBox[{"5", "d"}], "-", "2", "-", 
              RowBox[{"3", "e", 
               RowBox[{"(", 
                RowBox[{"d", "+", "4"}], ")"}]}], "+", 
              RowBox[{"6", 
               SuperscriptBox["e", "2"]}]}], ")"}]}], 
           RowBox[{"8", 
            SuperscriptBox["d", "2"]}]], "\[Nu]0"}]}], ",", 
        RowBox[{"\[Lambda]4", "\[Rule]", 
         RowBox[{
          FractionBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"1", "+", "e"}], ")"}], "2"], 
            RowBox[{"(", 
             RowBox[{"2", "-", "d", "+", 
              RowBox[{"3", "e", 
               RowBox[{"(", 
                RowBox[{"d", "+", "4"}], ")"}]}], "-", 
              RowBox[{"6", 
               SuperscriptBox["e", "2"]}]}], ")"}]}], 
           RowBox[{"4", "d", 
            RowBox[{"(", 
             RowBox[{"d", "+", "4"}], ")"}]}]], "\[Nu]0"}]}]}], "}"}]}]}], 
    ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"resultforPij1", "-", 
       RowBox[{
        FractionBox["1", "d"], 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i1", ",", "i2"}], "}"}], "]"}], "resultforP2"}]}], ")"}], 
     "-", "expPij1Paper"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.7383954198929977`*^9, 3.738395424674985*^9}, {
   3.738395505793868*^9, 3.738395508613287*^9}, {3.7383955414619293`*^9, 
   3.738395555856544*^9}, {3.738395587057211*^9, 3.7383956011687737`*^9}, {
   3.738397306746271*^9, 3.738397407307046*^9}, 3.7383974728312073`*^9, 
   3.7384019088503523`*^9, {3.738402075667809*^9, 3.7384021822473383`*^9}, {
   3.738402221796605*^9, 3.7384022477042303`*^9}, {3.738402391753244*^9, 
   3.7384023975098352`*^9}, 3.7384027990732927`*^9, 3.7384030767677307`*^9, {
   3.738403445419623*^9, 3.738403461962978*^9}, {3.7384054770313663`*^9, 
   3.7384055179400187`*^9}, {3.738405589561429*^9, 3.738405659047534*^9}, {
   3.738405707577346*^9, 3.738405786739287*^9}, {3.738405822922612*^9, 
   3.738405950430243*^9}, {3.7384060404813757`*^9, 3.738406044129868*^9}, {
   3.7384062232602663`*^9, 3.738406226988558*^9}, 3.738410030182653*^9, {
   3.738477980337686*^9, 3.738477984192157*^9}, {3.738478297687133*^9, 
   3.738478299047228*^9}},ExpressionUUID->"8f437c21-1496-4ce7-9c6e-\
9c024aa260fc"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.738478299757846*^9, 3.744961057851635*^9, 
  3.74496120393195*^9, 3.744961410498103*^9, 3.744962566860104*^9, 
  3.745014252770753*^9, 3.745017923555828*^9, 3.7451223561212883`*^9, 
  3.745122390613669*^9},ExpressionUUID->"32d2d238-6e2e-4958-8e4c-\
00fe7e36ef27"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   StyleBox[
    RowBox[{"To", " ", "write", " ", "in", " ", "the", " ", "paper"}],
    FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Pij1towrite", "=", 
     RowBox[{
      RowBox[{"Collect", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Einstein", "[", 
            RowBox[{"Expand", "[", 
             RowBox[{"m", " ", "resultPij1form1"}], "]"}], "]"}], "/.", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"\[Delta]", "[", "_", "]"}], "\[Rule]", "0"}], "}"}]}], "/.",
           "replace\[Rho]u"}], "/.", 
         RowBox[{"n", "\[Rule]", 
          FractionBox["\[Rho]", "m"]}]}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"u1", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i2"}], "}"}], "]"}], ",", 
          RowBox[{"\[Sigma]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i2"}], "}"}], "]"}], ",", 
          RowBox[{
           RowBox[{"\[Sigma]", "[", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "s0"}], "}"}], "]"}], " ", 
           RowBox[{"\[Sigma]", "[", 
            RowBox[{"{", 
             RowBox[{"i2", ",", "s0"}], "}"}], "]"}]}], ",", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i2"}], "}"}], "]"}]}], "}"}], ",", 
        "Simplify"}], "]"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"u1", "[", 
         RowBox[{"{", 
          RowBox[{"i1", ",", "i2"}], "}"}], "]"}], "\[Rule]", 
        RowBox[{
         RowBox[{"R", "[", 
          RowBox[{"{", 
           RowBox[{"i1", ",", "i2"}], "}"}], "]"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"d", "+", "4"}], ")"}], "\[Theta]", " ", 
          RowBox[{"\[Sigma]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "i2"}], "}"}], "]"}]}]}]}], "}"}]}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Pij1towrite", "-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "\[Nu]0"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[Nu]R", " ", 
            RowBox[{"R", "[", 
             RowBox[{"{", 
              RowBox[{"i1", ",", "i2"}], "}"}], "]"}]}], "+", 
           RowBox[{"\[Alpha]2", " ", "\[Theta]", " ", 
            RowBox[{"\[Sigma]", "[", 
             RowBox[{"{", 
              RowBox[{"i1", ",", "i2"}], "}"}], "]"}]}], "+", 
           RowBox[{"c1", 
            FractionBox[
             RowBox[{
              RowBox[{"\[Sigma]", "[", 
               RowBox[{"{", 
                RowBox[{"i1", ",", "s0"}], "}"}], "]"}], " ", 
              RowBox[{"\[Sigma]", "[", 
               RowBox[{"{", 
                RowBox[{"i2", ",", "s0"}], "}"}], "]"}]}], "\[Rho]"]}]}], 
          ")"}]}], ")"}]}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\[Nu]R", "\[Rule]", 
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", "e"}], ")"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"7", 
              SuperscriptBox["d", "2"]}], "+", 
             RowBox[{"31", "d"}], "+", "18", "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["d", "2"], "+", 
                RowBox[{"14", "d"}], "+", "34"}], ")"}], "e"}], "+", 
             RowBox[{"3", 
              RowBox[{"(", 
               RowBox[{"d", "+", "2"}], ")"}], 
              SuperscriptBox["e", "2"]}], "-", 
             RowBox[{"6", 
              SuperscriptBox["e", "3"]}]}], ")"}]}], 
          RowBox[{"8", "d", 
           RowBox[{"(", 
            RowBox[{"d", "+", "4"}], ")"}]}]]}], ",", 
        RowBox[{"\[Alpha]2", "\[Rule]", 
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", "e"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              SuperscriptBox["d", "2"]}], "+", 
             RowBox[{"13", " ", "d"}], "+", "10", "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["d", "2"], "+", 
                RowBox[{"8", " ", "d"}], "+", "10"}], ")"}], " ", "e"}], "+", 
             
             RowBox[{"3", 
              RowBox[{"(", 
               RowBox[{"d", "+", "2"}], ")"}], 
              SuperscriptBox["e", "2"]}], "-", 
             RowBox[{"6", " ", 
              SuperscriptBox["e", "3"]}]}], ")"}]}], 
          RowBox[{"4", " ", "d"}]]}], ",", 
        RowBox[{"c1", "\[Rule]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"1", "+", "e"}], ")"}], "2"], 
            RowBox[{"(", 
             RowBox[{"d", "-", "2", "-", 
              RowBox[{"3", 
               RowBox[{"(", 
                RowBox[{"d", "+", "4"}], ")"}], "e"}], "+", 
              RowBox[{"6", 
               SuperscriptBox["e", "2"]}]}], ")"}]}], 
           RowBox[{"4", "d", 
            RowBox[{"(", 
             RowBox[{"d", "+", "4"}], ")"}]}]]}]}]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"R", "[", 
        RowBox[{"{", 
         RowBox[{"i1", ",", "i2"}], "}"}], "]"}], ",", 
       RowBox[{"\[Sigma]", "[", 
        RowBox[{"{", 
         RowBox[{"i1", ",", "i2"}], "}"}], "]"}], ",", 
       RowBox[{
        RowBox[{"\[Sigma]", "[", 
         RowBox[{"{", 
          RowBox[{"i1", ",", "s0"}], "}"}], "]"}], 
        RowBox[{"\[Sigma]", "[", 
         RowBox[{"{", 
          RowBox[{"i2", ",", "s0"}], "}"}], "]"}]}], ",", 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"{", 
         RowBox[{"i1", ",", "i2"}], "}"}], "]"}]}], "}"}], ",", "Simplify"}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{
  3.738664826399189*^9, {3.73866486631916*^9, 3.7386649637144527`*^9}, {
   3.738665002264349*^9, 3.738665022622917*^9}, {3.738665072118774*^9, 
   3.738665136298582*^9}, {3.738665190016629*^9, 3.7386651932212477`*^9}, 
   3.7386662817799063`*^9, {3.7386664863643503`*^9, 3.738666524431271*^9}, {
   3.738666556049779*^9, 3.738666589125204*^9}, {3.744962602442113*^9, 
   3.7449626492491703`*^9}, {3.7449626968276463`*^9, 3.744962707097883*^9}, {
   3.744964035370309*^9, 3.744964156816532*^9}, {3.744964289298316*^9, 
   3.7449643860658007`*^9}, {3.744964486682667*^9, 3.744964537642252*^9}, {
   3.74496464973134*^9, 3.7449646693765173`*^9}, {3.744985412275031*^9, 
   3.7449854343377028`*^9}, {3.7450179394194183`*^9, 3.745017949490522*^9}, 
   3.745018263587586*^9, {3.7450197731162357`*^9, 
   3.745019776929233*^9}},ExpressionUUID->"33bf6746-9fc5-4617-be29-\
a865cf06e305"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.738664964381884*^9, 3.738665024016605*^9, {3.738665074123617*^9, 
   3.738665085798345*^9}, 3.738665149211368*^9, 3.738665194627501*^9, 
   3.738666288112006*^9, {3.738666333504463*^9, 3.738666350745865*^9}, {
   3.7386664805441027`*^9, 3.738666525136795*^9}, {3.738666556844636*^9, 
   3.738666590602971*^9}, 3.7449610580970583`*^9, 3.74496120417796*^9, 
   3.74496141073271*^9, 3.744962567098477*^9, 3.744962650989491*^9, 
   3.744962708920874*^9, {3.7449641287172413`*^9, 3.7449641387301407`*^9}, 
   3.744964316470149*^9, 3.744964387746785*^9, 3.7449645398974037`*^9, {
   3.7449646563057213`*^9, 3.74496467655976*^9}, {3.7449854206443663`*^9, 
   3.7449854361625*^9}, 3.7450142530230827`*^9, {3.745017923791102*^9, 
   3.745017951086918*^9}, 3.745018265488986*^9, 3.7450197778340883`*^9, 
   3.745122356379141*^9, 
   3.745122390851357*^9},ExpressionUUID->"94657d62-d498-48f8-a4f2-\
3b9aa4754318"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Alpha]2", "/.", 
     RowBox[{"\[Alpha]2", "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", "e"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["d", "2"]}], "+", 
          RowBox[{"13", " ", "d"}], "+", "10", "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["d", "2"], "+", 
             RowBox[{"8", " ", "d"}], "+", "10"}], ")"}], " ", "e"}], "+", 
          RowBox[{"3", 
           RowBox[{"(", 
            RowBox[{"d", "+", "2"}], ")"}], 
           SuperscriptBox["e", "2"]}], "-", 
          RowBox[{"6", " ", 
           SuperscriptBox["e", "3"]}]}], ")"}]}], 
       RowBox[{"4", " ", "d"}]]}]}], "/.", 
    RowBox[{"d", "\[Rule]", "2"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"e", ",", "0", ",", "1"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.744985468024858*^9, 3.7449855241776257`*^9}, {
  3.745017967394394*^9, 
  3.745017970090303*^9}},ExpressionUUID->"351793d0-0079-4934-94c8-\
735c743b3d16"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwV2Hk8VF8UAPARRagfKt4MKVmKiCSV0rlSJClbKZElQkmyVKIkUUlZi6SM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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 6.},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.74498549541593*^9, 3.744985524747857*^9}, 
   3.745014253077519*^9, 3.74501792384074*^9, 3.745017971961113*^9, 
   3.745122356423244*^9, 
   3.7451223908969097`*^9},ExpressionUUID->"54beac06-dc0b-4f2d-84a8-\
e52a04ed497d"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Production Term for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["C", "i"], 
    SubscriptBox["C", "j"], 
    SubscriptBox["C", "k"], 
    SubscriptBox["C", "l"]}], TraditionalForm]],ExpressionUUID->
  "0a9d027e-867c-4063-9280-eed18e7c33a3"]
}], "Subsection",
 CellChangeTimes->{{3.540736884072311*^9, 3.5407369043909597`*^9}, {
  3.542452633864394*^9, 3.542452671646845*^9}, {3.737272427807934*^9, 
  3.737272430722102*^9}, {3.737273281718402*^9, 3.7372732969187727`*^9}, {
  3.7384017425560913`*^9, 3.73840174518649*^9}, {3.738402807640226*^9, 
  3.738402810504265*^9}},
 TextAlignment->Center,
 FontColor->RGBColor[0.5, 0, 0.5],
 Background->RGBColor[
  1, 1, 0.85],ExpressionUUID->"693b3246-19a9-43c8-aad6-f0fc43a51422"],

Cell[BoxData[{
 RowBox[{"Clear", "[", 
  RowBox[{"w0", ",", "g"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"idx", "=", 
   RowBox[{"{", 
    RowBox[{"i1", ",", "i2", ",", "i3", ",", "i4"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"nn", "=", 
    RowBox[{"Length", "[", "idx", "]"}]}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   StyleBox[
    RowBox[{
    "raw", " ", "form", " ", "of", " ", "integrand", " ", "without", " ", 
     "factor", " ", 
     FractionBox[
      RowBox[{"m", " ", "\[Nu]"}], 
      RowBox[{"n", " ", "\[CapitalOmega]d"}]], " ", "and", " ", "f", " ", 
     "f1", " ", "in", " ", "the", " ", "collision", " ", "integral"}],
    FontColor->RGBColor[1, 0.5, 0]], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Pijkl0", "=", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"\[Beta]", "=", "1"}], "nn"], 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"\[Gamma]", "=", "0"}], 
       RowBox[{"\[Beta]", "/", "2"}]], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], "\[Beta]"], 
       SuperscriptBox["w0", "\[Beta]"], 
       RowBox[{"Binomial", "[", 
        RowBox[{"nn", ",", "\[Beta]"}], "]"}], 
       RowBox[{"Delta", "[", 
        RowBox[{
         RowBox[{"idx", "\[LeftDoubleBracket]", 
          RowBox[{"range", "[", 
           RowBox[{"1", ",", "\[Gamma]"}], "]"}], "\[RightDoubleBracket]"}], 
         ",", 
         RowBox[{"idx", "\[LeftDoubleBracket]", 
          RowBox[{"range", "[", 
           RowBox[{
            RowBox[{"\[Gamma]", "+", "1"}], ",", 
            RowBox[{"2", "\[Gamma]"}]}], "]"}], "\[RightDoubleBracket]"}]}], 
        "]"}], 
       RowBox[{"\[Alpha]", "[", 
        RowBox[{"\[Gamma]", ",", "\[Beta]"}], "]"}], 
       SuperscriptBox["g", 
        RowBox[{"2", "\[Gamma]"}]], 
       RowBox[{"gg", "[", 
        RowBox[{"idx", "\[LeftDoubleBracket]", 
         RowBox[{"range", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"2", "\[Gamma]"}], "+", "1"}], ",", "\[Beta]"}], "]"}], 
         "\[RightDoubleBracket]"}], "]"}], 
       RowBox[{"CC", "[", 
        RowBox[{"idx", "\[LeftDoubleBracket]", 
         RowBox[{"range", "[", 
          RowBox[{
           RowBox[{"\[Beta]", "+", "1"}], ",", "nn"}], "]"}], 
         "\[RightDoubleBracket]"}], "]"}]}]}]}]}], 
   RowBox[{"(*", 
    RowBox[{"f", " ", "f1"}], "*)"}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   StyleBox[
    RowBox[{"symmetrization", " ", "of", " ", "the", " ", "indices"}],
    FontColor->RGBColor[1, 0.5, 0]], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"perm", "=", 
   RowBox[{"Permutations", "[", "idx", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CollInt", "=", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{"CollInt", "+=", 
    RowBox[{"Pijkl0", "/.", 
     RowBox[{"Thread", "[", 
      RowBox[{"idx", "\[Rule]", 
       RowBox[{
       "perm", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}]}], 
      "]"}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{"ii", ",", "1", ",", 
     RowBox[{"Length", "[", "perm", "]"}]}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CollIntegralPijkl0", "=", 
    RowBox[{"ExpandAll", "[", 
     RowBox[{
      FractionBox["CollInt", 
       RowBox[{"Length", "[", "perm", "]"}]], "/.", "replace$gsq"}], "]"}]}], 
   ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   StyleBox[
    RowBox[{
     RowBox[{"main", " ", "working", " ", 
      RowBox[{"steps", ":", " ", 
       RowBox[{
        RowBox[{
        "1.", " ", "integrate", " ", "directions", " ", "in", " ", "h"}], "-",
         "vectors"}]}]}], ";", " ", 
     RowBox[{
      RowBox[{
      "2.", " ", "integrate", " ", "directions", " ", "in", " ", "g"}], "-", 
      "vectors"}], ";", " ", 
     RowBox[{
     "3.", " ", "integrate", " ", "Gauss", " ", "integrals", " ", "in", " ", 
      "h"}], ";", " ", 
     RowBox[{
     "4.", " ", "perform", " ", "contractions", " ", "on", " ", "\[Delta]"}]}],
    FontColor->RGBColor[1, 0.5, 0]], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g", "[", "idx_", "]"}], ":=", 
  RowBox[{
   RowBox[{"CC", "[", "idx", "]"}], "-", 
   RowBox[{"CC1", "[", "idx", "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CollIntegralPijkl0", "=", 
    RowBox[{"Expand", "[", "CollIntegralPijkl0", "]"}]}], ";"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   StyleBox[
    RowBox[{"Integration", " ", "over", " ", "C", " ", "and", " ", "C1"}],
    FontColor->RGBColor[1, 0.5, 0]], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"resultPijkl0", "=", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Einstein", "[", 
         RowBox[{"intoverCC1", "[", 
          RowBox[{
          "CollIntegralPijkl0", "\[LeftDoubleBracket]", "ii", 
           "\[RightDoubleBracket]"}], "]"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"ii", ",", "1", ",", 
          RowBox[{"Length", "[", "CollIntegralPijkl0", "]"}]}], "}"}]}], 
       "]"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"list\[Rho]Pijkl0", "=", 
   RowBox[{"DeleteDuplicates", "[", 
    RowBox[{"Extract", "[", 
     RowBox[{"resultPijkl0", ",", 
      RowBox[{"Position", "[", 
       RowBox[{"resultPijkl0", ",", 
        RowBox[{"\[Rho]", "[", 
         RowBox[{"_", ",", "_"}], "]"}]}], "]"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"replace\[Rho]Pijkl0", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
      "list\[Rho]Pijkl0", "\[LeftDoubleBracket]", "ii", 
       "\[RightDoubleBracket]"}], "\[Rule]", 
      RowBox[{"tracefreerepresentation", "[", 
       RowBox[{
       "list\[Rho]Pijkl0", "\[LeftDoubleBracket]", "ii", 
        "\[RightDoubleBracket]"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"ii", ",", "1", ",", 
       RowBox[{"Length", "[", "list\[Rho]Pijkl0", "]"}]}], "}"}]}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.537993578189455*^9, 3.537993610797545*^9}, {
   3.537993771670854*^9, 3.537993779038876*^9}, {3.5379938261036*^9, 
   3.537993894920753*^9}, 3.537993985202799*^9, {3.537994016572002*^9, 
   3.537994037555522*^9}, {3.537994388113123*^9, 3.5379944406823893`*^9}, {
   3.5379944716672297`*^9, 3.537994535484898*^9}, {3.5379946435344*^9, 
   3.537994670999247*^9}, {3.537994822992545*^9, 3.537994848706256*^9}, {
   3.537994948252141*^9, 3.5379951325767097`*^9}, {3.537995185554933*^9, 
   3.537995241802492*^9}, {3.537995276222849*^9, 3.537995281348686*^9}, {
   3.53799533558186*^9, 3.5379953402203913`*^9}, {3.537995373317173*^9, 
   3.537995389189156*^9}, {3.537995463503443*^9, 3.537995586335116*^9}, {
   3.537995620905704*^9, 3.537995685353702*^9}, {3.537995731882414*^9, 
   3.537995740818839*^9}, {3.53799608412899*^9, 3.537996120582891*^9}, {
   3.537996373868025*^9, 3.537996470581868*^9}, {3.537996552739531*^9, 
   3.537996599754401*^9}, {3.537996699014799*^9, 3.537996718444993*^9}, {
   3.5379967905373993`*^9, 3.537996835526949*^9}, {3.537996969586375*^9, 
   3.537997008865888*^9}, {3.537997054707327*^9, 3.5379970594661016`*^9}, {
   3.537997228824871*^9, 3.537997383715749*^9}, {3.537997495969655*^9, 
   3.537997504978291*^9}, {3.538049111849923*^9, 3.538049145198148*^9}, {
   3.538049184515108*^9, 3.538049258034523*^9}, {3.5380493781370897`*^9, 
   3.538049391682486*^9}, {3.538049424567073*^9, 3.538049487235387*^9}, {
   3.538049594582995*^9, 3.538049743296955*^9}, {3.538050939370043*^9, 
   3.5380509982737083`*^9}, {3.5380676731372538`*^9, 3.538067723150732*^9}, 
   3.53806785052652*^9, {3.538067941214231*^9, 3.538067990711932*^9}, {
   3.538068029462811*^9, 3.538068153307399*^9}, {3.53806855796034*^9, 
   3.538068627746333*^9}, {3.53806869188647*^9, 3.538068751511098*^9}, {
   3.538068919982791*^9, 3.538068952563477*^9}, {3.538120345641403*^9, 
   3.538120421155457*^9}, 3.538120780664413*^9, {3.538120852906658*^9, 
   3.538120953903056*^9}, {3.538121002642786*^9, 3.538121148063637*^9}, {
   3.538126353936679*^9, 3.538126386984695*^9}, {3.538126473001809*^9, 
   3.5381265005530252`*^9}, {3.538126537649548*^9, 3.538126555161577*^9}, {
   3.5381266439234133`*^9, 3.538126715750491*^9}, 3.538127882474265*^9, {
   3.538130944351671*^9, 3.538131077658307*^9}, {3.538131942442205*^9, 
   3.538132013760786*^9}, {3.538132283894219*^9, 3.538132360880001*^9}, {
   3.538133348588627*^9, 3.538133377632154*^9}, {3.53813341458228*^9, 
   3.538133595785343*^9}, {3.538133693428665*^9, 3.538133893912404*^9}, {
   3.538133930459076*^9, 3.538134125076247*^9}, {3.53813417768613*^9, 
   3.538134217260666*^9}, {3.538134259339695*^9, 3.538134264398603*^9}, {
   3.538137299532156*^9, 3.538137342311903*^9}, {3.538137430398448*^9, 
   3.538137473144889*^9}, {3.5381376929555693`*^9, 3.5381377022975807`*^9}, {
   3.5381379513516703`*^9, 3.538137995917336*^9}, {3.538138048946089*^9, 
   3.53813805994525*^9}, {3.538138121394474*^9, 3.5381381959580793`*^9}, {
   3.5381382502615757`*^9, 3.538138273902351*^9}, {3.5381383210109873`*^9, 
   3.538138336804418*^9}, 3.538138516977003*^9, {3.5381618433477077`*^9, 
   3.538161932597952*^9}, {3.538161987860311*^9, 3.5381620846113997`*^9}, {
   3.5381621539329453`*^9, 3.538162195795615*^9}, {3.538162226745761*^9, 
   3.538162260756913*^9}, {3.538162294790723*^9, 3.538162558108499*^9}, {
   3.5382004503666887`*^9, 3.538200516536386*^9}, {3.5382005504900503`*^9, 
   3.538200576308169*^9}, {3.538200918185061*^9, 3.5382009209833603`*^9}, 
   3.538200954918594*^9, {3.5382012679264*^9, 3.538201268242012*^9}, {
   3.5382013070166893`*^9, 3.538201311732603*^9}, 3.53820156656705*^9, {
   3.538201655677127*^9, 3.538201682767631*^9}, 3.538201919512535*^9, 
   3.538243145787212*^9, 3.53824318144276*^9, {3.538243282594778*^9, 
   3.5382432941723957`*^9}, {3.5382433354676323`*^9, 
   3.5382433373488293`*^9}, {3.538243583835874*^9, 3.538243588737722*^9}, {
   3.538244168454702*^9, 3.538244180740324*^9}, {3.538244332583802*^9, 
   3.538244339379407*^9}, 3.5382449465768633`*^9, {3.5388070078690643`*^9, 
   3.538807099973749*^9}, {3.538807180708592*^9, 3.5388071828035707`*^9}, 
   3.5388074844694977`*^9, {3.538807551230954*^9, 3.538807553504488*^9}, {
   3.538808873941285*^9, 3.538808875477491*^9}, {3.538808927009503*^9, 
   3.5388089304970512`*^9}, {3.538808998699823*^9, 3.538809020477653*^9}, {
   3.538809124555171*^9, 3.538809131039702*^9}, 3.538809175971305*^9, {
   3.538809338238731*^9, 3.5388093394879303`*^9}, 3.5388093971728573`*^9, {
   3.53881066031894*^9, 3.538810687713526*^9}, 3.538810748528813*^9, {
   3.5388107917831078`*^9, 3.538810794089106*^9}, {3.538811661821177*^9, 
   3.538811724776244*^9}, 3.538817331517233*^9, {3.5388192046322308`*^9, 
   3.538819214494584*^9}, {3.5392665470358353`*^9, 3.5392665745099287`*^9}, {
   3.539266610562613*^9, 3.539266615983183*^9}, {3.5392666830721903`*^9, 
   3.539266815780409*^9}, 3.539266848624251*^9, 3.539266890598507*^9, {
   3.539267060053648*^9, 3.539267072703176*^9}, 3.5392677537069807`*^9, 
   3.539267788390932*^9, {3.539268495010467*^9, 3.539268496663838*^9}, 
   3.539269140585288*^9, 3.539269235639429*^9, {3.539269355353408*^9, 
   3.539269383630211*^9}, {3.539269638969858*^9, 3.539269750991323*^9}, {
   3.53926979106437*^9, 3.539269810113697*^9}, {3.5392701517950487`*^9, 
   3.5392701920043097`*^9}, 3.539278908980487*^9, 3.539278996527172*^9, {
   3.539326343054734*^9, 3.539326435401582*^9}, {3.539326569957453*^9, 
   3.539326575804747*^9}, {3.539326991237306*^9, 3.5393270082806168`*^9}, {
   3.539329433774241*^9, 3.5393294960187607`*^9}, {3.5393305017074823`*^9, 
   3.539330556642144*^9}, 3.539330888641615*^9, {3.539339971597237*^9, 
   3.5393399876891327`*^9}, {3.5393400782346582`*^9, 3.539340081023357*^9}, {
   3.5393401448438396`*^9, 3.539340145504077*^9}, {3.539347774329233*^9, 
   3.539347843122929*^9}, 3.539366432292687*^9, {3.539367245443975*^9, 
   3.539367246347004*^9}, {3.540734202771955*^9, 3.5407342043103733`*^9}, {
   3.540736418761684*^9, 3.5407364226194553`*^9}, {3.540737768596367*^9, 
   3.540737768892754*^9}, {3.542388724376953*^9, 3.542388781889929*^9}, {
   3.542388924988758*^9, 3.542388987923122*^9}, {3.5423890458105783`*^9, 
   3.542389193224463*^9}, {3.542389272963728*^9, 3.54238930706011*^9}, {
   3.542437641275167*^9, 3.542437699202085*^9}, {3.542437730796095*^9, 
   3.5424378902358*^9}, 3.542437945897581*^9, {3.5424379882249823`*^9, 
   3.5424380665457783`*^9}, 3.5424381121082697`*^9, {3.542438249182868*^9, 
   3.5424382662648687`*^9}, 3.542438305697894*^9, {3.542439075760028*^9, 
   3.5424390838844147`*^9}, {3.542439173737357*^9, 3.542439220087296*^9}, {
   3.542443352398711*^9, 3.542443381775426*^9}, {3.542443447124556*^9, 
   3.542443480430725*^9}, {3.542443613406389*^9, 3.542443649481735*^9}, 
   3.542443699901371*^9, {3.5424462578396807`*^9, 3.542446274257043*^9}, {
   3.542446401017707*^9, 3.542446413600088*^9}, {3.5424464659327908`*^9, 
   3.5424464878337793`*^9}, {3.5424465291804132`*^9, 3.5424465329099913`*^9}, 
   3.542446742755765*^9, {3.542446778102816*^9, 3.542446785282056*^9}, {
   3.542446834089986*^9, 3.542446884468789*^9}, {3.542446919291979*^9, 
   3.542446939944065*^9}, {3.542446976270124*^9, 3.5424469866004257`*^9}, {
   3.542447056705858*^9, 3.5424470898445673`*^9}, {3.5424471344029417`*^9, 
   3.542447174506599*^9}, {3.5424472312410507`*^9, 3.54244726772272*^9}, {
   3.5424473125427227`*^9, 3.5424473254819317`*^9}, {3.5424473695330887`*^9, 
   3.542447388671294*^9}, 3.542448224058323*^9, {3.542451548746708*^9, 
   3.5424515774216213`*^9}, {3.5424519211077013`*^9, 3.542451928153799*^9}, {
   3.54245299950036*^9, 3.542453001194194*^9}, {3.542455811416429*^9, 
   3.542455815394039*^9}, {3.542622812244008*^9, 3.542622822000717*^9}, {
   3.542622859825048*^9, 3.542622931786152*^9}, {3.54269829979911*^9, 
   3.542698305254208*^9}, {3.542699025561718*^9, 3.542699026123849*^9}, {
   3.5426990707182913`*^9, 3.542699088670185*^9}, {3.542700118933394*^9, 
   3.542700121036415*^9}, 3.542700827765305*^9, {3.5429174051788473`*^9, 
   3.542917524367551*^9}, 3.5429176869021387`*^9, {3.542969166437325*^9, 
   3.542969172344721*^9}, {3.548190436221043*^9, 3.548190445993956*^9}, 
   3.548190491401569*^9, {3.548190752747745*^9, 3.548190753292897*^9}, {
   3.54901721401657*^9, 3.549017214311965*^9}, {3.549017247695644*^9, 
   3.5490173217517653`*^9}, {3.5490175863059607`*^9, 3.549017586840351*^9}, {
   3.64364096822392*^9, 3.643640983650118*^9}, 3.643641025520862*^9, {
   3.6436415353816833`*^9, 3.643641602069047*^9}, {3.643641636036574*^9, 
   3.643641702536974*^9}, 3.643641788051527*^9, {3.6436418353044577`*^9, 
   3.643641843368132*^9}, {3.678793251829185*^9, 3.678793285790352*^9}, 
   3.6787994439458447`*^9, {3.678862755048066*^9, 3.6788627561980753`*^9}, 
   3.678865112211464*^9, {3.681391437897203*^9, 3.681391452879457*^9}, {
   3.737108210053956*^9, 3.737108249563664*^9}, {3.7371084042540083`*^9, 
   3.7371084083262463`*^9}, 3.737109292446753*^9, {3.737109749523717*^9, 
   3.737109805554154*^9}, {3.737110028644668*^9, 3.737110070179446*^9}, {
   3.737110150417325*^9, 3.737110151300057*^9}, 3.737110382136352*^9, {
   3.737110458359399*^9, 3.737110460309579*^9}, {3.737110702040637*^9, 
   3.737110703878584*^9}, {3.7371117587819138`*^9, 3.73711177306219*^9}, {
   3.737113682711214*^9, 3.7371136853064327`*^9}, {3.7371138793370953`*^9, 
   3.737113881349288*^9}, {3.73718694545557*^9, 3.737186984864314*^9}, {
   3.737187015838509*^9, 3.7371870332629213`*^9}, {3.737187072238668*^9, 
   3.7371870800135736`*^9}, {3.737189762748537*^9, 3.737189763128755*^9}, {
   3.737189800186709*^9, 3.737189804667068*^9}, {3.7371898409234247`*^9, 
   3.737189845354582*^9}, 3.737190240046109*^9, {3.7371903718842573`*^9, 
   3.737190380979869*^9}, {3.737191435152549*^9, 3.737191467949527*^9}, {
   3.737191521249221*^9, 3.73719156092738*^9}, {3.737191766050044*^9, 
   3.7371917689123497`*^9}, 3.737197927456336*^9, {3.737198159489818*^9, 
   3.737198159886495*^9}, {3.737200386075508*^9, 3.7372003868555098`*^9}, {
   3.737264960908597*^9, 3.7372649614648647`*^9}, 3.7372710196476183`*^9, {
   3.737271124669427*^9, 3.737271139070385*^9}, {3.737271449376149*^9, 
   3.737271450701746*^9}, {3.737272473365141*^9, 3.737272503208777*^9}, {
   3.7372725472818527`*^9, 3.737272573132128*^9}, {3.737272872657456*^9, 
   3.737272875955984*^9}, {3.73727330346493*^9, 3.737273333526195*^9}, {
   3.737273441415806*^9, 3.73727346055801*^9}, {3.738396788506775*^9, 
   3.738396792615591*^9}, {3.738396838807775*^9, 3.738396881515554*^9}, {
   3.738397086236014*^9, 3.738397096880761*^9}, {3.738401749460299*^9, 
   3.738401774943083*^9}, {3.738402799046348*^9, 3.7384027990656652`*^9}, {
   3.738402857208009*^9, 
   3.738402887529553*^9}},ExpressionUUID->"f23b815c-e1e5-4246-9bee-\
6b3c62db3807"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"factor", "=", 
    RowBox[{"(*", "m", "*)"}], 
    FractionBox["\[Nu]", 
     RowBox[{"n", " ", "\[CapitalOmega]d"}]]}], ";"}], "\[IndentingNewLine]", 
  
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"resultPijkl0form1", "=", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"factor", " ", "resultPijkl0"}], "/.", 
         "replace\[Rho]Pijkl0"}], "/.", "replace\[Alpha]"}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\[Nu]", "\[Rule]", 
          RowBox[{
           FractionBox[
            RowBox[{"d", "+", "2"}], "2"], "\[Nu]0"}]}], ",", 
         RowBox[{"w0", "\[Rule]", 
          FractionBox[
           RowBox[{"1", "+", "e"}], "2"]}]}], "}"}]}], 
      RowBox[{"(*", 
       RowBox[{"/.", 
        RowBox[{"{", 
         RowBox[{"\[Nu]0", "\[Rule]", 
          RowBox[{
           FractionBox[
            RowBox[{"2", "d"}], 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "+", "e"}], ")"}], 
             RowBox[{"(", 
              RowBox[{"d", "+", "1", "-", "e"}], ")"}]}]], 
           RowBox[{"\[Nu]", "[", 
            RowBox[{"0", ",", "2"}], "]"}]}]}], "}"}]}], "*)"}], "]"}]}], 
    ";"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"resultPijkl0form1", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"factor", " ", "resultPijkl0"}], "/.", "replace\[Rho]Pijkl0"}],
       "/.", "replace\[Alpha]"}], "/.", "gammareplacements"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[Nu]", "\[Rule]", 
       RowBox[{
        FractionBox[
         RowBox[{"d", "+", "2"}], "2"], "\[Nu]0"}]}], ",", 
      RowBox[{"w0", "\[Rule]", 
       FractionBox[
        RowBox[{"1", "+", "e"}], "2"]}]}], "}"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.737272917319312*^9, 3.737272919047133*^9}, {
   3.73727297093484*^9, 3.73727298523519*^9}, {3.737273051179839*^9, 
   3.737273105514578*^9}, {3.737273137272187*^9, 3.737273225397573*^9}, 
   3.7372734650377493`*^9, 3.7372736090084267`*^9, {3.737273660475463*^9, 
   3.737273777624713*^9}, 3.738395699297328*^9, {3.7383960772383204`*^9, 
   3.738396078243876*^9}, {3.738396678794359*^9, 3.738396711670636*^9}, {
   3.738396763385541*^9, 3.738396783144718*^9}, {3.7383968961843367`*^9, 
   3.738396900581313*^9}, {3.738401908839529*^9, 3.7384019088444757`*^9}, 
   3.73840197000576*^9, {3.7384020287743187`*^9, 3.738402054020152*^9}, {
   3.738402799068179*^9, 3.738402799070344*^9}, {3.738406498527244*^9, 
   3.738406525916078*^9}, {3.738407733403331*^9, 3.7384077491159973`*^9}, {
   3.7384087367631187`*^9, 3.738408739148847*^9}, 3.738408784601871*^9, {
   3.7384103696245613`*^9, 
   3.738410372424474*^9}},ExpressionUUID->"6838028d-3dc2-4833-9815-\
9c925cae3be3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"resultforPijkl0", "=", 
   RowBox[{
    RowBox[{"Einstein", "[", 
     RowBox[{"Expand", "[", 
      RowBox[{"resultPijkl0form1", "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"\[Rho]", "[", 
           RowBox[{"n_", ",", "li_"}], "]"}], "\[Rule]", 
          RowBox[{"m", " ", 
           RowBox[{"M", "[", 
            RowBox[{
             RowBox[{"2", "n"}], ",", "li"}], "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"\[Upsilon]", "[", 
           RowBox[{"n_", ",", "li_"}], "]"}], "\[Rule]", 
          RowBox[{"m", " ", 
           RowBox[{"M", "[", 
            RowBox[{
             RowBox[{"2", "n"}], ",", "li"}], "]"}]}]}]}], "}"}]}], "]"}], 
     "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"M", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", 
         RowBox[{"s0", ",", "s0"}], "}"}]}], "]"}], "\[Rule]", "0"}], 
     "}"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.738478352631146*^9, 
  3.738478355170828*^9}},ExpressionUUID->"1ad69254-4694-427b-a489-\
a4660d73b68b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   StyleBox[
    RowBox[{
     RowBox[{"Eq", ".", " ", 
      RowBox[{"(", "2.25", ")"}]}], " ", "of", " ", "Garz\[OAcute]", " ", 
     "and", " ", "Santos", " ", "2007", " ", 
     RowBox[{"J", ".", " ", "Phys", ".", " ", 
      RowBox[{"A", ":", " ", 
       RowBox[{
        RowBox[{"Math", ".", " ", "Theor", ".", " ", 
         StyleBox["40",
          FontWeight->"Bold"]}], " ", "14927"}]}]}]}],
    FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"expPijkl0Paper", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"\[Nu]", "[", 
         RowBox[{"0", ",", "4"}], "]"}]}], 
       RowBox[{"M", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"i1", ",", "i2", ",", "i3", ",", "i4"}], "}"}]}], "]"}]}], 
      "+", 
      RowBox[{
       FractionBox["\[Lambda]5", "n"], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"M", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i2"}], "}"}]}], "]"}], 
          RowBox[{"M", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", 
             RowBox[{"i3", ",", "i4"}], "}"}]}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"M", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i3"}], "}"}]}], "]"}], 
          RowBox[{"M", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", 
             RowBox[{"i2", ",", "i4"}], "}"}]}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"M", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i4"}], "}"}]}], "]"}], 
          RowBox[{"M", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", 
             RowBox[{"i2", ",", "i3"}], "}"}]}], "]"}]}], "-", 
         RowBox[{
          FractionBox["2", 
           RowBox[{"d", "+", "4"}]], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"M", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", 
                RowBox[{"i1", ",", "s0"}], "}"}]}], "]"}], " ", 
             RowBox[{"M", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", 
                RowBox[{"i2", ",", "s0"}], "}"}]}], "]"}], 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i3", ",", "i4"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"M", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", 
                RowBox[{"i1", ",", "s0"}], "}"}]}], "]"}], " ", 
             RowBox[{"M", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", 
                RowBox[{"i3", ",", "s0"}], "}"}]}], "]"}], 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i2", ",", "i4"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"M", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", 
                RowBox[{"i1", ",", "s0"}], "}"}]}], "]"}], " ", 
             RowBox[{"M", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", 
                RowBox[{"i4", ",", "s0"}], "}"}]}], "]"}], 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i2", ",", "i3"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"M", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", 
                RowBox[{"i2", ",", "s0"}], "}"}]}], "]"}], " ", 
             RowBox[{"M", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", 
                RowBox[{"i3", ",", "s0"}], "}"}]}], "]"}], 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i1", ",", "i4"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"M", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", 
                RowBox[{"i2", ",", "s0"}], "}"}]}], "]"}], " ", 
             RowBox[{"M", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", 
                RowBox[{"i4", ",", "s0"}], "}"}]}], "]"}], 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i1", ",", "i3"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"M", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", 
                RowBox[{"i3", ",", "s0"}], "}"}]}], "]"}], " ", 
             RowBox[{"M", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", 
                RowBox[{"i4", ",", "s0"}], "}"}]}], "]"}], 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i1", ",", "i2"}], "}"}], "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          FractionBox["2", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"d", "+", "2"}], ")"}], 
            RowBox[{"(", 
             RowBox[{"d", "+", "4"}], ")"}]}]], 
          RowBox[{"M", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", 
             RowBox[{"s0", ",", "s1"}], "}"}]}], "]"}], 
          RowBox[{"M", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", 
             RowBox[{"s0", ",", "s1"}], "}"}]}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i1", ",", "i2"}], "}"}], "]"}], 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i3", ",", "i4"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i1", ",", "i3"}], "}"}], "]"}], 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i2", ",", "i4"}], "}"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i1", ",", "i4"}], "}"}], "]"}], 
             RowBox[{"\[Delta]", "[", 
              RowBox[{"{", 
               RowBox[{"i2", ",", "i3"}], "}"}], "]"}]}]}], ")"}]}]}], 
        ")"}]}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Nu]", "[", 
         RowBox[{"0", ",", "4"}], "]"}], "\[Rule]", 
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", "e"}], ")"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", 
              SuperscriptBox["d", "3"]}], "+", 
             RowBox[{"21", 
              SuperscriptBox["d", "2"]}], "+", 
             RowBox[{"61", "d"}], "+", "39", "-", 
             RowBox[{"3", "e", 
              RowBox[{"(", 
               RowBox[{"d", "+", "3"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"d", "+", "5"}], ")"}]}], "+", 
             RowBox[{"3", 
              SuperscriptBox["e", "2"], 
              RowBox[{"(", 
               RowBox[{"d", "+", "3"}], ")"}]}], "-", 
             RowBox[{"3", 
              SuperscriptBox["e", "3"]}]}], ")"}]}], 
          RowBox[{"2", "d", 
           RowBox[{"(", 
            RowBox[{"d", "+", "4"}], ")"}], 
           RowBox[{"(", 
            RowBox[{"d", "+", "6"}], ")"}]}]], "\[Nu]0"}]}], ",", 
       RowBox[{"\[Lambda]5", "\[Rule]", 
        RowBox[{
         FractionBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"1", "+", "e"}], ")"}], "2"], 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["d", "2"], "+", 
             RowBox[{"7", "d"}], "+", "9", "-", 
             RowBox[{"3", "e", 
              RowBox[{"(", 
               RowBox[{"d", "+", "4"}], ")"}]}], "+", 
             RowBox[{"3", 
              SuperscriptBox["e", "2"]}]}], ")"}]}], 
          RowBox[{"2", "d", 
           RowBox[{"(", 
            RowBox[{"d", "+", "4"}], ")"}], 
           RowBox[{"(", 
            RowBox[{"d", "+", "6"}], ")"}]}]], "\[Nu]0"}]}]}], "}"}]}]}], 
   ";"}]}]], "Input",
 CellChangeTimes->{{3.7383954198929977`*^9, 3.738395424674985*^9}, {
   3.738395505793868*^9, 3.738395508613287*^9}, {3.7383955414619293`*^9, 
   3.738395555856544*^9}, {3.738395587057211*^9, 3.7383956011687737`*^9}, {
   3.738397306746271*^9, 3.738397407307046*^9}, 3.7383974728312073`*^9, 
   3.7384019088503523`*^9, {3.738402075667809*^9, 3.7384021822473383`*^9}, {
   3.738402221796605*^9, 3.7384022477042303`*^9}, {3.738402391753244*^9, 
   3.7384023975098352`*^9}, 3.7384027990732927`*^9, {3.738406547144153*^9, 
   3.7384065499757433`*^9}, {3.738406650237116*^9, 3.738406764697784*^9}, {
   3.738406811241873*^9, 3.738406875531163*^9}, {3.738406919114876*^9, 
   3.7384069480266743`*^9}, {3.7384070025231867`*^9, 3.738407218190641*^9}, {
   3.7384110449590673`*^9, 3.738411045401945*^9}, {3.738478385014587*^9, 
   3.738478388287499*^9}, {3.738479692328019*^9, 
   3.738479694023612*^9}},ExpressionUUID->"5590a3dc-eeb3-45b7-923d-\
ed252f9fd2a0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"resultforPijkl0", "-", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"(", 
         RowBox[{"d", "+", "4"}], ")"}]], "6", 
       RowBox[{"Einstein", "[", 
        RowBox[{"sym", "[", 
         RowBox[{"Expand", "[", 
          RowBox[{"resultforPij1", " ", 
           RowBox[{"\[Delta]", "[", 
            RowBox[{"{", 
             RowBox[{"i3", ",", "i4"}], "}"}], "]"}]}], "]"}], "]"}], "]"}]}],
       "+", 
      RowBox[{
       FractionBox["1", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"d", "+", "2"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"d", "+", "4"}], ")"}]}]], "3", 
       RowBox[{"sym", "[", 
        RowBox[{
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"i1", ",", "i2"}], "}"}], "]"}], 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"{", 
           RowBox[{"i3", ",", "i4"}], "}"}], "]"}]}], "]"}], 
       "resultforP2"}]}], ")"}], "-", "expPijkl0Paper"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Nu]", "[", 
       RowBox[{"0", ",", "4"}], "]"}], "\[Rule]", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", "e"}], ")"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", 
            SuperscriptBox["d", "3"]}], "+", 
           RowBox[{"21", 
            SuperscriptBox["d", "2"]}], "+", 
           RowBox[{"61", "d"}], "+", "39", "-", 
           RowBox[{"3", "e", 
            RowBox[{"(", 
             RowBox[{"d", "+", "3"}], ")"}], 
            RowBox[{"(", 
             RowBox[{"d", "+", "5"}], ")"}]}], "+", 
           RowBox[{"3", 
            SuperscriptBox["e", "2"], 
            RowBox[{"(", 
             RowBox[{"d", "+", "3"}], ")"}]}], "-", 
           RowBox[{"3", 
            SuperscriptBox["e", "3"]}]}], ")"}]}], 
        RowBox[{"2", "d", 
         RowBox[{"(", 
          RowBox[{"d", "+", "4"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"d", "+", "6"}], ")"}]}]], "\[Nu]0"}]}], ",", 
     RowBox[{"\[Lambda]5", "\[Rule]", 
      RowBox[{
       FractionBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "+", "e"}], ")"}], "2"], 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["d", "2"], "+", 
           RowBox[{"7", "d"}], "+", "9", "-", 
           RowBox[{"3", "e", 
            RowBox[{"(", 
             RowBox[{"d", "+", "4"}], ")"}]}], "+", 
           RowBox[{"3", 
            SuperscriptBox["e", "2"]}]}], ")"}]}], 
        RowBox[{"2", "d", 
         RowBox[{"(", 
          RowBox[{"d", "+", "4"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"d", "+", "6"}], ")"}]}]], "\[Nu]0"}]}]}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.738479569661087*^9, 3.738479572790679*^9}, {
  3.738479644865754*^9, 
  3.738479659455578*^9}},ExpressionUUID->"5d5ac222-bca9-4fe3-b78b-\
4799e75ee7b8"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.738479638738109*^9, 3.73847964808604*^9}, 
   3.738479717819006*^9, 
   3.7449648398025846`*^9},ExpressionUUID->"dda8f8d7-493d-47fd-b08e-\
dc3f8c846bf4"]
}, Open  ]],

Cell["Another Verification", "Text",
 CellChangeTimes->{{3.738541659096702*^9, 3.7385416668312674`*^9}},
 FontColor->RGBColor[
  1, 0, 0],ExpressionUUID->"e07171c8-3edc-46f5-85c4-ffa5dc120c01"],

Cell[BoxData[
 RowBox[{
  RowBox[{"contributiontotracefreeproduction", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"resultforPijkl0", "/.", 
      RowBox[{
       RowBox[{"\[Delta]", "[", "_", "]"}], "\[Rule]", "0"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"M", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", 
         RowBox[{"i1", ",", "i2", ",", "i3", ",", "i4"}], "}"}]}], "]"}], 
      "}"}], ",", "Simplify"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.738540606238982*^9, 3.738540644628585*^9}, {
   3.738540741602552*^9, 3.738540755389991*^9}, {3.738540808289527*^9, 
   3.73854082633937*^9}, 
   3.738541699434013*^9},ExpressionUUID->"07e9fbfa-de4f-4fe2-9a10-\
b2f76a2b0ab3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"contributiontotracefreeproduction", "-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"\[Nu]", "[", 
         RowBox[{"0", ",", "4"}], "]"}]}], 
       RowBox[{"M", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"i1", ",", "i2", ",", "i3", ",", "i4"}], "}"}]}], "]"}]}], 
      "+", 
      RowBox[{
       FractionBox["\[Lambda]5", "n"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"M", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i4"}], "}"}]}], "]"}], " ", 
          RowBox[{"M", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", 
             RowBox[{"i2", ",", "i3"}], "}"}]}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"M", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i3"}], "}"}]}], "]"}], " ", 
          RowBox[{"M", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", 
             RowBox[{"i2", ",", "i4"}], "}"}]}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"M", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", 
             RowBox[{"i1", ",", "i2"}], "}"}]}], "]"}], " ", 
          RowBox[{"M", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", 
             RowBox[{"i3", ",", "i4"}], "}"}]}], "]"}]}]}], ")"}]}]}], 
     ")"}]}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Nu]", "[", 
       RowBox[{"0", ",", "4"}], "]"}], "\[Rule]", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", "e"}], ")"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", 
            SuperscriptBox["d", "3"]}], "+", 
           RowBox[{"21", 
            SuperscriptBox["d", "2"]}], "+", 
           RowBox[{"61", "d"}], "+", "39", "-", 
           RowBox[{"3", "e", 
            RowBox[{"(", 
             RowBox[{"d", "+", "3"}], ")"}], 
            RowBox[{"(", 
             RowBox[{"d", "+", "5"}], ")"}]}], "+", 
           RowBox[{"3", 
            SuperscriptBox["e", "2"], 
            RowBox[{"(", 
             RowBox[{"d", "+", "3"}], ")"}]}], "-", 
           RowBox[{"3", 
            SuperscriptBox["e", "3"]}]}], ")"}]}], 
        RowBox[{"2", "d", 
         RowBox[{"(", 
          RowBox[{"d", "+", "4"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"d", "+", "6"}], ")"}]}]], "\[Nu]0"}]}], ",", 
     RowBox[{"\[Lambda]5", "\[Rule]", 
      RowBox[{
       FractionBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "+", "e"}], ")"}], "2"], 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["d", "2"], "+", 
           RowBox[{"7", "d"}], "+", "9", "-", 
           RowBox[{"3", "e", 
            RowBox[{"(", 
             RowBox[{"d", "+", "4"}], ")"}]}], "+", 
           RowBox[{"3", 
            SuperscriptBox["e", "2"]}]}], ")"}]}], 
        RowBox[{"2", "d", 
         RowBox[{"(", 
          RowBox[{"d", "+", "4"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"d", "+", "6"}], ")"}]}]], "\[Nu]0"}]}]}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.738541731421072*^9, 
  3.738541737635027*^9}},ExpressionUUID->"f6e99e46-e125-4ea9-8626-\
2c6c13b502e3"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.738541739138612*^9, 
  3.744964840459495*^9},ExpressionUUID->"48bc36b4-3ee3-46e3-94e5-\
964161902b6e"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"newcontributiontotracefreeproduction", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      RowBox[{"\[Nu]", "[", 
       RowBox[{"0", ",", "4"}], "]"}]}], 
     RowBox[{"M", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"i1", ",", "i2", ",", "i3", ",", "i4"}], "}"}]}], "]"}]}], 
    "+", 
    RowBox[{
     FractionBox["\[Lambda]5", "n"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"M", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", 
           RowBox[{"i1", ",", "i4"}], "}"}]}], "]"}], " ", 
        RowBox[{"M", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", 
           RowBox[{"i2", ",", "i3"}], "}"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"M", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", 
           RowBox[{"i1", ",", "i3"}], "}"}]}], "]"}], " ", 
        RowBox[{"M", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", 
           RowBox[{"i2", ",", "i4"}], "}"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"M", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", 
           RowBox[{"i1", ",", "i2"}], "}"}]}], "]"}], " ", 
        RowBox[{"M", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", 
           RowBox[{"i3", ",", "i4"}], "}"}]}], "]"}]}]}], ")"}]}]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.7385417857724323`*^9, 
  3.73854180139736*^9}},ExpressionUUID->"9b6e4c7a-a813-4885-b650-\
bf6d5082afde"],

Cell[TextData[{
 "On taking trace of each term, it agrees with the expression of eq. (2.25) \
of Garz\[OAcute] and Santos 2007 J. Phys. A: Math. Theor. 40 14927. See \
below:\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["M", 
      RowBox[{"<", "ij"}]], 
     SubscriptBox["M", 
      RowBox[{"kl", ">"}]]}], "=", 
    RowBox[{
     RowBox[{
      SubscriptBox["M", 
       RowBox[{"(", "ij"}]], 
      SubscriptBox["M", 
       RowBox[{"kl", ")"}]]}], "-", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"d", "+", "4"}]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubscriptBox["M", 
          RowBox[{"(", "\[Alpha]\[Alpha]"}]], 
         SubscriptBox["M", 
          RowBox[{"kl", ")"}]], 
         SubscriptBox["\[Delta]", "ij"]}], "+", 
        RowBox[{
         SubscriptBox["M", 
          RowBox[{"(", "\[Alpha]j"}]], 
         SubscriptBox["M", 
          RowBox[{"\[Alpha]l", ")"}]], 
         SubscriptBox["\[Delta]", "ik"]}], "+", 
        RowBox[{
         SubscriptBox["M", 
          RowBox[{"(", "\[Alpha]j"}]], 
         SubscriptBox["M", 
          RowBox[{"k\[Alpha]", ")"}]], 
         SubscriptBox["\[Delta]", "il"]}], "+", 
        RowBox[{
         SubscriptBox["M", 
          RowBox[{"(", "i\[Alpha]"}]], 
         SubscriptBox["M", 
          RowBox[{"\[Alpha]l", ")"}]], 
         SubscriptBox["\[Delta]", "jk"]}], "+", 
        RowBox[{
         SubscriptBox["M", 
          RowBox[{"(", "i\[Alpha]"}]], 
         SubscriptBox["M", 
          RowBox[{"k\[Alpha]", ")"}]], 
         SubscriptBox["\[Delta]", "jl"]}], "+", 
        RowBox[{
         SubscriptBox["M", 
          RowBox[{"(", "ij"}]], 
         SubscriptBox["M", 
          RowBox[{"\[Alpha]\[Alpha]", ")"}]], 
         SubscriptBox["\[Delta]", "kl"]}]}], ")"}]}], "+", 
     RowBox[{
      FractionBox["1", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"d", "+", "2"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"d", "+", "4"}], ")"}]}]], 
      SubscriptBox["M", 
       RowBox[{"(", "\[Alpha]\[Alpha]"}]], 
      SubscriptBox["M", 
       RowBox[{"\[Beta]\[Beta]", ")"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubscriptBox["\[Delta]", "ij"], 
         SubscriptBox["\[Delta]", "kl"]}], "+", 
        RowBox[{
         SubscriptBox["\[Delta]", "ik"], 
         SubscriptBox["\[Delta]", "jl"]}], "+", 
        RowBox[{
         SubscriptBox["\[Delta]", "il"], 
         SubscriptBox["\[Delta]", "jk"]}]}], ")"}]}]}]}], TraditionalForm]],
  ExpressionUUID->"7f9bf0ca-1acf-44a3-a157-0f7338f56bd9"],
 "\n",
 Cell[BoxData[
  FormBox[
   RowBox[{"=", 
    RowBox[{
     FractionBox["1", "3"], "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubscriptBox["M", "ij"], 
         SubscriptBox["M", "kl"]}], "+", 
        RowBox[{
         SubscriptBox["M", "ik"], 
         SubscriptBox["M", "jl"]}], "+", 
        RowBox[{
         SubscriptBox["M", "il"], 
         SubscriptBox["M", "jk"]}]}], ")"}], "-", 
      RowBox[{
       FractionBox["2", 
        RowBox[{"d", "+", "4"}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["M", "\[Alpha]k"], 
          SubscriptBox["M", "\[Alpha]l"], 
          SubscriptBox["\[Delta]", "ij"]}], "+", 
         RowBox[{
          SubscriptBox["M", "\[Alpha]j"], 
          SubscriptBox["M", "\[Alpha]l"], 
          SubscriptBox["\[Delta]", "ik"]}], "+", 
         RowBox[{
          SubscriptBox["M", "\[Alpha]j"], 
          SubscriptBox["M", "\[Alpha]k"], 
          SubscriptBox["\[Delta]", "il"]}], "+", 
         RowBox[{
          SubscriptBox["M", "\[Alpha]i"], 
          SubscriptBox["M", "\[Alpha]l"], 
          SubscriptBox["\[Delta]", "jk"]}], "+", 
         RowBox[{
          SubscriptBox["M", "\[Alpha]i"], 
          SubscriptBox["M", "\[Alpha]k"], 
          SubscriptBox["\[Delta]", "jl"]}], "+", 
         RowBox[{
          SubscriptBox["M", "\[Alpha]i"], 
          SubscriptBox["M", "\[Alpha]j"], 
          SubscriptBox["\[Delta]", "kl"]}]}], ")"}]}], "+", 
      RowBox[{
       FractionBox["2", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"d", "+", "2"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"d", "+", "4"}], ")"}]}]], 
       SubscriptBox["M", "\[Alpha]\[Beta]"], 
       RowBox[{
        SubscriptBox["M", "\[Alpha]\[Beta]"], "(", 
        RowBox[{
         RowBox[{
          SubscriptBox["\[Delta]", "ij"], 
          SubscriptBox["\[Delta]", "kl"]}], "+", 
         RowBox[{
          SubscriptBox["\[Delta]", "ik"], 
          SubscriptBox["\[Delta]", "jl"]}], "+", 
         RowBox[{
          SubscriptBox["\[Delta]", "il"], 
          SubscriptBox["\[Delta]", "jk"]}]}], ")"}]}]}], "]"}]}], 
   TraditionalForm]],ExpressionUUID->"e3d08189-1df5-4371-991e-81d867b49d4e"],
 "\n\nas ",
 Cell[BoxData[
  FormBox["M", TraditionalForm]],ExpressionUUID->
  "0d334342-836a-4759-a872-8f3fe3e77053"],
 " is symmetric ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["M", "ij"], "=", 
     SubscriptBox["M", "ji"]}]}], TraditionalForm]],ExpressionUUID->
  "b4d330e1-4973-43ad-8700-0dd309ce8ad5"],
 ") and traceless ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["M", "\[Alpha]\[Alpha]"], "=", "0"}]}], TraditionalForm]],
  ExpressionUUID->"84ab4374-b553-4da5-ba2e-3d00fc496b81"],
 ") yielding\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["M", 
      RowBox[{"(", "ij"}]], 
     SubscriptBox["M", 
      RowBox[{"kl", ")"}]]}], "=", 
    RowBox[{
     FractionBox["1", "3"], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["M", "ij"], 
        SubscriptBox["M", "kl"]}], "+", 
       RowBox[{
        SubscriptBox["M", "ik"], 
        SubscriptBox["M", "jl"]}], "+", 
       RowBox[{
        SubscriptBox["M", "il"], 
        SubscriptBox["M", "jk"]}]}], ")"}]}]}], TraditionalForm]],
  ExpressionUUID->"18417377-2472-4cdb-9993-cf06b66d43f6"],
 ",\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["M", 
      RowBox[{"(", "\[Alpha]\[Alpha]"}]], 
     SubscriptBox["M", 
      RowBox[{"kl", ")"}]]}], "=", 
    RowBox[{
     RowBox[{
      FractionBox["1", "3"], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubscriptBox["M", "\[Alpha]\[Alpha]"], 
         SubscriptBox["M", "kl"]}], "+", 
        RowBox[{
         SubscriptBox["M", "\[Alpha]k"], 
         SubscriptBox["M", "\[Alpha]l"]}], "+", 
        RowBox[{
         SubscriptBox["M", "\[Alpha]l"], 
         SubscriptBox["M", "\[Alpha]k"]}]}], ")"}]}], "=", 
     RowBox[{
      FractionBox["2", "3"], 
      SubscriptBox["M", "\[Alpha]k"], 
      SubscriptBox["M", "\[Alpha]l"]}]}]}], TraditionalForm]],ExpressionUUID->
  "a3860888-6895-4126-b880-777cfc76c473"],
 ",\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["M", 
      RowBox[{"(", "\[Alpha]\[Alpha]"}]], 
     SubscriptBox["M", 
      RowBox[{"\[Beta]\[Beta]", ")"}]]}], "=", 
    RowBox[{
     RowBox[{
      FractionBox["1", "3"], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubscriptBox["M", "\[Alpha]\[Alpha]"], 
         SubscriptBox["M", "\[Beta]\[Beta]"]}], "+", 
        RowBox[{
         SubscriptBox["M", "\[Alpha]\[Beta]"], 
         SubscriptBox["M", "\[Alpha]\[Beta]"]}], "+", 
        RowBox[{
         SubscriptBox["M", "\[Alpha]\[Beta]"], 
         SubscriptBox["M", "\[Alpha]\[Beta]"]}]}], ")"}]}], "=", 
     RowBox[{
      FractionBox["2", "3"], 
      SubscriptBox["M", "\[Alpha]\[Beta]"], 
      SubscriptBox["M", "\[Alpha]\[Beta]"]}]}]}], TraditionalForm]],
  ExpressionUUID->"21ba0e5b-40e7-4140-8638-77abf3098f52"],
 "."
}], "Text",
 CellChangeTimes->{{3.738542728652343*^9, 3.738542768947958*^9}, {
  3.738542799650201*^9, 3.738543501564159*^9}, {3.738543536425802*^9, 
  3.738543674215073*^9}, {3.738543727785328*^9, 
  3.738544408880145*^9}},ExpressionUUID->"f70afac5-fcc0-4086-a92a-\
96b0fb52c6ee"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   StyleBox[
    RowBox[{"To", " ", "write", " ", "in", " ", "the", " ", "paper"}],
    FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Pijkl0towrite", "=", 
     RowBox[{"Collect", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Einstein", "[", 
          RowBox[{"Expand", "[", 
           RowBox[{
            RowBox[{"m", " ", "resultPijkl0form1"}], "/.", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"\[Delta]", "[", "_", "]"}], "\[Rule]", "0"}], "}"}]}], 
           "]"}], "]"}], "/.", "replace\[Rho]u"}], "/.", 
        RowBox[{"n", "\[Rule]", 
         FractionBox["\[Rho]", "m"]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"u", "[", 
         RowBox[{"{", 
          RowBox[{"i1", ",", "i2", ",", "i3", ",", "i4"}], "}"}], "]"}], 
        "}"}], ",", "Simplify"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Pijkl0towrite", "-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "\[Nu]0"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[Nu]u", " ", 
            RowBox[{"u", "[", 
             RowBox[{"{", 
              RowBox[{"i1", ",", "i2", ",", "i3", ",", "i4"}], "}"}], "]"}]}],
            "-", 
           RowBox[{"c", 
            FractionBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"\[Sigma]", "[", 
                 RowBox[{"{", 
                  RowBox[{"i1", ",", "i2"}], "}"}], "]"}], " ", 
                RowBox[{"\[Sigma]", "[", 
                 RowBox[{"{", 
                  RowBox[{"i3", ",", "i4"}], "}"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{"\[Sigma]", "[", 
                 RowBox[{"{", 
                  RowBox[{"i1", ",", "i3"}], "}"}], "]"}], " ", 
                RowBox[{"\[Sigma]", "[", 
                 RowBox[{"{", 
                  RowBox[{"i2", ",", "i4"}], "}"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{"\[Sigma]", "[", 
                 RowBox[{"{", 
                  RowBox[{"i1", ",", "i4"}], "}"}], "]"}], " ", 
                RowBox[{"\[Sigma]", "[", 
                 RowBox[{"{", 
                  RowBox[{"i2", ",", "i3"}], "}"}], "]"}]}]}], ")"}], 
             RowBox[{"3", "\[Rho]"}]]}]}], ")"}]}], ")"}]}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\[Nu]u", "\[Rule]", 
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", "e"}], ")"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", 
              SuperscriptBox["d", "3"]}], "+", 
             RowBox[{"21", 
              SuperscriptBox["d", "2"]}], "+", 
             RowBox[{"61", "d"}], "+", "39", "-", 
             RowBox[{"3", "e", 
              RowBox[{"(", 
               RowBox[{"d", "+", "3"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"d", "+", "5"}], ")"}]}], "+", 
             RowBox[{"3", 
              SuperscriptBox["e", "2"], 
              RowBox[{"(", 
               RowBox[{"d", "+", "3"}], ")"}]}], "-", 
             RowBox[{"3", 
              SuperscriptBox["e", "3"]}]}], ")"}]}], 
          RowBox[{"2", "d", 
           RowBox[{"(", 
            RowBox[{"d", "+", "4"}], ")"}], 
           RowBox[{"(", 
            RowBox[{"d", "+", "6"}], ")"}]}]]}], ",", 
        RowBox[{"c", "\[Rule]", 
         RowBox[{"3", 
          FractionBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"1", "+", "e"}], ")"}], "2"], 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["d", "2"], "+", 
              RowBox[{"7", "d"}], "+", "9", "-", 
              RowBox[{"3", "e", 
               RowBox[{"(", 
                RowBox[{"d", "+", "4"}], ")"}]}], "+", 
              RowBox[{"3", 
               SuperscriptBox["e", "2"]}]}], ")"}]}], 
           RowBox[{"2", "d", 
            RowBox[{"(", 
             RowBox[{"d", "+", "4"}], ")"}], 
            RowBox[{"(", 
             RowBox[{"d", "+", "6"}], ")"}]}]]}]}]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"u", "[", 
       RowBox[{"{", 
        RowBox[{"i1", ",", "i2", ",", "i3", ",", "i4"}], "}"}], "]"}], "}"}], 
     ",", "Simplify"}], "]"}]}]}]], "Input",
 CellChangeTimes->{
  3.738664826399189*^9, {3.73866486631916*^9, 3.7386649637144527`*^9}, {
   3.738665002264349*^9, 3.738665022622917*^9}, {3.738665072118774*^9, 
   3.738665136298582*^9}, {3.738665190016629*^9, 3.7386651932212477`*^9}, {
   3.738665652329639*^9, 3.7386657376028147`*^9}, {3.738665868232608*^9, 
   3.738665955989789*^9}, {3.7386659881303253`*^9, 3.738666002284251*^9}, 
   3.7386660358204947`*^9, {3.7386660737847767`*^9, 3.7386660938126287`*^9}, {
   3.738666134121554*^9, 3.738666141320374*^9}, {3.738666238101869*^9, 
   3.73866624417529*^9}, {3.744983185971252*^9, 
   3.744983274432288*^9}},ExpressionUUID->"6255bc0b-d979-449a-a49c-\
8c1821354b2e"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.7386656864241323`*^9, {3.738665940833682*^9, 3.738665956918221*^9}, {
   3.7386659891398697`*^9, 3.738666003696999*^9}, 3.7386660369466543`*^9, 
   3.738666142870625*^9, {3.7386662397720127`*^9, 3.7386662447364197`*^9}, 
   3.74496484112083*^9, 3.7449832068366947`*^9, {3.7449832584282827`*^9, 
   3.744983276937088*^9}},ExpressionUUID->"763e4dd2-9267-4e51-a9cd-\
bb7f00732741"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Production Term for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["C", "4"], 
    SubscriptBox["C", "i"]}], TraditionalForm]],ExpressionUUID->
  "da3439fc-ddda-4e69-8f5a-b50598c19e26"]
}], "Subsection",
 CellChangeTimes->{{3.540736884072311*^9, 3.5407369043909597`*^9}, {
  3.542452633864394*^9, 3.542452671646845*^9}, {3.737272427807934*^9, 
  3.737272430722102*^9}, {3.737273281718402*^9, 3.7372732969187727`*^9}, {
  3.7384017425560913`*^9, 3.73840174518649*^9}, {3.7384024868866043`*^9, 
  3.7384024963124943`*^9}, {3.743096435302997*^9, 3.743096435837837*^9}},
 TextAlignment->Center,
 FontColor->RGBColor[0.5, 0, 0.5],
 Background->RGBColor[
  1, 1, 0.85],ExpressionUUID->"f2ca2172-5ab5-4aa4-8fd8-33b57708e3aa"],

Cell[BoxData[{
 RowBox[{"Clear", "[", 
  RowBox[{"w0", ",", "g"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"idx", "=", 
   RowBox[{"{", 
    RowBox[{"i1", ",", "i2", ",", "i3", ",", "i4", ",", "i5"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"nn", "=", 
    RowBox[{"Length", "[", "idx", "]"}]}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   StyleBox[
    RowBox[{
    "raw", " ", "form", " ", "of", " ", "integrand", " ", "without", " ", 
     "factor", " ", 
     FractionBox[
      RowBox[{"m", " ", "\[Nu]"}], 
      RowBox[{"n", " ", "\[CapitalOmega]d"}]], " ", "and", " ", "f", " ", 
     "f1", " ", "in", " ", "the", " ", "collision", " ", "integral"}],
    FontColor->RGBColor[1, 0.5, 0]], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Pi2", "=", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"\[Beta]", "=", "1"}], "nn"], 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"\[Gamma]", "=", "0"}], 
       RowBox[{"\[Beta]", "/", "2"}]], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], "\[Beta]"], 
       SuperscriptBox["w0", "\[Beta]"], 
       RowBox[{"Binomial", "[", 
        RowBox[{"nn", ",", "\[Beta]"}], "]"}], 
       RowBox[{"Delta", "[", 
        RowBox[{
         RowBox[{"idx", "\[LeftDoubleBracket]", 
          RowBox[{"range", "[", 
           RowBox[{"1", ",", "\[Gamma]"}], "]"}], "\[RightDoubleBracket]"}], 
         ",", 
         RowBox[{"idx", "\[LeftDoubleBracket]", 
          RowBox[{"range", "[", 
           RowBox[{
            RowBox[{"\[Gamma]", "+", "1"}], ",", 
            RowBox[{"2", "\[Gamma]"}]}], "]"}], "\[RightDoubleBracket]"}]}], 
        "]"}], 
       RowBox[{"\[Alpha]", "[", 
        RowBox[{"\[Gamma]", ",", "\[Beta]"}], "]"}], 
       SuperscriptBox["g", 
        RowBox[{"2", "\[Gamma]"}]], 
       RowBox[{"gg", "[", 
        RowBox[{"idx", "\[LeftDoubleBracket]", 
         RowBox[{"range", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"2", "\[Gamma]"}], "+", "1"}], ",", "\[Beta]"}], "]"}], 
         "\[RightDoubleBracket]"}], "]"}], 
       RowBox[{"CC", "[", 
        RowBox[{"idx", "\[LeftDoubleBracket]", 
         RowBox[{"range", "[", 
          RowBox[{
           RowBox[{"\[Beta]", "+", "1"}], ",", "nn"}], "]"}], 
         "\[RightDoubleBracket]"}], "]"}]}]}]}]}], 
   RowBox[{"(*", 
    RowBox[{"f", " ", "f1"}], "*)"}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   StyleBox[
    RowBox[{"symmetrization", " ", "of", " ", "the", " ", "indices"}],
    FontColor->RGBColor[1, 0.5, 0]], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"perm", "=", 
   RowBox[{
    RowBox[{"Permutations", "[", "idx", "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"i5", "\[Rule]", "i4"}], ",", 
      RowBox[{"i3", "\[Rule]", "i2"}]}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CollInt", "=", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{"CollInt", "+=", 
    RowBox[{"Pi2", "/.", 
     RowBox[{"Thread", "[", 
      RowBox[{"idx", "\[Rule]", 
       RowBox[{
       "perm", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}]}], 
      "]"}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{"ii", ",", "1", ",", 
     RowBox[{"Length", "[", "perm", "]"}]}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CollIntegralPi2", "=", 
    RowBox[{"ExpandAll", "[", 
     RowBox[{
      FractionBox["CollInt", 
       RowBox[{"Length", "[", "perm", "]"}]], "/.", "replace$gsq"}], "]"}]}], 
   ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   StyleBox[
    RowBox[{
     RowBox[{"main", " ", "working", " ", 
      RowBox[{"steps", ":", " ", 
       RowBox[{
        RowBox[{
        "1.", " ", "integrate", " ", "directions", " ", "in", " ", "h"}], "-",
         "vectors"}]}]}], ";", " ", 
     RowBox[{
      RowBox[{
      "2.", " ", "integrate", " ", "directions", " ", "in", " ", "g"}], "-", 
      "vectors"}], ";", " ", 
     RowBox[{
     "3.", " ", "integrate", " ", "Gauss", " ", "integrals", " ", "in", " ", 
      "h"}], ";", " ", 
     RowBox[{
     "4.", " ", "perform", " ", "contractions", " ", "on", " ", "\[Delta]"}]}],
    FontColor->RGBColor[1, 0.5, 0]], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g", "[", "idx_", "]"}], ":=", 
  RowBox[{
   RowBox[{"CC", "[", "idx", "]"}], "-", 
   RowBox[{"CC1", "[", "idx", "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CollIntegralPi2", "=", 
    RowBox[{"Expand", "[", "CollIntegralPi2", "]"}]}], ";"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   StyleBox[
    RowBox[{"Integration", " ", "over", " ", "C", " ", "and", " ", "C1"}],
    FontColor->RGBColor[1, 0.5, 0]], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"resultPi2", "=", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Einstein", "[", 
         RowBox[{"intoverCC1", "[", 
          RowBox[{
          "CollIntegralPi2", "\[LeftDoubleBracket]", "ii", 
           "\[RightDoubleBracket]"}], "]"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"ii", ",", "1", ",", 
          RowBox[{"Length", "[", "CollIntegralPi2", "]"}]}], "}"}]}], "]"}]}],
      "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"list\[Rho]Pi2", "=", 
   RowBox[{"DeleteDuplicates", "[", 
    RowBox[{"Extract", "[", 
     RowBox[{"resultPi2", ",", 
      RowBox[{"Position", "[", 
       RowBox[{"resultPi2", ",", 
        RowBox[{"\[Rho]", "[", 
         RowBox[{"_", ",", "_"}], "]"}]}], "]"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"replace\[Rho]Pi2", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
      "list\[Rho]Pi2", "\[LeftDoubleBracket]", "ii", 
       "\[RightDoubleBracket]"}], "\[Rule]", 
      RowBox[{"tracefreerepresentation", "[", 
       RowBox[{
       "list\[Rho]Pi2", "\[LeftDoubleBracket]", "ii", 
        "\[RightDoubleBracket]"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"ii", ",", "1", ",", 
       RowBox[{"Length", "[", "list\[Rho]Pi2", "]"}]}], "}"}]}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.537993578189455*^9, 3.537993610797545*^9}, {
   3.537993771670854*^9, 3.537993779038876*^9}, {3.5379938261036*^9, 
   3.537993894920753*^9}, 3.537993985202799*^9, {3.537994016572002*^9, 
   3.537994037555522*^9}, {3.537994388113123*^9, 3.5379944406823893`*^9}, {
   3.5379944716672297`*^9, 3.537994535484898*^9}, {3.5379946435344*^9, 
   3.537994670999247*^9}, {3.537994822992545*^9, 3.537994848706256*^9}, {
   3.537994948252141*^9, 3.5379951325767097`*^9}, {3.537995185554933*^9, 
   3.537995241802492*^9}, {3.537995276222849*^9, 3.537995281348686*^9}, {
   3.53799533558186*^9, 3.5379953402203913`*^9}, {3.537995373317173*^9, 
   3.537995389189156*^9}, {3.537995463503443*^9, 3.537995586335116*^9}, {
   3.537995620905704*^9, 3.537995685353702*^9}, {3.537995731882414*^9, 
   3.537995740818839*^9}, {3.53799608412899*^9, 3.537996120582891*^9}, {
   3.537996373868025*^9, 3.537996470581868*^9}, {3.537996552739531*^9, 
   3.537996599754401*^9}, {3.537996699014799*^9, 3.537996718444993*^9}, {
   3.5379967905373993`*^9, 3.537996835526949*^9}, {3.537996969586375*^9, 
   3.537997008865888*^9}, {3.537997054707327*^9, 3.5379970594661016`*^9}, {
   3.537997228824871*^9, 3.537997383715749*^9}, {3.537997495969655*^9, 
   3.537997504978291*^9}, {3.538049111849923*^9, 3.538049145198148*^9}, {
   3.538049184515108*^9, 3.538049258034523*^9}, {3.5380493781370897`*^9, 
   3.538049391682486*^9}, {3.538049424567073*^9, 3.538049487235387*^9}, {
   3.538049594582995*^9, 3.538049743296955*^9}, {3.538050939370043*^9, 
   3.5380509982737083`*^9}, {3.5380676731372538`*^9, 3.538067723150732*^9}, 
   3.53806785052652*^9, {3.538067941214231*^9, 3.538067990711932*^9}, {
   3.538068029462811*^9, 3.538068153307399*^9}, {3.53806855796034*^9, 
   3.538068627746333*^9}, {3.53806869188647*^9, 3.538068751511098*^9}, {
   3.538068919982791*^9, 3.538068952563477*^9}, {3.538120345641403*^9, 
   3.538120421155457*^9}, 3.538120780664413*^9, {3.538120852906658*^9, 
   3.538120953903056*^9}, {3.538121002642786*^9, 3.538121148063637*^9}, {
   3.538126353936679*^9, 3.538126386984695*^9}, {3.538126473001809*^9, 
   3.5381265005530252`*^9}, {3.538126537649548*^9, 3.538126555161577*^9}, {
   3.5381266439234133`*^9, 3.538126715750491*^9}, 3.538127882474265*^9, {
   3.538130944351671*^9, 3.538131077658307*^9}, {3.538131942442205*^9, 
   3.538132013760786*^9}, {3.538132283894219*^9, 3.538132360880001*^9}, {
   3.538133348588627*^9, 3.538133377632154*^9}, {3.53813341458228*^9, 
   3.538133595785343*^9}, {3.538133693428665*^9, 3.538133893912404*^9}, {
   3.538133930459076*^9, 3.538134125076247*^9}, {3.53813417768613*^9, 
   3.538134217260666*^9}, {3.538134259339695*^9, 3.538134264398603*^9}, {
   3.538137299532156*^9, 3.538137342311903*^9}, {3.538137430398448*^9, 
   3.538137473144889*^9}, {3.5381376929555693`*^9, 3.5381377022975807`*^9}, {
   3.5381379513516703`*^9, 3.538137995917336*^9}, {3.538138048946089*^9, 
   3.53813805994525*^9}, {3.538138121394474*^9, 3.5381381959580793`*^9}, {
   3.5381382502615757`*^9, 3.538138273902351*^9}, {3.5381383210109873`*^9, 
   3.538138336804418*^9}, 3.538138516977003*^9, {3.5381618433477077`*^9, 
   3.538161932597952*^9}, {3.538161987860311*^9, 3.5381620846113997`*^9}, {
   3.5381621539329453`*^9, 3.538162195795615*^9}, {3.538162226745761*^9, 
   3.538162260756913*^9}, {3.538162294790723*^9, 3.538162558108499*^9}, {
   3.5382004503666887`*^9, 3.538200516536386*^9}, {3.5382005504900503`*^9, 
   3.538200576308169*^9}, {3.538200918185061*^9, 3.5382009209833603`*^9}, 
   3.538200954918594*^9, {3.5382012679264*^9, 3.538201268242012*^9}, {
   3.5382013070166893`*^9, 3.538201311732603*^9}, 3.53820156656705*^9, {
   3.538201655677127*^9, 3.538201682767631*^9}, 3.538201919512535*^9, 
   3.538243145787212*^9, 3.53824318144276*^9, {3.538243282594778*^9, 
   3.5382432941723957`*^9}, {3.5382433354676323`*^9, 
   3.5382433373488293`*^9}, {3.538243583835874*^9, 3.538243588737722*^9}, {
   3.538244168454702*^9, 3.538244180740324*^9}, {3.538244332583802*^9, 
   3.538244339379407*^9}, 3.5382449465768633`*^9, {3.5388070078690643`*^9, 
   3.538807099973749*^9}, {3.538807180708592*^9, 3.5388071828035707`*^9}, 
   3.5388074844694977`*^9, {3.538807551230954*^9, 3.538807553504488*^9}, {
   3.538808873941285*^9, 3.538808875477491*^9}, {3.538808927009503*^9, 
   3.5388089304970512`*^9}, {3.538808998699823*^9, 3.538809020477653*^9}, {
   3.538809124555171*^9, 3.538809131039702*^9}, 3.538809175971305*^9, {
   3.538809338238731*^9, 3.5388093394879303`*^9}, 3.5388093971728573`*^9, {
   3.53881066031894*^9, 3.538810687713526*^9}, 3.538810748528813*^9, {
   3.5388107917831078`*^9, 3.538810794089106*^9}, {3.538811661821177*^9, 
   3.538811724776244*^9}, 3.538817331517233*^9, {3.5388192046322308`*^9, 
   3.538819214494584*^9}, {3.5392665470358353`*^9, 3.5392665745099287`*^9}, {
   3.539266610562613*^9, 3.539266615983183*^9}, {3.5392666830721903`*^9, 
   3.539266815780409*^9}, 3.539266848624251*^9, 3.539266890598507*^9, {
   3.539267060053648*^9, 3.539267072703176*^9}, 3.5392677537069807`*^9, 
   3.539267788390932*^9, {3.539268495010467*^9, 3.539268496663838*^9}, 
   3.539269140585288*^9, 3.539269235639429*^9, {3.539269355353408*^9, 
   3.539269383630211*^9}, {3.539269638969858*^9, 3.539269750991323*^9}, {
   3.53926979106437*^9, 3.539269810113697*^9}, {3.5392701517950487`*^9, 
   3.5392701920043097`*^9}, 3.539278908980487*^9, 3.539278996527172*^9, {
   3.539326343054734*^9, 3.539326435401582*^9}, {3.539326569957453*^9, 
   3.539326575804747*^9}, {3.539326991237306*^9, 3.5393270082806168`*^9}, {
   3.539329433774241*^9, 3.5393294960187607`*^9}, {3.5393305017074823`*^9, 
   3.539330556642144*^9}, 3.539330888641615*^9, {3.539339971597237*^9, 
   3.5393399876891327`*^9}, {3.5393400782346582`*^9, 3.539340081023357*^9}, {
   3.5393401448438396`*^9, 3.539340145504077*^9}, {3.539347774329233*^9, 
   3.539347843122929*^9}, 3.539366432292687*^9, {3.539367245443975*^9, 
   3.539367246347004*^9}, {3.540734202771955*^9, 3.5407342043103733`*^9}, {
   3.540736418761684*^9, 3.5407364226194553`*^9}, {3.540737768596367*^9, 
   3.540737768892754*^9}, {3.542388724376953*^9, 3.542388781889929*^9}, {
   3.542388924988758*^9, 3.542388987923122*^9}, {3.5423890458105783`*^9, 
   3.542389193224463*^9}, {3.542389272963728*^9, 3.54238930706011*^9}, {
   3.542437641275167*^9, 3.542437699202085*^9}, {3.542437730796095*^9, 
   3.5424378902358*^9}, 3.542437945897581*^9, {3.5424379882249823`*^9, 
   3.5424380665457783`*^9}, 3.5424381121082697`*^9, {3.542438249182868*^9, 
   3.5424382662648687`*^9}, 3.542438305697894*^9, {3.542439075760028*^9, 
   3.5424390838844147`*^9}, {3.542439173737357*^9, 3.542439220087296*^9}, {
   3.542443352398711*^9, 3.542443381775426*^9}, {3.542443447124556*^9, 
   3.542443480430725*^9}, {3.542443613406389*^9, 3.542443649481735*^9}, 
   3.542443699901371*^9, {3.5424462578396807`*^9, 3.542446274257043*^9}, {
   3.542446401017707*^9, 3.542446413600088*^9}, {3.5424464659327908`*^9, 
   3.5424464878337793`*^9}, {3.5424465291804132`*^9, 3.5424465329099913`*^9}, 
   3.542446742755765*^9, {3.542446778102816*^9, 3.542446785282056*^9}, {
   3.542446834089986*^9, 3.542446884468789*^9}, {3.542446919291979*^9, 
   3.542446939944065*^9}, {3.542446976270124*^9, 3.5424469866004257`*^9}, {
   3.542447056705858*^9, 3.5424470898445673`*^9}, {3.5424471344029417`*^9, 
   3.542447174506599*^9}, {3.5424472312410507`*^9, 3.54244726772272*^9}, {
   3.5424473125427227`*^9, 3.5424473254819317`*^9}, {3.5424473695330887`*^9, 
   3.542447388671294*^9}, 3.542448224058323*^9, {3.542451548746708*^9, 
   3.5424515774216213`*^9}, {3.5424519211077013`*^9, 3.542451928153799*^9}, {
   3.54245299950036*^9, 3.542453001194194*^9}, {3.542455811416429*^9, 
   3.542455815394039*^9}, {3.542622812244008*^9, 3.542622822000717*^9}, {
   3.542622859825048*^9, 3.542622931786152*^9}, {3.54269829979911*^9, 
   3.542698305254208*^9}, {3.542699025561718*^9, 3.542699026123849*^9}, {
   3.5426990707182913`*^9, 3.542699088670185*^9}, {3.542700118933394*^9, 
   3.542700121036415*^9}, 3.542700827765305*^9, {3.5429174051788473`*^9, 
   3.542917524367551*^9}, 3.5429176869021387`*^9, {3.542969166437325*^9, 
   3.542969172344721*^9}, {3.548190436221043*^9, 3.548190445993956*^9}, 
   3.548190491401569*^9, {3.548190752747745*^9, 3.548190753292897*^9}, {
   3.54901721401657*^9, 3.549017214311965*^9}, {3.549017247695644*^9, 
   3.5490173217517653`*^9}, {3.5490175863059607`*^9, 3.549017586840351*^9}, {
   3.64364096822392*^9, 3.643640983650118*^9}, 3.643641025520862*^9, {
   3.6436415353816833`*^9, 3.643641602069047*^9}, {3.643641636036574*^9, 
   3.643641702536974*^9}, 3.643641788051527*^9, {3.6436418353044577`*^9, 
   3.643641843368132*^9}, {3.678793251829185*^9, 3.678793285790352*^9}, 
   3.6787994439458447`*^9, {3.678862755048066*^9, 3.6788627561980753`*^9}, 
   3.678865112211464*^9, {3.681391437897203*^9, 3.681391452879457*^9}, {
   3.737108210053956*^9, 3.737108249563664*^9}, {3.7371084042540083`*^9, 
   3.7371084083262463`*^9}, 3.737109292446753*^9, {3.737109749523717*^9, 
   3.737109805554154*^9}, {3.737110028644668*^9, 3.737110070179446*^9}, {
   3.737110150417325*^9, 3.737110151300057*^9}, 3.737110382136352*^9, {
   3.737110458359399*^9, 3.737110460309579*^9}, {3.737110702040637*^9, 
   3.737110703878584*^9}, {3.7371117587819138`*^9, 3.73711177306219*^9}, {
   3.737113682711214*^9, 3.7371136853064327`*^9}, {3.7371138793370953`*^9, 
   3.737113881349288*^9}, {3.73718694545557*^9, 3.737186984864314*^9}, {
   3.737187015838509*^9, 3.7371870332629213`*^9}, {3.737187072238668*^9, 
   3.7371870800135736`*^9}, {3.737189762748537*^9, 3.737189763128755*^9}, {
   3.737189800186709*^9, 3.737189804667068*^9}, {3.7371898409234247`*^9, 
   3.737189845354582*^9}, 3.737190240046109*^9, {3.7371903718842573`*^9, 
   3.737190380979869*^9}, {3.737191435152549*^9, 3.737191467949527*^9}, {
   3.737191521249221*^9, 3.73719156092738*^9}, {3.737191766050044*^9, 
   3.7371917689123497`*^9}, 3.737197927456336*^9, {3.737198159489818*^9, 
   3.737198159886495*^9}, {3.737200386075508*^9, 3.7372003868555098`*^9}, {
   3.737264960908597*^9, 3.7372649614648647`*^9}, 3.7372710196476183`*^9, {
   3.737271124669427*^9, 3.737271139070385*^9}, {3.737271449376149*^9, 
   3.737271450701746*^9}, {3.737272473365141*^9, 3.737272503208777*^9}, {
   3.7372725472818527`*^9, 3.737272573132128*^9}, {3.737272872657456*^9, 
   3.737272875955984*^9}, {3.73727330346493*^9, 3.737273333526195*^9}, {
   3.737273441415806*^9, 3.73727346055801*^9}, {3.738396788506775*^9, 
   3.738396792615591*^9}, {3.738396838807775*^9, 3.738396881515554*^9}, {
   3.738397086236014*^9, 3.738397096880761*^9}, {3.738401749460299*^9, 
   3.738401774943083*^9}, {3.7384024562326727`*^9, 3.738402456251067*^9}, {
   3.738402538623505*^9, 3.738402542567286*^9}, {3.743096354013144*^9, 
   3.743096377997151*^9}, {3.743096409830225*^9, 
   3.7430964098875504`*^9}},ExpressionUUID->"ee771499-3952-47ac-8dcf-\
1d1b74e7143c"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"factor", "=", 
    RowBox[{"(*", "m", "*)"}], 
    FractionBox["\[Nu]", 
     RowBox[{"n", " ", "\[CapitalOmega]d"}]]}], ";"}], "\[IndentingNewLine]", 
  
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"resultPi2form1", "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{"FullSimplify", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"factor", " ", "resultPi2"}], "/.", "replace\[Rho]Pi2"}], "/.",
           "replace\[Alpha]"}], "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\[Nu]", "\[Rule]", 
            RowBox[{
             FractionBox[
              RowBox[{"d", "+", "2"}], "2"], "\[Nu]0"}]}], ",", 
           RowBox[{"w0", "\[Rule]", 
            FractionBox[
             RowBox[{"1", "+", "e"}], "2"]}]}], "}"}]}], "]"}], "/.", 
       RowBox[{"{", 
        RowBox[{"\[Nu]0", "\[Rule]", 
         RowBox[{
          FractionBox[
           RowBox[{"8", "d"}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", "e"}], ")"}], 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"5", "d"}], "+", "4", "-", 
              RowBox[{"e", 
               RowBox[{"(", 
                RowBox[{"d", "+", "8"}], ")"}]}]}], ")"}]}]], 
          RowBox[{"\[Nu]", "[", 
           RowBox[{"2", ",", "1"}], "]"}]}]}], "}"}]}], "]"}]}], ";"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"resultPi2form1", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"factor", " ", "resultPi2"}], "/.", "replace\[Rho]Pi2"}], "/.",
        "replace\[Alpha]"}], "/.", "gammareplacements"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Nu]", "\[Rule]", 
        RowBox[{
         FractionBox[
          RowBox[{"d", "+", "2"}], "2"], "\[Nu]0"}]}], ",", 
       RowBox[{"w0", "\[Rule]", 
        FractionBox[
         RowBox[{"1", "+", "e"}], "2"]}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"resultPi2form2", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"Einstein", "[", 
      RowBox[{"Expand", "[", "resultPi2form1", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Rho]", "[", 
         RowBox[{"1", ",", 
          RowBox[{"{", "}"}]}], "]"}], " ", 
        RowBox[{"\[Rho]", "[", 
         RowBox[{"1", ",", 
          RowBox[{"{", "i1", "}"}]}], "]"}]}], ",", 
       RowBox[{"\[Rho]", "[", 
        RowBox[{"2", ",", 
         RowBox[{"{", "i1", "}"}]}], "]"}], ",", 
       RowBox[{
        RowBox[{"\[Rho]", "[", 
         RowBox[{"1", ",", 
          RowBox[{"{", "s0", "}"}]}], "]"}], " ", 
        RowBox[{"\[Upsilon]", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", 
           RowBox[{"i1", ",", "s0"}], "}"}]}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"\[Rho]", "[", 
         RowBox[{"1", ",", 
          RowBox[{"{", "i1", "}"}]}], "]"}], " ", 
        RowBox[{"\[Upsilon]", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", 
           RowBox[{"s0", ",", "s0"}], "}"}]}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"\[Rho]", "[", 
         RowBox[{"1", ",", 
          RowBox[{"{", "}"}]}], "]"}], " ", 
        RowBox[{"\[Upsilon]", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", 
           RowBox[{"i1", ",", "s0", ",", "s0"}], "}"}]}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"\[Upsilon]", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", 
           RowBox[{"s0", ",", "s1"}], "}"}]}], "]"}], " ", 
        RowBox[{"\[Upsilon]", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", 
           RowBox[{"i1", ",", "s0", ",", "s1"}], "}"}]}], "]"}]}]}], "}"}], 
     ",", "Simplify"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.737272917319312*^9, 3.737272919047133*^9}, {
   3.73727297093484*^9, 3.73727298523519*^9}, {3.737273051179839*^9, 
   3.737273105514578*^9}, {3.737273137272187*^9, 3.737273225397573*^9}, 
   3.7372734650377493`*^9, 3.7372736090084267`*^9, {3.737273660475463*^9, 
   3.737273777624713*^9}, 3.738395699297328*^9, {3.7383960772383204`*^9, 
   3.738396078243876*^9}, {3.738396678794359*^9, 3.738396711670636*^9}, {
   3.738396763385541*^9, 3.738396783144718*^9}, {3.7383968961843367`*^9, 
   3.738396900581313*^9}, {3.738401908839529*^9, 3.7384019088444757`*^9}, 
   3.73840197000576*^9, {3.7384020287743187`*^9, 3.738402054020152*^9}, {
   3.738402456253022*^9, 3.738402456254902*^9}, {3.738402610441186*^9, 
   3.738402656391753*^9}, {3.738409777263929*^9, 3.738409817023192*^9}, 
   3.738476933354168*^9, {3.743096409893117*^9, 3.743096409913418*^9}, 
   3.7430967177655687`*^9, {3.743097304239119*^9, 3.743097344871529*^9}, 
   3.743097589831258*^9, {3.743097630463319*^9, 3.74309772733917*^9}, {
   3.743097765070166*^9, 3.7430977781333847`*^9}, 
   3.7430978689835176`*^9},ExpressionUUID->"295c7c0e-dfa5-4cf2-aa5d-\
dda46609632f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   StyleBox["(*",
    FontColor->RGBColor[1, 0, 0]], 
   StyleBox[" ",
    FontColor->RGBColor[1, 0, 0]], 
   StyleBox[
    RowBox[{
    "in", " ", "notations", " ", "of", " ", "Garz\[OAcute]", " ", "and", " ", 
     "Santos", " ", "2007", " ", 
     RowBox[{"J", ".", " ", "Phys", ".", " ", 
      RowBox[{"A", ":", " ", 
       RowBox[{
        RowBox[{"Math", ".", " ", "Theor", ".", " ", 
         StyleBox["40",
          FontWeight->"Bold"]}], " ", "14927"}]}]}]}],
    FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"resultforPi2", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"resultPi2form2", "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"\[Rho]", "[", 
           RowBox[{"n_", ",", "li_"}], "]"}], "\[Rule]", 
          RowBox[{"m", " ", 
           RowBox[{"M", "[", 
            RowBox[{
             RowBox[{"2", "n"}], ",", "li"}], "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"\[Upsilon]", "[", 
           RowBox[{"n_", ",", "li_"}], "]"}], "\[Rule]", 
          RowBox[{"m", " ", 
           RowBox[{"M", "[", 
            RowBox[{
             RowBox[{"2", "n"}], ",", "li"}], "]"}]}]}]}], "}"}]}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"M", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", 
            RowBox[{"s0", ",", "s0"}], "}"}]}], "]"}], "\[Rule]", "0"}], ",", 
        
        RowBox[{
         RowBox[{"M", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "s0", ",", "s0"}], "}"}]}], "]"}], "\[Rule]", 
         "0"}]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"M", "[", 
        RowBox[{"4", ",", 
         RowBox[{"{", "i1", "}"}]}], "]"}], ",", 
       RowBox[{
        RowBox[{"M", "[", 
         RowBox[{"2", ",", 
          RowBox[{"{", "}"}]}], "]"}], " ", 
        RowBox[{"M", "[", 
         RowBox[{"2", ",", 
          RowBox[{"{", "i1", "}"}]}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"M", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", 
           RowBox[{"i1", ",", "s0"}], "}"}]}], "]"}], " ", 
        RowBox[{"M", "[", 
         RowBox[{"2", ",", 
          RowBox[{"{", "s0", "}"}]}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"M", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", 
           RowBox[{"s0", ",", "s1"}], "}"}]}], "]"}], " ", 
        RowBox[{"M", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", 
           RowBox[{"i1", ",", "s0", ",", "s1"}], "}"}]}], "]"}]}]}], "}"}], 
     ",", "Simplify"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.743096752498686*^9, 3.743096791080562*^9}, 
   3.743096852327943*^9, {3.7430969387674026`*^9, 3.743097042960498*^9}, {
   3.743097224300292*^9, 3.7430972409988823`*^9}, 
   3.743097854423855*^9},ExpressionUUID->"010b85fd-4f12-46e8-a94f-\
a2c72296ec7b"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "+", "e"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"d", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "-", 
         RowBox[{"6", " ", "e"}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["e", "2"]}]}], ")"}]}], "+", 
      RowBox[{"8", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], "-", 
         RowBox[{"3", " ", "e"}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["e", "2"]}]}], ")"}]}]}], ")"}], " ", "\[Nu]0", " ", 
    
    RowBox[{"M", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", 
       RowBox[{"s0", ",", "s1"}], "}"}]}], "]"}], " ", 
    RowBox[{"M", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", 
       RowBox[{"i1", ",", "s0", ",", "s1"}], "}"}]}], "]"}]}], 
   RowBox[{"8", " ", "d", " ", 
    RowBox[{"(", 
     RowBox[{"4", "+", "d"}], ")"}], " ", "n"}]], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"4", "+", "d"}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "+", "e"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"4", " ", "d"}], "-", 
      RowBox[{"6", " ", "e"}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["e", "2"]}]}], ")"}], " ", "\[Nu]0", " ", 
    RowBox[{"M", "[", 
     RowBox[{"2", ",", 
      RowBox[{"{", "}"}]}], "]"}], " ", 
    RowBox[{"M", "[", 
     RowBox[{"2", ",", 
      RowBox[{"{", "i1", "}"}]}], "]"}]}], 
   RowBox[{"16", " ", 
    SuperscriptBox["d", "2"], " ", "n"}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "+", "e"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{"4", "+", 
      RowBox[{"24", " ", "e"}], "-", 
      RowBox[{"12", " ", 
       SuperscriptBox["e", "2"]}], "+", 
      RowBox[{"d", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "5"}], "+", 
         RowBox[{"6", " ", "e"}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["e", "2"]}]}], ")"}]}]}], ")"}], " ", "\[Nu]0", " ", 
    
    RowBox[{"M", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", 
       RowBox[{"i1", ",", "s0"}], "}"}]}], "]"}], " ", 
    RowBox[{"M", "[", 
     RowBox[{"2", ",", 
      RowBox[{"{", "s0", "}"}]}], "]"}]}], 
   RowBox[{"8", " ", "d", " ", 
    RowBox[{"(", 
     RowBox[{"2", "+", "d"}], ")"}], " ", "n"}]], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "+", "e"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"8", " ", 
       SuperscriptBox["d", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "4"}], "+", "e"}], ")"}]}], "+", 
      RowBox[{"3", " ", "d", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "43"}], "+", 
         RowBox[{"27", " ", "e"}], "-", 
         RowBox[{"9", " ", 
          SuperscriptBox["e", "2"]}], "+", 
         SuperscriptBox["e", "3"]}], ")"}]}], "+", 
      RowBox[{"8", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "8"}], "+", 
         RowBox[{"17", " ", "e"}], "-", 
         RowBox[{"6", " ", 
          SuperscriptBox["e", "2"]}], "+", 
         RowBox[{"9", " ", 
          SuperscriptBox["e", "3"]}]}], ")"}]}]}], ")"}], " ", "\[Nu]0", " ", 
    
    RowBox[{"M", "[", 
     RowBox[{"4", ",", 
      RowBox[{"{", "i1", "}"}]}], "]"}]}], 
   RowBox[{"32", " ", "d", " ", 
    RowBox[{"(", 
     RowBox[{"4", "+", "d"}], ")"}]}]]}]], "Output",
 CellChangeTimes->{
  3.743096853005392*^9, 3.743096945342743*^9, {3.743096986133279*^9, 
   3.743097043628107*^9}, 3.743097207976789*^9, {3.743097855474628*^9, 
   3.7430978761693068`*^9}, 3.743145953531207*^9, 3.7432439093646717`*^9, 
   3.744983292897479*^9, 3.745014259327303*^9, 3.74501798460786*^9, 
   3.7451224132726183`*^9},ExpressionUUID->"b8334d26-bdec-4164-915b-\
96ba8149ed61"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", 
  StyleBox[
   RowBox[{"To", " ", "write", " ", "in", " ", "the", " ", "paper"}],
   FontColor->RGBColor[1, 0, 0]], "*)"}]], "Input",ExpressionUUID->"295b03de-\
3ed5-4a4f-8e30-5c72450358b6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pi2$paper", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"m", " ", "resultPi2form2"}], "/.", "replace\[Rho]u"}], "/.",
         "zeroReplacements"}], "/.", 
       RowBox[{"n", "\[Rule]", 
        FractionBox["\[Rho]", "m"]}]}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"ui2", "[", 
         RowBox[{"{", "i1", "}"}], "]"}], "\[Rule]", 
        RowBox[{
         RowBox[{"\[CurlyPhi]", "[", 
          RowBox[{"{", "i1", "}"}], "]"}], "+", 
         RowBox[{"4", 
          RowBox[{"(", 
           RowBox[{"d", "+", "4"}], ")"}], "\[Theta]", " ", 
          RowBox[{"q", "[", 
           RowBox[{"{", "i1", "}"}], "]"}]}]}]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[CapitalOmega]", "[", 
        RowBox[{"{", "i1", "}"}], "]"}], ",", 
       RowBox[{"q", "[", 
        RowBox[{"{", "i1", "}"}], "]"}], ",", 
       RowBox[{
        RowBox[{"q", "[", 
         RowBox[{"{", "s0", "}"}], "]"}], " ", 
        RowBox[{"\[Sigma]", "[", 
         RowBox[{"{", 
          RowBox[{"i1", ",", "s0"}], "}"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"m", "[", 
         RowBox[{"{", 
          RowBox[{"i1", ",", "s0", ",", "s1"}], "}"}], "]"}], " ", 
        RowBox[{"\[Sigma]", "[", 
         RowBox[{"{", 
          RowBox[{"s0", ",", "s1"}], "}"}], "]"}]}]}], "}"}], ",", 
     "Simplify"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7386590478810062`*^9, 3.738659067499036*^9}, 
   3.743096409928507*^9, {3.743097070369453*^9, 3.743097088026186*^9}, {
   3.74309738075384*^9, 3.743097474047295*^9}, {3.7430980459333687`*^9, 
   3.7430980561491117`*^9}, {3.743098159107798*^9, 3.7430981674193373`*^9}, {
   3.744983365888061*^9, 3.744983391512239*^9}, {3.744983507417609*^9, 
   3.744983535928561*^9}, {3.744984804401325*^9, 3.744984810584059*^9}, 
   3.744985790345064*^9, {3.745122430823513*^9, 
   3.7451224431680098`*^9}},ExpressionUUID->"ea6a6086-c731-44d4-ab88-\
f3804cfe8192"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", "\[Nu]"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Nu]\[CurlyPhi]", " ", 
        RowBox[{"\[CurlyPhi]", "[", 
         RowBox[{"{", "i1", "}"}], "]"}]}], "+", 
       RowBox[{"\[Alpha]3", " ", "\[Theta]", " ", 
        RowBox[{"q", "[", 
         RowBox[{"{", "i1", "}"}], "]"}]}], "+", 
       RowBox[{"c2", 
        FractionBox[
         RowBox[{
          RowBox[{"\[Sigma]", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "s0"}], "}"}], "]"}], 
          RowBox[{"q", "[", 
           RowBox[{"{", "s0", "}"}], "]"}]}], "\[Rho]"]}], "+", 
       RowBox[{"c3", 
        FractionBox[
         RowBox[{
          RowBox[{"m", "[", 
           RowBox[{"{", 
            RowBox[{"i1", ",", "s0", ",", "s1"}], "}"}], "]"}], " ", 
          RowBox[{"\[Sigma]", "[", 
           RowBox[{"{", 
            RowBox[{"s0", ",", "s1"}], "}"}], "]"}]}], "\[Rho]"]}]}], ")"}]}],
     "-", "Pi2$paper"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Nu]", "\[Rule]", "\[Nu]0"}], ",", 
     RowBox[{"\[Nu]\[CurlyPhi]", "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", "e"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"32", " ", 
           SuperscriptBox["d", "2"]}], "+", 
          RowBox[{"129", " ", "d"}], "+", "64", "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"8", " ", 
              SuperscriptBox["d", "2"]}], "+", 
             RowBox[{"81", " ", "d"}], "+", "136"}], ")"}], " ", "e"}], "+", 
          RowBox[{"3", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"9", "d"}], "+", "16"}], ")"}], " ", 
           SuperscriptBox["e", "2"]}], "-", 
          RowBox[{"3", 
           RowBox[{"(", 
            RowBox[{"d", "+", "24"}], ")"}], " ", 
           SuperscriptBox["e", "3"]}]}], ")"}]}], 
       RowBox[{"32", " ", "d", " ", 
        RowBox[{"(", 
         RowBox[{"d", "+", "4"}], ")"}]}]]}], ",", "\[IndentingNewLine]", 
     RowBox[{"\[Alpha]3", "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", "e"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"14", " ", 
           SuperscriptBox["d", "2"]}], "+", 
          RowBox[{"57", " ", "d"}], "+", "34", "-", 
          RowBox[{"3", 
           RowBox[{"(", 
            RowBox[{"d", "+", "6"}], ")"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", "d"}], "+", "3"}], ")"}], " ", "e"}], "+", 
          RowBox[{"15", 
           RowBox[{"(", 
            RowBox[{"d", "+", "2"}], ")"}], " ", 
           SuperscriptBox["e", "2"]}], "-", 
          RowBox[{"3", 
           RowBox[{"(", 
            RowBox[{"d", "+", "14"}], ")"}], " ", 
           SuperscriptBox["e", "3"]}]}], ")"}]}], 
       RowBox[{"4", " ", "d"}]]}], ",", "\[IndentingNewLine]", 
     RowBox[{"c2", "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "+", "e"}], ")"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"5", " ", "d"}], "-", "4", "-", 
           RowBox[{"6", 
            RowBox[{"(", 
             RowBox[{"d", "+", "4"}], ")"}], " ", "e"}], "-", 
           RowBox[{"3", 
            RowBox[{"(", 
             RowBox[{"d", "-", "4"}], ")"}], " ", 
            SuperscriptBox["e", "2"]}]}], ")"}]}], 
        RowBox[{"4", " ", "d", " ", 
         RowBox[{"(", 
          RowBox[{"d", "+", "2"}], ")"}]}]]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"c3", "\[Rule]", 
      FractionBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "+", "e"}], ")"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{"d", "+", "16", "+", 
          RowBox[{"6", 
           RowBox[{"(", 
            RowBox[{"d", "+", "4"}], ")"}], " ", "e"}], "-", 
          RowBox[{"3", 
           RowBox[{"(", 
            RowBox[{"d", "+", "8"}], ")"}], " ", 
           SuperscriptBox["e", "2"]}]}], ")"}]}], 
       RowBox[{"8", " ", "d", " ", 
        RowBox[{"(", 
         RowBox[{"d", "+", "4"}], ")"}]}]]}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7432444799251957`*^9, 3.743244625052005*^9}, {
   3.743244735966453*^9, 3.743244774680943*^9}, {3.7432448805403748`*^9, 
   3.743245072543501*^9}, {3.743245142513468*^9, 3.743245156925514*^9}, {
   3.743245213526566*^9, 3.743245285435615*^9}, {3.743245378130247*^9, 
   3.7432455272602777`*^9}, {3.7432455664758577`*^9, 
   3.7432455823671913`*^9}, {3.743245620079166*^9, 3.743245710781991*^9}, {
   3.743245866419161*^9, 3.743245869214809*^9}, {3.7432464161529284`*^9, 
   3.743246457170532*^9}, {3.744983569610446*^9, 3.74498358737873*^9}, {
   3.744983685082597*^9, 3.744983724208157*^9}, {3.7449841974523773`*^9, 
   3.7449842081682262`*^9}, 3.744984819640606*^9, {3.744985725106179*^9, 
   3.744985777888413*^9}, {3.745018002211323*^9, 3.745018024368976*^9}, {
   3.745122467610071*^9, 
   3.745122476906138*^9}},ExpressionUUID->"a55b623b-ca1d-4571-98c3-\
95c9c48e1229"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.743244626484229*^9, 3.743244776083906*^9, 3.7432449685875998`*^9, 
   3.743245015330256*^9, 3.743245073597781*^9, 3.743245172145602*^9, {
   3.7432452175225077`*^9, 3.743245228149728*^9}, {3.743245259060248*^9, 
   3.74324528627773*^9}, {3.743245381247354*^9, 3.743245460962469*^9}, 
   3.7432455019591007`*^9, 3.743245583675117*^9, {3.743245628021702*^9, 
   3.743245652772571*^9}, 3.7432457115052223`*^9, 3.743245871609602*^9, 
   3.743246157037332*^9, 3.743246447968212*^9, 3.744983293038159*^9, 
   3.744983593481086*^9, 3.744983726192404*^9, 3.744984209952218*^9, 
   3.744984820936627*^9, {3.744985730772973*^9, 3.744985795777128*^9}, 
   3.745014259523073*^9, 3.745017984680682*^9, 3.745018024891468*^9, 
   3.745122413419524*^9, {3.745122455218486*^9, 
   3.745122478779106*^9}},ExpressionUUID->"ba062787-be12-4f31-9fbb-\
12e3b9b89e2e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   StyleBox[
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Comparison", " ", "with", " ", "the", " ", "right"}], "-", 
       RowBox[{"hand", " ", "side", " ", "of", " ", "equation", " ", 
        RowBox[{"(", "A3", ")"}], " ", "of", " ", "Gu"}]}], " ", "&"}], " ", 
     "Emerson", " ", 
     RowBox[{"(", 
      RowBox[{"JFM", " ", "2009"}], ")"}]}],
    FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Pi2$paper", "-", 
       RowBox[{"2", 
        RowBox[{"(", 
         RowBox[{"d", "+", "4"}], ")"}], "\[Theta]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "\[Nu]q", " ", "\[Nu]0", " ", 
          RowBox[{"q", "[", 
           RowBox[{"{", "i1", "}"}], "]"}]}], ")"}]}], "-", 
       RowBox[{
        FractionBox[
         RowBox[{"4", 
          RowBox[{"(", 
           RowBox[{"d", "+", "4"}], ")"}]}], "d"], 
        FractionBox[
         RowBox[{"q", "[", 
          RowBox[{"{", "i1", "}"}], "]"}], "\[Rho]"], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"(", 
             RowBox[{"d", "+", "2"}], ")"}], "4"]}], 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            SuperscriptBox["e", "2"]}], ")"}], " ", "\[Theta]", " ", "\[Nu]0",
           " ", "\[Rho]"}], ")"}]}]}], "/.", 
      RowBox[{"\[Nu]q", "\[Rule]", 
       FractionBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", "e"}], ")"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"5", "d"}], "+", "4", "-", 
           RowBox[{"e", 
            RowBox[{"(", 
             RowBox[{"d", "+", "8"}], ")"}]}]}], ")"}]}], 
        RowBox[{"8", "d"}]]}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"d", "\[Rule]", "3"}], ",", 
       RowBox[{"e", "\[Rule]", "1"}]}], "}"}]}], ",", 
    RowBox[{"\[CurlyPhi]", "[", 
     RowBox[{"{", "i1", "}"}], "]"}], ",", "Simplify"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7430980661665983`*^9, 3.7430980806454067`*^9}, {
   3.743098111301238*^9, 3.743098125820928*^9}, {3.7431460855603743`*^9, 
   3.74314610224949*^9}, {3.743146177854549*^9, 3.743146184201271*^9}, {
   3.7431462307449503`*^9, 3.74314623405665*^9}, {3.743146283593589*^9, 
   3.743146322519742*^9}, {3.743146642235825*^9, 3.743146728044738*^9}, {
   3.743146758431961*^9, 3.743146808018662*^9}, {3.7431468738721657`*^9, 
   3.743146911122222*^9}, {3.7431469620294952`*^9, 3.743147026883806*^9}, {
   3.744984493106189*^9, 3.744984565665874*^9}, 3.74498461048982*^9, {
   3.744984646929055*^9, 3.744984680110515*^9}, {3.744984713697051*^9, 
   3.7449847377445297`*^9}, 3.744984771089278*^9, 3.74498484134586*^9, 
   3.744984889242469*^9, {3.744984956578013*^9, 3.7449849999599123`*^9}, 
   3.7451225077456427`*^9},ExpressionUUID->"7c835c04-3f60-4274-b11d-\
5219b86e4765"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"2", " ", "\[Nu]0", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"14", " ", 
        RowBox[{"q", "[", 
         RowBox[{"{", "s0", "}"}], "]"}], " ", 
        RowBox[{"\[Sigma]", "[", 
         RowBox[{"{", 
          RowBox[{"i1", ",", "s0"}], "}"}], "]"}]}], "+", 
       RowBox[{"5", " ", 
        RowBox[{"m", "[", 
         RowBox[{"{", 
          RowBox[{"i1", ",", "s0", ",", "s1"}], "}"}], "]"}], " ", 
        RowBox[{"\[Sigma]", "[", 
         RowBox[{"{", 
          RowBox[{"s0", ",", "s1"}], "}"}], "]"}]}]}], ")"}]}], 
    RowBox[{"15", " ", "\[Rho]"}]]}], "-", 
  RowBox[{"\[Nu]0", " ", 
   RowBox[{"\[CurlyPhi]", "[", 
    RowBox[{"{", "i1", "}"}], "]"}]}]}]], "Output",
 CellChangeTimes->{{3.7430980699924726`*^9, 3.743098081361766*^9}, 
   3.743098129532366*^9, 3.7431466822119417`*^9, 3.743146730375469*^9, {
   3.743146760433689*^9, 3.74314680949512*^9}, {3.743146887972076*^9, 
   3.743146911749111*^9}, 3.744983293115555*^9, 3.744984843907769*^9, 
   3.7449848897291927`*^9, {3.744984959838314*^9, 3.7449850011726837`*^9}, 
   3.744985785082869*^9, 3.7450142595929737`*^9, 3.7450179847216053`*^9, 
   3.7450180320409193`*^9, 3.7451224134539347`*^9, {3.745122499915702*^9, 
   3.745122509274469*^9}},ExpressionUUID->"19dcbe40-46ef-4205-97b3-\
3431ac02618b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Alpha]3", "/.", 
     RowBox[{"\[Alpha]3", "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", "e"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"14", " ", 
           SuperscriptBox["d", "2"]}], "+", 
          RowBox[{"57", " ", "d"}], "+", "34", "-", 
          RowBox[{"3", 
           RowBox[{"(", 
            RowBox[{"d", "+", "6"}], ")"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", "d"}], "+", "3"}], ")"}], " ", "e"}], "+", 
          RowBox[{"15", 
           RowBox[{"(", 
            RowBox[{"d", "+", "2"}], ")"}], " ", 
           SuperscriptBox["e", "2"]}], "-", 
          RowBox[{"3", 
           RowBox[{"(", 
            RowBox[{"d", "+", "14"}], ")"}], " ", 
           SuperscriptBox["e", "3"]}]}], ")"}]}], 
       RowBox[{"4", " ", "d"}]]}]}], "/.", 
    RowBox[{"d", "\[Rule]", "3"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"e", ",", "0", ",", "1"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.744985468024858*^9, 3.7449855241776257`*^9}, {
  3.744985912912986*^9, 3.744985926959834*^9}, {3.745018040306588*^9, 
  3.745018042890409*^9}},ExpressionUUID->"423e2d72-be3c-48ed-bc6b-\
a678ce017e03"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwd13k8VG0bB3D7U5ZKIkpKljbSM5Ywh+tOtooiCVnSoiwlWyEUWVKTrZQl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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 18.5},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.7449859214922533`*^9, 3.744985927325283*^9}, 
   3.745014259664071*^9, 3.745017984775835*^9, 3.745018044242886*^9, 
   3.745122413500493*^9},ExpressionUUID->"77e227ff-9796-4827-8879-\
423b3ff5c927"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Appendix", "Section",
 CellChangeTimes->{{3.737994206155859*^9, 
  3.73799420861027*^9}},ExpressionUUID->"a8fb0f47-3132-41b9-acbe-\
cd234ee68d98"],

Cell[CellGroupData[{

Cell["\<\
Function for computing the coefficients in a symmetric-traceless tensor of \
order n\
\>", "Subsection",
 CellChangeTimes->{{3.7372721891507196`*^9, 3.7372722074867897`*^9}, {
  3.737599752941257*^9, 
  3.737599790459433*^9}},ExpressionUUID->"3374725b-b06c-475d-b0c1-\
9a6837154205"],

Cell[BoxData[{
 StyleBox[
  RowBox[{
   RowBox[{
   "The", " ", "function", " ", "coeff$symtracefreetensor", " ", "is", " ", 
    "extremely", " ", "slow", " ", "for", " ", "tensors", " ", "of", " ", 
    "order", " ", "more", " ", "than", " ", "6.", " ", "Coefficients", " ", 
    "for", " ", 
    SuperscriptBox[
     StyleBox["7",
      FontColor->RGBColor[1, 0, 0]], "th"], " ", "order", " ", "tensor", " ", 
    "takes", " ", "about", " ", "4", " ", "minutes", " ", "in", " ", 
    "computing", " ", "while", " ", "those", " ", "for", " ", 
    SuperscriptBox["8", "th"], " ", "order", " ", "tensor", " ", "takes", " ",
     "about", " ", "2.75", " ", 
    RowBox[{"hours", ".", " ", "However"}]}], ",", " ", 
   RowBox[{
    RowBox[{
    "the", " ", "formula", " ", "for", " ", "coefficients", " ", "seems", " ",
      "to", " ", 
     RowBox[{"be", ":", " ", "\[IndentingNewLine]", 
      RowBox[{"c", "[", 
       RowBox[{"n_", ",", "k_"}], "]"}]}]}], ":=", 
    FractionBox[
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "k"], 
     RowBox[{
      UnderoverscriptBox["\[Product]", 
       RowBox[{"j", "=", "0"}], 
       RowBox[{"k", "-", "1"}]], 
      RowBox[{"(", 
       RowBox[{"d", "+", 
        RowBox[{"2", "n"}], "-", "4", "-", 
        RowBox[{"2", "j"}]}], ")"}]}]]}]}],
  FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     StyleBox["verified",
      FontColor->RGBColor[1, 0, 0]], 
     StyleBox[" ",
      FontColor->RGBColor[1, 0, 0]], "till", " ", 
     SuperscriptBox["8", "th"], 
     StyleBox[" ",
      FontColor->RGBColor[1, 0, 0]], 
     StyleBox["order",
      FontColor->RGBColor[1, 0, 0]], 
     StyleBox[" ",
      FontColor->RGBColor[1, 0, 0]], 
     StyleBox["tensor",
      FontColor->RGBColor[1, 0, 0]]}], ")"}], "."}],
  FontColor->RGBColor[1, 0, 0]]}], "Text",
 CellChangeTimes->{{3.737961727426546*^9, 
  3.737961775541202*^9}},ExpressionUUID->"1ba30855-3b20-4ce1-ad62-\
47075a9f0436"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "c", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"coeff$symtracefreetensor", "[", "tensororder_", "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "A", ",", "i", ",", "indices", ",", "ex", ",", "list$numof\[Delta]s", 
      ",", 
      RowBox[{"list", "=", 
       RowBox[{"{", "}"}]}], ",", "contractionreplacements", ",", 
      RowBox[{"product", "=", "1"}], ",", "listdeltas", ",", 
      "tensor\[Delta]combinations", ",", "generalform", ",", "c", ",", 
      "cvalues", ",", "\[Delta]"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"tensororder", "<=", "0"}], ",", 
      RowBox[{
      "Print", "[", 
       "\"\<Order of tensor is wrong for finding the coefficients!\>\"", 
       "]"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"indices", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"ToExpression", "[", 
           RowBox[{
            RowBox[{"ToString", "[", "i", "]"}], "<>", 
            RowBox[{"ToString", "[", "ii", "]"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"ii", ",", "1", ",", "tensororder"}], "}"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"ex", "=", 
        RowBox[{"A", "[", "indices", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"list$numof\[Delta]s", "=", 
          RowBox[{"2", 
           RowBox[{"Range", "[", 
            RowBox[{"tensororder", "/", "2"}], "]"}]}]}], ";"}], "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"contractionreplacements", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"list", "=", 
           RowBox[{"Join", "[", 
            RowBox[{"list", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"indices", "\[LeftDoubleBracket]", 
                RowBox[{"2", "ii"}], "\[RightDoubleBracket]"}], "\[Rule]", 
               RowBox[{"indices", "\[LeftDoubleBracket]", 
                RowBox[{
                 RowBox[{"2", "ii"}], "-", "1"}], "\[RightDoubleBracket]"}]}],
               "}"}]}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"ii", ",", 
            RowBox[{
             RowBox[{"Length", "[", "indices", "]"}], "/", "2"}], ",", "1", 
            ",", 
            RowBox[{"-", "1"}]}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"listdeltas", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"product", "=", 
           RowBox[{"product", "*", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"Sort", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"indices", "\[LeftDoubleBracket]", 
                 RowBox[{"2", "ii"}], "\[RightDoubleBracket]"}], ",", 
                RowBox[{"indices", "\[LeftDoubleBracket]", 
                 RowBox[{
                  RowBox[{"2", "ii"}], "-", "1"}], 
                 "\[RightDoubleBracket]"}]}], "}"}], "]"}], "]"}]}]}], ",", 
          RowBox[{"{", 
           RowBox[{"ii", ",", 
            RowBox[{
             RowBox[{"Length", "[", "indices", "]"}], "/", "2"}], ",", "1", 
            ",", 
            RowBox[{"-", "1"}]}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        StyleBox[
         RowBox[{
         "list", " ", "of", " ", "tensors", " ", "formed", " ", "with", " ", 
          "free", " ", "indices", " ", "and", " ", "deltas"}],
         FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
       RowBox[{"tensor\[Delta]combinations", "=", 
        RowBox[{"Join", "[", 
         RowBox[{
          RowBox[{"{", "ex", "}"}], ",", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"sym", "[", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"Einstein", "[", 
                 RowBox[{"Expand", "[", 
                  RowBox[{"ex", "/.", 
                   RowBox[{
                   "contractionreplacements", "\[LeftDoubleBracket]", "ii", 
                    "\[RightDoubleBracket]"}]}], "]"}], "]"}], "/.", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"s0", "\[Rule]", "\[CurlyKappa]0"}], ",", 
                  RowBox[{"s1", "\[Rule]", "\[CurlyKappa]1"}], ",", 
                  RowBox[{"s2", "\[Rule]", "\[CurlyKappa]2"}], ",", 
                  RowBox[{"s3", "\[Rule]", "\[CurlyKappa]3"}], ",", 
                  RowBox[{"s4", "\[Rule]", "\[CurlyKappa]4"}], ",", 
                  RowBox[{"s5", "\[Rule]", "\[CurlyKappa]5"}], ",", 
                  RowBox[{"s6", "\[Rule]", "\[CurlyKappa]6"}], ",", 
                  RowBox[{"s7", "\[Rule]", "\[CurlyKappa]7"}], ",", 
                  RowBox[{"s8", "\[Rule]", "\[CurlyKappa]8"}], ",", 
                  RowBox[{"s9", "\[Rule]", "\[CurlyKappa]9"}]}], "}"}]}], 
               ")"}], 
              RowBox[{
              "listdeltas", "\[LeftDoubleBracket]", "ii", 
               "\[RightDoubleBracket]"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"ii", ",", "1", ",", 
              RowBox[{"Length", "[", "listdeltas", "]"}]}], "}"}]}], "]"}]}], 
         "]"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"generalform", "=", 
        RowBox[{"Apply", "[", 
         RowBox[{"Plus", ",", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"c", "[", 
               RowBox[{"tensororder", ",", 
                RowBox[{"ii", "-", "1"}]}], "]"}], 
              RowBox[{
               RowBox[{"FactorTermsList", "[", 
                RowBox[{"sym", "[", 
                 RowBox[{
                 "tensor\[Delta]combinations", "\[LeftDoubleBracket]", "ii", 
                  "\[RightDoubleBracket]"}], "]"}], "]"}], 
               "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], ",", 
             
             RowBox[{"{", 
              RowBox[{"ii", ",", "1", ",", 
               RowBox[{"Length", "[", "tensor\[Delta]combinations", "]"}]}], 
              "}"}]}], "]"}], "/.", 
           RowBox[{
            RowBox[{"c", "[", 
             RowBox[{"tensororder", ",", "0"}], "]"}], "\[Rule]", "1"}]}]}], 
         "]"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"cvalues", "=", 
        RowBox[{"Factor", "[", 
         RowBox[{"Simplify", "[", 
          RowBox[{
           RowBox[{"Solve", "[", 
            RowBox[{
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"Einstein", "[", 
                 RowBox[{"Expand", "[", 
                  RowBox[{"generalform", "/.", 
                   RowBox[{
                   "contractionreplacements", "\[LeftDoubleBracket]", "ii", 
                    "\[RightDoubleBracket]"}]}], "]"}], "]"}], "\[Equal]", 
                "0"}], ",", 
               RowBox[{"{", 
                RowBox[{"ii", ",", "1", ",", 
                 RowBox[{"Length", "[", "contractionreplacements", "]"}]}], 
                "}"}]}], "]"}], ",", 
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"c", "[", 
                RowBox[{"tensororder", ",", "ii"}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"ii", ",", "1", ",", 
                 RowBox[{
                  RowBox[{"Length", "[", "tensor\[Delta]combinations", "]"}], 
                  "-", "1"}]}], "}"}]}], "]"}]}], "]"}], 
           "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "]"}], 
         "]"}]}]}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.737524947794498*^9, 3.73752496727885*^9}, {
   3.7375250363328047`*^9, 3.73752527850489*^9}, {3.737525326873888*^9, 
   3.7375253687839003`*^9}, {3.7375254805623417`*^9, 3.737525664156871*^9}, 
   3.737525739570159*^9, {3.7375257996881533`*^9, 3.737525811750266*^9}, {
   3.737525844784739*^9, 3.737525865824051*^9}, {3.737525918680382*^9, 
   3.737525947385838*^9}, {3.737526004050455*^9, 3.737526008430826*^9}, 
   3.737526095929443*^9, {3.73752612904255*^9, 3.73752621993226*^9}, {
   3.737526401962419*^9, 3.7375264820839643`*^9}, {3.7375265125822983`*^9, 
   3.737526595552986*^9}, {3.737526637628429*^9, 3.73752665188545*^9}, {
   3.737526772388612*^9, 3.7375267952028913`*^9}, {3.737526944090225*^9, 
   3.737526994308523*^9}, {3.7375270403740683`*^9, 3.737527081141994*^9}, {
   3.7375271196154118`*^9, 3.737527171483342*^9}, {3.737527208101762*^9, 
   3.737527227495617*^9}, {3.737527266059161*^9, 3.7375273113276167`*^9}, {
   3.737527358685672*^9, 3.737527380646299*^9}, {3.7375316218312473`*^9, 
   3.737531631228825*^9}, {3.737532172199319*^9, 3.737532195183737*^9}, 
   3.737532373387001*^9, {3.737532739878191*^9, 3.737532783181346*^9}, {
   3.737533127187861*^9, 3.737533139876005*^9}, {3.737544789954278*^9, 
   3.737544801504785*^9}, 3.737545151448142*^9, 3.737545233001498*^9, 
   3.737545431756481*^9, {3.737545893803878*^9, 3.73754591335131*^9}, {
   3.737545946913837*^9, 3.7375459780288677`*^9}, {3.737546037784113*^9, 
   3.7375460674172363`*^9}, {3.737546178804105*^9, 3.737546186823392*^9}, {
   3.737546216846642*^9, 3.737546228517716*^9}, {3.737546260298602*^9, 
   3.737546263209826*^9}, {3.737546304482407*^9, 3.7375463577655363`*^9}, {
   3.737546412162382*^9, 3.737546443618145*^9}, {3.737546531304599*^9, 
   3.737546537212325*^9}, {3.7375468689173403`*^9, 3.737546921216599*^9}, {
   3.7375470529206543`*^9, 3.737547053204917*^9}, {3.737547096450077*^9, 
   3.737547096917553*^9}, {3.737550884571529*^9, 3.73755090251095*^9}, {
   3.7375509915267563`*^9, 3.737550999154532*^9}, 3.737551035919751*^9, {
   3.7375513857067327`*^9, 3.737551388890045*^9}, {3.737552069490793*^9, 
   3.737552109674582*^9}, {3.737557757438682*^9, 3.737557769485519*^9}, {
   3.7375579327210608`*^9, 3.737558056504548*^9}, {3.737558527232813*^9, 
   3.73755853119805*^9}, {3.737558979863476*^9, 3.737558999077857*^9}, {
   3.737559044622282*^9, 3.737559049443733*^9}, {3.737565650640254*^9, 
   3.737565737854095*^9}, {3.737569712689893*^9, 3.737569718540669*^9}, {
   3.737569909082034*^9, 3.737569909429489*^9}, {3.737600599664276*^9, 
   3.737600600053783*^9}, {3.737961704519017*^9, 3.7379617083461514`*^9}, {
   3.73799461673103*^9, 
   3.737994632441929*^9}},ExpressionUUID->"501fb95f-e728-4b15-a320-\
d873b76e8d04"],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellChangeTimes->{{3.737994433498258*^9, 
  3.737994435064641*^9}},ExpressionUUID->"15406d92-3aa4-492a-9beb-\
e63a10952e62"],

Cell[BoxData[
 RowBox[{"Coefficients", " ", "for", " ", 
  SuperscriptBox[
   StyleBox["7",
    FontColor->RGBColor[1, 0, 0]], "th"], " ", "order", " ", "tensor", " ", 
  "takes", " ", "about", " ", "4", " ", "minutes", " ", "in", " ", 
  "computing", " ", "while", " ", "those", " ", "for", " ", 
  SuperscriptBox["8", "th"], " ", "order", " ", "tensor", " ", "takes", " ", 
  "about", " ", "2.75", " ", 
  RowBox[{"hours", ".", " ", "So"}], " ", "be", " ", "careful", " ", "in", 
  " ", "running", " ", "the", " ", "function", " ", "for", " ", "7", " ", 
  "and", " ", "8."}]], "Text",
 CellChangeTimes->{{3.737994546227517*^9, 3.7379946013741827`*^9}},
 FontColor->RGBColor[1, 0, 0],
 Background->RGBColor[
  0.87, 0.94, 1],ExpressionUUID->"157f108f-858e-4a6f-82c5-9db275637154"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"coeff$symtracefreetensor", "[", "2", "]"}], "\[IndentingNewLine]", 
   RowBox[{"coeff$symtracefreetensor", "[", "3", "]"}], "\[IndentingNewLine]", 
   RowBox[{"coeff$symtracefreetensor", "[", "4", "]"}], "\[IndentingNewLine]", 
   RowBox[{"coeff$symtracefreetensor", "[", "5", "]"}], "\[IndentingNewLine]", 
   RowBox[{"coeff$symtracefreetensor", "[", "6", "]"}], "\[IndentingNewLine]", 
   RowBox[{"coeff$symtracefreetensor", "[", "7", "]"}], "\[IndentingNewLine]", 
   RowBox[{"coeff$symtracefreetensor", "[", "8", "]"}]}], "*)"}]], "Input",
 CellChangeTimes->{{3.737600016232216*^9, 3.7376000434546537`*^9}, 
   3.7376001490004253`*^9},ExpressionUUID->"075714c7-b2f4-4375-b4f7-\
9b9950cb617f"],

Cell[CellGroupData[{

Cell[BoxData["\[IndentingNewLine]"], "Input",
 CellChangeTimes->{
  3.73760065184783*^9},ExpressionUUID->"f7c57cd8-2693-4940-ad4c-e0ff7761fffe"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"c", "[", 
    RowBox[{"2", ",", "1"}], "]"}], "\[Rule]", 
   RowBox[{"-", 
    FractionBox["1", "d"]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7375577831231947`*^9, 3.737557805648849*^9}, 
   3.7375590571020727`*^9},ExpressionUUID->"59876352-8f74-4ece-94ba-\
9434e1972c84"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"c", "[", 
    RowBox[{"3", ",", "1"}], "]"}], "\[Rule]", 
   RowBox[{"-", 
    FractionBox["1", 
     RowBox[{"2", "+", "d"}]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7375578195068407`*^9, 
  3.7375590596535177`*^9},ExpressionUUID->"c8dfd8be-d783-460f-8ac5-\
3424d7a366ea"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "1"}], "]"}], "\[Rule]", 
    RowBox[{"-", 
     FractionBox["1", 
      RowBox[{"4", "+", "d"}]]}]}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "2"}], "]"}], "\[Rule]", 
    FractionBox["1", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2", "+", "d"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"4", "+", "d"}], ")"}]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.737557831502275*^9, 3.7375578656880302`*^9}, 
   3.737559066007996*^9},ExpressionUUID->"b813841e-cf87-4df3-87ce-\
bf4219fc2f92"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "1"}], "]"}], "\[Rule]", 
    RowBox[{"-", 
     FractionBox["1", 
      RowBox[{"6", "+", "d"}]]}]}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "2"}], "]"}], "\[Rule]", 
    FractionBox["1", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4", "+", "d"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"6", "+", "d"}], ")"}]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.737557891321474*^9, 
  3.737559072894928*^9},ExpressionUUID->"62758334-00b6-4570-a8a5-\
d8799944e1f1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"6", ",", "1"}], "]"}], "\[Rule]", 
    RowBox[{"-", 
     FractionBox["1", 
      RowBox[{"8", "+", "d"}]]}]}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"6", ",", "2"}], "]"}], "\[Rule]", 
    FractionBox["1", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6", "+", "d"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"8", "+", "d"}], ")"}]}]]}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"6", ",", "3"}], "]"}], "\[Rule]", 
    RowBox[{"-", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"4", "+", "d"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"6", "+", "d"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"8", "+", "d"}], ")"}]}]]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.73755791668778*^9, 
  3.7375590890344543`*^9},ExpressionUUID->"ec06a39d-d9e8-493c-817f-\
076791526818"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"7", ",", "1"}], "]"}], "\[Rule]", 
    RowBox[{"-", 
     FractionBox["1", 
      RowBox[{"10", "+", "d"}]]}]}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"7", ",", "2"}], "]"}], "\[Rule]", 
    FractionBox["1", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"8", "+", "d"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"10", "+", "d"}], ")"}]}]]}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"7", ",", "3"}], "]"}], "\[Rule]", 
    RowBox[{"-", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"6", "+", "d"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"8", "+", "d"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"10", "+", "d"}], ")"}]}]]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7375523681846*^9, 
  3.7375593408354263`*^9},ExpressionUUID->"61aa826e-05f6-481c-ac18-\
679c4844bb0a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"8", ",", "1"}], "]"}], "\[Rule]", 
    RowBox[{"-", 
     FractionBox["1", 
      RowBox[{"12", "+", "d"}]]}]}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"8", ",", "2"}], "]"}], "\[Rule]", 
    FractionBox["1", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"10", "+", "d"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"12", "+", "d"}], ")"}]}]]}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"8", ",", "3"}], "]"}], "\[Rule]", 
    RowBox[{"-", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"8", "+", "d"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"10", "+", "d"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"12", "+", "d"}], ")"}]}]]}]}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"8", ",", "4"}], "]"}], "\[Rule]", 
    FractionBox["1", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6", "+", "d"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"8", "+", "d"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"10", "+", "d"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"12", "+", "d"}], ")"}]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.737569291444365*^9},ExpressionUUID->"7ae2e6ee-e60c-4fa0-bc8a-\
301888b16f0a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"n", "=", "8"}], ";", "\[IndentingNewLine]", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"n", ",", "k"}], "]"}], "\[Rule]", 
      FractionBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], "k"], 
       RowBox[{
        UnderoverscriptBox["\[Product]", 
         RowBox[{"j", "=", "0"}], 
         RowBox[{"k", "-", "1"}]], 
        RowBox[{"(", 
         RowBox[{"d", "+", 
          RowBox[{"2", "n"}], "-", "4", "-", 
          RowBox[{"2", "j"}]}], ")"}]}]]}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "1", ",", 
       RowBox[{"n", "/", "2"}]}], "}"}]}], "]"}]}], "*)"}]], "Input",
 CellChangeTimes->{{3.7375697555308933`*^9, 3.737569886955*^9}, 
   3.7376001401725607`*^9},ExpressionUUID->"2f145099-f4c7-4ee5-b62f-\
df83d0798b7f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"8", ",", "1"}], "]"}], "\[Rule]", 
    RowBox[{"-", 
     FractionBox["1", 
      RowBox[{"12", "+", "d"}]]}]}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"8", ",", "2"}], "]"}], "\[Rule]", 
    FractionBox["1", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"10", "+", "d"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"12", "+", "d"}], ")"}]}]]}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"8", ",", "3"}], "]"}], "\[Rule]", 
    RowBox[{"-", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"8", "+", "d"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"10", "+", "d"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"12", "+", "d"}], ")"}]}]]}]}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"8", ",", "4"}], "]"}], "\[Rule]", 
    FractionBox["1", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6", "+", "d"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"8", "+", "d"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"10", "+", "d"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"12", "+", "d"}], ")"}]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7375698254382067`*^9, 
  3.737569887970985*^9}},ExpressionUUID->"ededed41-961f-4eb0-a0a3-\
470406318f00"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Verification of definition of original variables with the Grad (26) \
distribution function\
\>", "Subsection",
 CellChangeTimes->{{3.7439209186985826`*^9, 3.743920922041936*^9}, {
  3.744048043092311*^9, 
  3.744048052361896*^9}},ExpressionUUID->"ebe48051-1cca-498e-a9b8-\
90ff3768a637"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Unprotect", "[", "C", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", "CC", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CC", "[", "idx_", "]"}], ":=", 
  RowBox[{
   UnderoverscriptBox["\[Product]", 
    RowBox[{"ii", "=", "1"}], 
    RowBox[{"Length", "[", "idx", "]"}]], 
   RowBox[{"C", "[", 
    RowBox[{"{", 
     RowBox[{"idx", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}], 
     "}"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"f", "=", 
    RowBox[{
     FractionBox["1", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"2", "\[Pi]"}], ")"}], 
       RowBox[{"d", "/", "2"}]]], 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{
        FractionBox[
         RowBox[{"d", 
          RowBox[{"(", 
           RowBox[{"d", "+", "2"}], ")"}]}], "8"], "\[CapitalDelta]", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{
           FractionBox["2", "d"], 
           RowBox[{"CC", "[", 
            RowBox[{"{", 
             RowBox[{"j1", ",", "j1"}], "}"}], "]"}]}], "+", 
          RowBox[{
           FractionBox["1", 
            RowBox[{"d", 
             RowBox[{"(", 
              RowBox[{"d", "+", "2"}], ")"}]}]], 
           RowBox[{"CC", "[", 
            RowBox[{"{", 
             RowBox[{"j1", ",", "j1", ",", "j2", ",", "j2"}], "}"}], 
            "]"}]}]}], ")"}]}], "+", 
       RowBox[{
        FractionBox["1", "2"], 
        RowBox[{"\[Sigma]", "[", 
         RowBox[{"{", 
          RowBox[{"j1", ",", "j2"}], "}"}], "]"}], 
        RowBox[{"CC", "[", 
         RowBox[{"{", 
          RowBox[{"j1", ",", "j2"}], "}"}], "]"}]}], "+", 
       RowBox[{
        FractionBox["1", 
         RowBox[{"d", "+", "2"}]], 
        RowBox[{"q", "[", 
         RowBox[{"{", "j1", "}"}], "]"}], 
        RowBox[{"CC", "[", 
         RowBox[{"{", 
          RowBox[{"j1", ",", "j2", ",", "j2"}], "}"}], "]"}]}], "-", 
       RowBox[{
        RowBox[{"q", "[", 
         RowBox[{"{", "j1", "}"}], "]"}], 
        RowBox[{"CC", "[", 
         RowBox[{"{", "j1", "}"}], "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "6"], 
        RowBox[{"m", "[", 
         RowBox[{"{", 
          RowBox[{"j1", ",", "j2", ",", "j3"}], "}"}], "]"}], 
        RowBox[{"CC", "[", 
         RowBox[{"{", 
          RowBox[{"j1", ",", "j2", ",", "j3"}], "}"}], "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "4"], 
        RowBox[{"R", "[", 
         RowBox[{"{", 
          RowBox[{"j1", ",", "j2"}], "}"}], "]"}], 
        RowBox[{"CC", "[", 
         RowBox[{"{", 
          RowBox[{"j1", ",", "j2"}], "}"}], "]"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["1", 
            RowBox[{"d", "+", "4"}]], 
           RowBox[{"CC", "[", 
            RowBox[{"{", 
             RowBox[{"j3", ",", "j3"}], "}"}], "]"}]}], "-", "1"}], ")"}]}]}],
       ")"}]}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"zeroReplacements", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Sigma]", "[", 
       RowBox[{"{", 
        RowBox[{"s0_", ",", "s0_"}], "}"}], "]"}], "\[Rule]", "0"}], ",", " ", 
     RowBox[{
      RowBox[{"m", "[", 
       RowBox[{"{", 
        RowBox[{"_", ",", "s0_", ",", "s0_"}], "}"}], "]"}], "\[Rule]", "0"}],
      ",", " ", 
     RowBox[{
      RowBox[{"m", "[", 
       RowBox[{"{", 
        RowBox[{"s0_", ",", "s0_", ",", "_"}], "}"}], "]"}], "\[Rule]", "0"}],
      ",", 
     RowBox[{
      RowBox[{"R", "[", 
       RowBox[{"{", 
        RowBox[{"s0_", ",", "s0_"}], "}"}], "]"}], "\[Rule]", "0"}]}], 
    "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.744046048774663*^9, 3.744046050261744*^9}, {
   3.744046154018383*^9, 3.744046155467428*^9}, {3.7440464542456017`*^9, 
   3.744046461196033*^9}, 3.744046783278841*^9, {3.744048121595421*^9, 
   3.74404813775639*^9}},ExpressionUUID->"1c88e2be-ffc3-44ac-9911-\
520984c34404"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"integrand", "=", 
   RowBox[{"Expand", "[", "f", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Einstein", "[", 
     RowBox[{"Expand", "[", 
      RowBox[{"Apply", "[", 
       RowBox[{"Plus", ",", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"IntGauss", "[", 
           RowBox[{"\[Gamma]", ",", 
            RowBox[{
             RowBox[{
              SqrtBox["2"], 
              RowBox[{"IntDir", "[", 
               RowBox[{"C", ",", 
                RowBox[{
                "integrand", "\[LeftDoubleBracket]", "ii", 
                 "\[RightDoubleBracket]"}]}], "]"}]}], "/.", 
             RowBox[{"C", "\[Rule]", 
              RowBox[{"\[Gamma]", 
               SqrtBox["2"]}]}]}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"ii", ",", "1", ",", 
            RowBox[{"Length", "[", "integrand", "]"}]}], "}"}]}], "]"}]}], 
       "]"}], "]"}], "]"}], "/.", "zeroReplacements"}], "/.", 
   "gammareplacements"}], "]"}]}], "Input",
 CellChangeTimes->{{3.743848123816659*^9, 3.743848238802013*^9}, {
   3.743848403821611*^9, 3.743848428097006*^9}, {3.743848519589879*^9, 
   3.7438485510914793`*^9}, {3.7438487255664053`*^9, 
   3.7438487336239767`*^9}, {3.743849293609921*^9, 3.743849309847989*^9}, {
   3.743849352045641*^9, 3.743849356036162*^9}, {3.743849787670142*^9, 
   3.7438498484643297`*^9}, {3.743849910481679*^9, 3.743849911471107*^9}, {
   3.743850877433714*^9, 3.7438508777853527`*^9}, {3.743851225417754*^9, 
   3.743851228865903*^9}, {3.743873654652812*^9, 3.743873667458528*^9}, 
   3.744045881342811*^9, 3.744045914666236*^9, 3.744046102025419*^9, {
   3.744046386086059*^9, 3.744046386740385*^9}, 
   3.744047994892605*^9},ExpressionUUID->"790b81d3-b800-4935-b85c-\
b641980d8de7"],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{
  3.743848174613483*^9, {3.743848212245219*^9, 3.7438482393833017`*^9}, 
   3.743848433321995*^9, 3.743848466351054*^9, 3.7438485532228003`*^9, 
   3.743848734783781*^9, {3.743849294968199*^9, 3.7438493108098993`*^9}, {
   3.743849776346595*^9, 3.743849849172308*^9}, 3.743849912408204*^9, {
   3.743850863830319*^9, 3.7438508823453693`*^9}, 3.743851113260397*^9, 
   3.74385122939363*^9, 3.743853855176162*^9, 3.743854313936213*^9, 
   3.7438544377085*^9, 3.743855527554592*^9, 3.743855566004937*^9, {
   3.743873658474248*^9, 3.743873668039667*^9}, 3.743875321252387*^9, 
   3.74392139103302*^9, 3.7440459343263617`*^9, 3.7440460588798523`*^9, 
   3.744046093817091*^9, 3.744046160101656*^9, 3.744046219259207*^9, 
   3.744046333857155*^9, 3.74404638832178*^9, 3.744046465743226*^9, 
   3.744046621914319*^9, {3.744046747260545*^9, 3.744046754123721*^9}, 
   3.744046788989397*^9, 3.744047000923917*^9, 3.7440470314118433`*^9, 
   3.744047268881462*^9, 3.744047854281804*^9, 3.744047996525161*^9, 
   3.744048146941897*^9},ExpressionUUID->"d4116d39-d02a-4352-a345-\
96c4cb7a9047"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"integrand", "=", 
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{"C", "[", 
      RowBox[{"{", "i", "}"}], "]"}], "f"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Einstein", "[", 
     RowBox[{"Expand", "[", 
      RowBox[{"Apply", "[", 
       RowBox[{"Plus", ",", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"IntGauss", "[", 
           RowBox[{"\[Gamma]", ",", 
            RowBox[{
             RowBox[{
              SqrtBox["2"], 
              RowBox[{"IntDir", "[", 
               RowBox[{"C", ",", 
                RowBox[{
                "integrand", "\[LeftDoubleBracket]", "ii", 
                 "\[RightDoubleBracket]"}]}], "]"}]}], "/.", 
             RowBox[{"C", "\[Rule]", 
              RowBox[{"\[Gamma]", 
               SqrtBox["2"]}]}]}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"ii", ",", "1", ",", 
            RowBox[{"Length", "[", "integrand", "]"}]}], "}"}]}], "]"}]}], 
       "]"}], "]"}], "]"}], "/.", "zeroReplacements"}], "/.", 
   "gammareplacements"}], "]"}]}], "Input",
 CellChangeTimes->{{3.743848123816659*^9, 3.743848238802013*^9}, {
   3.743848403821611*^9, 3.743848428097006*^9}, {3.743848519589879*^9, 
   3.7438485510914793`*^9}, {3.7438487255664053`*^9, 
   3.7438487336239767`*^9}, {3.743849293609921*^9, 3.743849309847989*^9}, {
   3.743849352045641*^9, 3.743849356036162*^9}, {3.743849787670142*^9, 
   3.7438498484643297`*^9}, {3.743849910481679*^9, 3.743849911471107*^9}, {
   3.743850877433714*^9, 3.7438508777853527`*^9}, {3.743851130159027*^9, 
   3.74385113497398*^9}, {3.7438512035563297`*^9, 3.7438512134433193`*^9}, {
   3.7438736724443007`*^9, 3.743873673098572*^9}, 3.744045881355654*^9, 
   3.744045914672173*^9, {3.744046476300458*^9, 3.744046476724534*^9}, 
   3.744048164934585*^9},ExpressionUUID->"f4898a41-f67a-4b1f-b615-\
e5742b13671c"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.743848174613483*^9, {3.743848212245219*^9, 3.7438482393833017`*^9}, 
   3.743848433321995*^9, 3.743848466351054*^9, 3.7438485532228003`*^9, 
   3.743848734783781*^9, {3.743849294968199*^9, 3.7438493108098993`*^9}, {
   3.743849776346595*^9, 3.743849849172308*^9}, 3.743849912408204*^9, {
   3.743850863830319*^9, 3.7438508823453693`*^9}, {3.743851113260397*^9, 
   3.743851136591984*^9}, {3.743851214950533*^9, 3.743851232249947*^9}, 
   3.7438538573918047`*^9, 3.743854439659782*^9, 3.743855568113546*^9, 
   3.743873674158393*^9, 3.743875321452012*^9, 3.74392139110247*^9, 
   3.7440464777436028`*^9, 
   3.744048168322287*^9},ExpressionUUID->"7e7304eb-3923-4cfe-b5d3-\
de17ce92df68"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"integrand", "=", 
   RowBox[{"Expand", "[", 
    RowBox[{
     FractionBox["1", "2"], 
     SuperscriptBox["C", "2"], "f"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Einstein", "[", 
     RowBox[{"Expand", "[", 
      RowBox[{"Apply", "[", 
       RowBox[{"Plus", ",", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"IntGauss", "[", 
           RowBox[{"\[Gamma]", ",", 
            RowBox[{
             RowBox[{
              SqrtBox["2"], 
              RowBox[{"IntDir", "[", 
               RowBox[{"C", ",", 
                RowBox[{
                "integrand", "\[LeftDoubleBracket]", "ii", 
                 "\[RightDoubleBracket]"}]}], "]"}]}], "/.", 
             RowBox[{"C", "\[Rule]", 
              RowBox[{"\[Gamma]", 
               SqrtBox["2"]}]}]}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"ii", ",", "1", ",", 
            RowBox[{"Length", "[", "integrand", "]"}]}], "}"}]}], "]"}]}], 
       "]"}], "]"}], "]"}], "/.", "zeroReplacements"}], "/.", 
   "gammareplacements"}], "]"}]}], "Input",
 CellChangeTimes->{{3.743848123816659*^9, 3.743848238802013*^9}, {
   3.743848403821611*^9, 3.743848428097006*^9}, {3.743848519589879*^9, 
   3.7438485510914793`*^9}, {3.7438487255664053`*^9, 
   3.7438487336239767`*^9}, {3.743849293609921*^9, 3.743849309847989*^9}, {
   3.743849352045641*^9, 3.743849356036162*^9}, {3.743849787670142*^9, 
   3.7438498484643297`*^9}, {3.743849910481679*^9, 3.743849911471107*^9}, {
   3.743850877433714*^9, 3.7438508777853527`*^9}, {3.743851130159027*^9, 
   3.74385113497398*^9}, {3.7438512035563297`*^9, 3.7438512134433193`*^9}, {
   3.743851254162632*^9, 3.743851265697742*^9}, {3.7438528216245317`*^9, 
   3.743852827235096*^9}, {3.743873676652348*^9, 3.7438736773228903`*^9}, 
   3.7440458813686113`*^9, 3.7440459146777143`*^9, {3.744048180823987*^9, 
   3.744048187885077*^9}},ExpressionUUID->"cd595a98-40e1-46fd-b291-\
9faa3e897f68"],

Cell[BoxData[
 FractionBox["d", "2"]], "Output",
 CellChangeTimes->{
  3.743848174613483*^9, {3.743848212245219*^9, 3.7438482393833017`*^9}, 
   3.743848433321995*^9, 3.743848466351054*^9, 3.7438485532228003`*^9, 
   3.743848734783781*^9, {3.743849294968199*^9, 3.7438493108098993`*^9}, {
   3.743849776346595*^9, 3.743849849172308*^9}, 3.743849912408204*^9, {
   3.743850863830319*^9, 3.7438508823453693`*^9}, {3.743851113260397*^9, 
   3.743851136591984*^9}, {3.743851214950533*^9, 3.7438512664757767`*^9}, 
   3.743852828667178*^9, 3.743853859443368*^9, 3.743854320879424*^9, 
   3.743854381849227*^9, 3.743854445316642*^9, 3.7438555705412807`*^9, 
   3.743873678206732*^9, 3.743875321498164*^9, 3.743921391123869*^9, {
   3.744048182711458*^9, 
   3.744048189396941*^9}},ExpressionUUID->"3cbc85af-e0cb-4ff7-af8e-\
f4c0311b69a9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"integrand", "=", 
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"C", "[", 
         RowBox[{"{", "i", "}"}], "]"}], 
        RowBox[{"C", "[", 
         RowBox[{"{", "j", "}"}], "]"}]}], "-", 
       RowBox[{
        FractionBox["1", "d"], 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i", ",", "j"}], "}"}], "]"}], 
        RowBox[{"CC", "[", 
         RowBox[{"{", 
          RowBox[{"k", ",", "k"}], "}"}], "]"}]}]}], ")"}], "f"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Einstein", "[", 
     RowBox[{"Expand", "[", 
      RowBox[{"Apply", "[", 
       RowBox[{"Plus", ",", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"IntGauss", "[", 
           RowBox[{"\[Gamma]", ",", 
            RowBox[{
             RowBox[{
              SqrtBox["2"], 
              RowBox[{"IntDir", "[", 
               RowBox[{"C", ",", 
                RowBox[{
                "integrand", "\[LeftDoubleBracket]", "ii", 
                 "\[RightDoubleBracket]"}]}], "]"}]}], "/.", 
             RowBox[{"C", "\[Rule]", 
              RowBox[{"\[Gamma]", 
               SqrtBox["2"]}]}]}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"ii", ",", "1", ",", 
            RowBox[{"Length", "[", "integrand", "]"}]}], "}"}]}], "]"}]}], 
       "]"}], "]"}], "]"}], "/.", "zeroReplacements"}], "/.", 
   "gammareplacements"}], "]"}]}], "Input",
 CellChangeTimes->{{3.743848123816659*^9, 3.743848238802013*^9}, {
   3.743848403821611*^9, 3.743848428097006*^9}, {3.743848519589879*^9, 
   3.7438485510914793`*^9}, {3.7438487255664053`*^9, 
   3.7438487336239767`*^9}, {3.743849293609921*^9, 3.743849309847989*^9}, {
   3.743849352045641*^9, 3.743849356036162*^9}, {3.743849787670142*^9, 
   3.7438498484643297`*^9}, {3.743849910481679*^9, 3.743849911471107*^9}, {
   3.743850877433714*^9, 3.7438508777853527`*^9}, {3.743851130159027*^9, 
   3.74385113497398*^9}, {3.7438512035563297`*^9, 3.7438512134433193`*^9}, {
   3.743851254162632*^9, 3.7438513397680483`*^9}, 3.7438736877178097`*^9, 
   3.7440458813808107`*^9, 3.744045914683745*^9, {3.744048197878335*^9, 
   3.7440482054825897`*^9}},ExpressionUUID->"b0431c7b-8142-41a8-9c2f-\
d3e628f14028"],

Cell[BoxData[
 RowBox[{"\[Sigma]", "[", 
  RowBox[{"{", 
   RowBox[{"i", ",", "j"}], "}"}], "]"}]], "Output",
 CellChangeTimes->{
  3.743848174613483*^9, {3.743848212245219*^9, 3.7438482393833017`*^9}, 
   3.743848433321995*^9, 3.743848466351054*^9, 3.7438485532228003`*^9, 
   3.743848734783781*^9, {3.743849294968199*^9, 3.7438493108098993`*^9}, {
   3.743849776346595*^9, 3.743849849172308*^9}, 3.743849912408204*^9, {
   3.743850863830319*^9, 3.7438508823453693`*^9}, {3.743851113260397*^9, 
   3.743851136591984*^9}, {3.743851214950533*^9, 3.743851296297868*^9}, 
   3.743851341254931*^9, 3.743853861660749*^9, 3.743854331712645*^9, 
   3.7438543875643673`*^9, 3.743854450607263*^9, 3.743855574526868*^9, 
   3.743873688130097*^9, 3.7438753215502234`*^9, 3.743921391152089*^9, 
   3.7440482066305428`*^9},ExpressionUUID->"070084f0-54f6-4781-9111-\
f8fe9e359825"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"integrand", "=", 
   RowBox[{"Expand", "[", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     SuperscriptBox["C", "2"], 
     RowBox[{"C", "[", 
      RowBox[{"{", "i", "}"}], "]"}], "f"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Einstein", "[", 
     RowBox[{"Expand", "[", 
      RowBox[{"Apply", "[", 
       RowBox[{"Plus", ",", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"IntGauss", "[", 
           RowBox[{"\[Gamma]", ",", 
            RowBox[{
             RowBox[{
              SqrtBox["2"], 
              RowBox[{"IntDir", "[", 
               RowBox[{"C", ",", 
                RowBox[{
                "integrand", "\[LeftDoubleBracket]", "ii", 
                 "\[RightDoubleBracket]"}]}], "]"}]}], "/.", 
             RowBox[{"C", "\[Rule]", 
              RowBox[{"\[Gamma]", 
               SqrtBox["2"]}]}]}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"ii", ",", "1", ",", 
            RowBox[{"Length", "[", "integrand", "]"}]}], "}"}]}], "]"}]}], 
       "]"}], "]"}], "]"}], "/.", "zeroReplacements"}], "/.", 
   "gammareplacements"}], "]"}]}], "Input",
 CellChangeTimes->{{3.743851918423224*^9, 3.743851920811401*^9}, 
   3.7438736906377497`*^9, 3.744045881392707*^9, 3.744045914689736*^9, {
   3.7440482111805162`*^9, 
   3.74404821571528*^9}},ExpressionUUID->"c70cf2dc-c176-48ce-80e1-\
8f316fcd37a5"],

Cell[BoxData[
 RowBox[{"q", "[", 
  RowBox[{"{", "i", "}"}], "]"}]], "Output",
 CellChangeTimes->{3.743851922642891*^9, 3.74385378801248*^9, 
  3.743853880200255*^9, 3.743854209541881*^9, 3.743854347102319*^9, 
  3.743855577961939*^9, 3.743873691025443*^9, 3.743875321616028*^9, 
  3.743921391172662*^9, 
  3.744048216773085*^9},ExpressionUUID->"44101ffd-71c6-4416-aae4-\
3725bd5f7115"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"integrand", "=", 
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"CC", "[", 
        RowBox[{"{", 
         RowBox[{"i", ",", "j", ",", "k"}], "}"}], "]"}], "-", 
       RowBox[{
        FractionBox["1", 
         RowBox[{"d", "+", "2"}]], 
        SuperscriptBox["C", "2"], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"C", "[", 
            RowBox[{"{", "i", "}"}], "]"}], 
           RowBox[{"\[Delta]", "[", 
            RowBox[{"{", 
             RowBox[{"j", ",", "k"}], "}"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"C", "[", 
            RowBox[{"{", "j", "}"}], "]"}], 
           RowBox[{"\[Delta]", "[", 
            RowBox[{"{", 
             RowBox[{"i", ",", "k"}], "}"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"C", "[", 
            RowBox[{"{", "k", "}"}], "]"}], 
           RowBox[{"\[Delta]", "[", 
            RowBox[{"{", 
             RowBox[{"i", ",", "j"}], "}"}], "]"}]}]}], ")"}]}]}], ")"}], 
     "f"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Einstein", "[", 
     RowBox[{"Expand", "[", 
      RowBox[{"Apply", "[", 
       RowBox[{"Plus", ",", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"IntGauss", "[", 
           RowBox[{"\[Gamma]", ",", 
            RowBox[{
             RowBox[{
              SqrtBox["2"], 
              RowBox[{"IntDir", "[", 
               RowBox[{"C", ",", 
                RowBox[{
                "integrand", "\[LeftDoubleBracket]", "ii", 
                 "\[RightDoubleBracket]"}]}], "]"}]}], "/.", 
             RowBox[{"C", "\[Rule]", 
              RowBox[{"\[Gamma]", 
               SqrtBox["2"]}]}]}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"ii", ",", "1", ",", 
            RowBox[{"Length", "[", "integrand", "]"}]}], "}"}]}], "]"}]}], 
       "]"}], "]"}], "]"}], "/.", "zeroReplacements"}], "/.", 
   "gammareplacements"}], "]"}]}], "Input",
 CellChangeTimes->{{3.743852345196858*^9, 3.743852348323756*^9}, {
   3.7438526702309093`*^9, 3.743852756217588*^9}, {3.74385388466894*^9, 
   3.743853888261162*^9}, 3.743855588792191*^9, 3.7438736949017887`*^9, 
   3.7440458814027443`*^9, 3.744045914646722*^9, {3.744048220517446*^9, 
   3.744048226875193*^9}},ExpressionUUID->"a83ee0c9-2e76-46df-a078-\
33ad443ec1a7"],

Cell[BoxData[
 RowBox[{"m", "[", 
  RowBox[{"{", 
   RowBox[{"i", ",", "j", ",", "k"}], "}"}], "]"}]], "Output",
 CellChangeTimes->{
  3.743853889462015*^9, {3.7438555807552767`*^9, 3.743855590149323*^9}, 
   3.743873695317038*^9, 3.7438753217419147`*^9, 3.743921391236528*^9, 
   3.7440482279777527`*^9},ExpressionUUID->"5d85b93d-cb02-46ae-a182-\
08e88e62e560"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"integrand", "=", 
   RowBox[{"Expand", "[", 
    RowBox[{
     SuperscriptBox["C", "2"], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"C", "[", 
         RowBox[{"{", "i", "}"}], "]"}], 
        RowBox[{"C", "[", 
         RowBox[{"{", "j", "}"}], "]"}]}], "-", 
       RowBox[{
        FractionBox["1", "d"], 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"{", 
          RowBox[{"i", ",", "j"}], "}"}], "]"}], 
        RowBox[{"CC", "[", 
         RowBox[{"{", 
          RowBox[{"k", ",", "k"}], "}"}], "]"}]}]}], ")"}], "f"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Einstein", "[", 
     RowBox[{"Expand", "[", 
      RowBox[{"Apply", "[", 
       RowBox[{"Plus", ",", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"IntGauss", "[", 
           RowBox[{"\[Gamma]", ",", 
            RowBox[{
             RowBox[{
              SqrtBox["2"], 
              RowBox[{"IntDir", "[", 
               RowBox[{"C", ",", 
                RowBox[{
                "integrand", "\[LeftDoubleBracket]", "ii", 
                 "\[RightDoubleBracket]"}]}], "]"}]}], "/.", 
             RowBox[{"C", "\[Rule]", 
              RowBox[{"\[Gamma]", 
               SqrtBox["2"]}]}]}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"ii", ",", "1", ",", 
            RowBox[{"Length", "[", "integrand", "]"}]}], "}"}]}], "]"}]}], 
       "]"}], "]"}], "]"}], "/.", "zeroReplacements"}], "/.", 
   "gammareplacements"}], "]"}]}], "Input",
 CellChangeTimes->{
  3.74385197102879*^9, 3.743873697781844*^9, 3.744045881321437*^9, 
   3.744045914652165*^9, {3.744048234973961*^9, 
   3.744048240171875*^9}},ExpressionUUID->"004e380b-ea39-411b-9a71-\
87d102feab83"],

Cell[BoxData[
 RowBox[{
  RowBox[{"R", "[", 
   RowBox[{"{", 
    RowBox[{"i", ",", "j"}], "}"}], "]"}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"4", "+", "d"}], ")"}], " ", 
   RowBox[{"\[Sigma]", "[", 
    RowBox[{"{", 
     RowBox[{"i", ",", "j"}], "}"}], "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.743851973665338*^9, 3.743855594135119*^9, 3.74387369821762*^9, 
   3.743875321821867*^9, 3.743921391265791*^9, {3.744048231785245*^9, 
   3.744048241367999*^9}},ExpressionUUID->"09dabc00-0bf9-431d-9f1d-\
af8708b72253"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"integrand", "=", 
   RowBox[{"Expand", "[", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"d", " ", 
       RowBox[{"(", 
        RowBox[{"2", "+", "d"}], ")"}]}]], " ", 
     SuperscriptBox["C", "4"], "f"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Einstein", "[", 
      RowBox[{"Expand", "[", 
       RowBox[{"Apply", "[", 
        RowBox[{"Plus", ",", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"IntGauss", "[", 
            RowBox[{"\[Gamma]", ",", 
             RowBox[{
              RowBox[{
               SqrtBox["2"], 
               RowBox[{"IntDir", "[", 
                RowBox[{"C", ",", 
                 RowBox[{
                 "integrand", "\[LeftDoubleBracket]", "ii", 
                  "\[RightDoubleBracket]"}]}], "]"}]}], "/.", 
              RowBox[{"C", "\[Rule]", 
               RowBox[{"\[Gamma]", 
                SqrtBox["2"]}]}]}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"ii", ",", "1", ",", 
             RowBox[{"Length", "[", "integrand", "]"}]}], "}"}]}], "]"}]}], 
        "]"}], "]"}], "]"}], "/.", "zeroReplacements"}], "/.", 
    "gammareplacements"}], "]"}], "-", "1"}]}], "Input",
 CellChangeTimes->{{3.743852857140861*^9, 3.7438529023460083`*^9}, {
   3.7438529484627867`*^9, 3.743852948724998*^9}, 3.743873701549715*^9, 
   3.744045881330379*^9, 3.744045914657529*^9, {3.744048251421426*^9, 
   3.744048255756021*^9}, 
   3.744048308443983*^9},ExpressionUUID->"5dbcae22-bbd5-4659-8165-\
3bae22b872f4"],

Cell[BoxData["\[CapitalDelta]"], "Output",
 CellChangeTimes->{3.74385286216387*^9, 3.743852903173491*^9, 
  3.743852949287875*^9, 3.743855600143188*^9, 3.7438737020033913`*^9, 
  3.7438753218974047`*^9, 3.74392139129029*^9, 3.744048261569604*^9, 
  3.7440483097881937`*^9},ExpressionUUID->"7d714ed6-04c6-44e8-86fb-\
cdfcc28e3f7e"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Right-hand sides of equations", "Section",
 CellChangeTimes->{{3.73873895823641*^9, 
  3.7387389690910463`*^9}},ExpressionUUID->"50968e94-c4a5-45f5-a7b2-\
7ad6981ccca9"],

Cell[CellGroupData[{

Cell["Maxwell molecules", "Subsection",
 CellChangeTimes->{{3.738738979642742*^9, 
  3.738738984026877*^9}},ExpressionUUID->"796a38a0-f723-4d17-af66-\
1944047aaa0c"],

Cell[CellGroupData[{

Cell["G29 (new version)", "Subsubsection",
 CellChangeTimes->{{3.74324658303837*^9, 3.743246584414062*^9}, {
  3.7449582122845488`*^9, 
  3.744958244295182*^9}},ExpressionUUID->"d8b987d0-773a-44d5-83ba-\
b423e84199e3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"replacements", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Nu]\[Sigma]", "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", "e"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"d", "+", "1", "-", "e"}], ")"}]}], 
       RowBox[{"2", "d"}]]}], ",", "\[IndentingNewLine]", 
     RowBox[{"\[Nu]q", "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", "e"}], ")"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"5", "d"}], "+", "4", "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"d", "+", "8"}], ")"}], "e"}]}], ")"}]}], 
       RowBox[{"8", "d"}]]}], ",", "\[IndentingNewLine]", 
     RowBox[{"\[Nu]m", "\[Rule]", 
      FractionBox[
       RowBox[{"3", 
        RowBox[{"(", 
         RowBox[{"1", "+", "e"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"d", "+", "1", "-", "e"}], ")"}]}], 
       RowBox[{"4", "d"}]]}], ",", "\[IndentingNewLine]", 
     RowBox[{"\[Nu]\[CapitalDelta]", "\[Rule]", 
      FractionBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "+", "e"}], ")"}], "2"], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", "d"}], "-", "7", "+", 
          RowBox[{"6", "e"}], "-", 
          RowBox[{"3", 
           SuperscriptBox["e", "2"]}]}], ")"}]}], 
       RowBox[{"16", "d"}]]}], ",", "\[IndentingNewLine]", 
     RowBox[{"\[Nu]R", "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", "e"}], ")"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"7", 
           SuperscriptBox["d", "2"]}], "+", 
          RowBox[{"31", "d"}], "+", "18", "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["d", "2"], "+", 
             RowBox[{"14", "d"}], "+", "34"}], ")"}], "e"}], "+", 
          RowBox[{"3", 
           RowBox[{"(", 
            RowBox[{"d", "+", "2"}], ")"}], 
           SuperscriptBox["e", "2"]}], "-", 
          RowBox[{"6", 
           SuperscriptBox["e", "3"]}]}], ")"}]}], 
       RowBox[{"8", "d", 
        RowBox[{"(", 
         RowBox[{"d", "+", "4"}], ")"}]}]]}], ",", "\[IndentingNewLine]", 
     RowBox[{"\[Nu]R\[Sigma]", "\[Rule]", 
      FractionBox[
       RowBox[{"3", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "+", "e"}], ")"}], "2"], 
        RowBox[{"(", 
         RowBox[{"1", "-", "e"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"d", "+", "2", "-", 
          RowBox[{"2", " ", "e"}]}], ")"}]}], 
       RowBox[{"4", " ", "d"}]]}], ",", "\[IndentingNewLine]", 
     RowBox[{"\[Nu]\[CurlyPhi]", "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", "e"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"32", " ", 
           SuperscriptBox["d", "2"]}], "+", 
          RowBox[{"129", " ", "d"}], "+", "64", "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"8", " ", 
              SuperscriptBox["d", "2"]}], "+", 
             RowBox[{"81", " ", "d"}], "+", "136"}], ")"}], " ", "e"}], "+", 
          RowBox[{"3", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"9", "d"}], "+", "16"}], ")"}], " ", 
           SuperscriptBox["e", "2"]}], "-", 
          RowBox[{"3", 
           RowBox[{"(", 
            RowBox[{"d", "+", "24"}], ")"}], " ", 
           SuperscriptBox["e", "3"]}]}], ")"}]}], 
       RowBox[{"32", " ", "d", " ", 
        RowBox[{"(", 
         RowBox[{"d", "+", "4"}], ")"}]}]]}], ",", "\[IndentingNewLine]", 
     RowBox[{"\[Nu]\[CurlyPhi]q", "\[Rule]", 
      FractionBox[
       RowBox[{"3", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "+", "e"}], ")"}], "2"], 
        RowBox[{"(", 
         RowBox[{"1", "-", "e"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"5", 
           RowBox[{"(", 
            RowBox[{"d", "+", "2"}], ")"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"d", "+", "14"}], ")"}], " ", "e"}]}], ")"}]}], 
       RowBox[{"4", " ", "d"}]]}], ",", "\[IndentingNewLine]", 
     RowBox[{"\[Alpha]0", "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", 
          SuperscriptBox["e", "2"]}], ")"}], 
        RowBox[{"(", 
         RowBox[{"d", "+", "2"}], ")"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", "d"}], "+", "5", "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["e", "2"]}]}], ")"}]}], "8"]}], " ", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"\[Alpha]1", "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", "e"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"d", "+", "2"}], ")"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"4", "d"}], "+", "3"}], ")"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"4", " ", "d"}], "+", "17"}], ")"}], " ", "e"}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["e", "2"]}], "-", 
          RowBox[{"3", " ", 
           SuperscriptBox["e", "3"]}]}], ")"}]}], "16"]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"\[Alpha]2", "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", "e"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["d", "2"]}], "+", 
          RowBox[{"13", " ", "d"}], "+", "10", "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["d", "2"], "+", 
             RowBox[{"8", " ", "d"}], "+", "10"}], ")"}], " ", "e"}], "+", 
          RowBox[{"3", 
           RowBox[{"(", 
            RowBox[{"d", "+", "2"}], ")"}], 
           SuperscriptBox["e", "2"]}], "-", 
          RowBox[{"6", " ", 
           SuperscriptBox["e", "3"]}]}], ")"}]}], 
       RowBox[{"4", " ", "d"}]]}], ",", "\[IndentingNewLine]", 
     RowBox[{"\[Alpha]3", "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", "e"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"14", " ", 
           SuperscriptBox["d", "2"]}], "+", 
          RowBox[{"57", " ", "d"}], "+", "34", "-", 
          RowBox[{"3", 
           RowBox[{"(", 
            RowBox[{"d", "+", "6"}], ")"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", "d"}], "+", "3"}], ")"}], " ", "e"}], "+", 
          RowBox[{"15", 
           RowBox[{"(", 
            RowBox[{"d", "+", "2"}], ")"}], " ", 
           SuperscriptBox["e", "2"]}], "-", 
          RowBox[{"3", 
           RowBox[{"(", 
            RowBox[{"d", "+", "14"}], ")"}], " ", 
           SuperscriptBox["e", "3"]}]}], ")"}]}], 
       RowBox[{"4", " ", "d"}]]}], ",", "\[IndentingNewLine]", 
     RowBox[{"c0", "\[Rule]", 
      FractionBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "+", "e"}], ")"}], "2"], 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"6", "e"}], "-", 
          RowBox[{"3", 
           SuperscriptBox["e", "2"]}]}], ")"}]}], 
       RowBox[{"8", 
        SuperscriptBox["d", "2"], 
        RowBox[{"(", 
         RowBox[{"d", "+", "2"}], ")"}]}]]}], ",", "\[IndentingNewLine]", 
     RowBox[{"c1", "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "+", "e"}], ")"}], "2"], 
         RowBox[{"(", 
          RowBox[{"d", "-", "2", "-", 
           RowBox[{"3", 
            RowBox[{"(", 
             RowBox[{"d", "+", "4"}], ")"}], "e"}], "+", 
           RowBox[{"6", 
            SuperscriptBox["e", "2"]}]}], ")"}]}], 
        RowBox[{"4", "d", 
         RowBox[{"(", 
          RowBox[{"d", "+", "4"}], ")"}]}]]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"c2", "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "+", "e"}], ")"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"5", " ", "d"}], "-", "4", "-", 
           RowBox[{"6", 
            RowBox[{"(", 
             RowBox[{"d", "+", "4"}], ")"}], " ", "e"}], "-", 
           RowBox[{"3", 
            RowBox[{"(", 
             RowBox[{"d", "-", "4"}], ")"}], " ", 
            SuperscriptBox["e", "2"]}]}], ")"}]}], 
        RowBox[{"4", " ", "d", " ", 
         RowBox[{"(", 
          RowBox[{"d", "+", "2"}], ")"}]}]]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"c3", "\[Rule]", 
      FractionBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "+", "e"}], ")"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{"d", "+", "16", "+", 
          RowBox[{"6", 
           RowBox[{"(", 
            RowBox[{"d", "+", "4"}], ")"}], " ", "e"}], "-", 
          RowBox[{"3", 
           RowBox[{"(", 
            RowBox[{"d", "+", "8"}], ")"}], " ", 
           SuperscriptBox["e", "2"]}]}], ")"}]}], 
       RowBox[{"8", " ", "d", " ", 
        RowBox[{"(", 
         RowBox[{"d", "+", "4"}], ")"}]}]]}]}], "\[IndentingNewLine]", 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.740200396742687*^9, 3.740200416389782*^9}, {
   3.740200874370634*^9, 3.7402009019768047`*^9}, {3.740200939389888*^9, 
   3.740201006824254*^9}, {3.740201114283352*^9, 3.740201114523697*^9}, 
   3.740201304588097*^9, {3.7402019995379047`*^9, 3.7402020105633183`*^9}, {
   3.7403079103375053`*^9, 3.7403079168156223`*^9}, 3.74037808456013*^9, {
   3.743246682209787*^9, 3.7432467201186857`*^9}, {3.74324676453076*^9, 
   3.743246764899349*^9}, {3.74324683291566*^9, 3.743246835733129*^9}, {
   3.743246883732154*^9, 3.7432468869498367`*^9}, {3.743246928005261*^9, 
   3.7432470169671783`*^9}, {3.743247049802909*^9, 3.743247137714294*^9}, {
   3.7432471677536783`*^9, 3.743247178378314*^9}, {3.743247209851351*^9, 
   3.743247210329391*^9}, {3.743247247834523*^9, 3.743247273465869*^9}, {
   3.743248912197569*^9, 3.743248918195324*^9}, {3.74324895569495*^9, 
   3.743249006430522*^9}, {3.743249197792172*^9, 3.743249201303651*^9}, 
   3.7432495366229486`*^9, {3.743249627820785*^9, 3.7432496412170362`*^9}, 
   3.7432516146022387`*^9, 3.743251741928252*^9, 3.743251857097625*^9, {
   3.743251922920453*^9, 3.743251952347054*^9}, {3.7432522326231413`*^9, 
   3.743252243080035*^9}, {3.745018149173581*^9, 3.745018151673896*^9}, {
   3.745018198923428*^9, 3.745018200562986*^9}, {3.745018280749021*^9, 
   3.7450182892739353`*^9}, {3.745018326075746*^9, 3.74501835662632*^9}, {
   3.745019067058791*^9, 3.7450190729623003`*^9}, {3.7450195537879467`*^9, 
   3.7450195581772423`*^9}, {3.74501959573818*^9, 3.745019610241529*^9}, {
   3.745019656691012*^9, 3.7450196600010767`*^9}, {3.7450196967141113`*^9, 
   3.745019700369475*^9}, {3.7450212944602137`*^9, 3.745021299009042*^9}, 
   3.745120315186191*^9, {3.745122578558921*^9, 
   3.745122578564167*^9}},ExpressionUUID->"ecc0eddb-330a-48a1-bd2a-\
8e0a77e7fce7"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"P1MM", "=", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"(", 
       RowBox[{"d", "+", "2"}], ")"}], "4"]}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      SuperscriptBox["e", "2"]}], ")"}], "\[Nu]", " ", "\[Rho]", " ", 
    "\[Theta]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Pij0MM", "=", 
   RowBox[{
    RowBox[{"-", "\[Nu]\[Sigma]"}], " ", "\[Nu]", " ", 
    RowBox[{"\[Sigma]", "[", 
     RowBox[{"{", 
      RowBox[{"i1", ",", "i2"}], "}"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Pi1MM", "=", 
   RowBox[{
    RowBox[{"-", "2"}], "\[Nu]q", " ", "\[Nu]", " ", 
    RowBox[{"q", "[", 
     RowBox[{"{", "i1", "}"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"P2MM", "=", 
   RowBox[{
    RowBox[{"-", "\[Nu]"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Alpha]0", "+", 
         RowBox[{"\[Alpha]1", " ", "\[CapitalDelta]"}]}], ")"}], " ", 
       "\[Rho]", " ", 
       SuperscriptBox["\[Theta]", "2"]}], "+", 
      RowBox[{"d", 
       RowBox[{"(", 
        RowBox[{"d", "+", "2"}], ")"}], "c0", 
       FractionBox[
        RowBox[{
         RowBox[{"\[Sigma]", "[", 
          RowBox[{"{", 
           RowBox[{"s0", ",", "s1"}], "}"}], "]"}], " ", 
         RowBox[{"\[Sigma]", "[", 
          RowBox[{"{", 
           RowBox[{"s0", ",", "s1"}], "}"}], "]"}]}], "\[Rho]"]}]}], 
     ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Pij1MM", "=", 
   RowBox[{
    RowBox[{"-", "\[Nu]"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Nu]R", " ", 
       RowBox[{"R", "[", 
        RowBox[{"{", 
         RowBox[{"i1", ",", "i2"}], "}"}], "]"}]}], "+", 
      RowBox[{"\[Alpha]2", " ", "\[Theta]", " ", 
       RowBox[{"\[Sigma]", "[", 
        RowBox[{"{", 
         RowBox[{"i1", ",", "i2"}], "}"}], "]"}]}], "+", 
      RowBox[{"c1", 
       FractionBox[
        RowBox[{
         RowBox[{"\[Sigma]", "[", 
          RowBox[{"{", 
           RowBox[{"i1", ",", "s0"}], "}"}], "]"}], " ", 
         RowBox[{"\[Sigma]", "[", 
          RowBox[{"{", 
           RowBox[{"i2", ",", "s0"}], "}"}], "]"}]}], "\[Rho]"]}]}], 
     ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Pi2MM", "=", 
   RowBox[{
    RowBox[{"-", "\[Nu]"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Nu]\[CurlyPhi]", " ", 
       RowBox[{"\[CurlyPhi]", "[", 
        RowBox[{"{", "i1", "}"}], "]"}]}], "+", 
      RowBox[{"\[Alpha]3", " ", "\[Theta]", " ", 
       RowBox[{"q", "[", 
        RowBox[{"{", "i1", "}"}], "]"}]}], "+", 
      RowBox[{"c2", 
       FractionBox[
        RowBox[{
         RowBox[{"\[Sigma]", "[", 
          RowBox[{"{", 
           RowBox[{"i1", ",", "s0"}], "}"}], "]"}], 
         RowBox[{"q", "[", 
          RowBox[{"{", "s0", "}"}], "]"}]}], "\[Rho]"]}], "+", 
      RowBox[{"c3", 
       FractionBox[
        RowBox[{
         RowBox[{"m", "[", 
          RowBox[{"{", 
           RowBox[{"i1", ",", "s0", ",", "s1"}], "}"}], "]"}], " ", 
         RowBox[{"\[Sigma]", "[", 
          RowBox[{"{", 
           RowBox[{"s0", ",", "s1"}], "}"}], "]"}]}], "\[Rho]"]}]}], 
     ")"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.73873902455914*^9, 3.738739034654142*^9}, 
   3.73873908894907*^9, {3.7387391724474688`*^9, 3.738739192348089*^9}, {
   3.73873923546525*^9, 3.738739257511209*^9}, 3.738739439572116*^9, 
   3.74013457784787*^9, {3.740200536359736*^9, 3.740200545109055*^9}, {
   3.7402007289173727`*^9, 3.740200745222474*^9}, {3.7402007761032543`*^9, 
   3.740200854582411*^9}, 3.740201045047072*^9, {3.74030793787356*^9, 
   3.74030793820722*^9}, {3.7403781066333942`*^9, 3.740378107319367*^9}, {
   3.743246685398218*^9, 3.7432466953307247`*^9}, 3.7432467332529573`*^9, 
   3.743246771925799*^9, 3.743246844243844*^9, {3.7432474824205*^9, 
   3.7432475081154633`*^9}, {3.7432475443795557`*^9, 
   3.7432475492367373`*^9}, {3.7432477037869587`*^9, 
   3.7432477495105057`*^9}, {3.743247890617197*^9, 3.743247890759039*^9}, {
   3.743249588257977*^9, 3.743249590753818*^9}, {3.743251755693417*^9, 
   3.743251756635034*^9}, 3.74325186798277*^9, {3.743251928494259*^9, 
   3.7432519294354486`*^9}, {3.7450184039947243`*^9, 3.7450184541785107`*^9}, 
   3.7450190621805067`*^9, {3.745122578571158*^9, 
   3.745122578574361*^9}},ExpressionUUID->"153c2301-e5dd-444e-afc6-\
bcad2aef2117"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"RHS$\[CapitalDelta]bal", "=", 
   RowBox[{
    RowBox[{"-", "\[Nu]"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Nu]\[CapitalDelta]", 
       RowBox[{"(", 
        RowBox[{"\[CapitalDelta]", "-", 
         FractionBox[
          RowBox[{"6", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"1", "-", "e"}], ")"}], "2"]}], 
          RowBox[{
           RowBox[{"4", " ", "d"}], "-", "7", "+", 
           RowBox[{"6", " ", "e"}], "-", 
           RowBox[{"3", " ", 
            SuperscriptBox["e", "2"]}]}]]}], ")"}]}], "+", 
      RowBox[{"c0", 
       FractionBox[
        RowBox[{
         RowBox[{"\[Sigma]", "[", 
          RowBox[{"{", 
           RowBox[{"s0", ",", "s1"}], "}"}], "]"}], " ", 
         RowBox[{"\[Sigma]", "[", 
          RowBox[{"{", 
           RowBox[{"s0", ",", "s1"}], "}"}], "]"}]}], 
        RowBox[{
         SuperscriptBox["\[Rho]", "2"], 
         SuperscriptBox["\[Theta]", "2"]}]]}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Collect", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"RHS$\[CapitalDelta]bal", "-", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"d", 
        RowBox[{"(", 
         RowBox[{"d", "+", "2"}], ")"}]}]], 
      FractionBox["1", 
       RowBox[{"\[Rho]", " ", 
        SuperscriptBox["\[Theta]", "2"]}]], 
      RowBox[{"(", 
       RowBox[{"P2MM", "-", 
        RowBox[{"2", 
         RowBox[{"(", 
          RowBox[{"d", "+", "2"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"1", "+", "\[CapitalDelta]"}], ")"}], "\[Theta]", " ", 
         "P1MM"}]}], ")"}]}]}], "/.", "replacements"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[CapitalDelta]", ",", 
     SuperscriptBox[
      RowBox[{"\[Sigma]", "[", 
       RowBox[{"{", 
        RowBox[{"s0", ",", "s1"}], "}"}], "]"}], "2"]}], "}"}], ",", 
   "Simplify"}], "]"}]}], "Input",
 CellChangeTimes->{{3.738741778803328*^9, 3.7387418216189213`*^9}, {
   3.7401359718907003`*^9, 3.740135976858953*^9}, {3.7401361086479483`*^9, 
   3.740136120501011*^9}, {3.7401362234323378`*^9, 3.740136245127634*^9}, 
   3.740136290154294*^9, {3.740137670494162*^9, 3.740137675887685*^9}, {
   3.740201346171953*^9, 3.740201357755332*^9}, 3.7402013928165617`*^9, {
   3.740201589168439*^9, 3.740201592586534*^9}, {3.740201636096326*^9, 
   3.740201705373282*^9}, {3.740201768206944*^9, 3.740201807520783*^9}, {
   3.74020187367994*^9, 3.740201894715806*^9}, {3.7402022001129847`*^9, 
   3.740202220687426*^9}, {3.7432476183600693`*^9, 3.743247619402104*^9}, {
   3.743248023506217*^9, 3.7432480794036083`*^9}, {3.7432490251386557`*^9, 
   3.7432490253107653`*^9}, 3.745018541002578*^9, 3.7450187888903837`*^9, {
   3.7450188813696327`*^9, 3.745018885032708*^9}, {3.7450190826822853`*^9, 
   3.745019082888597*^9}},ExpressionUUID->"f99078af-5850-4b85-8a26-\
9552c55ebea6"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.74020136511122*^9, 3.740201394377619*^9}, 
   3.74020160975841*^9, 3.740201657441514*^9, 3.740201708799994*^9, 
   3.7402018104688797`*^9, {3.740201878926009*^9, 3.740201895538155*^9}, 
   3.7402022218021507`*^9, 3.740307946888533*^9, 3.740378117299066*^9, 
   3.74324798540383*^9, {3.74324806989925*^9, 3.74324808087696*^9}, 
   3.743249026868854*^9, 3.743249656854793*^9, 3.743251623808139*^9, 
   3.7432519693685827`*^9, 3.743252251468479*^9, 3.745018494801445*^9, 
   3.745018541655394*^9, 3.745018791530176*^9, 3.745018885733439*^9, 
   3.745019084702032*^9, 3.745019566233494*^9, 3.745019620877821*^9, 
   3.74501967006523*^9, 3.7450197186619062`*^9, 3.745021306654169*^9, 
   3.74512261861355*^9, 
   3.745122687431985*^9},ExpressionUUID->"3460703e-7171-4921-b153-\
66e689131ca4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"RHS$Rijbal", "=", 
   RowBox[{
    RowBox[{"-", "\[Nu]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Nu]R", " ", 
       RowBox[{"R", "[", 
        RowBox[{"{", 
         RowBox[{"i1", ",", "i2"}], "}"}], "]"}]}], "-", 
      RowBox[{"\[Nu]R\[Sigma]", " ", "\[Theta]", " ", 
       RowBox[{"\[Sigma]", "[", 
        RowBox[{"{", 
         RowBox[{"i1", ",", "i2"}], "}"}], "]"}]}], "+", 
      RowBox[{"c1", 
       FractionBox[
        RowBox[{
         RowBox[{"\[Sigma]", "[", 
          RowBox[{"{", 
           RowBox[{"i1", ",", "s0"}], "}"}], "]"}], " ", 
         RowBox[{"\[Sigma]", "[", 
          RowBox[{"{", 
           RowBox[{"i2", ",", "s0"}], "}"}], "]"}]}], "\[Rho]"]}]}], " ", 
     ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Collect", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"RHS$Rijbal", "-", 
     RowBox[{"(", 
      RowBox[{"Pij1MM", "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"d", "+", "4"}], ")"}], "\[Theta]", " ", "Pij0MM"}], "-", 
       RowBox[{
        FractionBox[
         RowBox[{"(", 
          RowBox[{"d", "+", "4"}], ")"}], "d"], 
        FractionBox[
         RowBox[{"\[Sigma]", "[", 
          RowBox[{"{", 
           RowBox[{"i1", ",", "i2"}], "}"}], "]"}], "\[Rho]"], " ", 
        "P1MM"}]}], ")"}]}], "/.", "replacements"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"R", "[", 
      RowBox[{"{", 
       RowBox[{"i1", ",", "i2"}], "}"}], "]"}], ",", 
     RowBox[{"\[Sigma]", "[", 
      RowBox[{"{", 
       RowBox[{"i1", ",", "i2"}], "}"}], "]"}]}], "}"}], ",", "Simplify"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.7387404860414667`*^9, 3.738740499897077*^9}, {
   3.7401350496476927`*^9, 3.7401350713549967`*^9}, {3.740135112605345*^9, 
   3.7401351133071404`*^9}, {3.740135177005829*^9, 3.7401352237597437`*^9}, {
   3.7401376462214622`*^9, 3.7401376484683104`*^9}, {3.740201082779047*^9, 
   3.740201107944107*^9}, {3.740201140460227*^9, 3.7402011767264843`*^9}, {
   3.7402019319521303`*^9, 3.740201946078104*^9}, {3.740201982239935*^9, 
   3.740201990221229*^9}, {3.740307953363509*^9, 3.740307953632622*^9}, 
   3.740378122666667*^9, {3.743247821497993*^9, 3.743247824058402*^9}, {
   3.7432480879923277`*^9, 3.743248137355995*^9}, {3.743249032161667*^9, 
   3.7432490323018837`*^9}, 3.745018555026289*^9, {3.7450187124118834`*^9, 
   3.7450187132413483`*^9}},ExpressionUUID->"a5809965-84a6-4ce4-a276-\
acb09879c398"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.74020114832633*^9, 3.74020117834713*^9}, 
   3.740201312905766*^9, 3.740201947279351*^9, 3.740202018443211*^9, {
   3.7403079504800653`*^9, 3.740307954613296*^9}, 3.740378123591103*^9, {
   3.743248130522223*^9, 3.743248137837153*^9}, 3.7432490328266973`*^9, 
   3.743249658771453*^9, 3.743251625239702*^9, 3.7432519707611103`*^9, 
   3.743252253504792*^9, {3.745018527607354*^9, 3.745018555552249*^9}, 
   3.745018714828211*^9, 3.7450195681529007`*^9, 3.7450196226895647`*^9, 
   3.745019671944007*^9, 3.745019721856206*^9, 3.745021308220378*^9, 
   3.7451226254377737`*^9, 
   3.745122687487657*^9},ExpressionUUID->"266a5ecc-9857-4256-8fc2-\
96aabfbd0de4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"RHS\[CurlyPhi]ibal", "=", 
   RowBox[{
    RowBox[{"-", "\[Nu]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Nu]\[CurlyPhi]", " ", 
       RowBox[{"\[CurlyPhi]", "[", 
        RowBox[{"{", "i1", "}"}], "]"}]}], "-", 
      RowBox[{"\[Nu]\[CurlyPhi]q", " ", "\[Theta]", " ", 
       RowBox[{"q", "[", 
        RowBox[{"{", "i1", "}"}], "]"}]}], "+", 
      RowBox[{"c2", 
       FractionBox[
        RowBox[{
         RowBox[{"\[Sigma]", "[", 
          RowBox[{"{", 
           RowBox[{"i1", ",", "s0"}], "}"}], "]"}], 
         RowBox[{"q", "[", 
          RowBox[{"{", "s0", "}"}], "]"}]}], "\[Rho]"]}], "+", 
      RowBox[{"c3", " ", 
       FractionBox[
        RowBox[{
         RowBox[{"m", "[", 
          RowBox[{"{", 
           RowBox[{"i1", ",", "s0", ",", "s1"}], "}"}], "]"}], " ", 
         RowBox[{"\[Sigma]", "[", 
          RowBox[{"{", 
           RowBox[{"s0", ",", "s1"}], "}"}], "]"}]}], "\[Rho]"]}]}], 
     ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Collect", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"RHS\[CurlyPhi]ibal", "-", 
     RowBox[{"(", 
      RowBox[{"Pi2MM", "-", 
       RowBox[{"2", 
        RowBox[{"(", 
         RowBox[{"d", "+", "4"}], ")"}], "\[Theta]", " ", "Pi1MM"}], "-", 
       RowBox[{
        FractionBox[
         RowBox[{"4", 
          RowBox[{"(", 
           RowBox[{"d", "+", "4"}], ")"}]}], "d"], 
        FractionBox[
         RowBox[{"q", "[", 
          RowBox[{"{", "i1", "}"}], "]"}], "\[Rho]"], "P1MM"}]}], ")"}]}], "/.",
     "replacements"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[CurlyPhi]", "[", 
      RowBox[{"{", "i1", "}"}], "]"}], ",", 
     RowBox[{"q", "[", 
      RowBox[{"{", "i1", "}"}], "]"}], ",", 
     RowBox[{
      RowBox[{"q", "[", 
       RowBox[{"{", "s0", "}"}], "]"}], " ", 
      RowBox[{"\[Sigma]", "[", 
       RowBox[{"{", 
        RowBox[{"i1", ",", "s0"}], "}"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"m", "[", 
       RowBox[{"{", 
        RowBox[{"i1", ",", "s0", ",", "s1"}], "}"}], "]"}], " ", 
      RowBox[{"\[Sigma]", "[", 
       RowBox[{"{", 
        RowBox[{"s0", ",", "s1"}], "}"}], "]"}]}]}], "}"}], ",", "Simplify"}],
   "]"}]}], "Input",
 CellChangeTimes->{{3.743247832523075*^9, 3.743247937448595*^9}, {
   3.743248162010273*^9, 3.743248217720869*^9}, {3.743248253737123*^9, 
   3.743248387598743*^9}, {3.743248470285275*^9, 3.7432485397110977`*^9}, {
   3.7432485699975433`*^9, 3.743248615083809*^9}, {3.743248716591976*^9, 
   3.7432488908206673`*^9}, 3.743249113553623*^9, {3.743249173827503*^9, 
   3.743249192599173*^9}, {3.743249236019381*^9, 3.743249239726367*^9}, {
   3.743249283301427*^9, 3.743249335507612*^9}, {3.74324937432533*^9, 
   3.743249469953096*^9}, {3.743249500020784*^9, 3.743249551284175*^9}, {
   3.743249615189529*^9, 3.743249618176746*^9}, 3.743251607585051*^9, 
   3.743252259393489*^9, {3.745018561962119*^9, 3.745018564874041*^9}, 
   3.745018725587606*^9, {3.745122578581493*^9, 
   3.745122578597628*^9}},ExpressionUUID->"bc2b2c49-5d99-4240-9839-\
8cdffbfb32dd"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.743248871642476*^9, 3.743248891403645*^9}, 
   3.743249047477131*^9, 3.743249115194336*^9, 3.743249175282312*^9, 
   3.7432492095736923`*^9, 3.743249240876223*^9, {3.743249284779272*^9, 
   3.743249336683311*^9}, {3.7432493806347733`*^9, 3.743249401223956*^9}, {
   3.743249437362377*^9, 3.743249470543212*^9}, {3.743249502911756*^9, 
   3.743249516808219*^9}, {3.743249552837123*^9, 3.743249597035739*^9}, 
   3.743249661986208*^9, 3.743251627257663*^9, 3.743251766226757*^9, 
   3.7432518764909773`*^9, 3.743251937793035*^9, 3.743251972987503*^9, 
   3.743252256105653*^9, 3.745018565575954*^9, 3.745018727059576*^9, 
   3.745019570255727*^9, 3.745019624482575*^9, 3.745019674595536*^9, 
   3.745019724802434*^9, 3.745021310413109*^9, 3.74512263249335*^9, 
   3.745122687537404*^9},ExpressionUUID->"5be83fa8-5ab9-45a3-8d4f-\
c3cc28e73bbb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   StyleBox[
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Comparison", " ", "with", " ", "the", " ", "right"}], "-", 
       RowBox[{"hand", " ", "side", " ", "of", " ", "equation", " ", 
        RowBox[{"(", "A3", ")"}], " ", "of", " ", "Gu"}]}], " ", "&"}], " ", 
     "Emerson", " ", 
     RowBox[{"(", 
      RowBox[{"JFM", " ", "2009"}], ")"}]}],
    FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"RHS\[CurlyPhi]ibal", "/.", "replacements"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"d", "\[Rule]", "3"}], ",", 
     RowBox[{"e", "\[Rule]", "1"}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.743252732127307*^9, 3.743252760142845*^9}, {
   3.743252792400461*^9, 3.7432528208214207`*^9}, 
   3.745122578603488*^9},ExpressionUUID->"3ffb3477-573a-484d-a71b-\
09b94a971464"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "\[Nu]"}], " ", 
  RowBox[{"(", 
   RowBox[{
    FractionBox[
     RowBox[{"28", " ", 
      RowBox[{"q", "[", 
       RowBox[{"{", "s0", "}"}], "]"}], " ", 
      RowBox[{"\[Sigma]", "[", 
       RowBox[{"{", 
        RowBox[{"i1", ",", "s0"}], "}"}], "]"}]}], 
     RowBox[{"15", " ", "\[Rho]"}]], "+", 
    FractionBox[
     RowBox[{"2", " ", 
      RowBox[{"m", "[", 
       RowBox[{"{", 
        RowBox[{"i1", ",", "s0", ",", "s1"}], "}"}], "]"}], " ", 
      RowBox[{"\[Sigma]", "[", 
       RowBox[{"{", 
        RowBox[{"s0", ",", "s1"}], "}"}], "]"}]}], 
     RowBox[{"3", " ", "\[Rho]"}]], "+", 
    RowBox[{"\[CurlyPhi]", "[", 
     RowBox[{"{", "i1", "}"}], "]"}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.7451226424111443`*^9, 
  3.74512268758683*^9},ExpressionUUID->"37feee1c-2581-47aa-b618-6c65af283452"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"replacements", "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"d", "\[Rule]", "3"}], ",", 
    RowBox[{"e", "\[Rule]", "1"}]}], "}"}]}]], "Input",ExpressionUUID->\
"6df0ac22-a9f2-4e7f-80e0-b4db2a7f67b0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Nu]\[Sigma]", "\[Rule]", "1"}], ",", 
   RowBox[{"\[Nu]q", "\[Rule]", 
    FractionBox["2", "3"]}], ",", 
   RowBox[{"\[Nu]m", "\[Rule]", 
    FractionBox["3", "2"]}], ",", 
   RowBox[{"\[Nu]\[CapitalDelta]", "\[Rule]", 
    FractionBox["2", "3"]}], ",", 
   RowBox[{"\[Nu]R", "\[Rule]", 
    FractionBox["7", "6"]}], ",", 
   RowBox[{"\[Nu]R\[Sigma]", "\[Rule]", "0"}], ",", 
   RowBox[{"\[Nu]\[CurlyPhi]", "\[Rule]", "1"}], ",", 
   RowBox[{"\[Nu]\[CurlyPhi]q", "\[Rule]", "0"}], ",", 
   RowBox[{"\[Alpha]0", "\[Rule]", "0"}], ",", 
   RowBox[{"\[Alpha]1", "\[Rule]", "10"}], ",", 
   RowBox[{"\[Alpha]2", "\[Rule]", "7"}], ",", 
   RowBox[{"\[Alpha]3", "\[Rule]", 
    FractionBox["56", "3"]}], ",", 
   RowBox[{"c0", "\[Rule]", 
    FractionBox["2", "45"]}], ",", 
   RowBox[{"c1", "\[Rule]", 
    FractionBox["2", "3"]}], ",", 
   RowBox[{"c2", "\[Rule]", 
    FractionBox["28", "15"]}], ",", 
   RowBox[{"c3", "\[Rule]", 
    FractionBox["2", "3"]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7451226543938913`*^9, 
  3.7451226876365633`*^9},ExpressionUUID->"0347d4b1-37a3-43d2-8fee-\
85b4c9e9f86e"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"allvars", "=", 
   RowBox[{"{", 
    RowBox[{
    "\[Nu]\[Sigma]", ",", "\[Nu]q", ",", "\[Nu]m", ",", 
     "\[Nu]\[CapitalDelta]", ",", "\[Nu]R", ",", "\[Nu]R\[Sigma]", ",", 
     "\[Nu]\[CurlyPhi]", ",", "\[Nu]\[CurlyPhi]q", ",", "\[Alpha]0", ",", 
     "\[Alpha]1", ",", "\[Alpha]2", ",", "\[Alpha]3", ",", "c0", ",", "c1", 
     ",", "c2", ",", "c3"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.745413909164687*^9, 
  3.74541391964073*^9}},ExpressionUUID->"6fe13d71-3003-493e-aef9-\
7ca04b73f845"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "\[Nu]\[Sigma]", ",", "\[Nu]q", ",", "\[Nu]m", ",", 
        "\[Nu]\[CapitalDelta]", ",", "\[Nu]R", ",", "\[Nu]R\[Sigma]", ",", 
        "\[Nu]\[CurlyPhi]", ",", "\[Nu]\[CurlyPhi]q"}], "}"}], "/.", 
      "replacements"}], "/.", 
     RowBox[{"d", "\[Rule]", "3"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"e", ",", "0", ",", "1"}], "}"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.745413711151883*^9, 3.745413711311404*^9}, {
  3.745413746986239*^9, 3.745413882897208*^9}, {3.7454139161775513`*^9, 
  3.745413963488639*^9}, {3.745414045889937*^9, 
  3.745414061456275*^9}},ExpressionUUID->"0b9d506b-e882-463d-8048-\
82bc7e23df83"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwVkXk41Hkcxx0dJqWcNW0R6bSuUFF6Ex22aM3QlGoSjS5JT9fa1W5ionVE
dBD7qIldEkq1bFMU0UFTzDBPuQYz5v7GJrvWsb/++Dyv5/XH+3M8H+uwYwyO
no6Ojj9VX/kdR/6+RhG8LumFICQ4WIr+0u1hXXRXjCZ2K69ul8LCUJRWQfdF
5fA3h8UsKRzczQry6EEw7jJZuStECo93LuWX6fvh0aQzKXSvFDU3at1S6ScR
uaTjTMQhKeLjkn/4lZ4AZsu16oizUuw/SegX6VlwpJkLXAukMMjyu/lp4DZi
XzxQ3xiR4s93KzZtsizDk56oqLV+MuyIb/9Qm/wAnM12DhuvyHDs3gn765+r
sCtxw8crMhkG01tf6upWQ+B1ScB27sfLZ/XVgrXPIQnoLVoV149DMX4zdqrr
MP/TAivO2348o62YKDnagPux+n7+5nIU8urG5y56jdXJjTZ6++Twsnhyi1na
iEe2l2iZhXLYN7RX1i8X4FZ635rHCjmEXkxtkfYdOAYJGVHOCkROO9IscmqG
9br5RZ4nFHgjZj0xSmtBf4GDfliVAsyNOyR9fUJYnj5mRhtTYGV+MivfthU5
adOWzFijRPd4pvDgL22ocAw5tfCsElI/Ac+iVgzjnSmTK6uUKM/uinlv/QFV
i5n3l44oUZCkf3HZjx9Bcz68x221CkPhIcqIx+1YMjtIqHtcBUPfC4x7szsB
5wNmB+6qEDtLOl2yuwuTTViJd/tUmP7UTqfNvxsrJ9+pb6ar4Xl621jtSDd4
c3wXbWOokXs7hbcwV4JoA7ckNVcNdrBrE21LD6Z2NRrf4avxUMTJfPqlB0V+
Aa9dBtRwbyzXk13tRfGYXq+ltQYLNkQMZfr2gRPIHO9nauDm6pbxQNaHxzFm
r1zPa9A1mPqKx5Uie6vHvrRSDdQugVz6ChnKhGfiEjo0WKyyV+q2yHAxNOWz
p4EWdbanmqOpPxqZ5s5nu2lxSSgKZ9jKETPhPTOcrQVh1mTo1ckRv9C5K5Wr
xf1gcx/34woI+SSvo1QLXlN8Xo+JEpFJHqYMoRbDDbt/MnmuhLuTMuLhf1p0
Z1QPzYpSQRIbOLjMmuDL+zX080ZqnNtyo2SSD0F0lk1NDHV3nvGwfnIEwewm
m1l9bA0cnZbKr18gYIpKRueNa5CT/6V65DbB4N6bke3FWrDPGebV1xFUh5Zx
jbYSRL1urd8pIfhLELmlM4BAnMcfbqX80brlxqWBBLofU02DeghK5hXk+rMI
eJcHDQN6CXLEORUpYQS04boJLynBqe8vSKbFEBzNSv3bRkFg57XHc2ohQbp1
qWHbJ4LFZXP12/4g2G2vmxM4QGBjKX5ZeIdAewumjZTPGWUEbbxHwHrzc33N
IMGUys1HuHyCbcZTnIo+E0gcXbP1Wwjajq+eefofgvbfBtgtIoJW+vqthHLx
jDJbnpjgut2qkwf/JXirWla+vpOAk9KbEDJCwP/dqiGO2mupz4Yiz1GCSouO
lEA1gbd7secjyiu4OQxrQjAve4TvMEZQHG7eWUPNtby6J9ZqnKCguZmXPkyw
3iWaf43yfO/0Q6FU3+UeUf0zJwhyy/0dnaicqJg1lkj5NSvDoQmKPtxvx7/y
f2bWfmA=
      "]]}, 
    {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwV1nk8VGsYB3DUbUOikFCIFrKFLio/kYqKsstSSd1IUckSrqgohNKiUiqh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      "]]}, 
    {RGBColor[0.560181, 0.691569, 0.194885], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwVznk41AkAxvHR9GiLGbIbTbVKSWHFhvaxxSsdiFnbYGkrlauDDpva6KTG
askm88jZjoaOyeNYtouM68FWVhkTazFoCGP85v6VMnb2j/f5Pp//Xqvw46yo
ORQKhanf/90RNfa6fjzYY03X0rkUihzvyn4IFzNcMBO11kmht7mRKKOKsRXP
P3AChg3kWOf2RUkhIwjMNRmHmqlyfPvKueIGIxLSXAo1dZ4c9flNrtcY8cjs
H/nH2ESOy0lpZ35lXMGFgUoTmqUckfEE4yqDA0lLQP67jXJ8xvEtkiuKYcn5
RaE+K8ejV+u9vS3LQbMTsmQP5Qi93NfblFYN/9Pc22pCjuOVJx1y1E/AXh0f
Kf9KAeX1N20GBgLkn3iwdF6UAm0NLYKOTY2wPXtEMM5V4HCCL23XZDMsqkO7
X/Qq0DB//Wzp0VakFDZqP5gocYfXrFuy+jliDjHyGnyU8DR/djuw7CWu7rb3
njqnhENr3+MWuw4kxkpj/cuV6PIMnLo/9Qr+hqtkZiNKxC6I6RQ5dSJnSuRx
zFyFFz0hz+gZQhz9FJ4830+FwO2hQxJJF27mBHa0nFdhAzcthGv9BuoJ737f
UhUGdVldhy52o5VHzentV2HEt4Nn3tSDdi/buTuM1KjIFSe8tuqF0d469q2N
apSkUq/aJv6L1mITw7VH1NBE/DgRXdOHvQuxr4GjhtHWFFalxQDkkcwAWqMa
50xHjIf2iHGFmbQ6WaqGcZ09pZs5iPEtlEVhn2vgfjpgpml6EIlmqt017hoU
FKfzVhUMIahlTXRcpAZhwS7t8/2Gse3uLualaxr8KYrKqtMOA4+edo9Wa+D2
smLOaPZbeHp42XX3aLBiW7Qma6sExufrdDKdBq4urpnVoxL47+7IvmulhVh5
7S8eewQnn0jbJry0mHTeyWasH8UVMePAqmgtbKQOEwbCURz0OfzzuhQtmq1P
dZ5Iegd/umu24T0tfusSRbCsx5B/Mc7veYsWRGB95pzmMdzujTxoJ9Hij+BF
W9zixsFtP7nBhkqC1365cNhsAqzRmAz35STI1j1nzRonYF/sSGvbRGIwU6Ax
PSYF/8tnp8ShJLSvNzKS6ZPgnolP2vITiROclfUJtZP4hvnBayydhEX7SlNJ
mAzW1pZlymISgaLST8t0MsS/f29SW0NCua8oto8/BR9um4YjJCHYX86m+xMQ
WlgFU8dJPO2I9Rv4jkD46Xa3A3o/9LBbWLaTwOZIPl2gd+mykgJmCIFpmSY1
cYJEXk9eVXo4AZ8nQoFcSuLU9ylDCxIIsBz5G3qnSNh77nWfd4eAQ26jT5Ga
hE35Emr3PQKGw5ecZ/ReadnTducBAeenx+m7NCQWf2IFba8kkLRYzDHVkjB8
7BPDriXwMX2u5AJJYsjRJZcq1P8LPpIWOk2i75YiTCgicCDr64QqvXto5da8
HgJV+21D6B9J/C21rfAaIMC8z3/bpHft3eWtSeME9ilVHutmSDw270/fOUlA
wUdZqt5V7DyWFUHgjbKG9lZvfsSigXo1gWyn7YU3dSRKOjt510kCcTZB7Qq9
uZuvH94/TeD3BzdkfrMkCiqYjk4zBFbUG+hK9L653EgzO0tAFVGkm9X7PzPx
jw4=
      "]]}, 
    {RGBColor[0.922526, 0.385626, 0.209179], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwVx3840wkAx3HlykVJOrohP0oeSr/8qHNdPhSiUKPhSiM/elITFQp316OF
ipT0g6WOFi65xlFp1PxsXLmN2eyYbdhX0vLFk3ry87o/3s/reVuExfhFztfQ
0PD52v/ujhxqr3tHc04I6OeXlnLx9nFAmILiAHPdyWP0Ci4MdcRZlRQ3ZHnV
ftGv5mKD03dFdyn7kbvZpfu3Zi5+FNqXX6dEwMjZreSwkou6O42OVyhxeNFk
edLfsAbMlIyzlykXEO3Ja3h7vgYRcSTlEuUGrGwlbiJ6Lb694VU4OvYA1P6V
Ym/Pl3gmtNu1y5SD+8lVB8/o1SGIKetuzKiCKHJmMmauDjEVp9fnfnyOL/YL
M15rN2D8mqRl3jwezu07mj+k04iW+lc8wU8NMBObTfHXNiEq0WvJz+ompJsf
PVHh3Yz6RXZzZdF8DOQUu50Ke4VidtOs0Zq/kZTEr8m4zYeL4Yv7/o/fQHNE
vSGB14L1fFn1q7UCbLfTSKcPtaLTxX/k4YgQZ9TWczp2r8HQPt4h3tQBrbyL
04WMN3gtDXyhmyXCaGXelHFrG/w9gvpUqk6MHEvjFFkJsKUgI7DAUoJQQcpU
tpMQytmczqPnunBLryUueEwIwkvANmyUgkjwtTEqaEd5niKx3aIbsQmBDtLQ
DhRd1Lxkk9SDFTHpPQwLESbCDwwfqZGhROvEhZkuEXTc0vwqVsghs7lM0yjs
xC96xOK+YAV4z+IZZ0PEWPxynUaXjxJZXYmC5yYSbE/YO9M4qYRZCdevUS1B
/oNM9ur8PoxtpswdqOgCnebQtmhPP0p2MPMmL0rxRByZ8/JTP1yly0vMQv6F
05vy+YO3BiBZYsoYte6GufuRiRw3FXLFowbkgh44OjhmVw2qUC1UTBtLeqAY
v9LKTiVwJEIWK2LLoLanplLsBmEyYxjDu9ALq/frh+eJBvHN59836QXJ0WQZ
3xGb8hZR9K2SHGcFrnaKw/0sh3CoMuAUU0cJ0r8ue37TENYIPRTGCUr8RTPY
6XTyHe6wFAL7YSXYbcy7/frDqDeJPDsc0IfP/OBk/YZhXK25+VCrrQ/KbN6E
3on32OVpK3Zw7cen9m2U87pqLNUJaOD82Y/YG6vqEmvVaOIy3WmrB7CibZWe
iv4BwoPrFlKyB+AvLps2mf0A35BnZVemBzAeUsiQlY6Ac8+kXB6rAi+Uk6rr
TeJUq/4Per0qcAWMPXJfEgzbkOhxuQpPndcue0wl4c6xZnUqVSgzKcr3CSSx
IE6/O1elAkvKqswMI2EaHTxurlYhfl9an3YiCSsq+9eNUyqsczm0XauYRLJ2
QbM7hYAVx0iz6w8SzR1V3VbGBFaZSluKH5E4THUZ1FpJ4Ptpv/0eFSR2nGYp
W80JLKz2PJ5aS4KwjTvsY02gb6NDnqbo69ucz/TbSkB2b4wuEpNw1Vq9wN6J
gHQJx5ItJTHm/fT08m0E/nlvU75DTsJadd2u05lAbYkZP+UdiWW927bQPAhU
G/ZmUtUkcDf9kKMngcpUlp8FSSIuiJlksJtAabiBvO4jifDkqJtiHwJFHR3s
a59JzDrvzHmyl0CB67Wo0EkSx588SrtJJZBf7rNx0wyJ+susmHh/ArfNdCbm
5khEHNPypdEI/AdvoXdQ
      "]]}, 
    {RGBColor[0.528488, 0.470624, 0.701351], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwd13k8VN8bB3BSiFJa9B1pEckaiZLkQaGyZkt2QhKRaCNLUlqU0kaIbFmK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      "]]}, 
    {RGBColor[0.772079, 0.431554, 0.102387], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwV13k4FV0cB/CLLBHaKKEoIUIbpeQrvSjRIqVFor2ktNiKskRkiahQpCxJ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      "]]}, 
    {RGBColor[0.363898, 0.618501, 0.782349], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwd13k4lF8bB/CxZEm2UUIiQkWWRIvim5RS1kgLUaRVpKSkZC1tIiWkEknJ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      "]]}, 
    {RGBColor[1, 0.75, 0], AbsoluteThickness[1.6], Opacity[1.], 
     LineBox[CompressedData["
1:eJwBMQLO/SFib1JlAgAAACIAAAACAAAAFGbcNt806D/j+umeXj4CQO9TwJEC
xOg/+dCEkM7ZAECyVRVDOXHpP9afspwtVf4/o82DneIS6j/6e37HBDP7P/fH
XHsSwuo/570tfF/T9z/gkb/1EG7rP6zsAArji/Q/9tE7GYIO7D/IoePOzYbx
P3CUIsB5vOw/NQTb0ouc7D8XzSIQ5F7tP7sAedoOuOY/U9Ws/Bz+7T8dq+pK
bRPhP/JfoWzcqu4/sQdO3GRA1j+/YK+FDkzvP0wxdQpNB8c/us9sS95O7z9D
1/TnJ6nGP7Y+KhGuUe8/sKCUqBJLxj+sHKWcTVfvP7ZQtPEXj8U/mtias4xi
7z/klR154hfEP3VQhuEKee8/WN1wDH4swT8rQF09B6bvP8dUetkJxLY/Jq8a
A9eo7z9M0ZwF1gu2PyIe2Mimq+8/MiLy4sNTtT8Y/FJURrHvP8zX++4E5LM/
BrhIa4W87z+0ylD9HQaxP+EvNJkD0+8/iLeL/HKhpj/cnvFe09XvP2XVJ/xP
NaU/2A2vJKPY7z/jT8dNcsmjP87rKbBC3u8/HLlkY4fyoD+8px/HgenvP9hJ
LH7tj5Y/uBbdjFHs7z8YX2hrA7yTP7OFmlIh7+8/r3ae7qXokD+qYxXewPTv
PwMj0WAjh4Y/pdLSo5D37z/OM4jXtuOAP6BBkGlg+u8/1q+i2sqCdj+csE0v
MP3vP6fETHy+gGY/lx8L9f//7z/S03DawOmFPmrgIzw=
      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{{0, 1}, {0., 2.2804539122729337`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.745413822482235*^9, 3.745413883657954*^9}, {
  3.7454139355033216`*^9, 3.745413964237241*^9}, {3.7454140462962418`*^9, 
  3.745414062139894*^9}},ExpressionUUID->"705e5b3b-c448-4329-9d9c-\
4c90ac6ec52f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "\[Alpha]0", ",", "\[Alpha]1", ",", "\[Alpha]2", ",", "\[Alpha]3"}], 
       "}"}], "/.", "replacements"}], "/.", 
     RowBox[{"d", "\[Rule]", "3"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"e", ",", "0", ",", "1"}], "}"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.745414000121386*^9, {3.745414051689262*^9, 
   3.745414056777647*^9}},ExpressionUUID->"746f1f77-515d-4205-88b9-\
63f22fcaa407"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwV1Ak01FscB3DLS6Joo2aSdWaKQglJ+N1XaVGIsb7KSx4SldKCVomsZXve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      "]]}, 
    {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwV1nk4lN0bB/CRN4nIElFJaaKYJ9mKFvfptaRN2aKiJFkS2X6WUrJUIiIS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      "]]}, 
    {RGBColor[0.560181, 0.691569, 0.194885], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwV13lcjFsYB/BRaVORq5h6SVqQFirdhJ43S9K+KKm0SEW7llskW4YQWoUW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      "]]}, 
    {RGBColor[0.922526, 0.385626, 0.209179], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwd13k8VN0fB3BbngqVRJSKLBWKZ+zm5nuyKxVJKKRFoZKtECpZUpOtyJIW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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{{0, 1}, {0., 28.559782410483162`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.745414001706318*^9, {3.7454140521472282`*^9, 
   3.745414065023549*^9}},ExpressionUUID->"db2e814c-a728-4590-af8b-\
30c86ebef9fc"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"c0", ",", "c1", ",", "c2", ",", "c3"}], "}"}], "/.", 
      "replacements"}], "/.", 
     RowBox[{"d", "\[Rule]", "3"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"e", ",", "0", ",", "1"}], "}"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.745414129378646*^9, {3.745414232711679*^9, 3.7454142625615997`*^9}, {
   3.745414312944549*^9, 
   3.745414333138124*^9}},ExpressionUUID->"3a0952e6-bb4e-4703-b0b0-\
d20525dbdd9a"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwVj3040wkAx5krlTj1sMwhL6ue3k7nrZz0naKSKGPIU055n1mvelK5klbe
KkMplrD59XJiEnEp1hR5ad6WXefY3PKW+pWLale57o/P8/n387Has5cZQdHS
0vL+xv/eEjHS2TDKWifTp7I4kkgMlwXsGaA5ICiM21QjiwRVT36+kuaONTbT
urP6I/Gjs1HJVZo/eAee/lOmicTPHfbiLFo4Mh9r4i0cotCQL3U8RzuEO8Io
+unrUUhOSj+SRjsNFqG0ZmdGI/wQSUul5SDOqdq1kM3GrBzPorfvRFCZPfvJ
/yIX9zrsNm2yKIdxy+y2GP/9CErueyFNv4sR6bIEU/ZB7K04uPLy+1o8+3Wk
q/ZxPCYynzdra9eDd+qkNs3wCJolT+plax9hYOF3U4dERxGT4Km/Y7wR+Tfc
iqo8EiGZbTddGtcE1/sPPWplJ0AIG7+aLmqBYfmlYUv/JDCoD4r9ytowavM9
fVHlKaxs6qt5skwG+ziJTrDxafQw/N7cfNOB3Iw0hrSQB86c2C75qi6Y+AhX
j/1wFq2KwAcG57sRl6q+LZWkwG9jkEqt7gG9Vfoxn50Gp8L0wEL6c/i8K5ab
a2VA+TW7J/pEL2gq/bhHknN46SkTUqUKJB7PXxPCvQDxlYGETqsXYMw4wDMS
ZaIkRSd16dE/0bo8eYkjn4/JsOCxyPt9CAwdbvE+kAU99zPMigX9UPJWWe1m
Z+O44cu5qp0D6NB4bs1h5WDuw+Vavd5K8IsWlDJxEa6Ht32RapRwMVtsuJpx
CQJRhtBGoEI1fWv4c7tchLAc2md7DSJ8291q8drLqJJHZD+cGkSBaD9vh/sV
OLeJKUOX/sZbekBBxNo8WHpETma7q9E+4+Nhrlc+HB0c+XeH1JAbJH4y3iLA
wMS5p0LeS7imz+yleFzFuL0vj2Y3hKnouRPcgAIsfrVyTLt7CClpXjf9Aq6h
kR7ftS9pGNuLdUWWToW40CMPY9JHkEA18NDcKwTp18CnNI5g3RnLEafVRbjD
Mt7gvH8Ugm3MZE1DEYTtyVcH549Bai7dssStGB+adh6b/2gMCg7fiNNaDCW/
ftKQ+wop7BmJLKYQU50utFMG43CJsbd1kwmxL8e6IaFuHBHq+RsSWSIsaLc2
VIe8hvEsyouEThH85KWfzb6+xhRFKzrXswQTvxRx+m69gXrI6KRJSwnqQ8t5
BltJdJce55oyCPwu43j1+5BwnlOnoq8nUL1u2bwyXxLzmgJW2LoTKDUrEXgH
kohqDNq0YTOBPEVeZcYeEjYu17NithOI335GNSeBhDB8xd6yUALLGbtcdQkS
VtpHHpskEVhcbqrTe4OE/R8+FItkAtYWimbiNxLXGL5GNjwCJp+Z/hsrSLQE
Z91bkUpgZs3mWF7dt547Jp9c+QRUtg5XdLpJ1B9tDgoqItBX8C6kW06i6pix
MlhIQKFfThcqSOi1HXTZVULg2aul4vX9JBblmHN33yRQd31hU9IoCfJfR0lU
BYEa6l8ZvuMkBHXmw9GVBCp5eUwrkoSYmqqMqSJwK8y4v+H9t98CoXdsLYGS
ri5h5gcST71sJbH3CRS6ZcaEakiYZX3Q5TwgIBB72676QiLw9pgVp55A7kK9
yelpEoO9UwYcCYH/AFuJV2o=
      "]]}, 
    {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwVz3081AcAx3GdVSvcpEXX9ECy0YkVLUZfVyLpauii1tQ8vbQTei1blFcv
D+chefZKwlaJSeYhTlr0Ow9F5Twcx03nOH4/z/wkslVY++Pzev/90fMMdPFh
qKiocD/2v4d8RtpFo7y92248DRH8GEsMFx/37GOZoyV5N0fPJpbQVpMmlrPs
cLGxNOLB+lhih+XneTmsY/BxtzgvbI0hrNp2laayvDHlJRyztokhRFn1Fgms
C5hhVtQ6a0cTkeHxF6+yorCR05CRKIokvC/QrDhWOuqcNIy9x8KIT9Mdb0+/
vouNfO641/Bp4mHbTgeHTSUw9WQ/ukjy4R4p76mPr8Cafj+lyDcCgWU/m9yY
fYSc8UyGdWoSZpK7mpYtI+AffEhhf/g6mmqfEa3WdZhp9Q0IqcvB2RBHjRMT
DeAtmNbUE3dQu2rnUtG5RrzXZAQei89Hfm7D4oZtL9D5STz7695C2GrX3HEt
bsaIr1k4U6cEJo3yqmfGrYiMu7rZUFiGTlvXqXtTbUiV7a/R+aoC/qv5EqmZ
BJIVl7fJ4irxUuZWw0zswP3vDZNJy0dwtXdXkmQn0tbWOPT+8xi7b8W73TLo
wumlqWmt20/Qv5jW6XelG0mq2rXyFhEox9Zc7XoZsuw8d5ywrUNpZl9Iu14P
nNxUXC4p6pEXqxpnFPoK+yr9fl+MeIo5r5Njvo/lkLel6Ap1GqFmF+1SpqPA
nzH6TIa8CZc1KXXlqT5IB4WZbxJfQP3JdpVubj8cg1WWjA40w+aXowv17/rR
x094V2XSguy713K3ZiuhayBOnldpgwfPXLzKaQD2bKHayeXtEEp90p68HUBs
U97sfTUJLJtLGUPXB5Ehah61W9GBLQd859LsSPSWDO8I0u2EhblFSsUQiY75
lBJNQyn6ZhKe5woocAabuAumXZjY5Sxg7RwCvz2stvB4NwzHTcaWdQwhYVIc
dTBQhgaDYElQ+DDSJV38G3l/I6lT6uViMAKN80FsVXEPaFdRCqNhBOqsPQfl
b17hAW/dfsvzoxAkMzsDLHuRK47MGdAaQ1hm1prMAAXmG09d0qobQzPDO4Jb
34f+FGJOM2ActRw7ZmV8P962f8uKYE4gkOPq18JWIihdXxRSPQHPzwKfsxRK
6Ij1NUmPSagVp5Uvjx6Aq7Tog+7iJJIWY6ql7EHMnL7tLy+cwrmNoQ/NyUEQ
Z0oEzMM0VtZMvwxLIfFXq7+T4ggN9x5tq9h0EpV7jdcUO9MoaOxoS80gUaSb
l811o3FE6/2vBTkkbspull/zpOFg6VEkvUci+Lto5eoQGvysnwq+qSOx3fYH
m5X5NNTZzKesNyQMSzaodhfQ4IT3WBm9JaG/SdaUf59GDDNKtudfEus/uByz
L6Nh4usW775EYkXVQb6gmkbG5MmWTDUKSlPzTNUOGkaPyxq2GlCQ//bao0NK
g3BMEVp8SUGmUWKQK6OhoTotdjCm0DJuVLpPQWMrb22wvxmF6j82N4aPfvwl
nbIfWlOo0u695jxBo8/qStMLUCgX3HTRo2n4+jB0FfsoFHqtU4hmaXwR2r9n
uSOFPIkkN3meRmiUKYN1mMItTvLZM+9ozN6pnGEfpZBdyjU1W6AhGAxczXGh
kLFZbW5piYaHK8+Rx6PwH1h9dKY=
      "]]}, 
    {RGBColor[0.560181, 0.691569, 0.194885], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwViXs0lAkAR0WnQjk2GaZswugh0grnKPwojyRaQ41aPSRttgedqFVtL9QS
1pCK1UOT2a0UwjaivmFkKgpjJpM3OwYzw9dYr9r52PaPe+6551rsj2ZGamtp
aQV85X9viRxs5g9td0/Ibz906pSQGHiyY3833RFGrAtys1ghQdOXpJfSvWAx
eD2VHyMk1rgsKrhFD8EWb6cg7Z+ExPqmdcWZ9AOY0z5VHh0mJPi/C5zS6LE4
KSmqVHsIiYSLV39OoSdCnfB+JXuekDgQS9KT6dcQPuBJ+y6zjph3zS//k/o+
XD/azWGeekU8a3Lw9V1aBP3Jm/5agbVEaEJHm+BqGZa4fHI9rycgoktO2N0c
q4Cgp6y48nI1MZrx4fWsWQTyTJNdHo0SxOvqOqLRtQZWW/KbJd5VRFS834Kd
qlpszN57qYDFI6p1HWYKjwrBNt64LC28jOByaqcXW78Fr5CjWphQRHjQXtwL
ftKAcl7YrkB3LmEn7ODV2TSiS6W2/kjPIcQewSMPRpog6JjrnRgdSRzROyyS
rBUh4Ibns62ZWaiXsl4YpLfApi63sDubi2Cf0F6ZTIwXZswgxngJnO9eZd1l
fMDxHbp6Pybx0DOdJT50vhWQOhtE6fDR79fIoQmkOLGzenN0qQDFOd3xzRZt
6JTPjuuRC1Hwq07yqtPtYFt5HBW7NmA8YpfiYGUHlMqpskrXJuh7XWaWmHSh
aJsn9ZkjwlnD/vm9Yd3I8B9xOKwRY/7L1VqtAT14yn1g+yG8FW4nt1GCLz0Y
tfrhYJxJG/Lup3Ks8nqh/+2hteyKDuzZ7vhO178P5AKb7PaSbpRLIrNeTvQh
37XLbu/uXrg0FGvLr/+Nt3ou2WckfVjmfXA8y0uGqGn7K3fOyuDk6MQuk8sQ
m8lYZE2To3s07Q0nqR91pnYVB8oHoFoXlER3kMM516/0zpUhLFfaKWa1yHGF
64Ff/JSoZcSJYi4OYOzBlGm25zB+E0simIxBpHuGPZetIEEG89natYMw4saE
VCV/wtPtxptcjg/hfrqyhpenBuddwq2+hQqIiIoKZsEoJoVhZxbWKOAVyjeQ
NPyDHjYxbnhMiQuNsWnDk2OYaN5Av2SgQmBMjb2uyQRirlny46tUoNuumfFh
TcLknaWhbM8wzDi+9ypSphAsKdSYTQ+DNmXPWM7/jNG9+Uc6Ho4gnSaeP2z6
L4h9RUkGW0lIxbNT3CI0eN54xL8rkMSKN5lHjaI0+Mvd5psnQSQyaOZTQ8c0
KDQryAtgkThdEqCdc1qDXGluaep+ErbJhHKarUHc95d79eJJnJd8NFXwNVjt
sdttLpeEnt0XPXdzCsuLFuu0/knCLTisfaU1Bcul0tfcRyQ2KbKCF62mYKph
hviUkLBcf3vDsDOFObzNh5OqvramTcENpNBr75ij00JCrWiqdzlHoeO2ek+L
hERI42Mz+0QK0gVFDI7060e9sXUKhffKVcUbu0iEXurTMrpOoeoPc+HFIRIi
jlvlxGMKPFpnapCKRJlOW6C6lEJpUi7TgiTBClelqCooPIww7uKPkXB8k6aR
vaJQIBJxMiZJ+NjaOPTVU7jrmRG17wuJfneWYU8zhbziAPu1FImawiU3ulop
3DDXH5+ZIeFrca6us5PCf8aKh7k=
      "]]}, 
    {RGBColor[0.922526, 0.385626, 0.209179], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwVzHs01IkCB3CPHiSyu3mMU6KYpRLLjBPKl255S16LniIipE06ze1BD202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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{{0, 1}, {-0.1833333265306117, 1.8666665795918378`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.745414130526775*^9, {3.745414234178294*^9, 3.74541426313301*^9}, {
   3.7454143134423847`*^9, 
   3.7454143336055403`*^9}},ExpressionUUID->"d4ac4350-e3d9-4a17-9829-\
fedc887b5c9f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"c1", "/.", "replacements"}], "/.", 
   RowBox[{"d", "\[Rule]", "3"}]}], "/.", 
  RowBox[{"e", "\[Rule]", "0.01"}]}]], "Input",
 CellChangeTimes->{{3.745414273027882*^9, 
  3.745414305207485*^9}},ExpressionUUID->"f57fc3c3-e1a3-4764-ab55-\
cc5886881b1a"],

Cell[BoxData[
 RowBox[{"-", "0.009601084047619049`"}]], "Output",
 CellChangeTimes->{{3.745414277382599*^9, 
  3.745414306229167*^9}},ExpressionUUID->"5aac73e6-a022-4973-bc67-\
419dd3c676df"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1055, 449},
WindowMargins->{{0, Automatic}, {Automatic, 17}},
FrontEndVersion->"11.3 for Mac OS X x86 (32-bit, 64-bit Kernel) (March 5, \
2018)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 205, 3, 67, "Section",ExpressionUUID->"c913b4d3-eb50-4a2e-8a11-0620dac11554"],
Cell[788, 27, 284, 6, 51, "Text",ExpressionUUID->"f37fff76-5627-411b-9307-9424dff87b7e"],
Cell[CellGroupData[{
Cell[1097, 37, 166, 3, 54, "Subsection",ExpressionUUID->"c359f6e3-11d6-4de6-a1f9-fb7e47140308"],
Cell[1266, 42, 26970, 684, 5158, "Input",ExpressionUUID->"fd8609da-b380-4357-9965-9eb4e676b768"]
}, Closed]],
Cell[CellGroupData[{
Cell[28273, 731, 241, 4, 38, "Subsection",ExpressionUUID->"42a72e10-3e0d-4b42-898a-691f5071bb61"],
Cell[28517, 737, 546, 10, 2977, "Text",ExpressionUUID->"808f17e6-d6e2-48da-ba14-fbcead60736f"],
Cell[29066, 749, 15206, 318, 57495, "Input",ExpressionUUID->"496ed015-8bac-4c88-82b6-369aeb4d32ac"]
}, Closed]],
Cell[CellGroupData[{
Cell[44309, 1072, 183, 3, 38, "Subsection",ExpressionUUID->"5201fe82-7184-4ca0-a918-115d1c1dc2e3"],
Cell[44495, 1077, 18681, 393, 31300, "Input",ExpressionUUID->"dcee4a3e-232f-423f-bea8-bcf9fabb7d78"]
}, Closed]],
Cell[CellGroupData[{
Cell[63213, 1475, 347, 5, 38, "Subsection",ExpressionUUID->"da6ec88e-e2b6-4d2f-a1c8-311700687c73"],
Cell[63563, 1482, 823, 18, 2275, "Text",ExpressionUUID->"f753fa22-80b1-4abf-8649-aa15b313a374"],
Cell[64389, 1502, 6291, 115, 12938, "Input",ExpressionUUID->"9f80ff47-33b5-4533-8a34-73d9697c384b"],
Cell[70683, 1619, 1733, 47, 3127, "Text",ExpressionUUID->"1a4c01f0-2e94-4170-b624-74c863a1cf46"],
Cell[72419, 1668, 8937, 213, 37402, "Input",ExpressionUUID->"f7d6f1d4-e266-46f1-b45d-900aa833cbc1"]
}, Closed]],
Cell[CellGroupData[{
Cell[81393, 1886, 474, 8, 38, "Subsection",ExpressionUUID->"da6ec88e-e2b6-4d2f-a1c8-311700687c73"],
Cell[81870, 1896, 1331, 40, 1681, "Text",ExpressionUUID->"92ae5e9b-88da-4c04-a05e-966d8f94ea1e"],
Cell[83204, 1938, 1149, 30, 2197, "Text",ExpressionUUID->"09e880f8-3139-4339-aeb1-7f1566f77ee7"],
Cell[84356, 1970, 9771, 214, 27906, "Input",ExpressionUUID->"2281b670-b859-409f-b74b-ca0f89be388e"],
Cell[94130, 2186, 475, 10, 1681, "Text",ExpressionUUID->"820b23f9-373f-42aa-9f96-1eca3c30d6d7"],
Cell[94608, 2198, 8307, 165, 18116, "Input",ExpressionUUID->"2bdc4ccb-9953-49c2-8a7c-b39115c639c0"],
Cell[102918, 2365, 376, 8, 1681, "Text",ExpressionUUID->"a732fe26-5056-402f-ac76-f22e1e4db1fc"],
Cell[103297, 2375, 18793, 376, 34640, "Input",ExpressionUUID->"2997a001-ba2c-4d02-a12e-d677486bc8eb"],
Cell[122093, 2753, 1270, 32, 3353, "Input",ExpressionUUID->"2277e4b5-3c2e-41bb-809a-9dc2f4478c58"]
}, Closed]],
Cell[CellGroupData[{
Cell[123400, 2790, 176, 3, 38, "Subsection",ExpressionUUID->"3374725b-b06c-475d-b0c1-9a6837154205"],
Cell[123579, 2795, 1374, 33, 63, "Input",ExpressionUUID->"d95aff72-4a36-434e-a2c6-7a4288991e02"],
Cell[124956, 2830, 3043, 84, 74, "Text",ExpressionUUID->"b27ec653-491a-43f9-8092-537b52ed9a98"],
Cell[128002, 2916, 8519, 211, 569, "Input",ExpressionUUID->"03d7227e-1881-4ba5-ae21-1dceeca4b46c"]
}, Closed]],
Cell[CellGroupData[{
Cell[136558, 3132, 160, 3, 38, "Subsection",ExpressionUUID->"a03cc323-5c73-4e62-b060-5d1590e61145"],
Cell[136721, 3137, 13357, 409, 419, "Input",ExpressionUUID->"d329183c-bc48-45fc-8096-086b656e3efb"],
Cell[150081, 3548, 19963, 641, 1027, "Input",ExpressionUUID->"683bb60e-3ede-4f12-82ce-e6bb11dcda71"],
Cell[170047, 4191, 3098, 83, 97, "Input",ExpressionUUID->"7bd5c3eb-e232-4634-8f8a-12ffe858c59b"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[173194, 4280, 302, 9, 67, "Section",ExpressionUUID->"5d386878-2449-4b70-a81e-bd8d5eed01cb"],
Cell[173499, 4291, 1603, 50, 2426, "Input",ExpressionUUID->"4be78355-6340-4961-a7b5-c456a82fb27d"],
Cell[175105, 4343, 2462, 71, 2807, "Input",ExpressionUUID->"3d511f45-049b-42f7-a04b-c2ba418ce801"],
Cell[CellGroupData[{
Cell[177592, 4418, 5325, 155, 6945, "Input",ExpressionUUID->"cb1fc892-4f4f-4c5d-b2a3-d90c0b42b85c"],
Cell[CellGroupData[{
Cell[182942, 4577, 978, 15, 520, "Print",ExpressionUUID->"278aea36-ea57-4a3c-985f-a1600626648b"],
Cell[183923, 4594, 842, 13, 520, "Print",ExpressionUUID->"6e4ffce8-d9f6-414a-b56b-9b0d083f3277"]
}, Open  ]],
Cell[184780, 4610, 3414, 106, 3812, "Output",ExpressionUUID->"1c4dc36e-c132-4eab-a29b-e8982018e4af"]
}, Open  ]],
Cell[188209, 4719, 10192, 307, 16868, "Input",ExpressionUUID->"1c027d44-a138-4176-b77a-bcefd519bb51"],
Cell[CellGroupData[{
Cell[198426, 5030, 398, 10, 687, "Input",ExpressionUUID->"eb647c58-b6a5-4e49-90dc-779304f6dde4"],
Cell[198827, 5042, 197056, 5136, 16613, "Output",ExpressionUUID->"0b76a516-564d-48ec-9243-98e7eda05473"]
}, Open  ]],
Cell[395898, 10181, 206, 3, 782, "Text",ExpressionUUID->"f8f25d53-8c2f-4962-b265-b56e10e6ed4b"],
Cell[396107, 10186, 547, 16, 1126, "Input",ExpressionUUID->"b878be0a-24a7-4f27-8db9-10cd7cc7bf6b"],
Cell[CellGroupData[{
Cell[396679, 10206, 249, 4, 687, "Input",ExpressionUUID->"87899dc4-f633-48d3-9c32-6d1f933f203a"],
Cell[396931, 10212, 669, 20, 1268, "Output",ExpressionUUID->"eac449f8-22af-4538-ad0e-01f07ef3b6e3"]
}, Open  ]],
Cell[397615, 10235, 671, 17, 1645, "Input",ExpressionUUID->"9b3f6011-40c9-492c-a2a2-4838e629a33f"],
Cell[CellGroupData[{
Cell[398311, 10256, 1953, 54, 4931, "Input",ExpressionUUID->"47c409f3-3680-4e6f-8c9e-701e2ba5be18"],
Cell[400267, 10312, 152, 3, 782, "Output",ExpressionUUID->"08271917-56bf-4df3-95f2-b15ee367d1fb"],
Cell[400422, 10317, 226, 6, 782, "Output",ExpressionUUID->"7f5a3a0c-296e-4281-a417-7912a2acb1cb"],
Cell[400651, 10325, 223, 6, 782, "Output",ExpressionUUID->"ab8ce9b0-f4b3-44df-9649-0af73da8a262"],
Cell[400877, 10333, 605, 20, 1351, "Output",ExpressionUUID->"2e15555b-1b2e-4c9f-9f63-857a02e4147c"],
Cell[401485, 10355, 226, 6, 782, "Output",ExpressionUUID->"ea77c01e-f8df-4924-9744-53e59324e4dc"],
Cell[401714, 10363, 1597, 52, 1906, "Output",ExpressionUUID->"908e48c1-fb70-49bd-a693-91035caa0c8d"],
Cell[403314, 10417, 221, 6, 782, "Output",ExpressionUUID->"1ab59bfd-7b05-41f3-85c1-a7e465cdaf67"],
Cell[403538, 10425, 780, 26, 1351, "Output",ExpressionUUID->"34082cf9-2235-44ab-b046-965d2ec7daa6"],
Cell[404321, 10453, 5017, 160, 4691, "Output",ExpressionUUID->"dcab8643-41fe-47df-b650-27d7d4aa210a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[409375, 10618, 298, 8, 687, "Input",ExpressionUUID->"aa79e7ab-2829-4cb9-a24a-46bdce8a55fb"],
Cell[409676, 10628, 3053, 100, 2941, "Output",ExpressionUUID->"3b0cc5a9-bb1a-444c-abab-8173f5eded1d"]
}, Open  ]],
Cell[412744, 10731, 6743, 220, 13276, "Input",ExpressionUUID->"11556713-7c60-4882-bdbd-bad3b06a88fd"],
Cell[CellGroupData[{
Cell[419512, 10955, 402, 11, 687, "Input",ExpressionUUID->"b7a67637-713d-49cc-8829-e07bd15f9bdb"],
Cell[419917, 10968, 20219, 474, 27426, "Output",ExpressionUUID->"2c454c7e-4cef-47a6-b818-8ba74845f8a2"]
}, Open  ]],
Cell[440151, 11445, 5538, 180, 11116, "Input",ExpressionUUID->"5170bcbe-a889-461a-85c2-42800b8446e0"],
Cell[445692, 11627, 671, 17, 1645, "Input",ExpressionUUID->"fc9b4337-b791-4c82-aba8-3c8f4992f153"],
Cell[446366, 11646, 1399, 45, 2807, "Input",ExpressionUUID->"c19602cc-34e7-429a-bfe1-eef9541a07d4"],
Cell[CellGroupData[{
Cell[447790, 11695, 1244, 32, 2290, "Input",ExpressionUUID->"c44a9d51-c4db-4409-be44-aaa50f2a0090"],
Cell[449037, 11729, 296, 6, 782, "Output",ExpressionUUID->"31c622de-480c-482a-b8fb-167ee06c2b05"],
Cell[449336, 11737, 572, 16, 1268, "Output",ExpressionUUID->"3a5a42a4-dd0a-4670-8e83-60ee05211348"],
Cell[449911, 11755, 1058, 32, 1268, "Output",ExpressionUUID->"707a7dfb-9fc5-40bb-abaf-65166f14fcac"],
Cell[450972, 11789, 2975, 92, 2977, "Output",ExpressionUUID->"a967b29d-32ef-4cbe-9dec-643332367fb0"]
}, Open  ]],
Cell[453962, 11884, 1257, 38, 1681, "Text",ExpressionUUID->"6da84be1-4a22-4f1a-9e65-4d91b52eecfc"]
}, Closed]],
Cell[CellGroupData[{
Cell[455256, 11927, 187, 3, 53, "Section",ExpressionUUID->"7cd28e81-93c4-436d-8d2c-569ad6d6f273"],
Cell[CellGroupData[{
Cell[455468, 11934, 243, 4, 60, "Subsection",ExpressionUUID->"c7018255-f61d-4718-821a-ce64090087cc"],
Cell[455714, 11940, 4700, 128, 443, "Input",ExpressionUUID->"da3eacb0-2a21-48cd-831e-e03d8f2ac5e9"],
Cell[460417, 12070, 1951, 59, 127, "Input",ExpressionUUID->"cd1d952c-6e8c-4463-ac81-fc554e21e009"],
Cell[462371, 12131, 2450, 79, 63, "Input",ExpressionUUID->"caf8c2c1-d427-4b10-ba3e-b1b137bc5d89"]
}, Closed]],
Cell[CellGroupData[{
Cell[464858, 12215, 508, 13, 53, "Subsection",ExpressionUUID->"8cd26e3e-1095-4202-93d2-3cc353d14d1c"],
Cell[465369, 12230, 15763, 293, 404, "Input",ExpressionUUID->"9ce0994b-2f59-4b43-bcff-3a892139f501"],
Cell[481135, 12525, 2669, 78, 182, "Input",ExpressionUUID->"a26d46e5-536c-448e-9eca-7218db0f2d26"],
Cell[CellGroupData[{
Cell[483829, 12607, 1473, 39, 46, "Input",ExpressionUUID->"77d257e0-0efa-4e27-aaef-7304f9c551f1"],
Cell[485305, 12648, 485, 12, 70, "Output",ExpressionUUID->"fb90605f-69d8-4972-b17c-14e463e7012d"]
}, Open  ]],
Cell[485805, 12663, 291, 7, 28, "Input",ExpressionUUID->"e90ade09-0188-4434-bea4-62c90616de54"],
Cell[CellGroupData[{
Cell[486121, 12674, 697, 20, 53, "Input",ExpressionUUID->"7041161e-8762-4e28-8d8a-93bd85681b24"],
Cell[486821, 12696, 577, 15, 70, "Output",ExpressionUUID->"b66b6520-297b-4ddc-a178-60442f1e4d96"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[487447, 12717, 598, 15, 57, "Subsection",ExpressionUUID->"5b63e586-c80b-4678-908c-0e4836bab514"],
Cell[488048, 12734, 16837, 322, 455, "Input",ExpressionUUID->"62c6e26c-a95d-44d7-9a8e-e07db2e6f4f9"],
Cell[504888, 13058, 3014, 82, 223, "Input",ExpressionUUID->"56ad9ce0-7e9e-4a68-9691-7108bdfea20d"],
Cell[CellGroupData[{
Cell[507927, 13144, 1685, 44, 46, "Input",ExpressionUUID->"d20fd942-567b-46c6-b2c0-c4134755a5f6"],
Cell[509615, 13190, 984, 31, 50, "Output",ExpressionUUID->"7d95d90d-139c-4fd9-be43-8211704b5796"]
}, Open  ]],
Cell[CellGroupData[{
Cell[510636, 13226, 2171, 63, 108, "Input",ExpressionUUID->"d59fcb3c-62a1-4e54-a7a0-6a342f167a60"],
Cell[512810, 13291, 597, 14, 28, "Output",ExpressionUUID->"5756a28e-3f48-44e4-9dd2-83aa5e606400"]
}, Open  ]],
Cell[CellGroupData[{
Cell[513444, 13310, 2137, 58, 106, "Input",ExpressionUUID->"04286a9c-b0a4-42f4-894c-a3194e886622"],
Cell[515584, 13370, 199, 4, 28, "Output",ExpressionUUID->"5eccacea-5575-44fd-a6ae-ca41d633c2af"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[515832, 13380, 703, 17, 53, "Subsection",ExpressionUUID->"de83cfec-538a-4abc-915c-1fbce162bf86"],
Cell[516538, 13399, 17061, 326, 455, "Input",ExpressionUUID->"966e85b3-cd3d-47d5-afeb-ad875ce53385"],
Cell[533602, 13727, 3439, 93, 187, "Input",ExpressionUUID->"c85c1716-eb75-4fbb-965d-5e2d6d1770e1"],
Cell[CellGroupData[{
Cell[537066, 13824, 1748, 42, 46, "Input",ExpressionUUID->"1d1b9137-f503-4e0d-a75e-ed65efaa9daa"],
Cell[538817, 13868, 520, 13, 70, "Output",ExpressionUUID->"67be8500-f071-40e8-8bc2-a3c8f8371d41"]
}, Open  ]],
Cell[539352, 13884, 220, 5, 28, "Input",ExpressionUUID->"2d1f8ff2-e898-49a2-84ab-9f5e8721f5fe"],
Cell[CellGroupData[{
Cell[539597, 13893, 1439, 46, 88, "Input",ExpressionUUID->"9e70d684-29a9-4f44-861d-6f7cf626ccad"],
Cell[541039, 13941, 370, 7, 70, "Output",ExpressionUUID->"c2d76a62-8773-4175-9c95-439d7ec1981b"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[541458, 13954, 677, 17, 57, "Subsection",ExpressionUUID->"e01ad827-e344-4ebe-b1e7-7a72229f2d7f"],
Cell[542138, 13973, 16912, 323, 455, "Input",ExpressionUUID->"eac281a0-2833-44d4-b536-f0abe127bb57"],
Cell[559053, 14298, 3723, 103, 234, "Input",ExpressionUUID->"12a23c19-5a40-431d-a72f-c23d14fd59b5"],
Cell[CellGroupData[{
Cell[562801, 14405, 1945, 49, 63, "Input",ExpressionUUID->"2146e61d-a081-4fff-9334-67a741d0965a"],
Cell[564749, 14456, 1675, 53, 68, "Output",ExpressionUUID->"9b73ee2e-df39-4bd1-9c81-85f9dc1f1d93"]
}, Open  ]],
Cell[CellGroupData[{
Cell[566461, 14514, 2250, 65, 136, "Input",ExpressionUUID->"607eb799-f31e-4cd6-bc9f-78f607502fb5"],
Cell[568714, 14581, 517, 13, 28, "Output",ExpressionUUID->"18022929-ed1b-4e44-9748-b1ea3d5f77e1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[569268, 14599, 2623, 73, 148, "Input",ExpressionUUID->"141011a2-4e96-47bf-8e39-f2cb1e6916c0"],
Cell[571894, 14674, 203, 4, 28, "Output",ExpressionUUID->"83f322c7-6df7-4883-9708-ee8c2e72882e"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[572146, 14684, 703, 15, 53, "Subsection",ExpressionUUID->"a19c3fac-44d3-4360-a308-713cb79f188b"],
Cell[572852, 14701, 17269, 331, 455, "Input",ExpressionUUID->"29120c91-bbb2-4bae-9196-8882d8ab15a5"],
Cell[590124, 15034, 3272, 84, 169, "Input",ExpressionUUID->"4f13f0a1-9b32-46ce-a4a6-2fd0b4c797f8"],
Cell[593399, 15120, 2333, 63, 57, "Input",ExpressionUUID->"d5710de4-b75c-4245-902e-e63320271403"],
Cell[CellGroupData[{
Cell[595757, 15187, 4168, 111, 174, "Input",ExpressionUUID->"5dbcd5c9-d512-4f18-a2f3-92e3240fb46f"],
Cell[599928, 15300, 201, 4, 28, "Output",ExpressionUUID->"a618cfcf-7450-41f2-8214-ada6d72d9219"]
}, Open  ]],
Cell[CellGroupData[{
Cell[600166, 15309, 5031, 137, 244, "Input",ExpressionUUID->"c7b6a3a0-fafa-442f-a0b3-50bf9674058f"],
Cell[605200, 15448, 630, 10, 28, "Output",ExpressionUUID->"de427cb6-ea9f-476f-92ce-00a55f50fe6e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[605867, 15463, 1758, 50, 98, "Input",ExpressionUUID->"173225e5-a629-4de0-a00a-515c8f0e68ca"],
Cell[607628, 15515, 9688, 173, 245, "Output",ExpressionUUID->"e977366f-ec49-40ef-9958-4d1bc60e9220"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[617365, 15694, 776, 18, 57, "Subsection",ExpressionUUID->"70bfb913-4654-45fd-b716-3c2c3712d2bc"],
Cell[618144, 15714, 17188, 328, 455, "Input",ExpressionUUID->"7512c3e2-2906-438a-98f2-9f4886882ca4"],
Cell[635335, 16044, 3443, 88, 165, "Input",ExpressionUUID->"9d7a073a-b8ef-42a7-9fd6-bf7c0f032a0e"],
Cell[638781, 16134, 2113, 62, 46, "Input",ExpressionUUID->"c4957fc5-bc1e-462d-9d47-41476078f019"],
Cell[CellGroupData[{
Cell[640919, 16200, 5754, 152, 270, "Input",ExpressionUUID->"6cbd62c6-5459-49f4-9991-3dc2bf390d31"],
Cell[646676, 16354, 313, 5, 28, "Output",ExpressionUUID->"c7e797d3-b066-4717-8531-a49a4290c6ed"]
}, Open  ]],
Cell[CellGroupData[{
Cell[647026, 16364, 6836, 184, 284, "Input",ExpressionUUID->"a18b9cae-3e8e-4b1c-91cd-cea21030405f"],
Cell[653865, 16550, 955, 15, 28, "Output",ExpressionUUID->"0544d0ce-8af3-4c3d-a09b-61da5b5c6d23"]
}, Open  ]],
Cell[CellGroupData[{
Cell[654857, 16570, 1248, 35, 82, "Input",ExpressionUUID->"b51d117f-4ae5-4af3-97da-93aa787af1c8"],
Cell[656108, 16607, 6354, 118, 244, "Output",ExpressionUUID->"1e87bb24-8fe7-4717-a097-04979d8c7e7a"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[662511, 16731, 755, 19, 57, "Subsection",ExpressionUUID->"fd5b5804-1b9f-45c5-a6f3-18b7f76b3d02"],
Cell[663269, 16752, 17040, 325, 455, "Input",ExpressionUUID->"743a1f7a-4c1b-4af8-acbd-1e8f2afb4bbf"],
Cell[680312, 17079, 2818, 72, 142, "Input",ExpressionUUID->"5dd9f4b8-8b8b-4584-8bcf-669eb229e757"],
Cell[683133, 17153, 1086, 33, 46, "Input",ExpressionUUID->"61d61a45-0fbc-40b7-ab71-ad47f198cfb4"],
Cell[684222, 17188, 9055, 243, 342, "Input",ExpressionUUID->"7a6ee889-fe58-4126-b56c-e9ff5886d7b1"],
Cell[CellGroupData[{
Cell[693302, 17435, 3007, 92, 213, "Input",ExpressionUUID->"cb44db1f-ea03-4806-b68b-110ba2e9811d"],
Cell[696312, 17529, 204, 4, 28, "Output",ExpressionUUID->"30be21d7-55f7-4b40-adc1-c2d6d94bbf7a"]
}, Open  ]],
Cell[696531, 17536, 193, 3, 30, "Text",ExpressionUUID->"4c890b2a-d10f-43bc-bba2-6017827a3879"],
Cell[696727, 17541, 714, 18, 28, "Input",ExpressionUUID->"4ef561b1-981a-457f-96ac-fa1285401d08"],
Cell[CellGroupData[{
Cell[697466, 17563, 3381, 104, 222, "Input",ExpressionUUID->"0a72585c-1938-4389-b860-1258b3e87813"],
Cell[700850, 17669, 152, 3, 28, "Output",ExpressionUUID->"6c0ec3f5-69f7-4260-bd86-3ec8a73b0c29"]
}, Open  ]],
Cell[701017, 17675, 1484, 47, 83, "Input",ExpressionUUID->"33738539-baa2-491e-b7ab-7557808894bd"],
Cell[702504, 17724, 7987, 254, 298, "Text",ExpressionUUID->"dbcd6b24-2d86-4b97-8530-8c5cc3b4a504"],
Cell[CellGroupData[{
Cell[710516, 17982, 5109, 135, 266, "Input",ExpressionUUID->"ba446efb-4214-4269-876e-ca993ab6204a"],
Cell[715628, 18119, 431, 7, 62, "Output",ExpressionUUID->"5b2cc78b-ad18-4e8c-b976-c61ec4d282dd"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[716108, 18132, 749, 17, 53, "Subsection",ExpressionUUID->"1d21fb1d-a18b-489a-a212-47a947cf9057"],
Cell[716860, 18151, 17246, 330, 455, "Input",ExpressionUUID->"57b57a84-e9a7-4bbf-b7a4-6c5cd55d1cfe"],
Cell[734109, 18483, 4964, 132, 184, "Input",ExpressionUUID->"2da87414-ed9d-4fa5-8c95-f569029ab24e"],
Cell[CellGroupData[{
Cell[739098, 18619, 2947, 87, 97, "Input",ExpressionUUID->"5980a444-72a7-4038-b23d-2cb9b815d3d4"],
Cell[742048, 18708, 3952, 126, 189, "Output",ExpressionUUID->"42845d54-7c27-4b38-ad9e-4620aef3ca4b"]
}, Open  ]],
Cell[746015, 18837, 220, 5, 28, "Input",ExpressionUUID->"d6c5f51e-5ac1-472a-b3e8-1284b5ce81a1"],
Cell[746238, 18844, 2053, 53, 73, "Input",ExpressionUUID->"10946175-4d9d-4994-8b0c-325a56dc4b05"],
Cell[CellGroupData[{
Cell[748316, 18901, 5195, 139, 233, "Input",ExpressionUUID->"5a23aaa2-dc73-4309-b2d8-3c5572da23f8"],
Cell[753514, 19042, 897, 14, 28, "Output",ExpressionUUID->"f3e3595e-c094-42a1-be41-528dfef15655"]
}, Open  ]],
Cell[CellGroupData[{
Cell[754448, 19061, 2955, 75, 96, "Input",ExpressionUUID->"95871bee-056a-411b-8ef9-a92ce1a1a93c"],
Cell[757406, 19138, 1357, 32, 49, "Output",ExpressionUUID->"07c2a2b9-364c-40fc-8f8c-7c29812e094f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[758800, 19175, 1396, 38, 82, "Input",ExpressionUUID->"e06073a4-dcc9-4750-a5f0-068d3d2175d4"],
Cell[760199, 19215, 6563, 120, 245, "Output",ExpressionUUID->"8e247b8d-482f-46f6-9df3-c811af33a376"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[766823, 19342, 152, 3, 53, "Section",ExpressionUUID->"a8fb0f47-3132-41b9-acbe-cd234ee68d98"],
Cell[CellGroupData[{
Cell[767000, 19349, 293, 7, 44, "Subsection",ExpressionUUID->"b711897a-3c0a-4ad9-b52f-00f78c0a1b11"],
Cell[767296, 19358, 2017, 56, 29258, "Text",ExpressionUUID->"223101d5-92b0-4522-a487-95a4fbe04d30"],
Cell[769316, 19416, 10580, 223, 149807, "Input",ExpressionUUID->"5a74b9bb-e01b-4b92-9cb3-5e4c073d7fc1"],
Cell[CellGroupData[{
Cell[779921, 19643, 159, 3, 5691, "Subsubsection",ExpressionUUID->"db8e0fc4-7909-47d7-9d5c-4e43c3357922"],
Cell[780083, 19648, 782, 15, 15657, "Text",ExpressionUUID->"84efd451-0ab3-4ef7-b393-17ee71d062cd"],
Cell[780868, 19665, 749, 12, 26421, "Input",ExpressionUUID->"21162f55-791d-45c2-88ae-3442a997873e"],
Cell[CellGroupData[{
Cell[781642, 19681, 144, 2, 8837, "Input",ExpressionUUID->"fccd519d-c579-477b-a299-c4a944238776"],
Cell[781789, 19685, 328, 9, 6981, "Output",ExpressionUUID->"62afec5a-a26f-428e-b0d8-e3acc7d06f20"],
Cell[782120, 19696, 329, 10, 6981, "Output",ExpressionUUID->"900a5f1a-6ed1-4306-ba31-b9d627d6c252"],
Cell[782452, 19708, 626, 20, 7270, "Output",ExpressionUUID->"cb635498-0948-415d-a8eb-0cf5741019a4"],
Cell[783081, 19730, 599, 20, 7270, "Output",ExpressionUUID->"a267edb0-2eb4-4ebe-b52c-b728e626752c"],
Cell[783683, 19752, 948, 32, 7270, "Output",ExpressionUUID->"6ebb5bad-3eee-44fb-ac73-8656a2a9df79"],
Cell[784634, 19786, 950, 32, 7270, "Output",ExpressionUUID->"dc7aa1e7-080b-4a94-8f6a-28e17c44abf6"],
Cell[785587, 19820, 1317, 45, 13276, "Output",ExpressionUUID->"db856d84-1e91-4e1c-bcd9-e7b56c76bfde"]
}, Open  ]],
Cell[CellGroupData[{
Cell[786941, 19870, 882, 26, 12078, "Input",ExpressionUUID->"b1370d1e-5bf1-47ce-9b36-d6e60d652522"],
Cell[787826, 19898, 1343, 45, 13276, "Output",ExpressionUUID->"cf0c6127-3bc3-44d8-ae1c-b2e0b3090ef3"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[789230, 19950, 298, 7, 36, "Subsection",ExpressionUUID->"30d0aee6-dd47-4a40-87f4-5b5168a66dbe"],
Cell[789531, 19959, 4009, 120, 361, "Input",ExpressionUUID->"57830922-b959-475b-9dee-9b64030981e0"],
Cell[CellGroupData[{
Cell[793565, 20083, 1842, 42, 144, "Input",ExpressionUUID->"778c0d2f-a746-44d1-9e44-3ff50a565c7b"],
Cell[795410, 20127, 1131, 17, 32, "Output",ExpressionUUID->"fd8f236f-5387-412e-87f0-cf0471af95df"]
}, Open  ]],
Cell[CellGroupData[{
Cell[796578, 20149, 1952, 46, 144, "Input",ExpressionUUID->"80cad7de-844b-467f-9b94-a5c4661b3f59"],
Cell[798533, 20197, 739, 12, 32, "Output",ExpressionUUID->"e4511b9d-c774-4ef1-abeb-9d6b369ffc07"]
}, Open  ]],
Cell[CellGroupData[{
Cell[799309, 20214, 2027, 46, 161, "Input",ExpressionUUID->"5264d402-c4c5-4f66-af58-4e28964bc238"],
Cell[801339, 20262, 832, 14, 45, "Output",ExpressionUUID->"2d011f2f-0f08-4a69-bf04-6e248acc4157"]
}, Open  ]],
Cell[CellGroupData[{
Cell[802208, 20281, 2357, 59, 162, "Input",ExpressionUUID->"e9ac2013-1ea9-4dae-b3c9-14d7994a965e"],
Cell[804568, 20342, 867, 15, 32, "Output",ExpressionUUID->"c2893aff-b756-4a3f-8b07-aedd7e165a9b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[805472, 20362, 1472, 41, 161, "Input",ExpressionUUID->"ac2f8827-3892-4aeb-9b01-5819df96a1ca"],
Cell[806947, 20405, 386, 8, 32, "Output",ExpressionUUID->"c7ee8941-5c66-44ee-8d74-d5b995bc74cf"]
}, Open  ]],
Cell[CellGroupData[{
Cell[807370, 20418, 2432, 67, 211, "Input",ExpressionUUID->"45442f4e-c3db-41bf-b6ba-16accdd3e48d"],
Cell[809805, 20487, 362, 8, 32, "Output",ExpressionUUID->"ff3cd443-413b-4414-83cd-3ddaff19a0e9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[810204, 20500, 1808, 53, 162, "Input",ExpressionUUID->"9c7dd6fd-43c6-499c-af74-89e3a1c344dc"],
Cell[812015, 20555, 529, 15, 32, "Output",ExpressionUUID->"7da79f7d-d12a-4fb6-8c21-70ee2ad9e779"]
}, Open  ]],
Cell[CellGroupData[{
Cell[812581, 20575, 1612, 43, 186, "Input",ExpressionUUID->"1364492a-0d17-48c0-830b-e081fe71d4c6"],
Cell[814196, 20620, 330, 5, 32, "Output",ExpressionUUID->"ddb2090b-ac83-4291-9c0d-e93ba9aef22d"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[814587, 20632, 175, 3, 53, "Section",ExpressionUUID->"50968e94-c4a5-45f5-a7b2-7ad6981ccca9"],
Cell[CellGroupData[{
Cell[814787, 20639, 165, 3, 54, "Subsection",ExpressionUUID->"796a38a0-f723-4d17-af66-1944047aaa0c"],
Cell[CellGroupData[{
Cell[814977, 20646, 218, 4, 45, "Subsubsection",ExpressionUUID->"d8b987d0-773a-44d5-83ba-b423e84199e3"],
Cell[815198, 20652, 11282, 306, 743, "Input",ExpressionUUID->"c9aaf46c-68d4-4a96-bc27-79b947efd141"],
Cell[826483, 20960, 4415, 121, 204, "Input",ExpressionUUID->"f409a62c-02ad-441c-974e-240d4166704e"],
Cell[CellGroupData[{
Cell[830923, 21085, 2859, 73, 96, "Input",ExpressionUUID->"4e266b86-30fb-41cb-a564-283d5cb4ed48"],
Cell[833785, 21160, 838, 13, 28, "Output",ExpressionUUID->"703ee06f-5572-41f9-85ef-e4fd4de046e3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[834660, 21178, 2460, 63, 120, "Input",ExpressionUUID->"7445e2e1-8a71-49de-bd41-aa24d10be86e"],
Cell[837123, 21243, 709, 11, 28, "Output",ExpressionUUID->"7bb654d0-b6a3-436e-badc-df48f22a2532"]
}, Open  ]],
Cell[CellGroupData[{
Cell[837869, 21259, 3080, 81, 120, "Input",ExpressionUUID->"af8f4a0c-3144-41b0-914d-ff0fe1a09a99"],
Cell[840952, 21342, 892, 13, 28, "Output",ExpressionUUID->"9238d82b-e741-4fd4-a1ee-df73ad361fd8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[841881, 21360, 902, 23, 63, "Input",ExpressionUUID->"30975267-f96e-4a22-a36f-5d21855cea4c"],
Cell[842786, 21385, 860, 25, 49, "Output",ExpressionUUID->"c5b1c147-10d6-4a57-9e5e-a8b2ea94b509"]
}, Open  ]],
Cell[CellGroupData[{
Cell[843683, 21415, 227, 6, 28, "Input",ExpressionUUID->"15892257-e6fe-4208-b93a-7291cb115a24"],
Cell[843913, 21423, 1159, 30, 86, "Output",ExpressionUUID->"e9234788-0bf1-4a1c-ab2d-c6c475a42a4d"]
}, Open  ]],
Cell[845087, 21456, 542, 12, 28, "Input",ExpressionUUID->"3a69eb5a-5c04-4d8d-9226-252e8041b2d9"],
Cell[CellGroupData[{
Cell[845654, 21472, 828, 20, 28, "Input",ExpressionUUID->"fcd8cb15-95eb-468b-be7c-5a3b84232862"],
Cell[846485, 21494, 28663, 493, 244, "Output",ExpressionUUID->"ac6cbadd-fdfc-4b15-95e1-2bd29d1ca623"]
}, Open  ]],
Cell[CellGroupData[{
Cell[875185, 21992, 593, 17, 28, "Input",ExpressionUUID->"3283eddd-3bc1-493f-8e20-03ebea18e499"],
Cell[875781, 22011, 20747, 358, 250, "Output",ExpressionUUID->"3fdac90b-006b-4c03-b5d0-a7091d81e589"]
}, Open  ]],
Cell[CellGroupData[{
Cell[896565, 22374, 608, 17, 28, "Input",ExpressionUUID->"78813c55-ee50-44c3-9a63-28d8f77090c8"],
Cell[897176, 22393, 8786, 162, 278, "Output",ExpressionUUID->"e3691751-2001-4d18-ad33-0f11d377a446"]
}, Open  ]],
Cell[CellGroupData[{
Cell[905999, 22560, 299, 8, 28, "Input",ExpressionUUID->"d63b674c-a028-40ba-812f-38ac4be0a012"],
Cell[906301, 22570, 191, 4, 28, "Output",ExpressionUUID->"db7fc355-30ff-4feb-876c-4aca4afa1d51"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]]
}
]
*)

